@@ -19,7 +19,7 @@ namespace Rivet {
     /// Book histograms and initialise projections before the run
     void init() {
       // projection
-      declare(UnstableParticles(), "UFS");
+      declare(UnstableParticles(Cuts::pid == 443), "UFS");
       // histos
       book(_h_pT,1,1,1);
       book(_h_y ,4,1,1);
@@ -31,12 +31,13 @@ namespace Rivet {
       // Final state of unstable particles to get particle spectra
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       // loop over onium states
-      for( const Particle & p : ufs.particles(Cuts::pid==443)) {
-	// cuts on pT and rapidity
-	double y = p.absrap();
-	if(y>2.5 && y<4.)
-	  _h_pT->fill(p.perp());
-	_h_y->fill(p.rapidity());
+      for (const Particle& p : ufs.particles()) {
+        // cuts on pT and rapidity
+        double y = p.absrap();
+        if (y>2.5 && y<4.) {
+          _h_pT->fill(p.perp());
+        }
+        _h_y->fill(p.rap());
       }
     }
 
