@@ -21,15 +21,14 @@ namespace Rivet {
       // Book histos
       for (double eVal : allowedEnergies()) {
 
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
 
         bool is900GeV(en == "900"s);
         book(_h[en+"pi0"], 1 + is900GeV,1,1);
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
+
       book(_h["eta"], 3,1,1);
       // Temporary plots with the binning of _h_etaToPion to construct the eta/pi0 ratio
       book(_h["temp_eta"],  "TMP/h_eta" , refData(3,1,1));
