@@ -21,16 +21,15 @@ namespace Rivet {
       declare(UnstableParticles(Cuts::pid==443 || Cuts::pid==100443), "UFS");
 
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal/MeV));
+        const string en = toString(round(eVal));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
 
         size_t offset = (en == "5020"s)? 6 : 0;
         book(_h[en+"JPsi_pT"], 1+offset,1,1);
         book(_h[en+"JPsi_y"],  2+offset,1,1);
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
+
       book(_h["Psi2S_pT"], 3,1,1);
       book(_h["Psi2S_y"],  4,1,1);
       book(_h["JPsi_pT2"], "TMP/JPsi_pY", refData(5,1,1));
