@@ -475,13 +475,13 @@ namespace Rivet {
       double mix_nomalisation_K0h = (_hist_mix_K0h->bin(0))->integral()/(_hist_mix_K0h->bin(0))->numBins();
       double mix_scaling_K0h[38];
       for (auto& b : _hist_mix_K0h->bins()) {
-        mix_scaling_hh[b.index()-1] = b->integral()/b->numBins()/mix_nomalisation_K0h;
+        mix_scaling_K0h[b.index()-1] = b->integral()/b->numBins()/mix_nomalisation_K0h;
       }
 
       double mix_nomalisation_Lamh = (_hist_mix_Lamh->bin(0))->integral()/(_hist_mix_Lamh->bin(0))->numBins();
       double mix_scaling_Lamh[38];
       for (auto& b : _hist_mix_Lamh->bins()) {
-        mix_scaling_hh[b.index()-1] = b->integral()/b->numBins()/mix_nomalisation_Lamh;
+        mix_scaling_Lamh[b.index()-1] = b->integral()/b->numBins()/mix_nomalisation_Lamh;
       }
 
       size_t i_mix=0;
