@@ -22,7 +22,7 @@ namespace Rivet {
 
       for (double eVal : allowedEnergies()) {
 
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
         bool ih(en == "7000"s);
 
@@ -77,9 +77,7 @@ namespace Rivet {
         book(_p[en+"ptsum_toward_100"],     19+ih, 1, 2);
         book(_p[en+"ptsum_away_100"],       19+ih, 1, 3);
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
 
       // Profiles vs. eta (7 TeV only)
       book(_p["nch_vs_eta_transverse_100"],  21, 1, 1);
@@ -253,7 +251,7 @@ namespace Rivet {
     void finalize() {
       // Convert the various moments of the 500 MeV trans pT and Nch distributions to std devs with correct error
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         moments_to_stddev(en+"nch_transverse_500");
         moments_to_stddev(en+"ptsum_transverse_500");
       }
