@@ -26,7 +26,7 @@ namespace Rivet {
       // Book histograms
       for (double eVal : allowedEnergies()) {
 
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
 
         if (en == "2360") {
@@ -59,9 +59,7 @@ namespace Rivet {
         book(_h[en+"pt2500_nch1_eta"],   28+is7TeV, 1, 1);
         book(_p[en+"pt2500_nch1_ptnch"], 38+is7TeV, 1, 1);
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -93,7 +91,7 @@ namespace Rivet {
 
       for (double eVal : allowedEnergies()) {
 
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
 
         double sf = safediv(1.0, _h[en+"pt500_nch1_nch"]->integral(true), 1.0);
         scale(_h[en+"pt500_nch1_nch"], sf);
