@@ -48,13 +48,13 @@ namespace Rivet {
 
       // Identify the closest-matching l+MET to m == mW
       const Particles& esd = apply<LeptonFinder>(event, "Elecs_dressed").particles();
-      const int iedfound = closestMatchIndex(esd, pmiss, Kin::mass, 80.4*GeV, 0*GeV, 1000*GeV);
+      const int iedfound = closestMatchIndex(esd, pmiss, Kin::mass, 80.4*GeV);
       const Particles& esb = apply<LeptonFinder>(event, "Elecs_bare").particles();
-      const int iebfound = closestMatchIndex(esb, pmiss, Kin::mass, 80.4*GeV, 0*GeV, 1000*GeV);
+      const int iebfound = closestMatchIndex(esb, pmiss, Kin::mass, 80.4*GeV);
       const Particles& musd = apply<LeptonFinder>(event, "Muons_dressed").particles();
-      const int imdfound = closestMatchIndex(musd, pmiss, Kin::mass, 80.4*GeV, 0*GeV, 1000*GeV);
+      const int imdfound = closestMatchIndex(musd, pmiss, Kin::mass, 80.4*GeV);
       const Particles& musb = apply<LeptonFinder>(event, "Muons_bare").particles();
-      const int imbfound = closestMatchIndex(musb, pmiss, Kin::mass, 80.4*GeV, 0*GeV, 1000*GeV);
+      const int imbfound = closestMatchIndex(musb, pmiss, Kin::mass, 80.4*GeV);
 
       MSG_DEBUG("Found " << int(iedfound >= 0) + int(imdfound >= 0) << " dressed W -> e/mu nu");
       MSG_DEBUG("Found " << int(iebfound >= 0) + int(imbfound >= 0) << " bare W -> e/mu nu");
