@@ -33,7 +33,7 @@ namespace Rivet {
 
       for (double eVal : allowedEnergies()) {
 
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
 
         bool is900(en == "900");
@@ -53,9 +53,7 @@ namespace Rivet {
         book(_h[en+"lambda_v_pT"],    "TMP/lambda_v_pT_"+en,    is900? 8 : 18, 0.5, is900? 3.7 : 4.1);
         book(_h[en+"lambdabar_v_pT"], "TMP/lambdabar_v_pT_"+en, is900? 8 : 18, 0.5, is900? 3.7 : 4.1);
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -199,7 +197,7 @@ namespace Rivet {
     void finalize() {
       // Division of histograms to obtain lambda_bar/lambda ratios
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
 
         if (_h[en+"L_pT"]->sumW())  scale(_h[en+"L_y"], 1.0 / _h[en+"L_pT"]->sumW());
         divide(_h[en+"lambdabar_v_y"],  _h[en+"lambda_v_y"],  _e[en+"v_y"]);
