@@ -50,7 +50,7 @@ namespace Rivet {
             // prompt and non-prompt psi(2S)
             book(_h_psi2S[ie][ix]->bin(iy), 5+ie+2*ix,1,iy);
             // extra Jpsi for ratios with psi2s
-            if(ix<2) {
+            if (ix<2) {
               book(_h_JPsi[ie][ix+3]->bin(iy),
                    "TMP/JPsi_"+toString(ix+3)+"_"+toString(iy)+"_"+toString(ie),
                    refData(5+ie+2*ix,1,iy));
@@ -59,9 +59,7 @@ namespace Rivet {
         }
         ++ie;
       }
-      if (_ih == 10 && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_ih == 10);
     }
 
 
