@@ -30,7 +30,7 @@ namespace Rivet {
       declare(recoelectrons, "Electrons");
 
       PromptFinalState muons(Cuts::abspid == PID::MUON);
-      SmearedParticles recomuons(muons, MUON_EFF_ATLAS_RUN2, MUON_SMEAR_ATLAS_RUN2);
+      SmearedParticles recomuons(muons, MUON_EFF_ATLAS_RUN2_MEDIUM, MUON_SMEAR_ATLAS_RUN2);
       declare(recomuons, "Muons");
 
       FastJets jets4(IndirectFinalState(Cuts::open()), JetAlg::ANTIKT, 0.4);
