@@ -1,7 +1,7 @@
 // -*- C++ -*-
 #include "Rivet/Analysis.hh"
 #include "Rivet/Projections/ChargedFinalState.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/FastJets.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
 #include "Rivet/Projections/InvisibleFinalState.hh"
@@ -9,7 +9,8 @@
 
 namespace Rivet {
 
-  /// @brief: ttbar + gamma at 13 TeV
+
+  /// @brief ttbar + gamma at 13 TeV
   class ATLAS_2018_I1707015 : public Analysis {
   public:
 
@@ -21,7 +22,6 @@ namespace Rivet {
     // Book histograms and initialise projections before the run
     void init() {
 
-
       // Set default running mode to 3 (all)
       _mode = 3;
 
@@ -38,31 +38,31 @@ namespace Rivet {
       declare(cfs, "CFS");
 
       // Signal photons
-      PromptFinalState photons(Cuts::abspid == PID::PHOTON && Cuts::pT > 20*GeV && Cuts::abseta < 2.37, true);
+      PromptFinalState photons(Cuts::abspid == PID::PHOTON && Cuts::pT > 20*GeV && Cuts::abseta < 2.37, TauDecaysAs::PROMPT);
       declare(photons, "Photons");
 
       // Leptons
-      PromptFinalState leptons(Cuts::abspid == PID::MUON || Cuts::abspid == PID::ELECTRON, true);
+      PromptFinalState leptons(Cuts::abspid == PID::MUON || Cuts::abspid == PID::ELECTRON, TauDecaysAs::PROMPT);
 
       // Dress the leptons
       FinalState dressPhotons(Cuts::abspid == PID::PHOTON);
       Cut lepCuts = (Cuts::abseta < 2.5) && (Cuts::pT > 25*GeV);
-      DressedLeptons dressedLeptons(dressPhotons, leptons, 0.1, lepCuts);
+      LeptonFinder dressedLeptons(leptons, dressPhotons, 0.1, lepCuts);
       declare(dressedLeptons, "Leptons");
 
       // Jet alg input
       VetoedFinalState vfs(fs);
 
       // Remove prompt invisibles from jet input
-      vfs.addVetoOnThisFinalState(InvisibleFinalState(true, true));
+      vfs.addVetoOnThisFinalState(InvisibleFinalState(OnlyPrompt::YES, TauDecaysAs::PROMPT));
 
       // Remove prompt dressed muons (muons + associated photons) from jet input
-      PromptFinalState muons(Cuts::abspid == PID::MUON, true);
-      DressedLeptons dressedmuons(dressPhotons, muons, 0.1);
+      PromptFinalState muons(Cuts::abspid == PID::MUON, TauDecaysAs::PROMPT);
+      LeptonFinder dressedmuons(muons, dressPhotons, 0.1);
       vfs.addVetoOnThisFinalState(dressedmuons);
 
       // Jet clustering
-      FastJets jets(vfs, FastJets::ANTIKT, 0.4, JetAlg::Muons::ALL, JetAlg::Invisibles::ALL);
+      FastJets jets(vfs, JetAlg::ANTIKT, 0.4, JetMuons::ALL, JetInvisibles::ALL);
       declare(jets, "Jets");
 
       // Book histograms
@@ -84,13 +84,13 @@ namespace Rivet {
     void analyze(const Event& event) {
 
       // Fetch objects
-      const vector<DressedLepton>& leptons = apply<DressedLeptons>(event, "Leptons").dressedLeptons();
-      const Particles& photons = applyProjection<PromptFinalState>(event, "Photons").particles();
+      const DressedLeptons& leptons = apply<LeptonFinder>(event, "Leptons").dressedLeptons();
+      const Particles& photons = apply<PromptFinalState>(event, "Photons").particles();
       ChargedFinalState charged = apply<ChargedFinalState>(event, "CFS");
-      Jets jets = apply<JetAlg>(event, "Jets").jetsByPt(Cuts::abseta < 2.5 && Cuts::pT > 25*GeV);
+      Jets jets = apply<JetFinder>(event, "Jets").jetsByPt(Cuts::abseta < 2.5 && Cuts::pT > 25*GeV);
 
       // Immediate veto on events without one good photon
-      if ( photons.size() != 1 ) vetoEvent;
+      if (photons.size() != 1) vetoEvent;
       const Particle& photon = photons[0];
 
       // Veto event if photon too close to a lepton
@@ -104,7 +104,7 @@ namespace Rivet {
       // Overlap removel of jets near isolated photon
       const double conePt = sum(charged.particles(deltaRLess(photon, 0.3)), Kin::pT, 0.0);
       if ( conePt / photon.pT() < 0.1 ) {
-        ifilter_discard(jets, deltaRLess(photon, 0.4) );
+        idiscard(jets, deltaRLess(photon, 0.4));
       }
 
       // Veto event if photon too close to good jets
@@ -159,6 +159,5 @@ namespace Rivet {
 
   };
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(ATLAS_2018_I1707015);
 }
