@@ -4,7 +4,7 @@
 #include "Rivet/Projections/FastJets.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
 #include "Rivet/Projections/ChargedLeptons.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/MissingMomentum.hh"
 
 #include "fastjet/tools/Filter.hh"
@@ -13,7 +13,6 @@
 #include "fastjet/contrib/Njettiness.hh"
 #include "fastjet/contrib/EnergyCorrelator.hh"
 
-
 namespace Rivet {
 
 
@@ -23,10 +22,8 @@ namespace Rivet {
 
     RIVET_DEFAULT_ANALYSIS_CTOR(ATLAS_2019_I1724098);
 
-  private:
-
     /// @name Analysis methods
-    //@{
+    /// @{
 
     void init() {
 
@@ -41,19 +38,19 @@ namespace Rivet {
       const FinalState photons(Cuts::abspid == PID::PHOTON);
 
       // Use all bare muons as input to the DressedMuons projection
-      PromptFinalState bare_mu(Cuts::abspid == PID::MUON, true);
-      PromptFinalState bare_el(Cuts::abspid == PID::ELECTRON, true);
+      PromptFinalState bare_mu(Cuts::abspid == PID::MUON, TauDecaysAs::PROMPT);
+      PromptFinalState bare_el(Cuts::abspid == PID::ELECTRON, TauDecaysAs::PROMPT);
 
       // Muons must have |eta| < 2.5
       Cut eta_ranges = Cuts::abseta < 2.5;
-      DressedLeptons dressed_mu(photons, bare_mu, 0.1, eta_ranges && Cuts::pT > 30*GeV, true);
+      LeptonFinder dressed_mu(bare_mu, photons, 0.1, eta_ranges && Cuts::pT > 30*GeV);
       declare(dressed_mu, "muons");
-      DressedLeptons dressed_el(photons, bare_el, 0.1, eta_ranges && Cuts::pT > 25*GeV, true);
+      LeptonFinder dressed_el(bare_el, photons, 0.1, eta_ranges && Cuts::pT > 25*GeV);
       declare(dressed_el, "electrons");
 
-      FastJets fj(fs, FastJets::ANTIKT, 1.0, JetAlg::Muons::NONE, JetAlg::Invisibles::NONE);
+      FastJets fj(fs, JetAlg::ANTIKT, 1.0, JetMuons::NONE, JetInvisibles::NONE);
       declare(fj, "FJets");
-      FastJets sj(fs, FastJets::ANTIKT, 0.4, JetAlg::Muons::NONE, JetAlg::Invisibles::NONE);
+      FastJets sj(fs, JetAlg::ANTIKT, 0.4, JetMuons::NONE, JetInvisibles::NONE);
       declare(sj, "Jets");
 
       ChargedLeptons lfs(FinalState(Cuts::abseta < 2.5 && Cuts::pT > 25*GeV));
@@ -62,7 +59,8 @@ namespace Rivet {
       MissingMomentum missmom(fs);
       declare(missmom, "MissingMomentum");
 
-      _trimmer = fastjet::Filter(fastjet::JetDefinition(fastjet::kt_algorithm, 0.2), fastjet::SelectorPtFractionMin(0.05));
+      _trimmer = fastjet::Filter(fastjet::JetDefinition(fastjet::kt_algorithm, 0.2),
+				 fastjet::SelectorPtFractionMin(0.05));
 
       // Dijet
       if (_mode == 0 || _mode == 1) {
@@ -145,7 +143,7 @@ namespace Rivet {
       if (leptons.size())  return;
 
       // Normal fatjets
-      const Jets &fjets = apply<JetAlg>(event, "FJets").jetsByPt();
+      const Jets &fjets = apply<JetFinder>(event, "FJets").jetsByPt();
 
       // Trim the fatjets
       PseudoJets tr_ljets;
@@ -157,7 +155,7 @@ namespace Rivet {
       size_t nBaseline = count(tr_ljets, [](const Jet &j) { return j.pT() > 200*GeV && j.abseta() < 2.5; });
       if (nBaseline < 2)  return;
 
-      ifilter_select(tr_ljets, [](const PseudoJet &j) { return j.perp() > 450*GeV; });
+      iselect(tr_ljets, [](const PseudoJet &j) { return j.perp() > 450*GeV; });
       if (tr_ljets.size() > 1)  tr_ljets = sorted_by_pt(tr_ljets);
       else if (tr_ljets.empty())  return;
 
@@ -252,10 +250,10 @@ namespace Rivet {
 
       const double beta = 1, Rcut = 1;
 
-      const vector<DressedLepton>& muons = apply<DressedLeptons>(event, "muons").dressedLeptons();
+      const DressedLeptons& muons = apply<LeptonFinder>(event, "muons").dressedLeptons();
       if (muons.size() != 1)  return;
 
-      const vector<DressedLepton>& electrons = apply<DressedLeptons>(event, "electrons").dressedLeptons();
+      const DressedLeptons& electrons = apply<LeptonFinder>(event, "electrons").dressedLeptons();
       if (electrons.size() != 0)  return;
 
       const FourMomentum muonmom = muons[0].momentum();
@@ -281,7 +279,7 @@ namespace Rivet {
       const Jet& lepjet = jets[lepJetIndex];
 
 
-      const Jets fjets = apply<JetAlg>(event, "FJets").jetsByPt();
+      const Jets fjets = apply<JetFinder>(event, "FJets").jetsByPt();
       PseudoJets tr_ljets_all;
       for (const Jet& j : fjets) {
         tr_ljets_all += _trimmer(j);
@@ -566,6 +564,5 @@ namespace Rivet {
     size_t _mode;
   };
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(ATLAS_2019_I1724098);
 }
