@@ -52,13 +52,6 @@ namespace Rivet {
 
       InvisibleFinalState neutrinos(OnlyPrompt::YES, TauDecaysAs::PROMPT);
 
-      VetoedFinalState vfs(fs);
-      vfs.addVetoOnThisFinalState(dressedelectrons);
-      vfs.addVetoOnThisFinalState(dressedmuons);
-      vfs.addVetoOnThisFinalState(neutrinos);
-      FastJets jets(vfs, JetAlg::ANTIKT, 0.4, JetMuons::ALL, JetInvisibles::ALL);
-      declare(jets, "boosted_jets");
-
       VetoedFinalState vfs_res(fs);
       vfs_res.addVetoOnThisFinalState(ewdressedelectrons);
       vfs_res.addVetoOnThisFinalState(ewdressedmuons);
@@ -364,7 +357,7 @@ namespace Rivet {
       //Projections
       DressedLeptons electrons = apply<LeptonFinder>(event, "dressedelectrons").dressedLeptons();
       DressedLeptons muons = apply<LeptonFinder>(event, "dressedmuons").dressedLeptons();
-      const Jets& jets = apply<FastJets>(event, "boosted_jets").jetsByPt(Cuts::pT > 25*GeV && Cuts::abseta <= 2.5);
+      const Jets& jets = apply<FastJets>(event, "resolved_jets").jetsByPt(Cuts::pT > 25*GeV && Cuts::abseta <= 2.5);
       const FourMomentum& met = apply<MissingMomentum>(event, "MissingMomentum").missingMomentum();
 
       if (jets.size() < 2)  vetoEvent;
