@@ -2,7 +2,7 @@
 #include "Rivet/Analysis.hh"
 #include "Rivet/Projections/FinalState.hh"
 #include "Rivet/Projections/FastJets.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
 #include "Rivet/Projections/InvisibleFinalState.hh"
 #include "Rivet/Projections/VetoedFinalState.hh"
@@ -34,8 +34,8 @@ namespace Rivet {
       const FinalState allphoton_fs(Cuts::abspid == PID::PHOTON);
       const Cut leptoncut = Cuts::pT > 20 * GeV && Cuts::abseta < 2.47;
       // use *all* photons for dressing
-      const DressedLeptons dressedelectron_fs(allphoton_fs, bareelectron_fs, 0.1, leptoncut, true);
-      const DressedLeptons dressedmuon_fs(allphoton_fs, baremuon_fs, 0.1, leptoncut, true);
+      const LeptonFinder dressedelectron_fs(bareelectron_fs, allphoton_fs, 0.1, leptoncut);
+      const LeptonFinder dressedmuon_fs(baremuon_fs, allphoton_fs, 0.1, leptoncut);
 
       declare(dressedelectron_fs, "Electrons");
       declare(dressedmuon_fs, "Muons");
@@ -52,7 +52,7 @@ namespace Rivet {
       hadrons.addVetoOnThisFinalState(dressedmuon_fs);
 
       // Jets
-      FastJets jets(hadrons, FastJets::ANTIKT, 0.4, JetAlg::Muons::ALL, JetAlg::Invisibles::DECAY);
+      FastJets jets(hadrons, JetAlg::ANTIKT, 0.4, JetMuons::ALL, JetInvisibles::DECAY);
       declare(jets, "jets");
 
       // Histograms
@@ -70,8 +70,8 @@ namespace Rivet {
     void analyze(const Event &event) {
 
       // Sort the dressed leptons by pt
-      Particles electrons = apply<DressedLeptons>(event, "Electrons").particlesByPt();
-      Particles muons = apply<DressedLeptons>(event, "Muons").particlesByPt();
+      Particles electrons = apply<LeptonFinder>(event, "Electrons").particlesByPt();
+      Particles muons = apply<LeptonFinder>(event, "Muons").particlesByPt();
 
       if (electrons.size() < 2 && muons.size() < 2) vetoEvent;
 
