@@ -24,16 +24,16 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       book(_num3pi, 1, 1, 1);
+
       for (const string& en : _num3pi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
+        const double eval = std::stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en;
           break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
 
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -44,12 +44,13 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       if(ntotal!=3) vetoEvent;
-      if(nCount[-211]==1&&nCount[211]==1&&nCount[111]==1)
-	_num3pi->fill(_ecms);
+      if(nCount[-211]==1&&nCount[211]==1&&nCount[111]==1) {
+        _num3pi->fill(_sqs);
+      }
 
     }
 
@@ -65,7 +66,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _num3pi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
