@@ -21,20 +21,21 @@ namespace Rivet {
 
       // Initialise and register projections
       declare(FinalState(), "FS");
-      for(unsigned int ix=0;ix<3;++ix) {
-        book(_sigma[ix],1+ix,1,1);
+
+      _sqs = {"", "", ""};
+      for (size_t ix=0; ix<_sqs.size(); ++ix) {
+        book(_sigma[ix], 1+ix, 1,1);
         for (const string& en : _sigma[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
+          const double eval = std::stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en;
             break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty() && _ecms[2].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty() && _sqs[2].empty());
     }
-    
+
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
@@ -43,36 +44,36 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
 
-      if(ntotal!=6) vetoEvent;
-      if(nCount[-211]==3 && nCount[211]==3) {
-	if(!_ecms[0].empty()) _sigma[0]->fill(_ecms[0]);
+      if (ntotal!=6) vetoEvent;
+      if (nCount[-211]==3 && nCount[211]==3) {
+        if (!_sqs[0].empty()) _sigma[0]->fill(_sqs[0]);
       }
       else if(nCount[-211]==2 && nCount[211]==2 && nCount[111]==2) {
-	if(!_ecms[1].empty()) _sigma[1]->fill(_ecms[1]);
+        if (!_sqs[1].empty()) _sigma[1]->fill(_sqs[1]);
       }
-      else if(nCount[-211]==2 && nCount[211]==2 &&
-              nCount[321]==1 && nCount[-321]==1) {
-	if(!_ecms[2].empty()) _sigma[2]->fill(_ecms[2]);
+      else if (nCount[-211]==2 &&
+               nCount[211]==2  &&
+               nCount[321]==1  &&
+               nCount[-321]==1) {
+        if(!_sqs[2].empty()) _sigma[2]->fill(_sqs[2]);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      for(unsigned int ix=0; ix<3; ++ix)
-        scale(_sigma[ix],fact);
+      scale(_sigma, crossSection()/ sumOfWeights() /nanobarn);
     }
 
     /// @}
 
     // just count the number of events of the types we're looking for
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms[3];
+    vector<string> _sqs;
   };
 
 
