@@ -28,13 +28,13 @@ namespace Rivet {
       book(_c_hadrons, "/TMP/sigma_hadrons", refData<YODA::BinnedEstimate<string>>(1,1,1));
       book(_c_muons,   "/TMP/sigma_muons"  , refData<YODA::BinnedEstimate<string>>(1,1,1));
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
+        double eval = std::stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en;
           break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -44,25 +44,26 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       bool isBottom(false);
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
         if (PID::isBottomHadron(p.pid())) {
-	  isBottom = true;
-	  break;
-	}
+          isBottom = true;
+          break;
+        }
       }
 
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	_c_muons->fill(_ecms);
-      // everything else
-      else if(isBottom) {
-	_c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 and
+         nCount[13]==1 and
+         ntotal==2+nCount[22]) {
+        _c_muons->fill(_sqs);
+      }
+      else if (isBottom) { // everything else
+        _c_hadrons->fill(_sqs);
       }
     }
 
@@ -71,7 +72,7 @@ namespace Rivet {
     void finalize() {
       BinnedEstimatePtr<string> mult;
       book(mult, 1, 1, 1);
-      divide(_c_hadrons,_c_muons,mult);
+      divide(_c_hadrons, _c_muons,mult);
     }
 
     /// @}
@@ -80,7 +81,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
