@@ -26,25 +26,24 @@ namespace Rivet {
       // Book histograms
       book(_npion, 1,1,1);
       for (const string& en : _npion.binning().edges<0>()) {
-        const double end = std::stod(en)*MeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
+        const double eval = std::stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en;
           break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=4) vetoEvent;
+      if (fs.particles().size()!=4) vetoEvent;
       for (const Particle& p : fs.particles()) {
-	if(abs(p.pid())!=PID::PIPLUS) vetoEvent;
+        if (abs(p.pid())!=PID::PIPLUS) vetoEvent;
       }
-      _npion->fill(_ecms);
+      _npion->fill(_sqs);
     }
 
 
@@ -59,7 +58,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _npion;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
