@@ -24,18 +24,19 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      for(unsigned int ix=0;ix<4;++ix) {
+      bool pass = false;
+      for (size_t ix=0; ix<_sqs.size(); ++ix) {
         book(_sigma[ix], 9+ix, 1, 1);
         for (const string& en : _sigma[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
+          const double eval = std::stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en;
+            pass = true;
             break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty() && _ecms[2].empty() && _ecms[3].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(!pass);
     }
 
 
@@ -46,30 +47,28 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
 
-      if(ntotal==2 && nCount[130]==1 && nCount[310]==1) {
-	if(!_ecms[0].empty()) _sigma[0]->fill(_ecms[0]);
+      if (ntotal==2 && nCount[130]==1 && nCount[310]==1) {
+        if (!_sqs[0].empty()) _sigma[0]->fill(_sqs[0]);
       }
-      else if( ntotal==4 &&  nCount[130]==1 && nCount[310]==1 && nCount[211]==1 && nCount[-211]==1) {
-	if(!_ecms[1].empty()) _sigma[1]->fill(_ecms[1]);
+      else if(ntotal==4 &&  nCount[130]==1 && nCount[310]==1 && nCount[211]==1 && nCount[-211]==1) {
+        if(!_sqs[1].empty()) _sigma[1]->fill(_sqs[1]);
       }
-      else if( ntotal==4 && nCount[310]==2 && nCount[211]==1 && nCount[-211]==1 ) {
-	if(!_ecms[2].empty()) _sigma[2]->fill(_ecms[2]);
+      else if (ntotal==4 && nCount[310]==2 && nCount[211]==1 && nCount[-211]==1 ) {
+        if(!_sqs[2].empty()) _sigma[2]->fill(_sqs[2]);
       }
-      else if( ntotal==4 && nCount[310]==2 && nCount[321]==1 && nCount[-321]==1) {
-	if(!_ecms[3].empty()) _sigma[3]->fill(_ecms[3]);
+      else if (ntotal==4 && nCount[310]==2 && nCount[321]==1 && nCount[-321]==1) {
+        if(!_sqs[3].empty()) _sigma[3]->fill(_sqs[3]);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      for(unsigned int ix=0;ix<4;++ix)
-        scale(_sigma[ix],fact);
+      scale(_sigma, crossSection()/ sumOfWeights() /nanobarn);
     }
 
     /// @}
@@ -78,7 +77,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[4];
-    string _ecms[4];
+    vector<string> _sqs{""s, ""s, ""s, ""s};
     /// @}
 
 
