@@ -27,27 +27,28 @@ namespace Rivet {
       declare(UnstableParticles(),"UFS");
 
       // histos
-      if (isCompatibleWithSqrtS(10.52*GeV)) _mode=1;
-      else if (isCompatibleWithSqrtS(10.58*GeV,1e-4)) _mode=2;
-      else MSG_ERROR("Beam energy not supported!");
+      for (double eVal : allowedEnergies()) {
 
-      for (unsigned int ix=0;ix<7;++ix) {
-        if (_mode==1)
-          book(_r[ix],2,1,ix+1);
-        else
-          book(_r[ix],1,1,ix+1);
-        book(_h[ix],2+_mode,1,ix+1);
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal, 1e-3))  _sqs = en;
+        bool ih = en!="10520"s;
+
+        for (size_t ix=0; ix<7; ++ix) {
+          book(_r[en][ix], 2-ih, 1, ix+1);
+          book(_h[en][ix], 3+ih, 1, ix+1);
+        }
+        book(_c[en],"TMP/wgt"+en);
       }
-      book(_c,"TMP/wgt");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       // unstable particles
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
-      if (_mode==2 && ufs.particles(Cuts::pid==300553).size()!=1)
-        vetoEvent;
-      _c->fill();
+      if (_sqs=="10580"s && ufs.particles(Cuts::pid==300553).size()!=1)  vetoEvent;
+
+      _c[_sqs]->fill();
       for (const Particle & p : ufs.particles(Cuts::abspid==411 ||
                                               Cuts::abspid==421 ||
                                               Cuts::abspid==431 ||
@@ -55,36 +56,32 @@ namespace Rivet {
                                               Cuts::abspid==423 ||
                                               Cuts::abspid==4122 )) {
         double pmax = sqrt(0.25*sqr(sqrtS())-sqr(p.mass()));
-        double xp = p.momentum().p3().mod()/pmax;
+        double xp = p.mom().p3().mod()/pmax;
         if (p.abspid()==421) {
-          _r[0]->fill(0.5);
-          _h[0]->fill(xp);
-        }
-        else if (p.abspid()==421) {
-          _r[0]->fill(0.5);
-          _h[0]->fill(xp);
+          _r[_sqs][0]->fill(0.5);
+          _h[_sqs][0]->fill(xp);
         }
         else if (p.abspid()==411) {
-          _r[1]->fill(0.5);
-          _h[1]->fill(xp);
+          _r[_sqs][1]->fill(0.5);
+          _h[_sqs][1]->fill(xp);
         }
         else if (p.abspid()==431) {
-          _r[2]->fill(0.5);
-          _h[2]->fill(xp);
+          _r[_sqs][2]->fill(0.5);
+          _h[_sqs][2]->fill(xp);
         }
         else if (p.abspid()==4122) {
-          _r[3]->fill(0.5);
-          _h[3]->fill(xp);
+          _r[_sqs][3]->fill(0.5);
+          _h[_sqs][3]->fill(xp);
         }
         else if (p.abspid()==413) {
-          _r[4]->fill(0.5);
-          _h[4]->fill(xp);
-          _r[5]->fill(0.5);
-          _h[5]->fill(xp);
+          _r[_sqs][4]->fill(0.5);
+          _h[_sqs][4]->fill(xp);
+          _r[_sqs][5]->fill(0.5);
+          _h[_sqs][5]->fill(xp);
         }
         else if (p.abspid()==423) {
-          _r[6]->fill(0.5);
-          _h[6]->fill(xp);
+          _r[_sqs][6]->fill(0.5);
+          _h[_sqs][6]->fill(xp);
         }
       }
     }
@@ -92,17 +89,15 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      if (_mode==1) {
-        for (unsigned int ix=0;ix<7;++ix) {
-          scale(_r[ix],crossSection()/picobarn/sumOfWeights());
-          scale(_h[ix],crossSection()/nanobarn/sumOfWeights());
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (en == "10520"s) {
+          scale(_r[en], crossSection()/picobarn/sumOfWeights());
         }
-      }
-      else {
-        for (unsigned int ix=0;ix<7;++ix) {
-          scale(_r[ix], 0.5/ *_c);
-          scale(_h[ix],crossSection()/nanobarn/sumOfWeights());
+        else {
+          scale(_r[en], 0.5/ *_c[en]);
         }
+        scale(_h[en], crossSection()/nanobarn/sumOfWeights());
       }
     }
 
@@ -111,10 +106,10 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h[7];
-    Histo1DPtr _r[7];
-    CounterPtr _c;
-    unsigned int _mode=0;
+    map<string,map<int,Histo1DPtr>> _h;
+    map<string,map<int,Histo1DPtr>> _r;
+    map<string,CounterPtr> _c;
+    string _sqs = "";
     /// @}
 
 
