@@ -14,12 +14,12 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    ///@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
       // projections
-      declare(UnstableParticles(Cuts::pid==300553),"UFS");
+      declare(UnstableParticles(),"UFS");
       // histograms
       book(_w_ups4,"/TMP/w_ups4");
       book(_h_X,1,1,1);
@@ -48,7 +48,7 @@ namespace Rivet {
 	  K0.push_back(p);
 	}
 	else if(!p.children().empty()) {
-	  findDecay(p,charm,eta,pi0,pip,Kp,K0); 
+	  findDecay(p,charm,eta,pi0,pip,Kp,K0);
 	}
       }
     }
@@ -56,7 +56,7 @@ namespace Rivet {
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
-      for(const Particle & p : ufs.particles()) {
+      for(const Particle & p : ufs.particles(Cuts::pid==300553)) {
 	_w_ups4->fill();
         const LorentzTransform boost = LorentzTransform::mkFrameTransformFromBeta(p.mom().betaVec());
 	for(const Particle & B:p.children()) {
@@ -92,14 +92,14 @@ namespace Rivet {
       scale(_h_X, 0.5/ *_w_ups4);
     }
 
-    ///@}
+    /// @}
 
 
     /// @name Histograms
-    ///@{
+    /// @{
     CounterPtr _w_ups4;
     Histo1DPtr _h_X;
-    ///@}
+    /// @}
 
 
   };
