@@ -22,24 +22,24 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
+
       // counters
-      for (unsigned int ix=0; ix<5; ++ix) {
-        book(_sigma[ix],1+ix,1,1);
+      for (size_t ix=0; ix<5; ++ix) {
+        book(_sigma[ix], 1+ix, 1, 1);
       }
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
-          nRes[child.pid()]-=1;
+          nRes[child.pid()] -= 1;
           --ncount;
         }
         else {
@@ -97,7 +97,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _sigma[imode]->fill(_ecms);
+          _sigma[imode]->fill(_sqs);
           break;
         }
       }
@@ -115,7 +115,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[5];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
