@@ -25,21 +25,19 @@ namespace Rivet {
       declare(Beam(), "Beams");
       declare(FinalState(), "FS");
       // histograms
-      if(isCompatibleWithSqrtS(10.58,1e-4)) {
-	// histograms
-	for(unsigned int ix=0;ix<6;++ix) {
-	  book(_h[ix],1,1,1+ix);
-	}
+      if (isCompatibleWithSqrtS(10.58,1e-4)) {
+        for (size_t ix=0; ix<6; ++ix) {
+          book(_h[ix], 1, 1, 1+ix);
+        }
       }
       book(_sigma,2,1,1);
       for (const string& en : _sigma.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end,1e-4)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval,1e-4)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -77,8 +75,7 @@ namespace Rivet {
         for (const auto& D : parent.pid()==PID::JPSI ? JPSI : DD) {
           // D or J/psi already in list
           if (fuzzyEquals(D.mom(),parent.mom())) {
-            found=true;
-            break;
+            found=true; break;
           }
         }
         if (!found) {
@@ -90,12 +87,12 @@ namespace Rivet {
       if (DD[0].pid()!=-DD[1].pid()) vetoEvent;
       FourMomentum pDD = DD[0].mom()+DD[1].mom();
       // cross section
-      if(DD[0].parents()[0].pid()==_pid && DD[1].parents()[0].pid()==_pid) {
-	_sigma->fill(_ecms);
+      if (DD[0].parents()[0].pid()==_pid && DD[1].parents()[0].pid()==_pid) {
+        _sigma->fill(_sqs);
       }
       // histograms only at 10.58GeV
-      if(!_h[0]) return;
-      _h[0]->fill(pDD.mass());
+      if (!isCompatibleWithSqrtS(10.58,1e-4)) vetoEvent;
+      _h[0]->fill(pDD.mass()/GeV);
       const double cProd = axis.dot(JPSI[0].mom().p3().unit());
       _h[1]->fill(cProd);
       // finally the leptons from J/psi decay
@@ -135,7 +132,7 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       normalize(_h, 1.0, false);
-      scale(_sigma,crossSection()/ sumOfWeights() /femtobarn);
+      scale(_sigma, crossSection()/ sumOfWeights() /femtobarn);
     }
 
     /// @}
@@ -146,7 +143,7 @@ namespace Rivet {
     int _pid;
     Histo1DPtr _h[6];
     BinnedHistoPtr<string> _sigma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
