@@ -24,16 +24,15 @@ namespace Rivet {
       declare(UnstableParticles(Cuts::pid==20443), "UFS");
       book(_sigmaChi1,1,1,1);
       for (const string& en : _sigmaChi1.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -76,7 +75,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _sigmaChi1->fill(_ecms);
+          _sigmaChi1->fill(_sqs);
           break;
         }
       }
@@ -94,7 +93,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigmaChi1;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
