@@ -23,21 +23,20 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // histos
-      for (unsigned int ix=0; ix<3; ++ix) {
+      for (size_t ix=0; ix<3; ++ix) {
         book(_sigma[ix], 1, 1, 1+ix);
       }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -87,9 +86,9 @@ namespace Rivet {
             }
           }
           if (!matched) continue;
-          if (chi.pid()==10551)     _sigma[0]->fill(_ecms);
-          else if (chi.pid()==20553) _sigma[1]->fill(_ecms);
-          else if (chi.pid()==555)   _sigma[2]->fill(_ecms);
+          if (chi.pid()==10551)     _sigma[0]->fill(_sqs);
+          else if (chi.pid()==20553) _sigma[1]->fill(_sqs);
+          else if (chi.pid()==555)   _sigma[2]->fill(_sqs);
           break;
         }
         if (matched) break;
@@ -108,7 +107,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
