@@ -22,37 +22,34 @@ namespace Rivet {
 
       // Initialise and register projections
       declare(UnstableParticles(), "UFS");
-      _mode=0;
-      if      ( getOption("MODE") == "DECAY" ) _mode=0;
-      else if ( getOption("MODE") == "SIGMA" ) _mode=1;
+      _mode = getOption("MODE") == "SIGMA";
       // Upsilon decays
       if (_mode==0) {
-        for (unsigned int ix=0;ix<2;++ix) {
+        for (size_t ix=0; ix<2; ++ix) {
           book(_c[ix],"TMP/n_Ups_"+toString(ix+4));
-          book(_h_x [0][ix],3,1,ix+3);
-          book(_h_x [1][ix],3,1,ix+1);
-          for (unsigned int iy=0;iy<2;++iy) {
-            book(_h_br[ix][iy],1,1,2*ix+iy+1);
+          book(_h_x [0][ix], 3, 1, ix+3);
+          book(_h_x [1][ix], 3, 1, ix+1);
+          for (size_t iy=0; iy<2; ++iy) {
+            book(_h_br[ix][iy], 1, 1, 2*ix+iy+1);
           }
         }
-        book(_h_fs,1,1,5);
+        book(_h_fs, 1, 1, 5);
       }
       else {
-        for (unsigned int ix=0;ix<4;++ix) {
-          book(_sigma[ix],2,1,1+ix);
+        for (size_t ix=0; ix<4; ++ix) {
+          book(_sigma[ix], 2, 1, 1+ix);
         }
         for (const string& en : _sigma[0].binning().edges<0>()) {
-          double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
-        if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+        raiseBeamErrorIf(_sqs.empty());
       }
     }
 
-    void findDecayProducts(const Particle& p, bool& hasBs, Particles& d0, Particles& ds) {
+    void findDecayProducts(const Particle& p, bool& hasBs, Particles& d0, Particles& ds) const {
       for (const Particle& child : p.children()) {
         hasBs |= child.abspid()==531;
         if (child.abspid()==431) {
@@ -90,7 +87,7 @@ namespace Rivet {
             _h_x [iups][0]->fill(x  );
 
           }
-          for (const Particle & p : d0) {
+          for (const Particle& p : d0) {
             FourMomentum p2 = cms_boost.transform(p.mom());
             double x = p2.p3().mod()/sqrt(0.25*ups.mass2()-p2.mass2());
             _h_br[iups][1]->fill();
@@ -103,15 +100,15 @@ namespace Rivet {
         Particles B  = ufs.particles(Cuts::abspid==511 || Cuts::abspid==521);
         Particles Bs = ufs.particles(Cuts::abspid==531);
         // require B mesons
-        if(B.empty() && Bs.empty()) vetoEvent;
-        if(!B.empty()) _sigma[3]->fill(_ecms);
+        if (B.empty() && Bs.empty()) vetoEvent;
+        if (!B.empty()) _sigma[3]->fill(_sqs);
         Particles Ds = ufs.particles(Cuts::abspid==431);
         for (unsigned int ix=0;ix<Ds.size();++ix) {
-          _sigma[0]->fill(_ecms);
+          _sigma[0]->fill(_sqs);
         }
         Particles D0 = ufs.particles(Cuts::abspid==421);
         for (unsigned int ix=0;ix<D0.size();++ix) {
-          _sigma[1]->fill(_ecms);
+          _sigma[1]->fill(_sqs);
         }
         if (!Bs.empty() && !Ds.empty()) {
           for (const Particle& p : Bs) {
@@ -119,7 +116,7 @@ namespace Rivet {
             Particles ds,d0;
             bool hasBs=false;
             findDecayProducts(p, hasBs, d0, ds);
-            for (unsigned int ix=0;ix<ds.size();++ix) _sigma[2]->fill(_ecms);
+            for (unsigned int ix=0;ix<ds.size();++ix) _sigma[2]->fill(_sqs);
           }
         }
       }
@@ -128,13 +125,13 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       if (_mode==0) {
-      	for (unsigned int ix=0;ix<2;++ix) {
+      	for (size_t ix=0; ix<2; ++ix) {
       	  if (_c[ix]->numEntries()==0) continue;
           scale(_h_x[ix], 1.0/ *_c[ix]);
           // brs in % and at 4S /2 as br is for B decays
           if (ix==0) scale(_h_br[ix], 50  / *_c[ix]);
           else       scale(_h_br[ix], 100./ *_c[ix]);
-      	  if(ix==1) scale(_h_fs,100./ *_c[1]);
+      	  if (ix==1) scale(_h_fs,100./ *_c[1]);
       	}
       }
       else {
@@ -146,11 +143,11 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    unsigned int _mode;
+    size_t _mode;
     Histo1DPtr _h_x[2][2];
     CounterPtr _h_br[2][2],_h_fs,_c[2];
     BinnedHistoPtr<string> _sigma[4];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
