@@ -25,19 +25,17 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // histograms
-      for (unsigned int ix=0; ix<2; ++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigma[ix], 1, 1, 1+ix);
       }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
-
+      raiseBeamErrorIf(_sqs.empty());
     }
 
     void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
@@ -70,7 +68,7 @@ namespace Rivet {
         int ncount = ntotal;
         findChildren(hc,nRes,ncount);
         // h_c pi0 pi0
-        if(ncount!=2) continue;
+        if (ncount!=2) continue;
         bool matched = true;
         for (const auto& val : nRes) {
           if (abs(val.first)==111) {
@@ -85,12 +83,12 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _sigma[0]->fill(_ecms);
+          _sigma[0]->fill(_sqs);
           if (hc.parents().empty()) break;
           Particle Zc = hc.parents()[0];
           if (Zc.pid()==_pid && Zc.children().size()==2 &&
              (Zc.children()[0].pid()==PID::PI0 ||
-              Zc.children()[1].pid()==PID::PI0)) _sigma[1]->fill(_ecms);
+              Zc.children()[1].pid()==PID::PI0)) _sigma[1]->fill(_sqs);
           break;
         }
       }
@@ -108,7 +106,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     int _pid;
     /// @}
 
