@@ -25,23 +25,23 @@ namespace Rivet {
       book(_nChi1, 2, 1, 8);
       book(_nChi2, 3, 1, 8);
       for (const string& en : _nChi0.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for( const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -50,38 +50,35 @@ namespace Rivet {
       const FinalState& fs = apply<FinalState>(event, "FS");
       map<long,int> nCount;
       int ntotal(0);
-      for (const Particle& p :  fs.particles()) {
+      for (const Particle& p : fs.particles()) {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p :  ufs.particles(Cuts::pid==10441 or Cuts::pid==20443 or Cuts::pid==445)) {
-        if(p.children().empty()) continue;
+        if (p.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
         // chi gamma
-        if(ncount!=1) continue;
+        if (ncount!=1) continue;
         bool matched = true;
-        for(auto const & val : nRes) {
-          if(val.first==22) {
-            if(val.second !=1) {
+        for (const auto& val : nRes) {
+          if (val.first==22) {
+            if (val.second !=1) {
               matched = false;
               break;
             }
           }
-          else if(val.second!=0) {
+          else if (val.second!=0) {
             matched = false;
             break;
           }
         }
-        if(matched) {
-          if(p.pid()==10441)
-            _nChi0->fill(_ecms);
-          else if(p.pid()==20443)
-            _nChi1->fill(_ecms);
-          else if(p.pid()==445)
-            _nChi2->fill(_ecms);
+        if (matched) {
+          if (p.pid()==10441)       _nChi0->fill(_sqs);
+          else if (p.pid()==20443)  _nChi1->fill(_sqs);
+          else if (p.pid()==445)    _nChi2->fill(_sqs);
           break;
         }
       }
@@ -90,7 +87,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact =  crossSection()/ sumOfWeights() /picobarn;
+      const double fact =  crossSection()/ sumOfWeights() /picobarn;
       scale(_nChi0,fact);
       scale(_nChi1,fact);
       scale(_nChi2,fact);
@@ -99,8 +96,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    BinnedHistoPtr<string> _nChi0,_nChi1,_nChi2;
-    string _ecms;
+    BinnedHistoPtr<string> _nChi0, _nChi1, _nChi2;
+    string _sqs = "";
     /// @}
 
   };
