@@ -23,23 +23,23 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nJPsi, 1, 1, 10);
       for (const string& en : _nJPsi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -54,35 +54,35 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p1 : ufs.particles()) {
-        if(p1.children().empty()) continue;
+        if (p1.children().empty()) continue;
         bool matched=false;
         // find the j/psi
-        if(p1.pid()!=443) continue;
+        if (p1.pid()!=443) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p1,nRes,ncount);
 
         for (const Particle& p2 : ufs.particles()) {
-          if(p2.children().empty()) continue;
+          if (p2.children().empty()) continue;
           // find the j/psi
-          if(p2.pid()!=331) continue;
+          if (p2.pid()!=331) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2!=0) continue;
+          if (ncount2!=0) continue;
           matched=true;
-          for(auto const & val : nRes2) {
-            if(val.second!=0) {
+          for (const auto& val : nRes2) {
+            if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            _nJPsi->fill(_ecms);
+          if (matched) {
+            _nJPsi->fill(_sqs);
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -98,7 +98,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nJPsi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
