@@ -25,22 +25,21 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::pid== 20443 || Cuts::pid==100443), "UFS");
       // histograms
-      for (unsigned int ix=0; ix<2; ++ix) {
-        book(_sigma[ix],1,1,1+ix);
+      for (size_t ix=0; ix<2; ++ix) {
+        book(_sigma[ix], 1, 1, 1+ix);
       }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
@@ -88,14 +87,14 @@ namespace Rivet {
         }
         if (matched) {
           if (nphoton==0) {
-            _sigma[1]->fill(_ecms);
+            _sigma[1]->fill(_sqs);
             break;
           }
           else {
             Particle parent = psi.parents()[0];
             if (parent.pid()==_pid && parent.children().size()==2 &&
                (parent.children()[0].pid()==22 || parent.children()[1].pid()==22 )) {
-              _sigma[0]->fill(_ecms);
+              _sigma[0]->fill(_sqs);
               break;
             }
           }
@@ -106,8 +105,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=0;ix<2;++ix)
-        scale(_sigma[ix], crossSection()/ sumOfWeights() /picobarn);
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -116,7 +114,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     int _pid;
     /// @}
 
