@@ -23,24 +23,24 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nJPsi, 1, 1, 12);
       for (const string& en : _nJPsi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -55,29 +55,29 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-        if(p.children().empty()) continue;
+        if (p.children().empty()) continue;
         // find the j/psi
-        if(p.pid()==443) {
+        if (p.pid()==443) {
           map<long,int> nRes = nCount;
           int ncount = ntotal;
           findChildren(p,nRes,ncount);
           // J/psi pi0pi0
-          if(ncount!=2) continue;
+          if (ncount!=2) continue;
           bool matched = true;
-          for(auto const & val : nRes) {
-            if(abs(val.first)==111) {
-              if(val.second !=2) {
+          for (const auto& val : nRes) {
+            if (abs(val.first)==111) {
+              if (val.second !=2) {
                 matched = false;
                 break;
               }
             }
-            else if(val.second!=0) {
+            else if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            _nJPsi->fill(_ecms);
+          if (matched) {
+            _nJPsi->fill(_sqs);
             break;
           }
         }
@@ -96,7 +96,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nJPsi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
