@@ -24,20 +24,17 @@ namespace Rivet {
       // projections
       declare(FinalState(), "FS");
       // histograms
-      // histograms
-      if (isCompatibleWithSqrtS(4.23)) {
-        _ecms="4.23";
-        book(_h[0],2,1,2);
+      book(_sigma, 1, 1, 1);
+      book(_h["avg"], 2, 1, 1);
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en], 2, 1, 1+ih);
+        ++ih;
       }
-      else if (isCompatibleWithSqrtS(4.26)) {
-        _ecms="4.26";
-        book(_h[0],2,1,3);
-      }
-      else {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
-      book(_h[1],2,1,1);
-      book(_sigma,1,1,1);
+      raiseBeamErrorIf(_sqs.empty());
+      _edge = (_sqs == "4230"s)? "4.23" : "4.26";
     }
 
 
@@ -45,11 +42,11 @@ namespace Rivet {
     void analyze(const Event& event) {
       Particles fs = apply<FinalState>(event, "FS").particles();
       Particles DD,other;
-      for (const Particle & p : fs) {
+      for (const Particle& p : fs) {
         Particle parent=p;
         while (!parent.parents().empty()) {
           parent=parent.parents()[0];
-          if(parent.abspid()==413 || parent.abspid()==423) break;
+          if (parent.abspid()==413 || parent.abspid()==423) break;
         }
         if (parent.abspid()==413 || parent.abspid()==423) {
           bool found=false;
@@ -70,12 +67,13 @@ namespace Rivet {
       if (DD.size()!=2 || other.size()!=1) vetoEvent;
       if (DD[0].pid()!=-DD[1].pid()) vetoEvent;
       if (other[0].pid()!=111) vetoEvent;
-      const double mass = (DD[0].momentum()+DD[1].momentum()).mass();
-      _h[0]->fill(mass/GeV);
-      _h[1]->fill(mass/GeV);
+      const double mass = (DD[0].mom()+DD[1].mom()).mass();
+      _h[_sqs]->fill(mass/GeV);
+      _h["avg"]->fill(mass/GeV);
       // parent Z0
-      if (DD[0].parents()[0].pid()==_pid && DD[1].parents()[0].pid()==_pid &&
-          fuzzyEquals(DD[0].parents()[0].momentum(),DD[1].parents()[0].momentum()) ) _sigma->fill(_ecms);
+      if (DD[0].parents()[0].pid()==_pid &&
+          DD[1].parents()[0].pid()==_pid &&
+          fuzzyEquals(DD[0].parents()[0].mom(),DD[1].parents()[0].mom()) ) _sigma->fill(_edge);
     }
 
 
@@ -92,9 +90,9 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma;
-    Histo1DPtr _h[2];
+    map<string,Histo1DPtr> _h;
+    string _sqs = "", _edge = "";
     int _pid;
-    string _ecms;
     /// @}
 
 
