@@ -26,22 +26,14 @@ namespace Rivet {
       declare(Beam(), "Beams");
       declare(FinalState(), "FS");
       // histograms
-      unsigned int iEnergy=0;
-      if (isCompatibleWithSqrtS(4.23)) {
-        _ecms="4.23";
-        iEnergy=1;
-      }
-      else if (isCompatibleWithSqrtS(4.26)) {
-        _ecms="4.26";
-        iEnergy=2;
-      }
-      else {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      if (isCompatibleWithSqrtS(4.23))       _sqs="4.23";
+      else if (isCompatibleWithSqrtS(4.26))  _sqs="4.26";
+      raiseBeamErrorIf(_sqs.empty());
       // histos
-      for (unsigned int ix=0;ix<2;++ix) {
-        book(_h[ix],2,ix+1,iEnergy);
-        book(_h[2+ix],3,1,1+ix);
+      for (size_t ix=0;ix<2;++ix) {
+        book(_h["4.23"+toString(ix)],2,ix+1,1);
+        book(_h["4.26"+toString(ix)],2,ix+1,2);
+        book(_h[toString(ix)],3,1,1+ix);
         book(_sigma[ix],1,1,1+ix);
       }
     }
@@ -64,18 +56,20 @@ namespace Rivet {
         Particle parent=p;
         while (!parent.parents().empty()) {
           parent=parent.parents()[0];
-          if (parent.abspid()==411 || parent.abspid()==413 ||
-	          parent.abspid()==421 || parent.abspid()==423) break;
+          if (parent.abspid()==411 ||
+              parent.abspid()==413 ||
+	            parent.abspid()==421 ||
+              parent.abspid()==423) break;
         }
-        if ((parent.abspid()==411 || parent.abspid()==421)
-           && !parent.parents().empty()) {
+        if ((parent.abspid()==411 || parent.abspid()==421) &&
+            !parent.parents().empty()) {
           Particle Dstar = parent.parents()[0];
           if (Dstar.abspid()==413 || Dstar.abspid()==423) {
             parent=Dstar;
           }
         }
         if (parent.abspid()==411 || parent.abspid()==413 ||
-           parent.abspid()==421 || parent.abspid()==423) {
+            parent.abspid()==421 || parent.abspid()==423) {
           bool found=false;
           for (const auto& D : DD) {
             // D already in list
@@ -84,7 +78,7 @@ namespace Rivet {
               break;
             }
           }
-          if(!found) DD.push_back(parent);
+          if (!found) DD.push_back(parent);
         }
         else {
           other.push_back(p);
@@ -113,13 +107,13 @@ namespace Rivet {
       else {
       	vetoEvent;
       }
-      _h[iloc]->fill(mass);
+      _h[_sqs + toString(iloc)]->fill(mass);
       // parent Z+/-
       if (DD[0].parents()[0].abspid()==_pid && DD[1].parents()[0].abspid()==_pid &&
-      	 fuzzyEquals(DD[0].parents()[0].momentum(),DD[1].parents()[0].momentum()) ) {
-        _sigma[0]->fill(_ecms);
-        if (_ecms=="4.26") _sigma[1]->fill(_ecms);
-        _h[2+iloc]->fill(cTheta);
+      	 fuzzyEquals(DD[0].parents()[0].mom(),DD[1].parents()[0].mom()) ) {
+        _sigma[0]->fill(_sqs);
+        if (_sqs=="4.26"s)  _sigma[1]->fill(_sqs);
+        _h[toString(iloc)]->fill(cTheta);
       }
     }
 
@@ -128,8 +122,7 @@ namespace Rivet {
       // distributions
       normalize(_h, 1.0, false);
       // cross section
-      for(unsigned int ix=0;ix<2;++ix)
-        scale(_sigma[ix], crossSection()/ sumOfWeights() /picobarn);
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -138,9 +131,9 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    Histo1DPtr _h[4];
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     int _pid;
-    string _ecms;
     /// @}
 
 
