@@ -24,19 +24,14 @@ namespace Rivet {
       // projections
       declare(FinalState(), "FS");
       // histograms
-      if (isCompatibleWithSqrtS(4.226)) {
-        for (unsigned int ix=0; ix<2; ++ix) {
-          book(_h[ix], 2, ix+1, 2);
-        }
-        _ecms = "4.226";
+      if (isCompatibleWithSqrtS(4.226))       _sqs = "4.226";
+      else if (isCompatibleWithSqrtS(4.257))  _sqs = "4.257";
+      raiseBeamErrorIf(_sqs.empty());
+      for (size_t ix=0; ix<2; ++ix) {
+        book(_h["4.257"s+toString(ix)], 2, ix+1, 1);
+        book(_h["4.226"s+toString(ix)], 2, ix+1, 2);
       }
-      else if (isCompatibleWithSqrtS(4.257)) {
-        for (unsigned int ix=0; ix<2; ++ix) {
-          book(_h[ix], 2, ix+1, 1);
-        }
-        _ecms = "4.257";
-      }
-      book(_h[2],3,1,1);
+      book(_h["2"],3,1,1);
       book(_sigma,1,1,1);
     }
 
@@ -95,11 +90,12 @@ namespace Rivet {
       }
       // otherwise veto event
       else vetoEvent;
-      _h[iloc]->fill(mass);
-      _h[2]->fill(mass);
+      _h[_sqs+toString(iloc)]->fill(mass);
+      _h["2"]->fill(mass);
       // parent Z0
-      if (DD[0].parents()[0].pid()==_pid && DD[1].parents()[0].pid()==_pid &&
-	        fuzzyEquals(DD[0].parents()[0].momentum(),DD[1].parents()[0].momentum()) ) _sigma->fill(_ecms);
+      if (DD[0].parents()[0].pid()==_pid &&
+          DD[1].parents()[0].pid()==_pid &&
+	        fuzzyEquals(DD[0].parents()[0].mom(),DD[1].parents()[0].mom()) ) _sigma->fill(_sqs);
     }
 
 
@@ -117,9 +113,9 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma;
-    Histo1DPtr _h[3];
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     int _pid;
-    string _ecms;
     /// @}
 
 
