@@ -21,28 +21,28 @@ namespace Rivet {
     void init() {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_nChi[ix], 2+ix,1,6);
         for (const string& en : _nChi[ix].binning().edges<0>()) {
-          double end = std::stod(en)*GeV;
-          if(isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
+          double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en;
             break;
           }
         }
       }
-      if(_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for( const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -51,14 +51,14 @@ namespace Rivet {
       const FinalState& fs = apply<FinalState>(event, "FS");
       map<long,int> nCount;
       int ntotal(0);
-      for (const Particle& p :  fs.particles()) {
+      for (const Particle& p : fs.particles()) {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       bool matched = false;
-      for (const Particle& p :  ufs.particles(Cuts::pid==20443 or Cuts::pid==445)) {
-        if(p.children().empty()) continue;
+      for (const Particle& p : ufs.particles(Cuts::pid==20443 or Cuts::pid==445)) {
+        if (p.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
@@ -66,35 +66,32 @@ namespace Rivet {
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2!=0) continue;
+          if (ncount2!=0) continue;
           matched=true;
-          for(auto const & val : nRes2) {
-            if(val.second!=0) {
+          for (const auto& val : nRes2) {
+            if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            if(p.pid()==20443) {
-              if(!_ecms[0].empty()) _nChi[0]->fill(_ecms[0]);
+          if (matched) {
+            if (p.pid()==20443) {
+              if (!_sqs[0].empty()) _nChi[0]->fill(_sqs[0]);
             }
-            else if(p.pid()==445){
-              if(!_ecms[1].empty()) _nChi[1]->fill(_ecms[1]);
+            else if (p.pid()==445){
+              if (!_sqs[1].empty()) _nChi[1]->fill(_sqs[1]);
             }
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact =  crossSection()/ sumOfWeights() /picobarn;
-      for(unsigned int ix=0;ix<2;++ix) {
-        scale(_nChi[ix],fact);
-      }
+      scale(_nChi, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -103,7 +100,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nChi[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
