@@ -27,26 +27,29 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      if(isCompatibleWithSqrtS(3.1*GeV,1e-1)) {
-        book(_h_xi  , 2, 1, 1);
-        book(_h_sigm, 2, 1, 2);
-        book(_h_sigp, 2, 1, 3);
-      }
-      else if (isCompatibleWithSqrtS(3.686*GeV, 1E-1)) {
-        book(_h_xi ,  2, 1, 4);
-        book(_h_sigm, 2, 1, 5);
-        book(_h_sigp, 2, 1, 6);
+      size_t ih = 0;
+      for (double eVal : allowedEnergies()) {
+
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal,1e-1))  _sqs = en;
+
+        book(_h[en+"xi"],   2, 1, 1+ih);
+        book(_h[en+"sigm"], 2, 1, 2+ih);
+        book(_h[en+"sigp"], 2, 1, 3+ih);
+        ih += 3;
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for( const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) const {
+      for (const Particle &child : p.children()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -55,10 +58,12 @@ namespace Rivet {
       // get the axis, direction of incoming electron
       const ParticlePair& beams = apply<Beam>(event, "Beams").beams();
       Vector3 axis;
-      if(beams.first.pid()>0)
-        axis = beams.first .momentum().p3().unit();
-      else
-        axis = beams.second.momentum().p3().unit();
+      if (beams.first.pid()>0) {
+        axis = beams.first.mom().p3().unit();
+      }
+      else {
+        axis = beams.second.mom().p3().unit();
+      }
       // types of final state particles
       const FinalState& fs = apply<FinalState>(event, "FS");
       map<long,int> nCount;
@@ -70,56 +75,61 @@ namespace Rivet {
 
       const UnstableParticles & ufs = apply<UnstableParticles>(event, "UFS");
       for (const Particle& p :  ufs.particles(Cuts::abspid==3312 or Cuts::abspid==3224 or Cuts::abspid==3114)) {
-        if(p.children().empty()) continue;
+        if (p.children().empty()) continue;
         map<long,int> nRes=nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
         bool matched=false;
         // check for antiparticle
         for (const Particle& p2 :  ufs.particles(Cuts::pid==-p.pid())) {
-          if(p2.children().empty()) continue;
+          if (p2.children().empty()) continue;
           map<long,int> nRes2=nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2==0) {
+          if (ncount2==0) {
             matched = true;
-            for(auto const & val : nRes2) {
-              if(val.second!=0) {
+            for (const auto& val : nRes2) {
+              if (val.second!=0) {
                 matched = false;
                 break;
               }
             }
             // fond baryon and antibaryon
-            if(matched) {
+            if (matched) {
               // calc cosine
               double ctheta;
-              if(p.pid()>0)
-                ctheta = p .momentum().p3().unit().dot(axis);
-              else
-                ctheta = p2.momentum().p3().unit().dot(axis);
-              if(abs(p.pid())==3312)
-                _h_xi ->fill(ctheta);
-              else if(abs(p.pid())==3114)
-                _h_sigm->fill(ctheta);
-              else if(abs(p.pid())==3224)
-                _h_sigp->fill(ctheta);
+              if (p.pid()>0) {
+                ctheta = p .mom().p3().unit().dot(axis);
+              }
+              else {
+                ctheta = p2.mom().p3().unit().dot(axis);
+              }
+              if (abs(p.pid())==3312) {
+                _h[_sqs+"xi"]->fill(ctheta);
+              }
+              else if(abs(p.pid())==3114) {
+                _h[_sqs+"sigm"]->fill(ctheta);
+              }
+              else if(abs(p.pid())==3224) {
+                _h[_sqs+"sigp"]->fill(ctheta);
+              }
               break;
             }
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
-    pair<double,pair<double,double> > calcAlpha(Histo1DPtr hist) {
-      if(hist->numEntries()==0.) return make_pair(0.,make_pair(0.,0.));
+    pair<double,pair<double,double> > calcAlpha(const Histo1DPtr& hist) const {
+      if (hist->numEntries()==0.) return make_pair(0.,make_pair(0.,0.));
       double d = 3./(pow(hist->xMax(),3)-pow(hist->xMin(),3));
       double c = 3.*(hist->xMax()-hist->xMin())/(pow(hist->xMax(),3)-pow(hist->xMin(),3));
       double sum1(0.),sum2(0.),sum3(0.),sum4(0.),sum5(0.);
-      for (const auto& bin : hist->bins() ) {
+      for (const auto& bin : hist->bins()) {
         double Oi = bin.sumW();
-        if(Oi==0.) continue;
-        double a =  d*(bin.xMax() - bin.xMin());
+        if (Oi==0.) continue;
+        double a =  d*bin.xWidth();
         double b = d/3.*(pow(bin.xMax(),3) - pow(bin.xMin(),3));
         double Ei = bin.errW();
         sum1 +=   a*Oi/sqr(Ei);
@@ -135,7 +145,7 @@ namespace Rivet {
       double bb = -2*sqr(sum3 + sqr(c)*sum4 - 2*c*sum5)*(sum1 - c*sum2 + c*sum4 - sum5);
       double aa =  sqr(sum1 - c*sum2 + c*sum4 - sum5)*(-sum3 - sqr(c)*sum4 + sqr(sum1 - c*sum2 + c*sum4 - sum5) + 2*c*sum5);
       double dis = sqr(bb)-4.*aa*cc;
-      if(dis>0.) {
+      if (dis>0.) {
         dis = sqrt(dis);
         return make_pair(alpha,make_pair(0.5*(-bb+dis)/aa,-0.5*(-bb-dis)/aa));
       }
@@ -146,23 +156,22 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      // find energy
-      int ioff=0;
-      if(isCompatibleWithSqrtS(3.1*GeV,1e-1)) ioff=1;
-      else if (isCompatibleWithSqrtS(3.686*GeV, 1E-1)) ioff=4;
-      vector< pair<double,pair<double,double> > > alpha;
-      normalize(_h_xi,1.,false);
-      alpha.push_back(calcAlpha(_h_xi));
-      normalize(_h_sigm,1.,false);
-      alpha.push_back(calcAlpha(_h_sigm));
-      normalize(_h_sigp,1.,false);
-      alpha.push_back(calcAlpha(_h_sigp));
+
+      vector<string> edges = {"xi", "sigm", "sigp"};
+      normalize(_h, 1.0, false);
+
       BinnedEstimatePtr<string> _h_alpha;
       book(_h_alpha,1,1,3);
-      for (unsigned int ix=0;ix<3;++ix) {
-        _h_alpha->bin(ix+ioff).set(alpha[ix].first,
-                                   make_pair(alpha[ix].second.first,
-                                             alpha[ix].second.second));
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+
+        const string en = toString(round(eVal/MeV));
+
+        for (size_t ix=0; ix<edges.size(); ++ix) {
+          const auto alpha = calcAlpha(_h[en + edges[ix]]);
+          _h_alpha->bin(ix+ih).set(alpha.first, alpha.second);
+        }
+        ih += 3;
       }
     }
     /// @}
@@ -170,7 +179,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_xi,_h_sigm,_h_sigp;
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
 
