@@ -21,29 +21,27 @@ namespace Rivet {
     void init() {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::pid==10443), "UFS");
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_nhc[ix], 1+ix, 1, 1);
         for (const string& en : _nhc[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          const double eval = stod(en);
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -59,28 +57,28 @@ namespace Rivet {
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       // loop over the h_c
       for (const Particle& p : ufs.particles()) {
-        if(p.children().empty()) continue;
+        if (p.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
         // h_c pi+pi-
-        if(ncount!=2) continue;
+        if (ncount!=2) continue;
         bool matched = true;
-        for(auto const & val : nRes) {
-          if(abs(val.first)==211) {
-            if(val.second !=1) {
+        for (const auto& val : nRes) {
+          if (abs(val.first)==211) {
+            if (val.second !=1) {
               matched = false;
               break;
             }
           }
-          else if(val.second!=0) {
+          else if (val.second!=0) {
             matched = false;
             break;
           }
         }
-        if(matched) {
-          _nhc[0]->fill(_ecms[0]);
-          _nhc[1]->fill(_ecms[1]);
+        if (matched) {
+          _nhc[0]->fill(_sqs[0]);
+          _nhc[1]->fill(_sqs[1]);
           break;
         }
       }
@@ -88,9 +86,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      const double fact = crossSection()/ sumOfWeights() /picobarn;
-      for(unsigned int ix=0;ix<2;++ix)
-        scale(_nhc[ix],fact);
+      scale(_nhc, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -99,7 +95,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nhc[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
