@@ -27,24 +27,28 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      if(isCompatibleWithSqrtS(3.1*GeV,1e-1)) {
-        book(_h_lam, 1, 1, 1);
-        book(_h_sig, 1, 1, 3);
-      }
-      else if (isCompatibleWithSqrtS(3.686*GeV, 1E-1)) {
-        book(_h_lam, 1, 1, 2);
-        book(_h_sig, 1, 1, 4);
+      size_t ih = 0;
+      for (double eVal : allowedEnergies()) {
+
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal, 1e-1))  _sqs = en;
+
+        book(_h[en+"lam"], 1, 1, 1+ih);
+        book(_h[en+"sig"], 1, 1, 3+ih);
+        ++ih;
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for( const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -79,38 +83,42 @@ namespace Rivet {
           map<long,int> nRes2=nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2==0) {
+          if (ncount2==0) {
             matched = true;
-            for(auto const & val : nRes2) {
-              if(val.second!=0) {
+            for (const auto& val : nRes2) {
+              if (val.second!=0) {
                 matched = false;
                 break;
               }
             }
             // fond baryon and antibaryon
-            if(matched) {
+            if (matched) {
               // calc cosine
               double ctheta;
-              if(p.pid()>0)
-                ctheta = p .momentum().p3().unit().dot(axis);
-              else
-                ctheta = p2.momentum().p3().unit().dot(axis);
-              if(abs(p.pid())==3122)
-                _h_lam->fill(ctheta);
-              else
-                _h_sig->fill(ctheta);
+              if (p.pid()>0) {
+                ctheta = p .mom().p3().unit().dot(axis);
+              }
+              else {
+                ctheta = p2.mom().p3().unit().dot(axis);
+              }
+              if (p.abspid()==3122) {
+                _h[_sqs+"lam"]->fill(ctheta);
+              }
+              else {
+                _h[_sqs+"sig"]->fill(ctheta);
+              }
               break;
             }
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
-    pair<double,pair<double,double> > calcAlpha(Histo1DPtr hist) {
+    pair<double,pair<double,double> > calcAlpha(const Histo1DPtr& hist) const {
       if(hist->numEntries()==0.) return make_pair(0.,make_pair(0.,0.));
       double sum1(0.),sum2(0.),sum3(0.),sum4(0.),sum5(0.);
-      for (const auto& bin : hist->bins() ) {
+      for (const auto& bin : hist->bins()) {
         double Oi = bin.sumW();
         if(Oi==0.) continue;
         double a =  1.5*(bin.xMax() - bin.xMin());
@@ -129,7 +137,7 @@ namespace Rivet {
       double bb = -2*sqr(sum3 + 9*sum4 - 6*sum5)*(sum1 - 3*sum2 + 3*sum4 - sum5);
       double aa =  sqr(sum1 - 3*sum2 + 3*sum4 - sum5)*(-sum3 - 9*sum4 + sqr(sum1 - 3*sum2 + 3*sum4 - sum5) + 6*sum5);
       double dis = sqr(bb)-4.*aa*cc;
-      if(dis>0.) {
+      if (dis>0.) {
         dis = sqrt(dis);
         return make_pair(alpha,make_pair(0.5*(-bb+dis)/aa,-0.5*(-bb-dis)/aa));
       }
@@ -140,21 +148,27 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
+
+      normalize(_h);
+
       // find energy
-      int ioff=-1;
-      if (isCompatibleWithSqrtS(3.1*GeV,1e-1)) ioff=0;
-      else if (isCompatibleWithSqrtS(3.686*GeV, 1E-1))  ioff=1;
-      // normalize
-      normalize(_h_lam);
-      pair<double,pair<double,double> > alpha = calcAlpha(_h_lam);
-      Estimate0DPtr _h_alpha_lam;
-      book(_h_alpha_lam, 2,2*ioff+1,1);
-      _h_alpha_lam->set(alpha.first, alpha.second);
-      normalize(_h_sig);
-      alpha = calcAlpha(_h_sig);
-      Estimate0DPtr _h_alpha_sig;
-      book(_h_alpha_sig, 2,2*ioff+2,1);
-      _h_alpha_sig->set(alpha.first, alpha.second);
+      size_t ih = 0;
+      Estimate0DPtr est;
+      pair<double,pair<double,double> > alpha;
+      for (double eVal : allowedEnergies()) {
+
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal, 1e-1))  _sqs = en;
+
+        book(est, 2, 1+ih, 1);
+        alpha = calcAlpha(_h[en+"lam"]);
+        est->set(alpha.first, alpha.second);
+
+        book(est, 2, 2+ih, 1);
+        alpha = calcAlpha(_h[en+"sig"]);
+        est->set(alpha.first, alpha.second);
+        ih += 2;
+      }
     }
 
     /// @}
@@ -162,7 +176,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_lam,_h_sig;
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
 
