@@ -23,24 +23,23 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nhc, 1, 1, 1);
       for (const string& en : _nhc.binning().edges<0>()) {
-        const double end = std::stod(en)*MeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -56,37 +55,37 @@ namespace Rivet {
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       // loop over h_c
       for (const Particle& hc : ufs.particles(Cuts::pid==10443)) {
-        if(hc.children().empty()) continue;
+        if (hc.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(hc,nRes,ncount);
         bool matched = false;
         // loop over eta
-        for(const Particle & eta : ufs.particles(Cuts::pid==221)) {
+        for (const Particle& eta : ufs.particles(Cuts::pid==221)) {
           // check eta not child of h_c
           Particle parent=eta;
-          while(!parent.parents().empty()) {
+          while (!parent.parents().empty()) {
             parent=parent.parents()[0];
-            if(parent.abspid()==10443) break;
+            if (parent.abspid()==10443) break;
           }
-          if(fuzzyEquals(parent.momentum(),hc.momentum())) continue;
+          if( fuzzyEquals(parent.momentum(),hc.momentum())) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(eta,nRes2,ncount2);
-          if(ncount2!=0) continue;
+          if (ncount2!=0) continue;
           matched=true;
-          for(auto const & val : nRes2) {
-            if(val.second!=0) {
+          for (const auto & val : nRes2) {
+            if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            _nhc->fill(_ecms);
+          if (matched) {
+            _nhc->fill(_sqs);
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -102,7 +101,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nhc;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
