@@ -20,13 +20,18 @@ namespace Rivet {
     void init() {
       // projections
       declare(FinalState(), "FS");
-      unsigned int iloc=1;
-      if      (isCompatibleWithSqrtS(4.23)) iloc=1;
-      else if (isCompatibleWithSqrtS(4.26)) iloc=2;
-      for (unsigned int ix=0;ix<2;++ix) {
-      	book(_h_mass[ix], 1, iloc, 1+ix);
+      size_t ih = 0;
+      for (double eVal : allowedEnergies()) {
+
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+
+        book(_h[en+"mass1"], 1, 1+ih, 1);
+        book(_h[en+"mass2"], 1, 1+ih, 2);
+        ++ih;
       }
-      book(_h_cTheta, 2, 1, 1);
+      raiseBeamErrorIf(_sqs.empty());
+      book(_h["cTheta"], 2, 1, 1);
     }
 
     /// Perform the per-event analysis
@@ -46,7 +51,7 @@ namespace Rivet {
         bool found=false;
         for (const auto& psi : Jpsi) {
           // J/psi already in list
-          if (fuzzyEquals(psi.momentum(),parent.momentum())) {
+          if (fuzzyEquals(psi.mom(),parent.mom())) {
             found=true;
             break;
           }
@@ -54,17 +59,17 @@ namespace Rivet {
         if (!found) Jpsi.push_back(parent);
       }
       if (Jpsi.size()!=1 || other.size()!=2) vetoEvent;
-      if (other[0].pid()!=-other[1].pid() || other[0].abspid()!=PID::PIPLUS) vetoEvent;
-      _h_mass[0]->fill((other[0].momentum()+other[1].momentum()).mass());
-      for (unsigned int ix=0;ix<2;++ix) {
-        FourMomentum pZ = Jpsi[0].momentum()+other[ix].momentum();
-        double mZ = pZ.mass();
-        _h_mass[1]->fill(mZ);
+      if (other[0].pid() != -other[1].pid() || other[0].abspid()!=PID::PIPLUS) vetoEvent;
+      _h[_sqs+"mass1"]->fill((other[0].mom()+other[1].mom()).mass());
+      for (size_t ix=0; ix<2; ++ix) {
+        FourMomentum pZ = Jpsi[0].mom()+other[ix].mom();
+        double mZ = pZ.mass()/GeV;
+        _h[_sqs+"mass2"]->fill(mZ);
         if (mZ>3.86 && mZ<3.92) {
           LorentzTransform boost = LorentzTransform::mkFrameTransformFromBeta(pZ.betaVec());
           Vector3 axis1 = pZ.p3().unit();
-          Vector3 axis2 = boost.transform(other[ix].momentum()).p3().unit();
-          _h_cTheta->fill(abs(axis1.dot(axis2)));
+          Vector3 axis2 = boost.transform(other[ix].mom()).p3().unit();
+          _h["cTheta"]->fill(abs(axis1.dot(axis2)));
         }
       }
     }
@@ -72,8 +77,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      normalize(_h_mass,   1.0, false);
-      normalize(_h_cTheta, 1.0, false);
+      normalize(_h, 1.0, false);
     }
 
     /// @}
@@ -81,8 +85,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_mass[2];
-    Histo1DPtr _h_cTheta;
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
 
