@@ -23,22 +23,21 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::pid==223 || Cuts::pid==333), "UFS");
       // counters
-      for (unsigned int ix=0; ix<2; ++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigma[ix], 1+ix, 1, 1);
       }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
@@ -66,7 +65,7 @@ namespace Rivet {
       // first phi
       for (unsigned int ix=0; ix<phi.size(); ++ix) {
         const Particle & phi1 = phi[ix];
-        if(phi1.children().empty()) continue;
+        if (phi1.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(phi1,nRes,ncount);
@@ -91,8 +90,8 @@ namespace Rivet {
                 break;
               }
             }
-            if(found) {
-              _sigma[1]->fill(_ecms);
+            if (found) {
+              _sigma[1]->fill(_sqs);
               break;
             }
           }
@@ -112,11 +111,11 @@ namespace Rivet {
               }
             }
             if (found) {
-              _sigma[0]->fill(_ecms);
+              _sigma[0]->fill(_sqs);
               break;
             }
           }
-          if(found) break;
+          if (found) break;
         }
         if (found) break;
       }
@@ -134,7 +133,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
