@@ -25,25 +25,23 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nLambda, 1, 1, 1);
       for (const string& en : _nLambda.binning().edges<0>()) {
-        const double end = std::stod(en)*MeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
-
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for( const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -59,34 +57,32 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
 
-      for(unsigned int ix=0;ix<ufs.particles().size();++ix) {
+      for (size_t ix=0; ix<ufs.particles().size(); ++ix) {
         const Particle& p1 = ufs.particles()[ix];
-        if(abs(p1.pid())!=4122) continue;
+        if (p1.abspid()!=4122) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p1,nRes,ncount);
         bool matched=false;
-        for(unsigned int iy=0;iy<ufs.particles().size();++iy) {
-          if(ix==iy) continue;
+        for (size_t iy=0; iy<ufs.particles().size(); ++iy) {
+          if (ix==iy) continue;
           const Particle& p2 = ufs.particles()[iy];
-          if(p2.pid() != -p1.pid()) continue;
+          if (p2.pid() != -p1.pid()) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2!=0) continue;
+          if (ncount2!=0) continue;
           matched=true;
-          for(auto const & val : nRes2) {
-            if(val.second!=0) {
+          for (const auto& val : nRes2) {
+            if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            break;
-          }
+          if (matched) break;
         }
-        if(matched) {
-          _nLambda->fill(_ecms);
+        if (matched) {
+          _nLambda->fill(_sqs);
           break;
         }
       }
@@ -104,7 +100,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nLambda;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
