@@ -24,24 +24,23 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nLambda, 1, 1, 1);
       for (const string& en : _nLambda.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -57,52 +56,52 @@ namespace Rivet {
       }
       // find the Lambdas
       const FinalState& ufs = apply<UnstableParticles>(event, "UFS");
-      for(unsigned int ix=0;ix<ufs.particles().size();++ix) {
+      for (size_t ix=0; ix<ufs.particles().size(); ++ix) {
         const Particle& p1 = ufs.particles()[ix];
-        if(abs(p1.pid())!=3122) continue;
+        if (p1.abspid()!=3122) continue;
         bool matched = false;
         // check fs
         bool fs = true;
         for (const Particle & child : p1.children()) {
-          if(child.pid()==p1.pid()) {
+          if (child.pid()==p1.pid()) {
             fs = false;
             break;
           }
         }
-        if(!fs) continue;
+        if (!fs) continue;
         // find the children
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p1,nRes,ncount);
-        for(unsigned int iy=ix+1;iy<ufs.particles().size();++iy) {
+        for (size_t iy=ix+1; iy<ufs.particles().size(); ++iy) {
           const Particle& p2 = ufs.particles()[iy];
-          if(abs(p2.pid())!=3122) continue;
+          if (p2.abspid()!=3122) continue;
           // check fs
           bool fs = true;
           for (const Particle & child : p2.children()) {
-            if(child.pid()==p2.pid()) {
+            if (child.pid()==p2.pid()) {
               fs = false;
               break;
             }
           }
-          if(!fs) continue;
+          if (!fs) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2!=0) continue;
+          if (ncount2!=0) continue;
           matched=true;
-          for(auto const & val : nRes2) {
+          for (const auto& val : nRes2) {
             if(val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            _nLambda->fill(_ecms);
+          if (matched) {
+            _nLambda->fill(_sqs);
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -116,7 +115,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nLambda;
-    string _ecms;
+    string _sqs = "";
     /// @}
   };
 
