@@ -24,23 +24,23 @@ namespace Rivet {
       book(_nKp, 1, 1, 1);
       book(_nK0, 1, 1, 2);
       for (const string& en : _nKp.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -55,15 +55,15 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-        if(p.children().empty()) continue;
+        if (p.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
         // J/psi KK
-        if(ncount!=2) continue;
+        if (ncount!=2) continue;
         bool matched = true;
-        for(auto const & val : nRes) {
-          if(abs(val.first)==321 || abs(val.first)==310) {
+        for (const auto& val : nRes) {
+          if (abs(val.first)==321 || abs(val.first)==310) {
             continue;
           }
           else if(val.second!=0) {
@@ -71,13 +71,13 @@ namespace Rivet {
             break;
           }
         }
-        if(matched) {
-          if(nRes[321]==1 && nRes[-321]==1) {
-            _nKp->fill(_ecms);
+        if (matched) {
+          if (nRes[321]==1 && nRes[-321]==1) {
+            _nKp->fill(_sqs);
             break;
           }
-          else if(nRes[310]==2) {
-            _nK0->fill(_ecms);
+          else if (nRes[310]==2) {
+            _nK0->fill(_sqs);
             break;
           }
         }
@@ -96,7 +96,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nKp, _nK0;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
