@@ -22,22 +22,20 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::pid==102134), "UFS");
       // counters
-      for (unsigned int ix=0; ix<3; ++ix) {
+      for (size_t ix=0; ix<3; ++ix) {
         book(_sigma[ix], 1, 1, 1+ix);
       }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
-
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p,map<long,int>& nRes, int &ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -63,7 +61,7 @@ namespace Rivet {
       if (ntotal==4&&nCount[310]==1) {
         if ((nCount[ 2212]==1 && nCount[-2112]==1 && nCount[-321]==1) ||
            (nCount[-2212]==1 && nCount[ 2112]==1 && nCount[ 321]==1)) {
-          _sigma[0]->fill(_ecms);
+          _sigma[0]->fill(_sqs);
         }
       }
       for (const Particle& p : apply<FinalState>(event, "UFS").particles()) {
@@ -87,7 +85,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _sigma[1]->fill(_ecms);
+          _sigma[1]->fill(_sqs);
           break;
         }
         matched = true;
@@ -105,7 +103,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _sigma[2]->fill(_ecms);
+          _sigma[2]->fill(_sqs);
           break;
         }
       }
@@ -123,7 +121,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
