@@ -24,28 +24,27 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // Book histograms
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_nD0[ix], 1+ix, 1, 1);
         for (const string& en : _nD0[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
+          const double end = stod(en)*GeV;
           if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -62,41 +61,41 @@ namespace Rivet {
       const FinalState& ufs = apply<FinalState>(event, "UFS");
 
 
-      for(unsigned int ix=0;ix<ufs.particles().size();++ix) {
+      for (size_t ix=0; ix<ufs.particles().size(); ++ix) {
         const Particle& p1 = ufs.particles()[ix];
-        if(abs(p1.pid())!=421) continue;
+        if (p1.abspid() != 421) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p1,nRes,ncount);
         bool matched=false;
         int id2 = p1.pid()>0 ? -413 :  413;
         int ipi = p1.pid()>0 ?  211 : -211;
-        for(unsigned int iy=0;iy<ufs.particles().size();++iy) {
-          if(ix==iy) continue;
+        for (size_t iy=0; iy<ufs.particles().size(); ++iy) {
+          if (ix==iy) continue;
           const Particle& p2 = ufs.particles()[iy];
-          if(p2.pid()!=id2) continue;
+          if (p2.pid()!=id2) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2!=1) continue;
+          if (ncount2!=1) continue;
           matched=true;
-          for(auto const & val : nRes2) {
-            if(val.first==ipi) {
-              if(val.second!=1) {
+          for (const auto& val : nRes2) {
+            if (val.first==ipi) {
+              if (val.second!=1) {
                 matched = false;
                 break;
               }
             }
-            else if(val.second!=0) {
+            else if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) break;
+          if (matched) break;
         }
-        if(matched) {
-          for(unsigned int ix=0;ix<2;++ix) {
-            if(!_ecms[ix].empty()) _nD0[ix]->fill(_ecms[ix]);
+        if (matched) {
+          for (size_t ix=0; ix<2; ++ix) {
+            if(!_sqs[ix].empty()) _nD0[ix]->fill(_sqs[ix]);
           }
         }
       }
@@ -105,9 +104,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      for(unsigned int ix=0;ix<2;++ix)
-        scale(_nD0[ix],fact);
+      scale(_nD0, crossSection()/ sumOfWeights() /nanobarn);
     }
 
     /// @}
@@ -116,7 +113,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nD0[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
