@@ -23,13 +23,12 @@ namespace Rivet {
       book(_nKKpi, 1, 1, 1);
 
       for (const string& en : _nKKpi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -44,10 +43,10 @@ namespace Rivet {
         ++ntotal;
       }
 
-      if(ntotal==3 && nCount[310]==1 &&
-         ((nCount[ 321]=1 &&  nCount[-211] ==1) ||
-          (nCount[-321]=1 &&  nCount[ 211] ==1)))
-        _nKKpi->fill(_ecms);
+      if (ntotal==3 && nCount[310]==1 &&
+        ((nCount[ 321]=1 && nCount[-211] ==1) ||
+         (nCount[-321]=1 && nCount[ 211] ==1)))
+        _nKKpi->fill(_sqs);
     }
 
 
@@ -62,7 +61,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nKKpi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
