@@ -24,32 +24,30 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
 
       // Book histograms
-      for(unsigned int ix=0;ix<2;++ix)
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigma[ix], 1+ix, 1, 1);
- 
+      }
+
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) {
-        if(isCompatibleWithSqrtS(4.085)) _ecms="4.085"s;
-        else
-          MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      if (_sqs.empty() && isCompatibleWithSqrtS(4.085))  _sqs = "4.085"s;
+      else raiseBeamErrorIf(_sqs.empty());
     }
 
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -64,48 +62,48 @@ namespace Rivet {
         ++ntotal;
       }
       // K K pi pi
-      if(ntotal==4 && nCount[310]==1 && nCount[111]==1 &&
-         ((nCount[ 321]==1 &&nCount[-211]==1) ||
-          (nCount[-321]==1 &&nCount[ 211]==1) ))
-        _sigma[0]->fill(_ecms);
+      if (ntotal==4 && nCount[310]==1 && nCount[111]==1 &&
+        ((nCount[ 321]==1 &&nCount[-211]==1) ||
+         (nCount[-321]==1 &&nCount[ 211]==1) )) {
+        _sigma[0]->fill(_sqs);
+      }
       // eta resonance
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-        if(p.children().empty()) continue;
-        if(p.pid()!=221) continue;
+        if (p.children().empty()) continue;
+        if (p.pid()!=221) continue;
         map<long,int> nRes=nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
-        if(ncount!=3) continue;
+        if (ncount!=3) continue;
         bool matched=true;
-        for(auto const & val : nRes) {
-          if(abs(val.first)==321 || abs(val.first)==211) {
+        for (const auto& val : nRes) {
+          if (abs(val.first)==321 || abs(val.first)==211) {
             continue;
           }
-          else if(abs(val.first)==310) {
-            if(val.second!=1) {
+          else if (abs(val.first)==310) {
+            if (val.second!=1) {
               matched = false;
               break;
             }
           }
-          else if(val.second!=0) {
+          else if (val.second!=0) {
             matched = false;
             break;
           }
         }
-        if(matched==false) continue;
-        if((nCount[ 321] == 1 && nCount[-211] ==1) ||
-           (nCount[-321] == 1 && nCount[ 211] ==1))
-          _sigma[1]->fill(_ecms);
+        if (matched==false) continue;
+        if ((nCount[ 321] == 1 && nCount[-211] ==1) ||
+            (nCount[-321] == 1 && nCount[ 211] ==1)) {
+          _sigma[1]->fill(_sqs);
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn;
-      for (unsigned int ix=0;ix<2;++ix)
-        scale(_sigma[ix],fact);
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
     /// @}
 
@@ -113,7 +111,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
