@@ -25,24 +25,23 @@ namespace Rivet {
       // Book histograms
       book(_nkaon, 1, 1, 1);
       for (const string& en : _nkaon.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-        if(abs(p.pid())!=PID::KPLUS) vetoEvent;
+        if (p.abspid() != PID::KPLUS) vetoEvent;
       }
-      _nkaon->fill(_ecms);
+      _nkaon->fill(_sqs);
     }
 
 
@@ -57,7 +56,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nkaon;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
