@@ -29,18 +29,17 @@ namespace Rivet {
       book(_sigma,1,1,1);
 
       for (const string& en : _sigma.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
@@ -61,20 +60,20 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       // loop over any eta mesons
-      for (const Particle & eta : ufs.particles(Cuts::pid==221)) {
+      for (const Particle& eta : ufs.particles(Cuts::pid==221)) {
         bool matched = false;
         if(eta.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(eta,nRes,ncount);
-        for (const Particle & phi : ufs.particles(Cuts::pid==333)) {
+        for (const Particle& phi : ufs.particles(Cuts::pid==333)) {
           if (phi.children().empty()) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(phi,nRes2,ncount2);
           matched = true;
           // required eta phi pi+ pi- final state
-          for (auto const & val : nRes2) {
+          for (const auto& val : nRes2) {
             if (abs(val.first)==211) {
               if (val.second !=1) {
                 matched = false;
@@ -123,7 +122,7 @@ namespace Rivet {
           if (matched) break;
         }
         if (matched) {
-          _sigma->fill(_ecms);
+          _sigma->fill(_sqs);
           break;
         }
       }
@@ -142,7 +141,7 @@ namespace Rivet {
     /// @{
     int _pid;
     BinnedHistoPtr<string> _sigma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
