@@ -20,7 +20,7 @@ namespace Rivet {
     void init() {
 
       // Initialise and register projections
-      declare(UnstableParticles(Cuts::pid==431), "UFS");
+      declare(UnstableParticles(), "UFS");
       // histograms
       for(unsigned int ix=0;ix<2;++ix)
 	for(unsigned int iy=0;iy<2;++iy)
@@ -31,7 +31,7 @@ namespace Rivet {
 
     // Calculate the Q2 using mother and daugher meson
     double q2(const Particle& B, int mesonID) {
-      FourMomentum q = B.mom() - filter_select(B.children(), Cuts::pid==mesonID)[0];
+      FourMomentum q = B.mom() - select(B.children(), Cuts::pid==mesonID)[0];
       return q*q;
     }
     
@@ -47,7 +47,7 @@ namespace Rivet {
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       // Loop over Ds mesons
-      for (const Particle& p : apply<UnstableParticles>(event, "UFS").particles()) {
+      for (const Particle& p : apply<UnstableParticles>(event, "UFS").particles(Cuts::pid==431)) {
 	_nDs->fill();
         if (isSemileptonicDecay(p, {PID::ETA, PID::POSITRON, PID::NU_E})) {
           _h[0][0]->fill(q2(p, PID::ETA));
