@@ -23,24 +23,24 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nChi0, 1,1,1);
       for (const string& en : _nChi0.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for( const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -65,20 +65,20 @@ namespace Rivet {
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2!=0) continue;
+          if (ncount2!=0) continue;
           matched=true;
-          for(auto const & val : nRes2) {
-            if(val.second!=0) {
+          for (const auto& val : nRes2) {
+            if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            _nChi0->fill(_ecms);
+          if (matched) {
+            _nChi0->fill(_sqs);
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -94,7 +94,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nChi0;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
