@@ -25,23 +25,22 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // counters
-      for (unsigned int ix=0;ix<2;++ix) {
-        book(_sigma[ix],1,1,1+ix);
+      for (size_t ix=0; ix<2; ++ix) {
+        book(_sigma[ix], 1, 1, 1+ix);
       }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
 
     }
 
-    void findChildren(const Particle & p,map<long,int>& nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
@@ -63,7 +62,7 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       int mode=-1;
-      for (const Particle & psi : ufs.particles(Cuts::pid==443)) {
+      for (const Particle& psi : ufs.particles(Cuts::pid==443)) {
         if (psi.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
@@ -103,7 +102,7 @@ namespace Rivet {
                 break;
               }
             }
-            else if(val.second!=0) {
+            else if (val.second!=0) {
               matched = false;
               break;
             }
@@ -137,7 +136,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _sigma[mode]->fill(_ecms);
+          _sigma[mode]->fill(_sqs);
           break;
         }
       }
@@ -156,7 +155,7 @@ namespace Rivet {
     /// @{
     int _pid;
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
