@@ -23,27 +23,28 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // book counters
-      for(unsigned int ix=0;ix<2;++ix)
-	book(_sigma[ix],ix+1, 1, 1);
+      for (size_t ix=0; ix<2; ++ix) {
+        book(_sigma[ix], ix+1, 1, 1);
+      }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for( const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -57,31 +58,33 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if(ntotal==4 && nCount[321]==2 && nCount[-321]==2)
-        _sigma[0]->fill(_ecms);
+      if (ntotal==4 && nCount[321]==2 && nCount[-321]==2) {
+        _sigma[0]->fill(_sqs);
+      }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p :  ufs.particles(Cuts::pid==333)) {
-        if(p.children().empty()) continue;
+        if (p.children().empty()) continue;
         map<long,int> nRes=nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
         // phi K+K-
-        if(ncount==2) {
+        if (ncount==2) {
           bool matched = true;
-          for(auto const & val : nRes) {
-            if(abs(val.first)==321) {
-              if(val.second!=1) {
+          for (const auto& val : nRes) {
+            if (abs(val.first)==321) {
+              if (val.second!=1) {
                 matched = false;
                 break;
               }
             }
-            else if(val.second!=0) {
+            else if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched)
-            _sigma[1]->fill(_ecms);
+          if (matched) {
+            _sigma[1]->fill(_sqs);
+          }
         }
       }
     }
@@ -89,8 +92,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=0;ix<2;++ix)
-        scale(_sigma[ix],crossSection()/ sumOfWeights() /picobarn);
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -99,7 +101,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
