@@ -21,23 +21,20 @@ namespace Rivet {
     void init() {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for (unsigned int ix=0; ix<2; ++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigmaJPsi[ix], 1+ix, 1, 1);
-        for(const string& en : _sigmaJPsi[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+        for (const string& en : _sigmaJPsi[ix].binning().edges<0>()) {
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
@@ -90,8 +87,8 @@ namespace Rivet {
           }
           if (matched) {
             for (unsigned int ix=0; ix<2; ++ix)
-              if (!_ecms[ix].empty()) {
-                _sigmaJPsi[ix]->fill(_ecms[ix]);
+              if (!_sqs[ix].empty()) {
+                _sigmaJPsi[ix]->fill(_sqs[ix]);
                 break;
               }
             }
@@ -112,7 +109,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigmaJPsi[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
