@@ -26,23 +26,23 @@ namespace Rivet {
       book(_nEtaPhi, 1, 1, 1);
 
       for (const string& en : _nEtaPhi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
-          nRes[child.pid()]-=1;
+        if (child.children().empty()) {
+          nRes[child.pid()] -= 1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -58,25 +58,25 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles(Cuts::pid==PID::PHI)) {
-        if(p.children().empty()) continue;
+        if (p.children().empty()) continue;
         map<long,int> nRes=nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
         for (const Particle& p2 : ufs.particles(Cuts::pid==PID::ETAPRIME)) {
-          if(p2.parents()[0].isSame(p)) continue;
+          if (p2.parents()[0].isSame(p)) continue;
           map<long,int> nResB = nRes;
           int ncountB = ncount;
           findChildren(p2,nResB,ncountB);
-          if(ncountB!=0) continue;
+          if (ncountB!=0) continue;
           bool matched2 = true;
-          for(auto const & val : nResB) {
-            if(val.second!=0) {
+          for (const auto& val : nResB) {
+            if (val.second!=0) {
               matched2 = false;
               break;
             }
           }
-          if(matched2) {
-            _nEtaPhi->fill(_ecms);
+          if (matched2) {
+            _nEtaPhi->fill(_sqs);
           }
         }
       }
@@ -94,7 +94,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nEtaPhi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
