@@ -22,34 +22,34 @@ namespace Rivet {
       _pid = getOption<double>("PID", 9030443);
       // projections
       declare(FinalState(), "FS");
+
       // histos
-      unsigned int iloc=0;
-      if      (isCompatibleWithSqrtS(4.226)) iloc=1;
-      else if (isCompatibleWithSqrtS(4.236)) iloc=2;
-      else if (isCompatibleWithSqrtS(4.244)) iloc=3;
-      else if (isCompatibleWithSqrtS(4.258)) iloc=4;
-      if (iloc>0) {
-        for (unsigned int iy=0; iy<2; ++iy) {
-          book(_h[iy], 2, iloc, 1+iy);
-        }
+      size_t ih = 1;
+      for (double eval : { 4.226, 4.236, 4.244, 4.258 }) {
+
+        const string en = toString(round(eval/MeV));
+        if (isCompatibleWithSqrtS(eval))  _sqs = en;
+
+        book(_h[en+"_1"], 2, ih, 1);
+        book(_h[en+"_2"], 2, ih, 2);
+        ++ih;
       }
+
       book(_sigma[0], 1, 1, 1);
-      book(_sigma[1],"TMP/numer", refData<YODA::BinnedEstimate<string>>(1,1,2));
-      book(_sigma[2],"TMP/denom", refData<YODA::BinnedEstimate<string>>(1,1,2));
+      const auto& ref = refData<YODA::BinnedEstimate<string>>(1,1,2);
+      book(_sigma[1],"TMP/numer", ref);
+      book(_sigma[2],"TMP/denom", ref);
       book(_sigma[3], 3, 1, 1);
 
-      for (unsigned int ix=0; ix<3; ++ix) {
+      for (size_t ix=0; ix<3; ++ix) {
         for (const string& en : _sigma[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
+          const double end = stod(en);
           if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+            _edges[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf(_edges[0].empty());
     }
 
 
@@ -68,7 +68,7 @@ namespace Rivet {
           continue;
         }
         bool found=false;
-        for (auto & psi : Jpsi) {
+        for (const auto& psi : Jpsi) {
           // J/psi already in list
           if (fuzzyEquals(psi.momentum(),parent.momentum())) {
             found=true;
@@ -79,29 +79,28 @@ namespace Rivet {
       }
       if (Jpsi.size()!=1 || other.size()!=2) vetoEvent;
       if (other[0].pid()==PID::PI0 && other[1].pid()==PID::PI0) {
-        _sigma[0]->fill(_ecms[0]);
-        if(!_ecms[1].empty()) _sigma[1]->fill(_ecms[1]);
-        if (Jpsi[0].parents()[0].pid()==_pid && !_ecms[2].empty()) _sigma[3]->fill(_ecms[2]);
-        if (_h[0]) {
-          for (unsigned int iy=0; iy<2; ++iy) {
-            _h[0]->fill((Jpsi[0].mom()+other[iy].mom()).mass());
+        _sigma[0]->fill(_edges[0]);
+        if (!_edges[1].empty()) _sigma[1]->fill(_edges[1]);
+        if (Jpsi[0].parents()[0].pid()==_pid && !_edges[2].empty()) _sigma[3]->fill(_edges[2]);
+        if (_sqs != "") {
+          for (size_t iy=0; iy<2; ++iy) {
+            _h[_sqs+"_1"]->fill((Jpsi[0].mom()+other[iy].mom()).mass());
           }
-          _h[1]->fill((other[0].mom()+other[1].mom()).mass());
+          _h[_sqs+"_2"]->fill((other[0].mom()+other[1].mom()).mass());
         }
       }
       else if (other[0].pid()==-other[1].pid() &&
                other[0].abspid()==PID::PIPLUS &&
-               !_ecms[1].empty()) {
-        _sigma[2]->fill(_ecms[1]);
+               !_edges[1].empty()) {
+        _sigma[2]->fill(_edges[1]);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for (unsigned int iy=0; iy<2; ++iy) {
-	      if (_h[iy]) normalize(_h[iy], 1.0, false);
-      }
+
+      normalize(_h, 1.0, false);
       scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
       BinnedEstimatePtr<string> tmp;
       book(tmp,1,1,2);
@@ -114,9 +113,9 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     int _pid;
-    Histo1DPtr _h[2];
+    map<string,Histo1DPtr> _h;
     BinnedHistoPtr<string> _sigma[4];
-    string _ecms[3];
+    string _edges[3], _sqs = "";
     /// @}
 
 
