@@ -27,23 +27,23 @@ namespace Rivet {
       book(_c_Ds    , 1, 1, 1);
       book(_c_DsStar, 2, 1, 1);
       for (const string& en : _c_Ds.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for(const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle &child : p.children()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -58,15 +58,16 @@ namespace Rivet {
         ++ntotal;
       }
       // unstable charm analysis
-      Particles ds = apply<UnstableParticles>(event, "UFS").particles(Cuts::abspid==431 or Cuts::abspid==433 or
+      Particles ds = apply<UnstableParticles>(event, "UFS").particles(Cuts::abspid==431 or
+                                                                      Cuts::abspid==433 or
                                                                       Cuts::abspid==20433);
-      for(unsigned int ix=0;ix<ds.size();++ix) {
+      for (size_t ix=0; ix<ds.size(); ++ix) {
         const Particle& p1 = ds[ix];
         int id1 = abs(p1.pid());
         // check fs
         bool fs = true;
-        for (const Particle & child : p1.children()) {
-          if(child.pid()==p1.pid()) {
+        for (const Particle& child : p1.children()) {
+          if (child.pid()==p1.pid()) {
             fs = false;
             break;
           }
@@ -79,42 +80,41 @@ namespace Rivet {
         bool matched=false;
         int sign = p1.pid()/id1;
         // loop over the other fs particles
-        for(unsigned int iy=ix+1;iy<ds.size();++iy) {
+        for (size_t iy=ix+1; iy<ds.size(); ++iy) {
           const Particle& p2 = ds[iy];
           fs = true;
-          for (const Particle & child : p2.children()) {
-            if(child.pid()==p2.pid()) {
+          for (const Particle& child : p2.children()) {
+            if (child.pid()==p2.pid()) {
               fs = false;
               break;
             }
           }
-          if(!fs) continue;
-          if(p2.pid()/abs(p2.pid())==sign) continue;
+          if (!fs) continue;
+          if (p2.pid()/abs(p2.pid())==sign) continue;
           int id2 = abs(p2.pid());
-          if(!p2.parents().empty() && p2.parents()[0].pid()==p1.pid())
-            continue;
+          if (!p2.parents().empty() && p2.parents()[0].pid()==p1.pid()) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2!=0) continue;
+          if (ncount2!=0) continue;
           matched=true;
-          for(auto const & val : nRes2) {
-            if(val.second!=0) {
+          for (const auto& val : nRes2) {
+            if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            if((id1==431 && id2==20433) || (id1==20433 && id2==421)) {
-              _c_Ds->fill(_ecms);
+          if (matched) {
+            if ((id1==431 && id2==20433) || (id1==20433 && id2==421)) {
+              _c_Ds->fill(_sqs);
             }
-            else if((id1==433 && id2==20433) || (id1==20433 && id2==433)) {
-              _c_DsStar->fill(_ecms);
+            else if ((id1==433 && id2==20433) || (id1==20433 && id2==433)) {
+              _c_DsStar->fill(_sqs);
             }
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -132,7 +132,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_Ds,_c_DsStar;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
