@@ -5,7 +5,7 @@
 namespace Rivet {
 
 
-  /// @brief 
+  /// @brief ee -> mumu cross section between 3.8 and 4.6 GeV
   class BESIII_2020_I1808875 : public Analysis {
   public:
 
@@ -22,13 +22,12 @@ namespace Rivet {
       declare(FinalState(), "FS");
       book(_sigma_muons, 1,1,1);
       for (const string& en : _sigma_muons.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -44,7 +43,7 @@ namespace Rivet {
       }
       // mu+mu- + photons
       if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
-        _sigma_muons->fill(_ecms);
+        _sigma_muons->fill(_sqs);
       }
     }
 
@@ -60,7 +59,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
