@@ -24,25 +24,24 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_numOmegaPi, 2, 1, 1);
       book(_nOmegaEta,  1, 1, 1);
-
       for (const string& en : _numOmegaPi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -57,26 +56,26 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles(Cuts::pid==223)) {
-        if(p.children().empty()) continue;
+        if (p.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
         // check for omega pi0
         bool matched = true;
-        for(auto const & val : nRes) {
-          if(val.first==111) {
-            if(val.second!=1) {
+        for (const auto& val : nRes) {
+          if (val.first==111) {
+            if (val.second!=1) {
               matched = false;
               break;
             }
           }
-          else if(val.second!=0) {
+          else if (val.second!=0) {
             matched = false;
             break;
           }
         }
-        if(matched) {
-          _numOmegaPi->fill(_ecms);
+        if (matched) {
+          _numOmegaPi->fill(_sqs);
           break;
         }
         // now for omega eta
@@ -84,27 +83,27 @@ namespace Rivet {
           map<long,int> nResB = nRes;
           int ncountB = ncount;
           findChildren(p2,nResB,ncountB);
-          if(ncountB!=0) continue;
+          if (ncountB!=0) continue;
           matched = true;
-          for(auto const & val : nResB) {
-            if(val.second!=0) {
+          for (const auto& val : nResB) {
+            if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            _nOmegaEta->fill(_ecms);
+          if (matched) {
+            _nOmegaEta->fill(_sqs);
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn;
+      const double fact = crossSection()/ sumOfWeights() /picobarn;
       scale(_nOmegaEta ,fact);
       scale(_numOmegaPi,fact);
     }
@@ -115,7 +114,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nOmegaEta,_numOmegaPi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
