@@ -25,23 +25,23 @@ namespace Rivet {
       // histograms
       book(_nPiPiEta, 1, 1, 1);
       for (const string& en : _nPiPiEta.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for(const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  nRes[child.pid()]-=1;
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          nRes[child.pid()]-=1;
+          --ncount;
+        }
+        else {
+          findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -52,30 +52,30 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles(Cuts::pid==331)) {
-	if(p.children().empty()) continue;
-	map<long,int> nRes = nCount;
-	int ncount = ntotal;
-	findChildren(p,nRes,ncount);
-	if(ncount!=2) continue;
-	bool matched = true;
-	for(auto const & val : nRes) {
-	  if(abs(val.first)==211) {
-	    if(val.second!=1) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  else if(val.second!=0) {
-	    matched = false;
-	    break;
-	  }
-	}
-	if(matched) _nPiPiEta->fill(_ecms);
+        if (p.children().empty()) continue;
+        map<long,int> nRes = nCount;
+        int ncount = ntotal;
+        findChildren(p,nRes,ncount);
+        if (ncount!=2) continue;
+        bool matched = true;
+        for (const auto& val : nRes) {
+          if (abs(val.first)==211) {
+            if (val.second!=1) {
+              matched = false;
+              break;
+            }
+          }
+          else if (val.second!=0) {
+            matched = false;
+            break;
+          }
+        }
+        if (matched) _nPiPiEta->fill(_sqs);
       }
     }
 
@@ -90,7 +90,7 @@ namespace Rivet {
     /// @name Histograms
     ///@{
     BinnedHistoPtr<string> _nPiPiEta;
-    string _ecms;
+    string _sqs = "";
     ///@}
 
 
