@@ -25,23 +25,23 @@ namespace Rivet {
       book(_nEta,   1,1,1);
       book(_nOmega, 2,1,1);
       for (const string& en : _nOmega.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  nRes[child.pid()]-=1;
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          nRes[child.pid()]-=1;
+          --ncount;
+        }
+        else {
+          findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -52,42 +52,44 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       // find the eta/omega
       const FinalState& ufs = apply<UnstableParticles>(event, "UFS");
-      for(const Particle& p : ufs.particles(Cuts::pid==PID::ETA or Cuts::pid==PID::OMEGA)) {
-	map<long,int> nRes = nCount;
-	int ncount = ntotal;
-	findChildren(p,nRes,ncount);
-	bool matched=true;
-	for(auto const & val : nRes) {
-	  if(abs(val.first)==PID::PROTON) {
-	    if(val.second!=1) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  else if(val.second!=0) {
-	    matched = false;
-	    break;
-	  }
-	}
-	if(matched) {
-	  if(p.pid()==PID::ETA)
-	    _nEta->fill(_ecms);
-	  else
-	    _nOmega->fill(_ecms);
-	  break;
-	}
+      for (const Particle& p : ufs.particles(Cuts::pid==PID::ETA or Cuts::pid==PID::OMEGA)) {
+        map<long,int> nRes = nCount;
+        int ncount = ntotal;
+        findChildren(p,nRes,ncount);
+        bool matched=true;
+        for (const auto& val : nRes) {
+          if (abs(val.first)==PID::PROTON) {
+            if (val.second!=1) {
+              matched = false;
+              break;
+            }
+          }
+          else if (val.second!=0) {
+            matched = false;
+            break;
+          }
+        }
+        if (matched) {
+          if (p.pid()==PID::ETA) {
+            _nEta->fill(_sqs);
+          }
+          else {
+            _nOmega->fill(_sqs);
+          }
+          break;
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn;
+      const double fact = crossSection()/ sumOfWeights() /picobarn;
       scale(_nEta  ,fact);
       scale(_nOmega,fact);
     }
@@ -98,7 +100,7 @@ namespace Rivet {
     /// @name Histograms
     ///@{
     BinnedHistoPtr<string> _nEta,_nOmega;
-    string _ecms;
+    string _sqs = "";
     ///@}
 
 
