@@ -23,7 +23,7 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      book(_nproton, "TMP/proton");
+      book(_nproton, "TMP/proton", refData(1,1,1));
     }
 
 
@@ -34,32 +34,16 @@ namespace Rivet {
       for (const Particle& p : fs.particles()) {
 	if(abs(p.pid())!=PID::PROTON) vetoEvent;
       }
-      _nproton->fill();
+      _nproton->fill(sqrtS()/GeV);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double sigma = _nproton->val();
-      double error = _nproton->err();
-      sigma *= crossSection()/ sumOfWeights() /picobarn;
-      error *= crossSection()/ sumOfWeights() /picobarn; 
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr  mult;
+      scale(_nproton, crossSection()/ sumOfWeights() /picobarn);
+      Estimate1DPtr  mult;
       book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      barchart(_nproton,mult);
     }
 
     ///@}
@@ -67,7 +51,7 @@ namespace Rivet {
 
     /// @name Histograms
     ///@{
-    CounterPtr _nproton;
+    Histo1DPtr _nproton;
     ///@}
 
 
