@@ -24,16 +24,15 @@ namespace Rivet {
       book(_sigma, 1, 1, 1);
 
       for (const string& en : _sigma.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -86,7 +85,7 @@ namespace Rivet {
             }
           }
           if (matched) {
-            _sigma->fill(_ecms);
+            _sigma->fill(_sqs);
             break;
           }
         }
@@ -106,7 +105,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
