@@ -25,24 +25,23 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nPhiEta, 1, 1, 1);
       for (const string& en : _nPhiEta.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
-
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  nRes[child.pid()]-=1;
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+        if (child.children().empty()) {
+          nRes[child.pid()]-=1;
+          --ncount;
+        }
+        else {
+	        findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -54,33 +53,33 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
 
       // loop over eta mesons
       for (const Particle& p : ufs.particles(Cuts::pid==221)) {
-	if(p.children().empty()) continue;
-	map<long,int> nRes = nCount;
-	int ncount = ntotal;
-	findChildren(p,nRes,ncount);
-	// loop over phi mesons
-	for (const Particle& p2 : ufs.particles(Cuts::pid==333)) {
-	  if(p2.parents()[0].isSame(p)) continue;
-	  map<long,int> nResB = nRes;
-	  int ncountB = ncount;
-	  findChildren(p2,nResB,ncountB);
-	  if(ncountB!=0) continue;
-	  bool matched = true;
-	  for(auto const & val : nResB) {
-	    if(val.second!=0) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  if(matched) _nPhiEta->fill(_ecms);
-	}
+        if (p.children().empty()) continue;
+        map<long,int> nRes = nCount;
+        int ncount = ntotal;
+        findChildren(p,nRes,ncount);
+        // loop over phi mesons
+        for (const Particle& p2 : ufs.particles(Cuts::pid==333)) {
+          if (p2.parents()[0].isSame(p)) continue;
+          map<long,int> nResB = nRes;
+          int ncountB = ncount;
+          findChildren(p2,nResB,ncountB);
+          if (ncountB!=0) continue;
+          bool matched = true;
+          for (const auto& val : nResB) {
+            if (val.second!=0) {
+              matched = false;
+              break;
+            }
+          }
+          if (matched) _nPhiEta->fill(_sqs);
+        }
       }
     }
 
@@ -96,7 +95,7 @@ namespace Rivet {
     /// @name Histograms
     ///@{
     BinnedHistoPtr<string> _nPhiEta;
-    string _ecms;
+    string _sqs = "";
     ///@}
 
 
