@@ -25,13 +25,12 @@ namespace Rivet {
       // Book histograms
       book(_nKSKL, 1, 1, 1);
       for (const string& en : _nKSKL.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
+        const double end = stod(en)*GeV;
         if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -42,12 +41,13 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
 
-      if(ntotal==2 && nCount[130]==1 && nCount[310]==1)
-	_nKSKL->fill(_ecms);
+      if (ntotal==2 && nCount[130]==1 && nCount[310]==1) {
+        _nKSKL->fill(_sqs);
+      }
     }
 
 
@@ -62,7 +62,7 @@ namespace Rivet {
     /// @name Histograms
     ///@{
     BinnedHistoPtr<string> _nKSKL;
-    string _ecms;
+    string _sqs = "";
     ///@}
 
 
