@@ -21,16 +21,15 @@ namespace Rivet {
 
       // Initialise and register projections
       declare(UnstableParticles(), "UFS");
-      book(_c_kaons   , "TMP/nK", refData<YODA::BinnedEstimate<string>>(1, 1, 1));
+      book(_c_kaons, "TMP/nK", refData<YODA::BinnedEstimate<string>>(1, 1, 1));
 
       for (const string& en : _c_kaons.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -38,7 +37,7 @@ namespace Rivet {
     void analyze(const Event& event) {
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       unsigned int count = ufs.particles(Cuts::pid==310).size();
-      _c_kaons->fill(_ecms,count);
+      _c_kaons->fill(_sqs,count);
     }
 
 
@@ -56,7 +55,7 @@ namespace Rivet {
     /// @name Histograms
     ///@{
     BinnedProfilePtr<string> _c_kaons;
-    string _ecms;
+    string _sqs = "";
     ///@}
 
 
