@@ -21,21 +21,20 @@ namespace Rivet {
     void init() {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::pid==20443 || Cuts::pid==445), "UFS");
-      for (unsigned int ix=0; ix<2; ++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigmaChi[ix], 1+ix, 1, 1);
       }
 
       for (const string& en : _sigmaChi[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -79,10 +78,10 @@ namespace Rivet {
         }
         if (matched) {
           if (p.pid()==20443) {
-            _sigmaChi[0]->fill(_ecms);
+            _sigmaChi[0]->fill(_sqs);
           }
           else {
-            _sigmaChi[1]->fill(_ecms);
+            _sigmaChi[1]->fill(_sqs);
           }
           break;
         }
@@ -101,7 +100,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigmaChi[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
