@@ -21,24 +21,23 @@ namespace Rivet {
 
       // Initialise and register projections
       declare(UnstableParticles(), "UFS");
-      book(_c_psi   , 1, 1, 1);
+      book(_c_psi, 1, 1, 1);
 
       for (const string& en : _c_psi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
-      unsigned int count = ufs.particles(Cuts::pid==443).size();
-      _c_psi->fill(_ecms,count);
+      size_t count = ufs.particles(Cuts::pid==443).size();
+      _c_psi->fill(_sqs,count);
     }
 
 
@@ -53,7 +52,7 @@ namespace Rivet {
     /// @name Histograms
     ///@{
     BinnedHistoPtr<string> _c_psi;
-    string _ecms;
+    string _sqs = "";
     ///@}
 
 
