@@ -23,23 +23,23 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nPsi2s, 1, 1, 3);
       for (const string& en : _nPsi2s.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  --nRes[child.pid()];
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+        if (child.children().empty()) {
+          --nRes[child.pid()];
+          --ncount;
+        }
+        else {
+          findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -50,37 +50,37 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	if(p.children().empty()) continue;
-	// find the psi(2S)
-	if(p.pid()==100443) {
-	  map<long,int> nRes = nCount;
-	  int ncount = ntotal;
-	  findChildren(p,nRes,ncount);
-	  // omega pi+pi-
-	  if(ncount!=2) continue;
-	  bool matched = true;
-	  for(auto const & val : nRes) {
-	    if(abs(val.first)==211) {
-	      if(val.second !=1) {
-		matched = false;
-		break;
-	      }
-	    }
-	    else if(val.second!=0) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  if(matched) {
-	    _nPsi2s->fill(_ecms);
-	    break;
-	  }
-	}
+        if (p.children().empty()) continue;
+        // find the psi(2S)
+        if (p.pid()==100443) {
+          map<long,int> nRes = nCount;
+          int ncount = ntotal;
+          findChildren(p,nRes,ncount);
+          // omega pi+pi-
+          if (ncount!=2) continue;
+          bool matched = true;
+          for (const auto& val : nRes) {
+            if (abs(val.first)==211) {
+              if (val.second !=1) {
+                matched = false;
+                break;
+              }
+            }
+            else if (val.second!=0) {
+              matched = false;
+              break;
+            }
+          }
+          if (matched) {
+            _nPsi2s->fill(_sqs);
+            break;
+          }
+        }
       }
     }
 
@@ -96,7 +96,7 @@ namespace Rivet {
     /// @name Histograms
     ///@{
     BinnedHistoPtr<string> _nPsi2s;
-    string _ecms;
+    string _sqs = "";
     ///@}
 
 
