@@ -26,24 +26,23 @@ namespace Rivet {
       book(_nneutron, 1, 1, 1);
 
       for (const string& en : _nneutron.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p :  fs.particles()) {
-	if(abs(p.pid())!=PID::NEUTRON) vetoEvent;
+        if (p.abspid()!=PID::NEUTRON) vetoEvent;
       }
-      _nneutron->fill(_ecms);
+      _nneutron->fill(_sqs);
     }
 
 
@@ -58,7 +57,7 @@ namespace Rivet {
     /// @name Histograms
     ///@{
     BinnedHistoPtr<string> _nneutron;
-    string _ecms;
+    string _sqs = "";
     ///@}
 
 
