@@ -23,26 +23,25 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       book(_numOmegaPiPi , 1, 1, 1);
- 
+
       for (const string& en : _numOmegaPiPi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for(const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  --nRes[child.pid()];
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle &child : p.children()) {
+        if (child.children().empty()) {
+          --nRes[child.pid()];
+          --ncount;
+        }
+        else {
+          findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -52,33 +51,33 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles(Cuts::pid==223)) {
-     	if(p.children().empty()) continue;
-	map<long,int> nRes = nCount;
-	int ncount = ntotal;
-	findChildren(p,nRes,ncount);
-	if(ncount!=2) continue;	    
-	bool matched = true;
-	for(auto const & val : nRes) {
-	  if(abs(val.first)==111) {
-	    if(val.second !=2) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  else if(val.second!=0) {
-	    matched = false;
-	    break;
-	  }
-	}
-	if(matched) {
-	  _numOmegaPiPi->fill(_ecms);
-	  break;
-	}
+     	if (p.children().empty()) continue;
+        map<long,int> nRes = nCount;
+        int ncount = ntotal;
+        findChildren(p,nRes,ncount);
+        if (ncount!=2) continue;
+        bool matched = true;
+        for (const auto& val : nRes) {
+          if (abs(val.first)==111) {
+            if (val.second !=2) {
+              matched = false;
+              break;
+            }
+          }
+          else if(val.second!=0) {
+            matched = false;
+            break;
+          }
+        }
+        if (matched) {
+          _numOmegaPiPi->fill(_sqs);
+          break;
+        }
       }
     }
 
@@ -94,7 +93,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _numOmegaPiPi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
