@@ -25,16 +25,15 @@ namespace Rivet {
       book(_nDSS, 1,1,3);
       book(_nDS,  2,1,3);
       for (const string& en : _nDS.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -59,9 +58,9 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
 
-      for (unsigned int ix=0; ix<ufs.particles().size(); ++ix) {
+      for (size_t ix=0; ix<ufs.particles().size(); ++ix) {
         const Particle& p1 = ufs.particles()[ix];
-        if(abs(p1.pid())!=413) continue;
+        if (p1.abspid()!=413) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p1,nRes,ncount);
@@ -91,8 +90,8 @@ namespace Rivet {
           }
         }
         if (matched) {
-          if (sign==411)     _nDS->fill(_ecms);
-          else if(sign==413) _nDSS->fill(_ecms);
+          if (sign==411)     _nDS->fill(_sqs);
+          else if(sign==413) _nDSS->fill(_sqs);
         }
       }
     }
@@ -109,7 +108,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nDSS,_nDS;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
