@@ -24,18 +24,17 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_sigma, 1,1,1);
       for (const string& en : _sigma.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
@@ -56,37 +55,36 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& chi : ufs.particles(Cuts::pid==20443)) {
-	if(chi.children().empty()) continue;
-	map<long,int> nRes=nCount;
-	int ncount = ntotal;
-	findChildren(chi,nRes,ncount);
-	if(ncount!=3) continue;
-	bool matched = true;
-	for(auto const & val : nRes) {
-	  if(abs(val.first)==211) {
-	    if(val.second!=1) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  else if(abs(val.first)==22) {
-	    if(val.second!=1) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  else if(val.second!=0) {
-	    matched = false;
-	    break;
-	  }
-	}
-	if(!matched) continue;
-	if(chi.parents().empty()) continue;
-	Particle psi = chi.parents()[0];
-	if(psi.pid()!=20445 || psi.children().size()!=2) continue;
-	if(psi.children()[0].pid()==PID::PHOTON ||
-	   psi.children()[1].pid()==PID::PHOTON) {
-          _sigma->fill(_ecms);
+        if (chi.children().empty()) continue;
+        map<long,int> nRes=nCount;
+        int ncount = ntotal;
+        findChildren(chi,nRes,ncount);
+        if (ncount!=3) continue;
+        bool matched = true;
+        for (const auto& val : nRes) {
+          if (abs(val.first)==211) {
+            if (val.second!=1) {
+              matched = false;
+              break;
+            }
+          }
+          else if (abs(val.first)==22) {
+            if (val.second!=1) {
+              matched = false;
+              break;
+            }
+          }
+          else if (val.second!=0) {
+            matched = false;
+            break;
+          }
+        }
+        if (!matched) continue;
+        if (chi.parents().empty()) continue;
+        Particle psi = chi.parents()[0];
+        if (psi.pid()!=20445 || psi.children().size()!=2) continue;
+        if (psi.children()[0].pid()==PID::PHOTON || psi.children()[1].pid()==PID::PHOTON) {
+          _sigma->fill(_sqs);
           break;
         }
       }
@@ -104,7 +102,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
