@@ -24,16 +24,15 @@ namespace Rivet {
       book(_sigmaPsi, 1, 1, 1);
 
       for (const string& en : _sigmaPsi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -77,7 +76,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _sigmaPsi->fill(_ecms);
+          _sigmaPsi->fill(_sqs);
           break;
         }
       }
@@ -95,7 +94,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigmaPsi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
