@@ -96,7 +96,7 @@ namespace Rivet {
 	      else {
 		Xi    = p2;
 		XiBar = p;
-	      }	
+	      }
        	      break;
        	    }
        	  }
@@ -144,30 +144,30 @@ namespace Rivet {
       _h_cTheta->fill(cosX);
       _wsum->fill();
     }
-    
+
     pair<double,pair<double,double> > calcAlpha0(Histo1DPtr hist) {
       if(hist->numEntries()==0.) return make_pair(0.,make_pair(0.,0.));
       double d = 3./(pow(hist->xMax(),3)-pow(hist->xMin(),3));
       double c = 3.*(hist->xMax()-hist->xMin())/(pow(hist->xMax(),3)-pow(hist->xMin(),3));
       double sum1(0.),sum2(0.),sum3(0.),sum4(0.),sum5(0.);
-      for (auto bin : hist->bins() ) {
-       	double Oi = bin.area();
-	if(Oi==0.) continue;
-	double a =  d*(bin.xMax() - bin.xMin());
-	double b = d/3.*(pow(bin.xMax(),3) - pow(bin.xMin(),3));
-       	double Ei = bin.areaErr();
-	sum1 +=   a*Oi/sqr(Ei);
-	sum2 +=   b*Oi/sqr(Ei);
-	sum3 += sqr(a)/sqr(Ei);
-	sum4 += sqr(b)/sqr(Ei);
-	sum5 +=    a*b/sqr(Ei);
+      for (const auto& bin : hist->bins() ) {
+       	double Oi = bin.sumW();
+        if(Oi==0.) continue;
+        double a =  d*(bin.xMax() - bin.xMin());
+        double b = d/3.*(pow(bin.xMax(),3) - pow(bin.xMin(),3));
+        double Ei = bin.errW();
+        sum1 +=   a*Oi/sqr(Ei);
+        sum2 +=   b*Oi/sqr(Ei);
+        sum3 += sqr(a)/sqr(Ei);
+        sum4 += sqr(b)/sqr(Ei);
+        sum5 +=    a*b/sqr(Ei);
       }
       // calculate alpha
       double alpha = (-c*sum1 + sqr(c)*sum2 + sum3 - c*sum5)/(sum1 - c*sum2 + c*sum4 - sum5);
       // and error
       double cc = -pow((sum3 + sqr(c)*sum4 - 2*c*sum5),3);
       double bb = -2*sqr(sum3 + sqr(c)*sum4 - 2*c*sum5)*(sum1 - c*sum2 + c*sum4 - sum5);
-      double aa =  sqr(sum1 - c*sum2 + c*sum4 - sum5)*(-sum3 - sqr(c)*sum4 + sqr(sum1 - c*sum2 + c*sum4 - sum5) + 2*c*sum5);      
+      double aa =  sqr(sum1 - c*sum2 + c*sum4 - sum5)*(-sum3 - sqr(c)*sum4 + sqr(sum1 - c*sum2 + c*sum4 - sum5) + 2*c*sum5);
       double dis = sqr(bb)-4.*aa*cc;
       if(dis>0.) {
 	dis = sqrt(dis);
@@ -177,26 +177,26 @@ namespace Rivet {
 	return make_pair(alpha,make_pair(0.,0.));
       }
     }
-    
+
     pair<double,double> calcCoeff(unsigned int imode,Histo1DPtr hist) {
       if(hist->numEntries()==0.) return make_pair(0.,0.);
       double sum1(0.),sum2(0.);
-      for (auto bin : hist->bins() ) {
-	double Oi = bin.area();
-	if(Oi==0.) continue;
-	double ai(0.),bi(0.);
-	if(imode==0) {
-	  bi = (pow(1.-sqr(bin.xMin()),1.5) - pow(1.-sqr(bin.xMax()),1.5))/3.;
-	}
-	else if(imode>=2 && imode<=4) {
-	  bi = ( pow(bin.xMin(),3)*( -5. + 3.*sqr(bin.xMin()))  +
-		 pow(bin.xMax(),3)*(  5. - 3.*sqr(bin.xMax())))/15.;
-	}
-	else
-	  assert(false);
-	double Ei = bin.areaErr();
-	sum1 += sqr(bi/Ei);
-	sum2 += bi/sqr(Ei)*(Oi-ai);
+      for (const auto& bin : hist->bins() ) {
+        double Oi = bin.sumW();
+        if(Oi==0.) continue;
+        double ai(0.),bi(0.);
+        if(imode==0) {
+          bi = (pow(1.-sqr(bin.xMin()),1.5) - pow(1.-sqr(bin.xMax()),1.5))/3.;
+        }
+        else if(imode>=2 && imode<=4) {
+          bi = ( pow(bin.xMin(),3)*( -5. + 3.*sqr(bin.xMin()))  +
+           pow(bin.xMax(),3)*(  5. - 3.*sqr(bin.xMax())))/15.;
+        }
+        else
+          assert(false);
+        double Ei = bin.errW();
+        sum1 += sqr(bi/Ei);
+        sum2 += bi/sqr(Ei)*(Oi-ai);
       }
       return make_pair(sum2/sum1,sqrt(1./sum1));
     }
@@ -204,14 +204,14 @@ namespace Rivet {
     pair<double,double> calcAlpha(Histo1DPtr hist) {
       if(hist->numEntries()==0.) return make_pair(0.,0.);
       double sum1(0.),sum2(0.);
-      for (auto bin : hist->bins() ) {
-	double Oi = bin.area();
-	if(Oi==0.) continue;
-	double ai = 0.5*(bin.xMax()-bin.xMin());
-	double bi = 0.5*ai*(bin.xMax()+bin.xMin());
-	double Ei = bin.areaErr();
-	sum1 += sqr(bi/Ei);
-	sum2 += bi/sqr(Ei)*(Oi-ai);
+      for (const auto& bin : hist->bins() ) {
+        double Oi = bin.sumW();
+        if(Oi==0.) continue;
+        double ai = 0.5*(bin.xMax()-bin.xMin());
+        double bi = 0.5*ai*(bin.xMax()+bin.xMin());
+        double Ei = bin.errW();
+        sum1 += sqr(bi/Ei);
+        sum2 += bi/sqr(Ei)*(Oi-ai);
       }
       return make_pair(sum2/sum1,sqrt(1./sum1));
     }
@@ -226,10 +226,9 @@ namespace Rivet {
       scale(_h_T5,1./ *_wsum);
       // calculate alpha0
       pair<double,pair<double,double> > alpha0 = calcAlpha0(_h_cTheta);
-      Scatter2DPtr _h_alpha0;
+      Estimate0DPtr _h_alpha0;
       book(_h_alpha0,2,1,1);
-      _h_alpha0->addPoint(0.5, alpha0.first, make_pair(0.5,0.5),
-			  make_pair(alpha0.second.first,alpha0.second.second) );
+      _h_alpha0->set(alpha0.first, make_pair(alpha0.second.first,alpha0.second.second));
       double s2 = -1. + sqr(alpha0.first);
       double s3 = 3 + alpha0.first;
       double s1 = sqr(s3);
@@ -277,15 +276,13 @@ namespace Rivet {
 														     8*(c_T3.first*c_T4.first*alpha0.second.second +  s3*c_T4.first*c_T3.second +  s3*c_T3.first*c_T4.second)* s1*s5*s6))/
 													    (4* pow(3 + alpha0.first,3)* pow(c_T3.first,3)* pow(c_T4.first,3) -  9*s2*s3*c_T3.first*c_T4.first*s4)))/
 		      (disc + 2*s1*s5*s6)))/(2.*pow(c_T3.first,2));
-      Scatter2DPtr _h_alphaM;
+      Estimate0DPtr _h_alphaM;
       book(_h_alphaM,2,1,3);
-      _h_alphaM->addPoint(0.5, aM, make_pair(0.5,0.5),
-			  make_pair(-aM_M , -aM_P ) );
-      
-      Scatter2DPtr _h_alphaP;
+      _h_alphaM->set(aM, make_pair(-aM_M , -aM_P ));
+
+      Estimate0DPtr _h_alphaP;
       book(_h_alphaP,2,1,4);
-      _h_alphaP->addPoint(0.5, aP, make_pair(0.5,0.5),
-			  make_pair(-aP_M , -aP_P  ) );
+      _h_alphaP->set(aP, make_pair(-aP_M , -aP_P));
       // now for Delta
       double sDelta = (-2.*(3. + alpha0.first)*c_T3.first)/(aM*sqrt(1 - sqr(alpha0.first)));
       double cDelta = (-3*(3 + alpha0.first)*c_T2.first)/(aM*aP*sqrt(1 - sqr(alpha0.first)));
@@ -299,9 +296,9 @@ namespace Rivet {
 	(pow(1 - pow(alpha0.first,2),1.5)*pow(c_T4.first,3)*pow(-((disc + 2*s1*s5*s6)/   (s2*s6)),1.5)*(-9*s2*s4 + 4*s1*s5*s6));
       ds_P /= sqrt(1.-sqr(sDelta));
       ds_M /= sqrt(1.-sqr(sDelta));
-      Scatter2DPtr _h_sin;
+      Estimate0DPtr _h_sin;
       book(_h_sin,2,1,2);
-      _h_sin->addPoint(0.5, Delta, make_pair(0.5,0.5), make_pair( -ds_P, -ds_M) );
+      _h_sin->set(Delta, make_pair( -ds_P, -ds_M));
     }
 
     /// @}
