@@ -22,23 +22,20 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for (unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigma[ix], ix+1, 1, 1);
         for (const string& en : _sigma[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
-    void findChildren(const Particle& p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
@@ -84,8 +81,8 @@ namespace Rivet {
               break;
             }
           }
-          if(matched) {
-            _sigma[0]->fill(_ecms[0]);
+          if (matched) {
+            _sigma[0]->fill(_sqs[0]);
             if (!Dm.parents().empty() && !Dp.parents().empty()) {
               // see if D+ from psi3
               Particle parent1=Dp;
@@ -102,13 +99,13 @@ namespace Rivet {
               }
               if (parent2.pid()!=447) break;
               if (fuzzyEquals(parent1.momentum(),parent2.momentum())) {
-                _sigma[1]->fill(_ecms[1]);
+                _sigma[1]->fill(_sqs[1]);
               }
             }
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -124,7 +121,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
