@@ -23,24 +23,21 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       book(_sigma[0], 1, 1, 1);
-      for (unsigned int ix=1; ix<7; ++ix) {
+      for (size_t ix=1; ix<7; ++ix) {
         book(_sigma[ix], 2, 1, ix);
         if (ix < 3) {
           for (const string& en : _sigma[ix-1].binning().edges<0>()) {
-            const double end = std::stod(en)*GeV;
-            if (isCompatibleWithSqrtS(end)) {
-              _ecms[ix-1] = en;
-              break;
+            const double eval = stod(en)*GeV;
+            if (isCompatibleWithSqrtS(eval)) {
+              _sqs[ix-1] = en; break;
             }
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
-    void findChildren(const Particle& p,map<long,int>& nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -83,13 +80,13 @@ namespace Rivet {
               break;
             }
           }
-          if (hasOmegaPiPi) _sigma[0]->fill(_ecms[0]);
+          if (hasOmegaPiPi) _sigma[0]->fill(_sqs[0]);
         }
         // now omega + second resonance
         for (const Particle& p2 : ufs.particles(Cuts::pid==9000221||
-                  Cuts::pid==9010221||
-                  Cuts::pid==10221||
-                  Cuts::pid==225)) {
+                                                Cuts::pid==9010221||
+                                                Cuts::pid==10221||
+                                                Cuts::pid==225)) {
           if (p2.children().empty()) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
@@ -103,10 +100,10 @@ namespace Rivet {
             }
           }
           if (hasResonance) {
-            if      (p2.pid()==9000221 ) _sigma[1]->fill(_ecms[1]);
-            else if (p2.pid()==9010221 ) _sigma[2]->fill(_ecms[1]);
-            else if (p2.pid()==10221   ) _sigma[3]->fill(_ecms[1]);
-            else if (p2.pid()==225     ) _sigma[4]->fill(_ecms[1]);
+            if      (p2.pid()==9000221 ) _sigma[1]->fill(_sqs[1]);
+            else if (p2.pid()==9010221 ) _sigma[2]->fill(_sqs[1]);
+            else if (p2.pid()==10221   ) _sigma[3]->fill(_sqs[1]);
+            else if (p2.pid()==225     ) _sigma[4]->fill(_sqs[1]);
             break;
           }
         }
@@ -119,7 +116,7 @@ namespace Rivet {
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
-        if(ncount!=1) continue;
+        if (ncount!=1) continue;
         int ipi = -p.pid()/p.abspid()*211;
         hasResonance=true;
         for (const auto& val : nRes) {
@@ -129,17 +126,17 @@ namespace Rivet {
               break;
             }
           }
-          else if(val.second!=0) {
+          else if (val.second!=0) {
             hasResonance = false;
             break;
           }
         }
         if (hasResonance) {
-          _sigma[5]->fill(_ecms[1]);
+          _sigma[5]->fill(_sqs[1]);
           break;
         }
       }
-      if (hasOmegaPiPi && !hasResonance) _sigma[6]->fill(_ecms[1]);
+      if (hasOmegaPiPi && !hasResonance) _sigma[6]->fill(_sqs[1]);
     }
 
 
@@ -154,7 +151,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[7];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
