@@ -24,16 +24,15 @@ namespace Rivet {
       declare(UnstableParticles(Cuts::pid==331 or Cuts::pid==333), "UFS");
       book(_sigma,1,1,1);
       for (const string& en : _sigma.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -56,29 +55,29 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       // loop over any phi mesons
-      for(const Particle& phi : ufs.particles(Cuts::pid==333)) {
+      for (const Particle& phi : ufs.particles(Cuts::pid==333)) {
         bool matched = false;
-        if(phi.children().empty()) continue;
+        if (phi.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(phi,nRes,ncount);
-        for(const Particle & chi : ufs.particles(Cuts::pid==331)) {
-          if(chi.children().empty()) continue;
+        for (const Particle & chi : ufs.particles(Cuts::pid==331)) {
+          if (chi.children().empty()) continue;
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(chi,nRes2,ncount2);
           matched = true;
-          for(auto const & val : nRes2) {
-            if(val.second!=0) {
+          for (const auto& val : nRes2) {
+            if (val.second!=0) {
               matched = false;
               break;
             }
           }
           if (!matched) continue;
-          _sigma->fill(_ecms);
+          _sigma->fill(_sqs);
           break;
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -94,7 +93,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
