@@ -22,20 +22,19 @@ namespace Rivet {
       // projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for (unsigned int ix=0; ix<2; ++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigma[ix],1,1,1+ix);
       }
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle & p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -58,9 +57,9 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       // loop over any phi mesons
-      for (const Particle & phi : ufs.particles(Cuts::pid==333)) {
+      for (const Particle& phi : ufs.particles(Cuts::pid==333)) {
         bool matched = false;
-        if(phi.children().empty()) continue;
+        if (phi.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(phi,nRes,ncount);
@@ -77,8 +76,8 @@ namespace Rivet {
             }
           }
           if (!matched) continue;
-          if     (chi.pid()==20443) _sigma[0]->fill(_ecms);
-          else if(chi.pid()==  445) _sigma[1]->fill(_ecms);
+          if     (chi.pid()==20443) _sigma[0]->fill(_sqs);
+          else if(chi.pid()==  445) _sigma[1]->fill(_sqs);
           break;
         }
         if (matched) break;
@@ -97,7 +96,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
