@@ -21,41 +21,40 @@ namespace Rivet {
       // projection
       declare(UnstableParticles(Cuts::pid==PID::PI0 || Cuts::pid==PID::K0S), "UFS");
       // find beam energy
-      unsigned int iloc(0);
-      if (isCompatibleWithSqrtS(2.2324, 1E-3))
-        iloc = 1;
-      else if (isCompatibleWithSqrtS(2.4 , 1E-3))
-        iloc = 2;
-      else if (isCompatibleWithSqrtS(2.8 , 1E-3))
-        iloc = 3;
-      else if (isCompatibleWithSqrtS(3.05 , 1E-3))
-        iloc = 4;
-      else if (isCompatibleWithSqrtS(3.4 , 1E-3))
-        iloc = 5;
-      else if (isCompatibleWithSqrtS(3.671 , 1E-3))
-        iloc = 6;
-      else
-        MSG_ERROR("Beam energy not supported!");
-      // book histos
-      for (unsigned int ix=0; ix<2; ++ix) {
-        book(_h[ix],1+ix,1,iloc);
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+
+        book(_h[en+"_1"], 1, 1, ih);
+        book(_h[en+"_2"], 2, 1, ih);
+        book(_c[en], "_aux_sigma_"+en);
+        ++ih;
       }
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
+      _c[_sqs]->fill();
       for (const Particle& p : apply<UnstableParticles>(event, "UFS").particles()) {
         const double pp = p.p3().mod();
-        if (p.pid()==PID::PI0) _h[0]->fill(pp);
-        else                  _h[1]->fill(pp);
+        if (p.pid()==PID::PI0) _h[_sqs+"_1"]->fill(pp);
+        else                   _h[_sqs+"_2"]->fill(pp);
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_h, 1./sumOfWeights());
+      scale(_h, crossSectionPerEvent());
+      scale(_c, crossSectionPerEvent());
+      for (const auto& item : _c) {
+        scale(_h[item.first+"_1"s], 1.0/item.second->sumW());
+        scale(_h[item.first+"_2"s], 1.0/item.second->sumW());
+      }
     }
 
     /// @}
@@ -63,7 +62,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h[2];
+    map<string,Histo1DPtr> _h;
+    map<string,CounterPtr> _c;
+    string _sqs = "";
     /// @}
 
 
