@@ -27,16 +27,15 @@ namespace Rivet {
       // counters
       book(_sigma,1,1,1);
       for(const string& en : _sigma.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p, map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -76,12 +75,12 @@ namespace Rivet {
               break;
             }
           }
-          if(matched) {
-            _sigma->fill(_ecms);
+          if (matched) {
+            _sigma->fill(_sqs);
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -98,7 +97,7 @@ namespace Rivet {
     /// @{
     int _pid;
     BinnedHistoPtr<string> _sigma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
