@@ -22,22 +22,19 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigma[ix], 1+ix, 1, 1);
         for (const string& en : _sigma[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          const double eval = stod(en);
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if(child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -89,7 +86,7 @@ namespace Rivet {
       	}
       	if (matched) {
           for (unsigned int ix=0; ix<2; ++ix) {
-            if (!_ecms[ix].empty()) _sigma[ix]->fill(_ecms[ix]);
+            if (!_sqs[ix].empty()) _sigma[ix]->fill(_sqs[ix]);
           }
         }
       }
@@ -107,7 +104,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
