@@ -24,20 +24,14 @@ namespace Rivet {
       declare(UnstableParticles(Cuts::abspid==433), "UFS");
       // Book histograms
       book(_sigma,1,1,1);
-      double delta=1e30;
       for (const string& en : _sigma.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          if(abs(end-sqrtS())<delta) {
-            _ecms = en;
-            delta = abs(end-sqrtS());
-          }
-        }
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval, 1e-6))  _sqs = en;
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p,map<long,int>& nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -104,7 +98,7 @@ namespace Rivet {
             }
           }
           if (matched) {
-	    _sigma->fill(_ecms);
+            _sigma->fill(_sqs);
             break;
           }
         }
@@ -124,7 +118,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
