@@ -21,26 +21,17 @@ namespace Rivet {
     void init() {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::abspid==2224), "UFS");
-      vector<string> energies({"2.3094", "2.3864", "2.396", "2.5", "2.6444", "2.6464"});
-      bool matched=false;
-      for(const string& en : energies) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          matched=true;
-          break;
+      for (size_t ih=0; ih<2; ++ih) {
+        book(_sigma[ih], 1+ih, 1, 1);
+        for (const string& en : _sigma[ih].binning().edges<0>()) {
+          double eval = stod(en);
+          if (isCompatibleWithSqrtS(eval))  _sqs = en;
         }
       }
-      if(!_ecms.empty())
-        book(_sigma[0],1,1,1);
-      if(isCompatibleWithSqrtS(2.6454)) {
-        book(_sigma[1],2,1,1);
-        matched=true;
-      }
-      if(!matched) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) {
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -81,8 +72,8 @@ namespace Rivet {
           }
         }
         if (matched) {
-	  if(_sigma[0]) _sigma[0]->fill(_ecms);
-          if(_sigma[1]) _sigma[1]->fill(string("2.6454"));
+          size_t ih = _sqs == "2.6454"s;
+          _sigma[ih]->fill(_sqs);
           break;
         }
       }
@@ -91,8 +82,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn;
-      for(unsigned int ix=0;ix<2;++ix) scale(_sigma[ix],fact);
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -101,7 +91,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
