@@ -25,22 +25,21 @@ namespace Rivet {
       declare(UnstableParticles(Cuts::abspid==4122), "UFS");
       declare(FinalState(), "FS");
       // histograms
-      book(_h_cThetaL,"cThetaL",20,-1.,1.);
-      book(_wsum,"TMP/wsum");
-
-      vector<string> energies({"4.6119", "4.628", "4.6409", "4.6612", "4.6819", "4.6988",
-          "4.7397", "4.75", "4.7805", "4.8431", "4.918", "4.9509"});
-      for(const string& en : energies) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
-        }
+      for (size_t ih=0; ih<5; ++ih) {
+        book(_est[ih], 1, 1, 1+ih);
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      for (const string& en : _est[0].binning().edges<0>()) {
+
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval))  _sqs = en;
+
+        book(_h[en+"cThetaL"], "TMP/cThetaL_"+en, 20,-1.,1.);
+
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p, map<long,int>& nRes, int & ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -57,12 +56,8 @@ namespace Rivet {
       // get the axis, direction of incoming electron
       const ParticlePair& beams = apply<Beam>(event, "Beams").beams();
       Vector3 axis;
-      if (beams.first.pid()>0) {
-        axis = beams.first .mom().p3().unit();
-      }
-      else {
-        axis = beams.second.mom().p3().unit();
-      }
+      if (beams.first.pid()>0)  axis = beams.first .mom().p3().unit();
+      else                      axis = beams.second.mom().p3().unit();
       // types of final state particles
       const FinalState& fs = apply<FinalState>(event, "FS");
       map<long,int> nCount;
@@ -112,11 +107,10 @@ namespace Rivet {
       }
       if (!matched) vetoEvent;
       const double cosL = axis.dot(Lambda.mom().p3().unit());
-      _wsum->fill();
-      _h_cThetaL->fill(cosL);
+      _h[_sqs+"cThetaL"]->fill(cosL);
     }
 
-    pair<double,pair<double,double> > calcAlpha0(Histo1DPtr hist) {
+    pair<double,pair<double,double> > calcAlpha0(const Histo1DPtr& hist) const {
       if (hist->numEntries()==0.)  return make_pair(0.,make_pair(0.,0.));
       const double d = 3./(pow(hist->xMax(),3)-pow(hist->xMin(),3));
       const double c = 3.*(hist->xMax()-hist->xMin())/(pow(hist->xMax(),3)-pow(hist->xMin(),3));
@@ -153,56 +147,63 @@ namespace Rivet {
     void finalize() {
       // storage of the values to fill histos
       const double mn    = 2.28646;
-      const double tau   = 4.*sqr(mn/sqrtS());
-      const double beta  = sqrt(1.-tau);
       const double alpha = 7.2973525693e-3;
       const double GeV2pb = 0.3893793721e9;
-      scale(_wsum, crossSection()/ sumOfWeights()/picobarn);
-      // prefactor and sigma
-      double sigma0 = 4.*M_PI*sqr(alpha/sqrtS())*beta*GeV2pb;
-      // calculate alpha0
-      pair<double,pair<double,double> > alpha0 = calcAlpha0(_h_cThetaL);
-      // Geff
-      pair<double,double> Geff = make_pair(1e2*sqrt(3.*_wsum->val()/(sigma0*(1 + 0.5*tau))),
-                                           1e2*1.5*_wsum->val()/(sigma0*(1 + 0.5*tau)));
-      // GM
-      double GMv = 1e2*sqrt(6.*((1+alpha0.first)*_wsum->val())/((3+alpha0.first)*sigma0));
-      double GMe1 = 1e2*sqrt((3*(sqr(_wsum->err())*sqr(1 + alpha0.first)*sqr(3 + alpha0.first) + 4*sqr(alpha0.second.first)*sqr(_wsum->val())))/
-                             (2.*(1 + alpha0.first)*pow(3 + alpha0.first,3)*_wsum->val()*sigma0));
-      double GMe2 = 1e2*sqrt((3*(sqr(_wsum->err())*sqr(1 + alpha0.first)*sqr(3 + alpha0.first) + 4*sqr(alpha0.second.second)*sqr(_wsum->val())))/
-                             (2.*(1 + alpha0.first)*pow(3 + alpha0.first,3)*_wsum->val()*sigma0));
-      pair<double,pair<double,double> > GM = make_pair(std::move(GMv), make_pair(std::move(GMe1), std::move(GMe2)));
-      // ratio
-      pair<double,pair<double,double>> R;
-      R.first = sqrt((1 - alpha0.first)/(tau + alpha0.first*tau));
-      R.second.first  = R.first*alpha0.second.first /(1.-sqr(alpha0.first));
-      R.second.second = R.first*alpha0.second.second/(1.-sqr(alpha0.first));
-      for(unsigned int ix=1; ix<6; ++ix) {
-        double val;
-        pair<double,double> err;
-        if (ix==1) {
-          val = _wsum->val();
-          err = make_pair(_wsum->err(),_wsum->err());
+
+      for (const string& en : _est[0].binning().edges<0>()) {
+
+        if (isZero(_h[en+"cThetaL"]->effNumEntries()))  continue;
+        double eval = stod(en);
+
+        const double tau  = 4.*sqr(mn/eval);
+        const double beta = sqrt(1.-tau);
+        // prefactor and sigma
+        double sigma0 = 4.*M_PI*sqr(alpha/eval)*beta*GeV2pb;
+        // calculate alpha0
+        pair<double,pair<double,double> > alpha0 = calcAlpha0(_h[en+"cThetaL"]);
+        scale(_h[en+"cThetaL"], crossSection()/ sumOfWeights()/picobarn);
+        const double wsum = _h[en+"cThetaL"]->integral();
+        const double werr = _h[en+"cThetaL"]->integralError();
+        // Geff
+        pair<double,double> Geff = make_pair(1e2*sqrt(3.*wsum/(sigma0*(1 + 0.5*tau))),
+                                             1e2*1.5*wsum/(sigma0*(1 + 0.5*tau)));
+        // GM
+        double GMv = 1e2*sqrt(6.*((1+alpha0.first)*wsum)/((3+alpha0.first)*sigma0));
+        double GMe1 = 1e2*sqrt((3*(sqr(werr)*sqr(1 + alpha0.first)*sqr(3 + alpha0.first) + 4*sqr(alpha0.second.first)*sqr(wsum)))/
+                               (2.*(1 + alpha0.first)*pow(3 + alpha0.first,3)*wsum*sigma0));
+        double GMe2 = 1e2*sqrt((3*(sqr(werr)*sqr(1 + alpha0.first)*sqr(3 + alpha0.first) + 4*sqr(alpha0.second.second)*sqr(wsum)))/
+                               (2.*(1 + alpha0.first)*pow(3 + alpha0.first,3)*wsum*sigma0));
+        pair<double,pair<double,double> > GM = make_pair(std::move(GMv), make_pair(std::move(GMe1), std::move(GMe2)));
+        // ratio
+        pair<double,pair<double,double>> R;
+        R.first = sqrt((1 - alpha0.first)/(tau + alpha0.first*tau));
+        R.second.first  = R.first*alpha0.second.first /(1.-sqr(alpha0.first));
+        R.second.second = R.first*alpha0.second.second/(1.-sqr(alpha0.first));
+        for (size_t ix=1; ix<6; ++ix) {
+          double val;
+          pair<double,double> err;
+          if (ix==1) {
+            val = wsum;
+            err = make_pair(werr, werr);
+          }
+          else if (ix==2) {
+            val = Geff.first;
+            err = make_pair(Geff.second,Geff.second);
+          }
+          else if (ix==3) {
+            val = alpha0.first;
+            err = alpha0.second;
+          }
+          else if (ix==4) {
+            val = R.first;
+            err = R.second;
+          }
+          else {
+            val = GM.first;
+            err = GM.second;
+          }
+          _est[ix-1]->binAt(en).set(val,err);
         }
-        else if (ix==2) {
-          val = Geff.first;
-          err = make_pair(Geff.second,Geff.second);
-        }
-        else if (ix==3) {
-          val = alpha0.first;
-          err = alpha0.second;
-        }
-        else if (ix==4) {
-          val = R.first;
-          err = R.second;
-        }
-        else {
-          val = GM.first;
-          err = GM.second;
-        }
-        BinnedEstimatePtr<string> tmp;
-        book(tmp, 1, 1, ix);
-        tmp->binAt(_ecms).set(val,err);
       }
     }
 
@@ -211,9 +212,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_cThetaL;
-    CounterPtr _wsum;
-    string _ecms;
+    map<string,Histo1DPtr> _h;
+    BinnedEstimatePtr<string> _est[5];
+    string _sqs = "";
     /// @}
 
 
