@@ -21,20 +21,19 @@ namespace Rivet {
     void init() {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for (unsigned int ix=0; ix<2; ++ix)
+      for (size_t ix=0; ix<2; ++ix) {
         book(_nPhi[ix], 1, 1, 1+ix);
+      }
       for (const string& en : _nPhi[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -86,7 +85,7 @@ namespace Rivet {
             }
           }
           if (matched) {
-            _nPhi[imode]->fill(_ecms);
+            _nPhi[imode]->fill(_sqs);
             break;
           }
         }
@@ -106,7 +105,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nPhi[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
