@@ -24,17 +24,15 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nLS, 1, 1, 1);
       for (const string& en : _nLS.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -97,7 +95,7 @@ namespace Rivet {
       	    }
       	  }
       	  if (matched) {
-            _nLS->fill(_ecms);
+            _nLS->fill(_sqs);
       	    break;
       	  }
        	}
@@ -111,14 +109,15 @@ namespace Rivet {
       scale(_nLS, crossSection()/ sumOfWeights() /picobarn);
       const double mL = 1.115683;
       const double mS = 1.192642;
-      const double tau  = sqr(sqrtS()/(mL+mS));
-      const double beta = sqrt(1.-2.*(sqr(mS)+sqr(mL))/sqr(sqrtS())+sqr((sqr(mS)-sqr(mL))/sqr(sqrtS())));
       const double alpha = 7.2973525693e-3;
       const double GeV2pb = 0.3893793721e9;
-      const double sigma0 = 4.*M_PI*sqr(alpha/sqrtS())*beta*GeV2pb;
       BinnedEstimatePtr<string> tmp;
       book(tmp,1,1,2);
-      for(const auto & b : _nLS->bins()) {
+      for (const auto& b : _nLS->bins()) {
+        const double eval = std::stod(b.xEdge());
+        const double tau  = sqr(eval/(mL+mS));
+        const double beta = sqrt(1.-2.*(sqr(mS)+sqr(mL))/sqr(sqrtS())+sqr((sqr(mS)-sqr(mL))/sqr(eval)));
+        const double sigma0 = 4.*M_PI*sqr(alpha/eval)*beta*GeV2pb;
         tmp->bin(b.index()).set(sqrt(3.*b.sumW()*tau/(sigma0*(0.5 + 0.5*tau))),
                                 sqrt(1.5*tau/b.sumW()/sigma0/(1.+2.*tau))*b.errW());
       }
@@ -130,7 +129,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nLS;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
