@@ -25,18 +25,16 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       // counter
       book(_cphipippim, 1, 1, 1);
-      for(const string& en : _cphipippim.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+      for (const string& en : _cphipippim.binning().edges<0>()) {
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if( _ecms.empty() )
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) {
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -81,7 +79,7 @@ namespace Rivet {
             }
           }
           if (matched) {
-            _cphipippim->fill(_ecms);
+            _cphipippim->fill(_sqs);
             break;
           }
         }
@@ -100,7 +98,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _cphipippim;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
