@@ -24,18 +24,16 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       book(_sigmaPhiEta,1,1,1);
-
       for (const string& en : _sigmaPhiEta.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -78,7 +76,7 @@ namespace Rivet {
               break;
             }
           }
-	  if(matched) _sigmaPhiEta->fill(_ecms);
+          if (matched) _sigmaPhiEta->fill(_sqs);
         }
       }
     }
@@ -95,7 +93,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigmaPhiEta;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
