@@ -22,19 +22,17 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::abspid==3312), "UFS");
-      book(_sigmaXi, 1,1,1);
-
+      book(_sigmaXi, 1, 1, 1);
       for (const string& en : _sigmaXi.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -96,7 +94,7 @@ namespace Rivet {
       	    }
       	  }
       	  if(matched) {
-	    _sigmaXi->fill(_ecms);
+            _sigmaXi->fill(_sqs);
       	    break;
       	  }
        	}
@@ -107,19 +105,19 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact  = crossSection()/ sumOfWeights() /femtobarn;
-      scale(_sigmaXi, fact);
       double mXi = 1.32171;
-      double tau  = 0.25*sqr(sqrtS()/mXi);
-      double beta = sqrt(1.-1./tau);
       double alpha = 7.2973525693e-3;
       double GeV2fb = 0.3893793721e12;
-      double sigma0 = 4.*M_PI*sqr(alpha/sqrtS())*beta*GeV2fb/3.;
+      scale(_sigmaXi, crossSection()/ sumOfWeights() /femtobarn);
       BinnedEstimatePtr<string> tmp;
       book(tmp,1,1,2);
-      for(const auto & b :_sigmaXi->bins()) {
+      for (const auto& b :_sigmaXi->bins()) {
+        double eval = stod(b.xEdge());
+        double tau  = 0.25*sqr(eval/mXi);
+        double beta = sqrt(1.-1./tau);
+        double sigma0 = 4.*M_PI*sqr(alpha/eval)*beta*GeV2fb/3.;
         tmp->bin(b.index()).set(1e3*sqrt(b.sumW()/(sigma0*(1. + 0.5/tau))),
-                               1e3*0.5*sqrt(1./b.sumW()/sigma0/(1. + 0.5/tau))*b.errW());
+                                1e3*0.5*sqrt(1./b.sumW()/sigma0/(1. + 0.5/tau))*b.errW());
       }
     }
 
@@ -129,7 +127,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigmaXi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
