@@ -24,20 +24,20 @@ namespace Rivet {
       declare(UnstableParticles(Cuts::abspid==313 || Cuts::abspid==315), "UFS");
 
       // histograms
-      for(unsigned int ix=0;ix<3;++ix)
-	book(_sigma[ix],1+ix,1,1);
-      
+      for (size_t ix=0; ix<3; ++ix) {
+        book(_sigma[ix],1+ix,1,1);
+      }
+
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p ,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -60,9 +60,9 @@ namespace Rivet {
         ++ntotal;
       }
       // KSO KL0 pi0 final state
-      if( ntotal == 3 && nCount[130] == 1 &&
-	  nCount[310] == 1 && nCount[111] == 1)
-	_sigma[0]->fill(_ecms);
+      if( ntotal == 3 && nCount[130] == 1 && nCount[310] == 1 && nCount[111] == 1) {
+        _sigma[0]->fill(_sqs);
+      }
 
       // unstable particles
       const FinalState& ufs = apply<FinalState>(event, "UFS");
@@ -84,8 +84,8 @@ namespace Rivet {
           }
         }
         if (matched && nk0==1) {
-	  if(p.abspid()==313) _sigma[1]->fill(_ecms);
-	  else                _sigma[2]->fill(_ecms);
+          if (p.abspid()==313) _sigma[1]->fill(_sqs);
+          else                 _sigma[2]->fill(_sqs);
           break;
         }
       }
@@ -94,8 +94,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=0;ix<3;++ix)
-	scale(_sigma[ix],crossSection()/ sumOfWeights() /picobarn);
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -104,7 +103,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
