@@ -22,20 +22,19 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0;ix<2;++ix)
-	book(_sigma[ix],1,1,1+ix);
-
+      for (size_t ix=0; ix<2; ++ix) {
+        book(_sigma[ix], 1, 1, 1+ix);
+      }
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -87,8 +86,8 @@ namespace Rivet {
             }
           }
           if (matched) {
-	    _sigma[0]->fill(_ecms);
-	    if(born) _sigma[1]->fill(_ecms);
+            _sigma[0]->fill(_sqs);
+            if (born) _sigma[1]->fill(_sqs);
           }
         }
       }
@@ -97,10 +96,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights()/picobarn;
-      for(unsigned int ix=0;ix<2;++ix) {
-	scale(_sigma[ix],fact);
-      }
+      scale(_sigma,  crossSection()/ sumOfWeights()/picobarn);
     }
 
     /// @}
@@ -109,7 +105,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
