@@ -23,16 +23,15 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_sigmaJPsi, 1, 1, 1);
       for (const string& en : _sigmaJPsi.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -86,7 +85,7 @@ namespace Rivet {
             }
           }
           if (matched) {
-	    _sigmaJPsi->fill(_ecms);
+            _sigmaJPsi->fill(_sqs);
             break;
           }
         }
@@ -106,7 +105,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigmaJPsi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
