@@ -21,19 +21,19 @@ namespace Rivet {
     void init() {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0;ix<3;++ix)     
-        book(_sigma[ix] , 1+ix,1,1);
+      for (size_t ix=0; ix<3; ++ix) {
+        book(_sigma[ix], 1+ix, 1, 1);
+      }
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -74,7 +74,7 @@ namespace Rivet {
           }
         }
         if (!matched) continue;
-        _sigma[0]->fill(_ecms);
+        _sigma[0]->fill(_sqs);
         for (const Particle& p2 : ufs.particles(Cuts::pid==113)) {
           map<long,int> nResB = nRes;
           int ncountB = ncount;
@@ -87,7 +87,7 @@ namespace Rivet {
               break;
             }
           }
-	  if(matched) _sigma[1]->fill(_ecms);
+          if (matched) _sigma[1]->fill(_sqs);
         }
       }
       // loop over a_2 mesons
@@ -111,7 +111,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-	  _sigma[2]->fill(_ecms);
+          _sigma[2]->fill(_sqs);
           break;
         }
       }
@@ -120,10 +120,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn;
-      for(unsigned int ix=0;ix<3;++ix) {
-	scale(_sigma[ix],fact);
-      }
+	    scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -132,7 +129,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
