@@ -21,14 +21,12 @@ namespace Rivet {
       declare(FinalState(), "FS");
       book(_nK0K0, 1, 1, 2);
       for (const string& en : _nK0K0.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -43,8 +41,7 @@ namespace Rivet {
         ++ntotal;
       }
 
-      if(ntotal==2 && nCount[130]==1 && nCount[310]==1)
-        _nK0K0->fill(_ecms);
+      if (ntotal==2 && nCount[130]==1 && nCount[310]==1)  _nK0K0->fill(_sqs);
     }
 
 
@@ -59,7 +56,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nK0K0;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
