@@ -22,19 +22,18 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::abspid==3222), "UFS");
-      book(_sigma_plus ,1,1,1);
+      book(_sigma_plus, 1, 1, 1);
 
       for (const string& en : _sigma_plus.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -58,7 +57,7 @@ namespace Rivet {
       }
       // find the Sigmas
       const FinalState& ufs = apply<UnstableParticles>(event, "UFS");
-      for (unsigned int ix=0;ix<ufs.particles().size();++ix) {
+      for (size_t ix=0; ix<ufs.particles().size(); ++ix) {
       	const Particle& p1 = ufs.particles()[ix];
       	bool matched = false;
        	// check fs
@@ -74,7 +73,7 @@ namespace Rivet {
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p1,nRes,ncount);
-        for (unsigned int iy=ix+1; iy<ufs.particles().size(); ++iy) {
+        for (size_t iy=ix+1; iy<ufs.particles().size(); ++iy) {
        	  const Particle& p2 = ufs.particles()[iy];
        	  if (p2.pid() != -p1.pid()) continue;
        	  // check fs
@@ -97,10 +96,10 @@ namespace Rivet {
       	      break;
       	    }
       	  }
-      	  if(matched) {
-	    _sigma_plus->fill(_ecms);
-	    break;
-	  }
+      	  if (matched) {
+            _sigma_plus->fill(_sqs);
+            break;
+          }
       	}
         if (matched) break;
       }
@@ -118,7 +117,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma_plus;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
