@@ -22,20 +22,19 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0;ix<3;++ix)
-	book(_sigma[ix], 1, 1, 1+ix);
-      
+      for (size_t ix=0; ix<3; ++ix)
+        book(_sigma[ix], 1, 1, 1+ix);
+
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -63,7 +62,7 @@ namespace Rivet {
       }
       if (ntotal!=3) vetoEvent;
       if (nCount[-211]==1&&nCount[211]==1&&nCount[111]==1) {
-        _sigma[0]->fill(_ecms);
+        _sigma[0]->fill(_sqs);
       }
       else {
         vetoEvent;
@@ -96,23 +95,19 @@ namespace Rivet {
             break;
           }
         }
-        if (!matched) continue;
         if (matched) {
-          if (p.pid()==213 || p.pid()==113)
-	    _sigma[1]->fill(_ecms);
-	  else
-	    _sigma[2]->fill(_ecms);
+          if (p.pid()==213 || p.pid()==113)  _sigma[1]->fill(_sqs);
+          else                               _sigma[2]->fill(_sqs);
           break;
         }
+        else  continue;
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/picobarn/sumOfWeights();
-      for(unsigned int ix=0;ix<3;++ix)
-	scale(_sigma[ix],fact);
+      scale(_sigma, crossSection()/picobarn/sumOfWeights());
     }
 
     /// @}
@@ -121,7 +116,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
