@@ -22,20 +22,20 @@ namespace Rivet {
       // projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0;ix<2;++ix)
-	book(_sigma[ix],1+ix,1,1);
-      
+      for (size_t ix=0; ix<2; ++ix) {
+        book(_sigma[ix], 1+ix, 1, 1);
+      }
+
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -58,7 +58,7 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       // loop over any phi mesons
-      for (const Particle & phi : ufs.particles(Cuts::pid==223)) {
+      for (const Particle& phi : ufs.particles(Cuts::pid==223)) {
         bool matched = false;
         if (phi.children().empty()) continue;
         map<long,int> nRes = nCount;
@@ -77,8 +77,8 @@ namespace Rivet {
             }
           }
           if (!matched) continue;
-	  if     (chi.pid()==20443) _sigma[0]->fill(_ecms);
-	  else if(chi.pid()==  445) _sigma[1]->fill(_ecms);
+          if     (chi.pid()==20443) _sigma[0]->fill(_sqs);
+          else if(chi.pid()==  445) _sigma[1]->fill(_sqs);
           break;
         }
         if (matched) break;
@@ -88,9 +88,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact =  crossSection()/ sumOfWeights() /picobarn;
-      for(unsigned int ix=0;ix<2;++ix)
-        scale(_sigma[ix],fact);
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -99,7 +97,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
