@@ -21,29 +21,37 @@ namespace Rivet {
       // Initialise and register projections
       declare(UnstableParticles(Cuts::pid==221), "UFS");
       // histos
-      vector<double> energies = { 2.0, 2.2, 2.396, 2.6444, 2.9, 3.05, 3.5000, 3.671};
-      unsigned int iloc;
-      for(iloc=0;iloc<energies.size();++iloc) {
-        if(isCompatibleWithSqrtS(energies[iloc])) break;
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_c[en], "_aux_sigma_"+en);
+        book(_h[en],1,1,ih);
+        ++ih;
       }
-      if (iloc==energies.size())
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      book(_h,1,1,1+iloc);
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
+      _c[_sqs]->fill();
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
-      for(const Particle& p : ufs.particles()) {
-        _h->fill(p.momentum().p3().mod());
+      for (const Particle& p : ufs.particles()) {
+        _h[_sqs]->fill(p.mom().p3().mod());
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_h,1./sumOfWeights());
+      scale(_h, crossSectionPerEvent());
+      scale(_c, crossSectionPerEvent());
+      for (const auto& item : _c) {
+        if (isZero(item.second->sumW()))  continue;
+        scale(_h[item.first], 1.0/item.second->sumW());
+      }
     }
 
     /// @}
@@ -51,7 +59,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h;
+    map<string,Histo1DPtr> _h;
+    map<string,CounterPtr> _c;
+    string _sqs = "";
     /// @}
 
 
