@@ -22,20 +22,19 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::abspid==411 or Cuts::abspid==421), "UFS");
-      for(unsigned int ix=0;ix<2;++ix)
-	book(_sigma[ix],ix+1, 1, 1);
-
+      for (size_t ix=0; ix<2; ++ix) {
+        book(_sigma[ix],ix+1, 1, 1);
+      }
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p,map<long,int>& nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -58,13 +57,13 @@ namespace Rivet {
         ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
-      for (unsigned int ix=0; ix<ufs.particles().size(); ++ix) {
+      for (size_t ix=0; ix<ufs.particles().size(); ++ix) {
        	const Particle& p1 = ufs.particles()[ix];
       	map<long,int> nRes = nCount;
       	int ncount = ntotal;
       	findChildren(p1,nRes,ncount);
       	bool matched=false;
-       	for (unsigned int iy=ix+1; iy<ufs.particles().size(); ++iy) {
+       	for (size_t iy=ix+1; iy<ufs.particles().size(); ++iy) {
           const Particle& p2 = ufs.particles()[iy];
           if (p2.pid()!=-p1.pid()) continue;
           if (!p2.parents().empty() && p2.parents()[0].pid()==p1.pid()) continue;
@@ -81,10 +80,10 @@ namespace Rivet {
           }
           if (matched) break;
        	}
-       	if(matched) {
-	  if(p1.abspid()==421) _sigma[0]->fill(_ecms);
-	  else                 _sigma[1]->fill(_ecms);
-	  break;
+       	if (matched) {
+          if (p1.abspid()==421) _sigma[0]->fill(_sqs);
+          else                  _sigma[1]->fill(_sqs);
+          break;
       	}
       }
     }
@@ -92,9 +91,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn; 
-      for(unsigned int ix=0;ix<2;++ix)
-        scale(_sigma[ix],fact);
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -103,7 +100,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
