@@ -25,21 +25,21 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // histos
-      for(unsigned int ix=0;ix<3;++ix)
+      for (size_t ix=0; ix<3; ++ix) {
         book(_h[ix],1+ix,1,1);
-      for(const string& en : _h[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+      }
+      for (const string& en : _h[0].binning().edges<0>()) {
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren2(const Particle& p, map<long,int> & nRes, int &ncount) {
+    void findChildren2(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-        if(child.pid()==443 ) {
+        if (child.pid()==443 ) {
           nRes[child.pid()] += 1;
           ++ncount;
         }
@@ -53,7 +53,7 @@ namespace Rivet {
       }
     }
 
-    void findChildren(const Particle& p, map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -94,20 +94,19 @@ namespace Rivet {
             }
           }
           if(matched) {
-            if     (XX.pid()==20443) _h[1]->fill(_ecms);
-            else if(XX.pid()==  445) _h[2]->fill(_ecms);
+            if      (XX.pid()==20443) _h[1]->fill(_sqs);
+            else if (XX.pid()==  445) _h[2]->fill(_sqs);
             // check decay mode
             else {
               int nOut=0;
               map<long,int> nDecay;
               findChildren2(XX, nDecay,nOut);
-              if(nOut==3 && nDecay[443]==1 && nDecay[211]==1 && nDecay[-211]==1)
-                _h[0]->fill(_ecms);
+              if (nOut==3 && nDecay[443]==1 && nDecay[211]==1 && nDecay[-211]==1)  _h[0]->fill(_sqs);
             }
             break;
           }
         }
-        if(matched) break;
+        if (matched) break;
       }
     }
 
@@ -124,7 +123,7 @@ namespace Rivet {
     /// @{
     int _pid;
     BinnedHistoPtr<string> _h[3];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
