@@ -22,16 +22,16 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      book(_c_hadrons, "/TMP/sigma_hadrons", refData<YODA::BinnedEstimate<string>>(1,1,1));
-      book(_c_muons,   "/TMP/sigma_muons"  , refData<YODA::BinnedEstimate<string>>(1,1,1));
+      const YODA::BinnedEstimate<string>& ref = refData<YODA::BinnedEstimate<string>>(1,1,1);
+      book(_c_hadrons, "/TMP/sigma_hadrons", ref);
+      book(_c_muons,   "/TMP/sigma_muons"  , ref);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = std::stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -46,11 +46,12 @@ namespace Rivet {
         ++ntotal;
       }
       // mu+mu- + photons
-      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22])
-        _c_muons->fill(_ecms);
-      // everything else
-      else
-        _c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 &&
+          nCount[13]==1 &&
+          ntotal==2+nCount[22])  _c_muons->fill(_sqs);
+      else { // everything else
+        _c_hadrons->fill(_sqs);
+      }
     }
 
 
@@ -58,7 +59,7 @@ namespace Rivet {
     void finalize() {
       BinnedEstimatePtr<string> mult;
       book(mult, 1, 1, 1);
-      divide(_c_hadrons,_c_muons,mult);
+      divide(_c_hadrons,_c_muons, mult);
     }
 
     /// @}
@@ -67,7 +68,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
