@@ -20,17 +20,16 @@ namespace Rivet {
     void init() {
       const ChargedFinalState fs;
       declare(fs, "FS");
-      unsigned int iloc(0);
-      if(isCompatibleWithSqrtS(2.2 , 1E-3)) iloc = 1;
-      else if(isCompatibleWithSqrtS(2.6 , 1E-3)) iloc = 2;
-      else if(isCompatibleWithSqrtS(3.0 , 1E-3)) iloc = 3;
-      else if(isCompatibleWithSqrtS(3.2 , 1E-3)) iloc = 4;
-      else if(isCompatibleWithSqrtS(4.6 , 1E-3)) iloc = 5;
-      else if(isCompatibleWithSqrtS(4.8 , 1E-3)) iloc = 6;
-      else MSG_ERROR("Beam energy not supported!");
-      assert(iloc != 0);
-      book(_h_ln, iloc, 1, 1);
-      book(_h_weight, "TMP/Weight");
+
+      size_t ih = 0;
+      for (double eVal : allowedEnergies()) {
+        ++ih;
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal, 1e-3))  _sqs = en;
+        book(_h[en], ih, 1, 1);
+        book(_c[en], "TMP/Weight_"+en);
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
     string map2string(const double xi) const {
@@ -41,7 +40,7 @@ namespace Rivet {
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
-      if (edges.empty())  edges = _h_ln->xEdges();
+      if (edges.empty())  edges = _h[_sqs]->xEdges();
       const ChargedFinalState& fs = apply<ChargedFinalState>(event, "FS");
       if (fs.particles().size()==2 &&
           abs(fs.particles()[0].pid())==13 &&
@@ -50,18 +49,20 @@ namespace Rivet {
         const Vector3 mom3 = p.p3();
         double pp = mom3.mod();
         double xi = -log(2.*pp/sqrtS());
-        _h_ln->fill(map2string(xi));
+        _h[_sqs]->fill(map2string(xi));
       }
-      _h_weight->fill();
+      _c[_sqs]->fill();
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_h_ln, 1./dbl(*_h_weight));
-      for(auto & b: _h_ln->bins()) {
-        const size_t idx = b.index();
-        b.scaleW(1./axis.width(idx));
+      for (auto& item : _h) {
+        scale(item.second, 1./dbl(*_c[item.first]));
+        for (auto& b : item.second->bins()) {
+          const size_t idx = b.index();
+          b.scaleW(1./axis.width(idx));
+        }
       }
     }
 
@@ -70,9 +71,10 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    BinnedHistoPtr<string> _h_ln;
-    CounterPtr _h_weight;
+    map<string,BinnedHistoPtr<string>> _h;
+    map<string,CounterPtr> _c;
     vector<string> edges;
+    string _sqs = "";
     YODA::Axis<double> axis{0.05, 0.45, 0.6, 0.7, 0.8, 0.9, 1.0,
                             1.1, 1.2, 1.3, 1.4, 1.5, 1.6, 1.7, 1.8, 1.9, 2.0,
                             2.1, 2.2, 2.3, 2.4, 2.5, 2.6, 2.7, 2.8, 2.9, 3.0, 3.5};
