@@ -23,20 +23,20 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // counter
-      for(unsigned int ix=0;ix<3;++ix)
-	book(_sigma[ix],1,1,1+ix);
+      for (size_t ix=0; ix<3; ++ix) {
+        book(_sigma[ix],1,1,1+ix);
+      }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) const {
       for(const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -80,9 +80,9 @@ namespace Rivet {
       	      break;
       	    }
       	  }
-      	  if(matched) {
-      	    _sigma[0]->fill(_ecms);
-	    break;
+      	  if (matched) {
+      	    _sigma[0]->fill(_sqs);
+            break;
       	  }
       	}
       }
@@ -107,8 +107,8 @@ namespace Rivet {
             }
           }
           if (matched) {
-	    if(p2.pid()==221) _sigma[1]->fill(_ecms);
-	    else if(_ecms=="3.686") _sigma[2]->fill(_ecms);
+            if (p2.pid()==221) _sigma[1]->fill(_sqs);
+            else if (_sqs=="3.686") _sigma[2]->fill(_sqs);
             break;
           }
         }
@@ -118,8 +118,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/picobarn/sumOfWeights();
-      for(unsigned int ix=0;ix<3; ++ix) scale(_sigma[ix],fact);
+      scale(_sigma, crossSection()/picobarn/sumOfWeights());
     }
 
     /// @}
@@ -128,7 +127,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
