@@ -25,14 +25,12 @@ namespace Rivet {
       // Book histograms
       book(_nproton, 1, 1, 1);
       for (const string& en : _nproton.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = std::stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -41,9 +39,9 @@ namespace Rivet {
       const FinalState& fs = apply<FinalState>(event, "FS");
       if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-        if (abs(p.pid())!=PID::PROTON) vetoEvent;
+        if (p.abspid() != PID::PROTON) vetoEvent;
       }
-      _nproton->fill(_ecms);
+      _nproton->fill(_sqs);
     }
 
 
@@ -58,7 +56,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nproton;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
