@@ -25,14 +25,12 @@ namespace Rivet {
       book(_c_hadrons, 2,1,1);
       book(_c_muons,   "/TMP/sigma_muons", refData<YODA::BinnedEstimate<string>>(2,1,1));
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = std::stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -47,12 +45,12 @@ namespace Rivet {
         ++ntotal;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-         ntotal==2+nCount[22])
-        _c_muons->fill(_ecms);
-      // everything else
-      else
-        _c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 &&
+          nCount[13]==1 &&
+          ntotal==2+nCount[22]) _c_muons->fill(_sqs);
+      else { // everything else
+        _c_hadrons->fill(_sqs);
+      }
     }
 
 
@@ -70,7 +68,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
