@@ -22,19 +22,18 @@ namespace Rivet {
       declare(UnstableParticles(Cuts::abspid==100443 || Cuts::abspid==30443),"UFS");
       declare(FinalState(), "FS");
       // Book histograms
-      for (unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigma_hadrons[ix], "/TMP/sigma_hadrons_"+toString(ix+1),refData<YODA::BinnedEstimate<string>>(1,1,1+ix));
       }
       book(_sigma_muons,   "/TMP/sigma_muons",refData<YODA::BinnedEstimate<string>>(1,1,1));
 
       for (const string& en : _sigma_muons.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -51,18 +50,18 @@ namespace Rivet {
       // mu+mu- + photons
       if (nCount[-13]==1 and nCount[13]==1 &&
          ntotal==2+nCount[22])
-        _sigma_muons->fill(_ecms);
+        _sigma_muons->fill(_sqs);
       // everything else
       else {
-        _sigma_hadrons[1]->fill(_ecms);
+        _sigma_hadrons[1]->fill(_sqs);
         Particles psi = apply<UnstableParticles>(event,"UFS").particles();
         if (psi.empty()) {
-          _sigma_hadrons[0]->fill(_ecms);
+          _sigma_hadrons[0]->fill(_sqs);
         }
         else {
           bool psi3770 = false;
           for (const Particle& p : psi) psi3770 |= p.pid()==30443;
-          if (psi3770) _sigma_hadrons[0]->fill(_ecms);
+          if (psi3770) _sigma_hadrons[0]->fill(_sqs);
         }
       }
     }
@@ -70,7 +69,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         BinnedEstimatePtr<string> R;
         book(R,1,1,1+ix);
         divide(_sigma_hadrons[ix], _sigma_muons, R);
@@ -83,7 +82,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string>  _sigma_hadrons[2], _sigma_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
