@@ -25,29 +25,29 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
 
       // Book histograms
-      for(unsigned int ix=4;ix<8;++ix) {
-        book(_nMeson[ix], 1,1,ix);
+      for (size_t ix=4; ix<8; ++ix) {
+        book(_nMeson[ix], 1, 1, ix);
       }
 
       for (const string& en : _nMeson[5].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
         }
-        else
+        else {
           findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -64,105 +64,96 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-        if(p.children().empty()) continue;
-        if(p.pid()!=223 && p.pid()!=113&&abs(p.pid())!=313&& abs(p.pid())!=323)
-          continue;
+        if (p.children().empty()) continue;
+        if (p.pid()!=223 && p.pid()!=113 && p.abspid()!=313 && p.abspid()!=323) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p,nRes,ncount);
-        if(p.pid()==113) {
-          if(ncount!=3) continue;
+        if (p.pid()==113) {
+          if (ncount!=3) continue;
           unsigned int npi(0),nK(0);
           bool matched = true;
-          for(auto const & val : nRes) {
-            if(abs(val.first)==111 && val.second==1) {
-              npi+=1;
+          for (const auto& val : nRes) {
+            if (abs(val.first)==111 && val.second==1) {
+              npi += 1;
             }
-            else if(abs(val.first)==321 && val.second==1) {
-              nK+=1;
+            else if (abs(val.first)==321 && val.second==1) {
+              nK += 1;
             }
-            else if(val.second!=0) {
+            else if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            if(npi==1&&nK==2)
-              if(_ecms=="3.65") _nMeson[4]->fill(_ecms);
-          }
+          if (matched && npi==1 && nK==2 && _sqs=="3.65") _nMeson[4]->fill(_sqs);
         }
-        else if(abs(p.pid())==213) {
-          if(ncount!=3) continue;
+        else if (p.abspid()==213) {
+          if (ncount!=3) continue;
           unsigned int npi(0),nK(0);
           bool matched = true;
           int ipi = p.pid()==213 ? -211 : 211;
-          for(auto const & val : nRes) {
-            if(abs(val.first)== ipi && val.second==1) {
+          for (const auto& val : nRes) {
+            if (abs(val.first)== ipi && val.second==1) {
               npi+=1;
             }
-            else if(abs(val.first)==321 && val.second==1) {
+            else if (abs(val.first)==321 && val.second==1) {
               nK+=1;
             }
-            else if(val.second!=0) {
+            else if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            if(npi==1&&nK==2)
-              _nMeson[5]->fill(_ecms);
-          }
+          if (matched && npi==1 && nK==2)  _nMeson[5]->fill(_sqs);
         }
-        else if(abs(p.pid())==313) {
-          if(ncount!=3) continue;
+        else if (p.abspid()==313) {
+          if (ncount!=3) continue;
           unsigned int npi(0),nK(0),npi0(0);
           bool matched = true;
           int ipi = p.pid()==313 ?  211 : -211;
           int iK  = p.pid()==313 ? -321 :  321;
-          for(auto const & val : nRes) {
-            if(abs(val.first)== ipi && val.second==1) {
+          for (const auto& val : nRes) {
+            if (abs(val.first)== ipi && val.second==1) {
               npi+=1;
             }
-            else if(abs(val.first)==iK && val.second==1) {
+            else if (abs(val.first)==iK && val.second==1) {
               nK+=1;
             }
-            if(abs(val.first)== 111 && val.second==1) {
+            if (abs(val.first)== 111 && val.second==1) {
               npi0+=1;
             }
-            else if(val.second!=0) {
+            else if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            if(npi==1&&nK==1&&npi0==1)
-              _nMeson[6]->fill(_ecms);
+          if (matched && npi==1 && nK==1 && npi0==1) {
+            _nMeson[6]->fill(_sqs);
           }
         }
-        else if(abs(p.pid())==323) {
-          if(ncount!=3) continue;
+        else if (p.abspid()==323) {
+          if (ncount!=3) continue;
           unsigned int npi(0),nK(0),npi0(0);
           bool matched = true;
           int ipi = p.pid()==323 ?  211 : -211;
           int iK  = p.pid()==323 ? -321 :  321;
-          for(auto const & val : nRes) {
-            if(abs(val.first)== ipi && val.second==1) {
+          for (const auto& val : nRes) {
+            if (abs(val.first)== ipi && val.second==1) {
               npi+=1;
             }
-            else if(abs(val.first)==iK && val.second==1) {
+            else if (abs(val.first)==iK && val.second==1) {
               nK+=1;
             }
-            if(abs(val.first)== 111 && val.second==1) {
+            if (abs(val.first)== 111 && val.second==1) {
               npi0+=1;
             }
-            else if(val.second!=0) {
+            else if (val.second!=0) {
               matched = false;
               break;
             }
           }
-          if(matched) {
-            if(npi==1&&nK==1&&npi0==1)
-              _nMeson[7]->fill(_ecms);
+          if (matched && npi==1 && nK==1 && npi0==1) {
+            _nMeson[7]->fill(_sqs);
           }
         }
       }
@@ -171,9 +162,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn; 
-      for(unsigned int ix=4;ix<8;++ix)
-        scale(_nMeson[ix],fact);
+      scale(_nMeson, crossSection()/ sumOfWeights() /nanobarn);
     }
 
     /// @}
@@ -181,8 +170,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    BinnedHistoPtr<string> _nMeson[8];
-    string _ecms;
+    map<int,BinnedHistoPtr<string>> _nMeson;
+    string _sqs = "";
     /// @}
 
 
