@@ -23,17 +23,16 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      for(unsigned int ix=1;ix<6;++ix)
+      for (size_t ix=1; ix<6; ++ix) {
         book(_nMeson[ix], 1, 1, ix);
+      }
       for (const string& en : _nMeson[1].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -47,24 +46,19 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if(nCount[111]!=2) vetoEvent;
+      if (nCount[111]!=2) vetoEvent;
 
-      if(ntotal==4) {
-        if(nCount[211]==1 && nCount[-211]==1)
-          _nMeson[1]->fill(_ecms);
-        else if(nCount[321]==1 && nCount[-321]==1)
-          _nMeson[2]->fill(_ecms);
+      if (ntotal==4) {
+        if (nCount[211]==1 && nCount[-211]==1)       _nMeson[1]->fill(_sqs);
+        else if (nCount[321]==1 && nCount[-321]==1)  _nMeson[2]->fill(_sqs);
       }
-      else if(ntotal==6) {
-        if(nCount[211]==2 && nCount[-211]==2)
-          _nMeson[3]->fill(_ecms);
-        else if(nCount[321]==1 && nCount[-321]==1 &&
-                nCount[211]==1 && nCount[-211]==1)
-          _nMeson[4]->fill(_ecms);
+      else if (ntotal==6) {
+        if (nCount[211]==2 && nCount[-211]==2) _nMeson[3]->fill(_sqs);
+        else if (nCount[321]==1 && nCount[-321]==1 &&
+                 nCount[211]==1 && nCount[-211]==1) _nMeson[4]->fill(_sqs);
       }
-      else if(ntotal==8) {
-        if(nCount[211]==3 && nCount[-211]==3)
-          _nMeson[5]->fill(_ecms);
+      else if (ntotal==8) {
+        if (nCount[211]==3 && nCount[-211]==3) _nMeson[5]->fill(_sqs);
       }
 
     }
@@ -72,8 +66,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=1;ix<6;++ix)
-        scale(_nMeson[ix], crossSection()/ sumOfWeights() /picobarn);
+      scale(_nMeson, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -82,7 +75,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nMeson[6];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
