@@ -23,23 +23,20 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::abspid==411 || Cuts::abspid==421), "UFS");
       // histos
-      for (unsigned int ix=0; ix<3; ++ix) {
+      for (size_t ix=0; ix<3; ++ix) {
         book(_sigma[ix], 1, 1, 1+ix);
       }
 
       for (const string& en : _sigma[0].binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf (_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -84,9 +81,9 @@ namespace Rivet {
           if (matched) break;
         }
         if (matched) {
-          _sigma[2]->fill(_ecms);
-          if (p1.abspid()==421)      _sigma[0]->fill(_ecms);
-          else if (p1.abspid()==411) _sigma[1]->fill(_ecms);
+          _sigma[2]->fill(_sqs);
+          if (p1.abspid()==421)      _sigma[0]->fill(_sqs);
+          else if (p1.abspid()==411) _sigma[1]->fill(_sqs);
           break;
         }
       }
@@ -104,7 +101,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
