@@ -21,16 +21,17 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       // Book histograms
-      book(_c_hadrons, "/TMP/sigma_hadrons", refData<YODA::BinnedEstimate<string>>(1,1,1));
-      book(_c_muons,   "/TMP/sigma_muons"  , refData<YODA::BinnedEstimate<string>>(1,1,1));
+      book(_mult, 1, 1, 1);
+      const YODA::BinnedEstimate<string>& ref = refData<YODA::BinnedEstimate<string>>(1,1,1);
+      book(_c_hadrons, "/TMP/sigma_hadrons", ref);
+      book(_c_muons,   "/TMP/sigma_muons"  , ref);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -45,20 +46,18 @@ namespace Rivet {
         ++ntotal;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-         ntotal==2+nCount[22])
-        _c_muons->fill(_ecms);
-      // everything else
-      else
-        _c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 && nCount[13]==1 &&  ntotal==2+nCount[22]) {
+        _c_muons->fill(_sqs);
+      }
+      else { // everything else
+        _c_hadrons->fill(_sqs);
+      }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      BinnedEstimatePtr<string> mult;
-      book(mult, 1, 1, 1);
-      divide(_c_hadrons,_c_muons,mult);
+      divide(_c_hadrons, _c_muons, _mult);
     }
 
     /// @}
@@ -67,7 +66,8 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    BinnedEstimatePtr<string> _mult;
+    string _sqs = "";
     /// @}
 
 
