@@ -22,22 +22,21 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      if (isCompatibleWithSqrtS(3.773)) {
-        book(_sigma[1],1,1,2);
-        _ecms="3.773";
+
+      if (isCompatibleWithSqrtS(3.65))  _sqs = "3.65";
+      else if (isCompatibleWithSqrtS(3.773)) {
+        _sqs = "3.773";
+        book(_sigma[1], 1, 1, 2);
       }
-      else if (isCompatibleWithSqrtS(3.65)) {
-        _ecms = "3.65";
-      }
-      // histograms
-      for (unsigned int ix=0; ix<7; ++ix) {
-        if(ix>0 && ix<5) continue;
+      raiseBeamErrorIf(_sqs.empty());
+      for (size_t ix=0; ix<7; ++ix) {
+        if (ix>0 && ix<5) continue;
         book(_sigma[ix], 1, 1, 1+ix);
       }
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
@@ -63,11 +62,13 @@ namespace Rivet {
       if (ntotal==5 && nCount[310]==1 &&
         ((nCount[-321]==2 && nCount[ 321]==1 && nCount[ 211]==1) ||
 				 (nCount[ 321]==2 && nCount[-321]==1 && nCount[-211]==1))) {
-        _sigma[0]->fill(_ecms);
+        _sigma[0]->fill(_sqs);
       }
 
       // loop over unstable particles
-      for (const Particle& p : ufs.particles(Cuts::pid==221 || Cuts::pid==113 || Cuts::abspid==213)) {
+      for (const Particle& p : ufs.particles(Cuts::pid==221 ||
+                                             Cuts::pid==113 ||
+                                             Cuts::abspid==213)) {
         if (p.children().empty()) continue;
       	map<long,int> nRes = nCount;
       	int ncount = ntotal;
@@ -84,7 +85,7 @@ namespace Rivet {
                   break;
                 }
       	      }
-              else if(abs(val.first)==211) {
+              else if (abs(val.first)==211) {
                 if (val.second!=1) {
                   matched = false;
                   break;
@@ -102,13 +103,13 @@ namespace Rivet {
       	      }
             }
             if (matched) {
-              if (p.pid()==113) _sigma[6]->fill(_ecms);
-              else if (p.pid()==221 &&_sigma[1]) _sigma[1]->fill(_ecms);
+              if (p.pid()==113) _sigma[6]->fill(_sqs);
+              else if (p.pid()==221 && _sqs=="3.773"s) _sigma[1]->fill(_sqs);
             }
           }
         }
         // rho+/-
-        else if(p.abspid()==213) {
+        else if (p.abspid()==213) {
           if (ncount==2) {
             int sign = p.pid()>0 ? -1 : 1;
             matched=true;
@@ -125,12 +126,12 @@ namespace Rivet {
                   break;
                 }
       	      }
-      	      else if(val.second!=0) {
+      	      else if (val.second!=0) {
                 matched = false;
                 break;
       	      }
       	    }
-            if (matched) _sigma[5]->fill(_ecms);
+            if (matched) _sigma[5]->fill(_sqs);
           }
         }
         if (matched) break;
@@ -140,10 +141,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      const double fact = crossSection()/ sumOfWeights() /picobarn;
-      for (unsigned int ix=0; ix<7; ++ix) {
-        if (_sigma[ix]) scale(_sigma[ix],fact);
-      }
+      scale(_sigma, crossSection()/ sumOfWeights() /picobarn);
     }
 
     /// @}
@@ -151,8 +149,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    BinnedHistoPtr<string> _sigma[7];
-    string _ecms;
+    map<int,BinnedHistoPtr<string>> _sigma;
+    string _sqs = "";
     /// @}
 
 
