@@ -10,26 +10,25 @@ namespace Rivet {
   class CDF_2012_NOTE10874 : public Analysis {
   public:
 
-    CDF_2012_NOTE10874()
-      : Analysis("CDF_2012_NOTE10874")
-    {}
+    RIVET_DEFAULT_ANALYSIS_CTOR(CDF_2012_NOTE10874);
 
 
   public:
 
     void init() {
-      const ChargedFinalState cfs((Cuts::etaIn(-1.0, 1.0) && Cuts::pT >=  0.5*GeV));
+      const ChargedFinalState cfs(Cuts::abseta < 1.0 && Cuts::pT >= 0.5*GeV);
       declare(cfs, "CFS");
 
-      int isqrts = -1;
-      if (isCompatibleWithSqrtS(300*GeV)) isqrts = 1;
-      else if (isCompatibleWithSqrtS(900*GeV)) isqrts = 2;
-      else if (isCompatibleWithSqrtS(1960*GeV)) isqrts = 3;
-      assert(isqrts >= 0);
-
-      book(_h_nch_transverse ,1,1,isqrts);
-      book(_h_ptSumDen ,2,1,isqrts);
-      book(_h_avePt ,3,1,isqrts);
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_p[en+"nch_transverse"], 1, 1, ih);
+        book(_p[en+"ptSumDen"], 2, 1, ih);
+        book(_p[en+"avePt"], 3, 1, ih);
+        ++ih;
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
     // Little helper function to identify Delta(phi) regions
@@ -43,9 +42,7 @@ namespace Rivet {
 
     void analyze(const Event& event) {
       const ChargedFinalState& cfs = apply<ChargedFinalState>(event, "CFS");
-      if (cfs.size() < 1) {
-        vetoEvent;
-      }
+      if (cfs.size() < 1) vetoEvent;
 
       Particles particles = cfs.particlesByPt();
       Particle p_lead = particles[0];
@@ -59,29 +56,25 @@ namespace Rivet {
         const double dPhi = deltaPhi(philead, p.phi());
         const int ir = region_index(dPhi);
         if (ir==1) {
-          tNch++;
+          ++tNch;
           ptSum += pT;
         }
       }
 
       const double dEtadPhi = 4.0*PI/3.0;
 
-      _h_nch_transverse->fill(pTlead/GeV, tNch/dEtadPhi);
-      _h_ptSumDen->fill(pTlead/GeV, ptSum/dEtadPhi);
+      _p[_sqs+"nch_transverse"]->fill(pTlead/GeV, tNch/dEtadPhi);
+      _p[_sqs+"ptSumDen"]->fill(pTlead/GeV, ptSum/dEtadPhi);
 
-      if (tNch > 0) {
-        _h_avePt->fill(pTlead/GeV, ptSum/tNch);
-      }
-    }
-
-
-    void finalize() {
+      if (tNch > 0)  _p[_sqs+"avePt"]->fill(pTlead/GeV, ptSum/tNch);
     }
 
 
   private:
 
-    Profile1DPtr _h_nch_transverse, _h_ptSumDen, _h_avePt;
+    map<string,Profile1DPtr> _p;
+
+    string _sqs = "";
 
   };
 
