@@ -22,16 +22,6 @@ namespace Rivet {
     void init() {
 
       // Energy selection
-      int isqrts = -1;
-      if (isCompatibleWithSqrtS(300*GeV)) {
-        isqrts = 2;
-      } else if (isCompatibleWithSqrtS(900*GeV)) {
-        isqrts = 1;
-      } else if (isCompatibleWithSqrtS(1960*GeV)) {
-        isqrts = 0;
-      } else {
-        throw UserError("Unexpected sqrtS ! Only 300, 900, 1960 GeV is supported by CDF_2015_I1388868");
-      }
       MSG_DEBUG("CDF Tevatron UE: running with " << sqrtS()/GeV);
 
       // Book projection
@@ -39,15 +29,22 @@ namespace Rivet {
       declare(cfs, "Tracks");
 
       // Book profile histos
-      book(_NchgPDFden1,  8*isqrts+4,1,1);
-      book(_NchgPMNden1,  8*isqrts+2,1,1);
-      book(_NchgPMXden1,  8*isqrts+1,1,1);
-      book(_NchgPden1,    8*isqrts+3,1,1);
-      book(_PTsumPDFden1, 8*isqrts+8,1,1);
-      book(_PTsumPMNden1, 8*isqrts+6,1,1);
-      book(_PTsumPMXden1, 8*isqrts+5,1,1);
-      book(_PTsumPden1,   8*isqrts+7,1,1);
-
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        size_t ih = 0;
+        if (en == "900"s)  ih = 1;
+        if (en == "300"s)  ih = 2;
+        book(_p[en+"NchgPDFden1"],  8*ih+4,1,1);
+        book(_p[en+"NchgPMNden1"],  8*ih+2,1,1);
+        book(_p[en+"NchgPMXden1"],  8*ih+1,1,1);
+        book(_p[en+"NchgPden1"],    8*ih+3,1,1);
+        book(_p[en+"PTsumPDFden1"], 8*ih+8,1,1);
+        book(_p[en+"PTsumPMNden1"], 8*ih+6,1,1);
+        book(_p[en+"PTsumPMXden1"], 8*ih+5,1,1);
+        book(_p[en+"PTsumPden1"],   8*ih+7,1,1);
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -101,14 +98,14 @@ namespace Rivet {
       const double PTsumPDFden = PTsumPMXden - PTsumPMNden;
 
       // Fill histograms
-      _NchgPden1  ->fill(ptlead/GeV, NchgPtot/AREA);
-      _NchgPMXden1->fill(ptlead/GeV, NchgPmax/AREA);
-      _NchgPMNden1->fill(ptlead/GeV, NchgPmin/AREA);
-      _NchgPDFden1->fill(ptlead/GeV, NchgPDFden );
-      _PTsumPden1  ->fill(ptlead/GeV, PTsumPtot/AREA);
-      _PTsumPMXden1->fill(ptlead/GeV, PTsumPmax/AREA);
-      _PTsumPMNden1->fill(ptlead/GeV, PTsumPmin/AREA);
-      _PTsumPDFden1->fill(ptlead/GeV, PTsumPDFden );
+      _p[_sqs+"NchgPden1"]  ->fill(ptlead/GeV, NchgPtot/AREA);
+      _p[_sqs+"NchgPMXden1"]->fill(ptlead/GeV, NchgPmax/AREA);
+      _p[_sqs+"NchgPMNden1"]->fill(ptlead/GeV, NchgPmin/AREA);
+      _p[_sqs+"NchgPDFden1"]->fill(ptlead/GeV, NchgPDFden );
+      _p[_sqs+"PTsumPden1"]  ->fill(ptlead/GeV, PTsumPtot/AREA);
+      _p[_sqs+"PTsumPMXden1"]->fill(ptlead/GeV, PTsumPmax/AREA);
+      _p[_sqs+"PTsumPMNden1"]->fill(ptlead/GeV, PTsumPmin/AREA);
+      _p[_sqs+"PTsumPDFden1"]->fill(ptlead/GeV, PTsumPDFden );
     }
 
     /// @}
@@ -118,7 +115,9 @@ namespace Rivet {
     constexpr static double AREA = 2*0.8 * M_PI/3;
 
     /// Histograms
-    Profile1DPtr _NchgPden1, _NchgPMXden1,_NchgPMNden1,_NchgPDFden1,_PTsumPden1,_PTsumPMXden1,_PTsumPMNden1,_PTsumPDFden1;
+    map<string,Profile1DPtr> _p;
+
+    string _sqs = "";
 
   };
 
