@@ -14,11 +14,11 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    ///@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
-      declare(UnstableParticles(Cuts::abspid==PID::TAU), "UFS");
+      declare(UnstableParticles(), "UFS");
       book(_hist,  1, 1, 1);
     }
 
@@ -46,7 +46,7 @@ namespace Rivet {
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
-      for (const Particle& p : ufs.particles()) {
+      for (const Particle& p : ufs.particles(Cuts::abspid==PID::TAU)) {
         Particles pi0,pim;
         unsigned int nstable = 0;
         // find the decay products we want
@@ -68,13 +68,13 @@ namespace Rivet {
       normalize(_hist);
     }
 
-    ///@}
+    /// @}
 
 
     /// @name Histograms
-    ///@{
+    /// @{
     Histo1DPtr _hist;
-    ///@}
+    /// @}
 
 
   };
