@@ -29,14 +29,15 @@ namespace Rivet {
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
+      if(_edges.empty()) _edges = _h_sigma->xEdges();
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	double xE = 2.*p.E()/sqrtS();
-	_h_spect->fill(xE);
-	for(unsigned int ix=0;ix<2;++ix) {
-	  if(xE>0.5) _h_sigma->fill(1.);
-	  if(xE>0.7) _h_sigma->fill(2.);
-	}
+        double xE = 2.*p.E()/sqrtS();
+        _h_spect->fill(xE);
+        for (unsigned int ix=0; ix<2; ++ix) {
+          if (xE>0.5) _h_sigma->fill(_edges[0]);
+          if (xE>0.7) _h_sigma->fill(_edges[1]);
+        }
       }
     }
 
@@ -52,7 +53,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_spect,_h_sigma;
+    Histo1DPtr _h_spect;
+    BinnedHistoPtr<string> _h_sigma;
+    vector<string> _edges;
     /// @}
 
 
