@@ -22,13 +22,12 @@ namespace Rivet {
       // Book histograms
       book(_c_hadrons, 1, 1, 1);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -39,23 +38,20 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	vetoEvent;
-      // everything else
-      else
-	_c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22])	vetoEvent;
+      else { // everything else
+        _c_hadrons->fill(_sqs);
+      }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      scale(_c_hadrons, fact);
+      scale(_c_hadrons, crossSection()/ sumOfWeights() /nanobarn);
     }
 
     /// @}
@@ -64,7 +60,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
