@@ -25,14 +25,12 @@ namespace Rivet {
       book(_c_B    , 1, 1, 1);
       book(_c_Bstar, 2, 1, 1);
       for (const string& en : _c_B.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
-
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -44,22 +42,20 @@ namespace Rivet {
       const Particles bhads = select(ufs.particles(), isBottomHadron);
       // find the Bstars
       for (const Particle& p : bhads) {
-        if(abs(p.pid())==513 || abs(p.pid())==523) {
-          if(!p.hasDescendantWith(Cuts::pid == p.pid())) ++nBstar;
+        if (p.abspid()==513 || p.abspid()==523) {
+          if (!p.hasDescendantWith(Cuts::pid == p.pid())) ++nBstar;
         }
       }
-      if(!bhads.empty())
-        _c_B->fill(_ecms);
-      if(nBstar!=0)
-        _c_Bstar->fill(_ecms,nBstar);
+      if (!bhads.empty()) _c_B->fill(_sqs);
+      if (nBstar!=0)      _c_Bstar->fill(_sqs,nBstar);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn;
-      scale(_c_B,fact);
-      scale(_c_Bstar,fact);
+      const double fact = crossSection()/ sumOfWeights() /picobarn;
+      scale(_c_B, fact);
+      scale(_c_Bstar, fact);
     }
 
     /// @}
@@ -68,7 +64,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_B, _c_Bstar;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
