@@ -20,28 +20,27 @@ namespace Rivet {
     /// Book histograms and initialise projections before the run
     void init() {
       declare(FinalState(), "FS");
-      declare(UnstableParticles(Cuts::pid==100553 ||
-                                Cuts::pid==200553), "UFS");
+      declare(UnstableParticles(Cuts::pid==100553 || Cuts::pid==200553), "UFS");
       book(_nUps2pipi, 1,1,2);
       book(_nUps3pipi, 1,1,1);
       for (const string& en : _nUps2pipi.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  --nRes[child.pid()];
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+        if (child.children().empty()) {
+          --nRes[child.pid()];
+          --ncount;
+        }
+        else {
+          findChildren(child,nRes,ncount);
+        }
       }
     }
 
@@ -51,51 +50,49 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	if(p.children().empty()) continue;
-	map<long,int> nRes = nCount;
-	int ncount = ntotal;
-	findChildren(p,nRes,ncount);
-	if(ncount!=1) continue;
-	bool matched = true;
-	for(auto const & val : nRes) {
-	  if(val.first==22) {
-	    if(val.second!=1) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  else if(val.second!=0) {
-	    matched = false;
-	    break;
-	  }
-	}
-	if(matched) {
-	  if(p.pid()==100553)
-	    _nUps2pipi->fill(_ecms);
-	  else if(p.pid()==200553)
-	    _nUps3pipi->fill(_ecms);
-	}
+        if (p.children().empty()) continue;
+        map<long,int> nRes = nCount;
+        int ncount = ntotal;
+        findChildren(p,nRes,ncount);
+        if (ncount!=1) continue;
+        bool matched = true;
+        for (const auto& val : nRes) {
+          if (val.first==22) {
+            if (val.second!=1) {
+              matched = false;
+              break;
+            }
+          }
+          else if (val.second!=0) {
+            matched = false;
+            break;
+          }
+        }
+        if (matched) {
+          if (p.pid()==100553)       _nUps2pipi->fill(_sqs);
+          else if (p.pid()==200553)  _nUps3pipi->fill(_sqs);
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn;
-      scale(_nUps3pipi,fact);
-      scale(_nUps2pipi,fact);
+      const double fact = crossSection()/ sumOfWeights() /picobarn;
+      scale(_nUps3pipi, fact);
+      scale(_nUps2pipi, fact);
     }
     /// @}
 
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nUps2pipi,_nUps3pipi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
