@@ -26,24 +26,22 @@ namespace Rivet {
       book(_c_Bstar, 1, 1, 1);
       for (const string& en : _c_Bstar.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
+        if (idx!=string::npos) {
           const double emin = std::stod(en.substr(0,idx));
           const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms = en;
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs = en;
             break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -55,12 +53,11 @@ namespace Rivet {
       const Particles bhads = ufs.particles(Cuts::abspid==513 or Cuts::abspid==523);
       // find the Bstars
       for (const Particle& p : bhads) {
-        if(abs(p.pid())==513 || abs(p.pid())==523) {
+        if (p.abspid()==513 || p.abspid()==523) {
           if(!p.hasDescendantWith(Cuts::pid == p.pid())) ++nBstar;
         }
       }
-      if(nBstar!=0)
-        _c_Bstar->fill(_ecms,nBstar);
+      if (nBstar!=0)  _c_Bstar->fill(_sqs,nBstar);
     }
 
 
@@ -75,7 +72,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_Bstar;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
