@@ -25,7 +25,7 @@ namespace Rivet {
       declare(ChargedFinalState(Cuts::abseta < 2.4 && Cuts::pT >= 1.0*GeV), "CFS_24_10");
 
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
         size_t offset = (en == "900"s)? 4 : 0;
 
@@ -39,9 +39,7 @@ namespace Rivet {
         book(_c[en+"pt05_eta24"], "_pt05_eta24_"+en);
         book(_c[en+"pt10_eta24"], "_pt10_eta24_"+en);
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -75,7 +73,7 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (dbl(*_c[en+"pt05_eta08"])) scale(_h[en+"dNch_deta_pt05_eta08"], 1./ *_c[en+"pt05_eta08"]);
         if (dbl(*_c[en+"pt10_eta08"])) scale(_h[en+"dNch_deta_pt10_eta08"], 1./ *_c[en+"pt10_eta08"]);
         if (dbl(*_c[en+"pt05_eta24"])) scale(_h[en+"dNch_deta_pt05_eta24"], 1./ *_c[en+"pt05_eta24"]);
