@@ -9,9 +9,7 @@ namespace Rivet {
   class CMS_2012_PAS_QCD_11_010 : public Analysis {
   public:
 
-    CMS_2012_PAS_QCD_11_010()
-      : Analysis("CMS_2012_PAS_QCD_11_010")
-    {  }
+    RIVET_DEFAULT_ANALYSIS_CTOR(CMS_2012_PAS_QCD_11_010);
 
     void init() {
       const FastJets jets(ChargedFinalState(Cuts::abseta < 2.5 && Cuts::pT > 0.5*GeV), JetAlg::ANTIKT, 0.5);
@@ -70,8 +68,6 @@ namespace Rivet {
     }
 
 
-    void finalize() { }
-
   private:
 
     Profile1DPtr _h_nTrans_Kaon;
