@@ -37,7 +37,7 @@ namespace Rivet {
 
       size_t id = 0;
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
         ++id;
 
@@ -51,9 +51,7 @@ namespace Rivet {
         book(_h[en+"num"], "TMP/eflow_jet"+en,  refData(id, 1, 1)); // Leading jet energy flow in pt
         book(_h[en+"den"], "TMP/number_jet"+en, refData(id, 1, 1)); // Number of events in pt
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -138,7 +136,7 @@ namespace Rivet {
 
     void finalize() {
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (_c[en+"incl"]->sumW()) scale(_h[en+"num"], *_c[en+"pass"] / *_c[en+"incl"]);
         divide(_h[en+"num"], _h[en+"den"], _e[en+"ratio"]);
       }
