@@ -346,21 +346,17 @@ namespace Rivet {
 
       /// The default constructor. May specify cuts
       SpecialLeptonFinder(const FinalState& fs, const Cut& cut)
-        : FinalState(cut)
-      {
-        setName("SpecialLeptonFinder");
+        : FinalState(cut) {
+        setName("CMS_2016_I1491950::SpecialLeptonFinder");
         IdentifiedFinalState ifs(fs);
         ifs.acceptIdPair(PID::PHOTON);
         ifs.acceptIdPair(PID::ELECTRON);
         ifs.acceptIdPair(PID::MUON);
-        declare(ifs, "IFS");
         declare(FastJets(ifs, JetAlg::ANTIKT, 0.1), "LeptonJets");
       }
 
-      /// Clone on the heap.
-      virtual unique_ptr<Projection> clone() const {
-        return unique_ptr<Projection>(new SpecialLeptonFinder(*this));
-      }
+      /// Clone on the heap
+      RIVET_DEFAULT_PROJ_CLONE(SpecialLeptonFinder);
 
       /// Import to avoid warnings about overload-hiding
       using Projection::operator =;
@@ -368,11 +364,17 @@ namespace Rivet {
       /// Retrieve the dressed leptons
       const DressedLeptons& dressedLeptons() const { return _clusteredLeptons; }
 
-    private:
-      /// Container which stores the clustered lepton objects
-      DressedLeptons _clusteredLeptons;
+      /// Compare projections
+      CmpState compare(const Projection& p) const {
+        const PCmp fscmp = mkNamedPCmp(p, "LeptonJets");
+        if (fscmp != CmpState::EQ) return fscmp;
+        const SpecialLeptonFinder& other = dynamic_cast<const SpecialLeptonFinder&>(p);
+        const bool cutcmp = _cuts == other._cuts;
+        if (!cutcmp) return CmpState::NEQ;
+        return CmpState::EQ;
+      }
 
-    public:
+      /// Perform the calculation
       void project(const Event& e) {
 
         _theParticles.clear();
@@ -384,7 +386,7 @@ namespace Rivet {
         for (const Jet& jet : jets) {
           Particle lepCand;
           for (const Particle& cand : jet.particles()) {
-            const int absPdgId = abs(cand.pid());
+            const int absPdgId = cand.abspid();
             if (absPdgId == PID::ELECTRON || absPdgId == PID::MUON) {
               if (cand.pt() > lepCand.pt()) lepCand = cand;
             }
@@ -403,7 +405,7 @@ namespace Rivet {
         }
 
         for (const DressedLepton& lepton : allClusteredLeptons) {
-          if (accept(lepton)) {
+          if (_cuts->accept(static_cast<const Particle&>(lepton))) {
             _clusteredLeptons.push_back(lepton);
             _theParticles.push_back(lepton.bareLepton());
             _theParticles += lepton.photons();
@@ -411,6 +413,10 @@ namespace Rivet {
         }
       }
 
+    protected:
+      /// Container which stores the clustered lepton objects
+      DressedLeptons _clusteredLeptons;
+
     };
 
 
