@@ -23,32 +23,29 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::pid==113 || Cuts::pid==223), "UFS");
       // histos
-      for (unsigned int ix=0; ix<2; ++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_c[ix], 1+ix, 1, 1);
         for (const string& en : _c[ix].binning().edges<0>()) {
           const size_t idx = en.find("-");
-          if(idx!=std::string::npos) {
+          if (idx!=std::string::npos) {
             const double emin = std::stod(en.substr(0,idx));
-            const double emax = std::stod(en.substr(idx+1,string::npos));
-            if(inRange(sqrtS()/GeV, emin, emax)) {
-              _ecms[ix] = en;
-              break;
+            const double emax = stod(en.substr(idx+1,string::npos));
+            if (inRange(sqrtS()/GeV, emin, emax)) {
+              _sqs[ix] = en; break;
             }
           }
           else {
-            const double end = std::stod(en)*GeV;
-            if (isCompatibleWithSqrtS(end)) {
-              _ecms[ix] = en;
-              break;
+            const double eval = stod(en)*GeV;
+            if (isCompatibleWithSqrtS(eval)) {
+              _sqs[ix] = en; break;
             }
           }
         }
       }
-      if(_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
-    void findChildren(const Particle& p,map<long,int>& nRes, int & ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -71,7 +68,7 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if (ntotal==5 && nCount[211]==2 && nCount[-211]==2 && nCount[111]==1) _c[0]->fill(_ecms[0]);
+      if (ntotal==5 && nCount[211]==2 && nCount[-211]==2 && nCount[111]==1) _c[0]->fill(_sqs[0]);
       // rho0 mesons
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       for (const Particle& rho : ufs.particles(Cuts::pid==113)) {
@@ -82,11 +79,11 @@ namespace Rivet {
         bool matched=false;
         // omega
         for (const Particle& omega : ufs.particles(Cuts::pid==223)) {
-       	  if(omega.children().empty()) continue;
+       	  if (omega.children().empty()) continue;
           map<long,int> nRes2=nRes;
           int ncount2 = ncount;
           findChildren(omega,nRes2,ncount2);
-          if(ncount2 !=0 ) continue;
+          if (ncount2 !=0 ) continue;
           matched = true;
       	  for (const auto& val : nRes2) {
       	    if (val.second!=0) {
@@ -95,7 +92,7 @@ namespace Rivet {
       	    }
       	  }
           if (matched) {
-            _c[1]->fill(_ecms[1]);
+            _c[1]->fill(_sqs[1]);
             break;
           }
         }
@@ -115,7 +112,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
