@@ -23,17 +23,21 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // book histos
-      if (inRange(sqrtS()/GeV,1.6,3.5)) {
-        for (unsigned int ix=0; ix<9; ++ix) {
-          book(_nMeson[ix],"TMP/nMeson_"+toString(ix+1));
+      for (size_t ih=0; ih<5; ++ih) {
+        book(_est[ih], 5, 1, ih+1);
+        book(_xsec[ih], "_aux_xsec_"+toString(ih), _est[ih].binning().edges<0>());
+      }
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        for (size_t ix=0; ix<9; ++ix) {
+          book(_nMeson[en+toString(ix)],"TMP/nMeson_"+en+"_"+toString(ix+1));
         }
       }
-      else {
-        throw Error("Invalid CMS energy for ARGUS_1987_I248680");
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -59,14 +63,14 @@ namespace Rivet {
       int ires=-1;
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       Particles Kstar=ufs.particles(Cuts::abspid==313);
-      for (unsigned int ix=0;ix<Kstar.size();++ix) {
-       	if(Kstar[ix].children().empty()) continue;
-       	map<long,int> nRes=nCount;
-       	int ncount = ntotal;
-       	findChildren(Kstar[ix],nRes,ncount);
+      for (size_t ix=0; ix<Kstar.size(); ++ix) {
+        if (Kstar[ix].children().empty()) continue;
+        map<long,int> nRes=nCount;
+        int ncount = ntotal;
+        findChildren(Kstar[ix],nRes,ncount);
         bool matched=false;
         // K*K*
-        for (unsigned int iy=ix+1; iy<Kstar.size(); ++iy) {
+        for (size_t iy=ix+1; iy<Kstar.size(); ++iy) {
           if (Kstar[iy].children().empty()) continue;
           if (Kstar[ix].pid()!=-Kstar[iy].pid()) continue;
           map<long,int> nRes2=nRes;
@@ -85,7 +89,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _nMeson[1]->fill();
+          _nMeson[_sqs+"1"s]->fill();
           ires=7;
           break;
         }
@@ -108,8 +112,8 @@ namespace Rivet {
               }
             }
           }
-          if(matched) {
-            _nMeson[2]->fill();
+          if (matched) {
+            _nMeson[_sqs+"2"s]->fill();
             ires=6;
             break;
           }
@@ -147,44 +151,40 @@ namespace Rivet {
       if (ntotal==4 &&
          nCount[PID::KPLUS ]==1 && nCount[PID::KMINUS ]==1 &&
          nCount[PID::PIPLUS]==1 && nCount[PID::PIMINUS]==1 ) {
-          _nMeson[0]->fill();
-          _nMeson[4]->fill();
+        _nMeson[_sqs+"0"s]->fill();
+        _nMeson[_sqs+"4"s]->fill();
+        _xsec[0]->fill(sqrtS()/GeV);
         if (ires<0) {
-          _nMeson[3]->fill();
-          _nMeson[5]->fill();
+          _nMeson[_sqs+"3"s]->fill();
+          _nMeson[_sqs+"5"s]->fill();
+          _xsec[1]->fill(sqrtS()/GeV);
+        }
+        else {
+          _nMeson[_sqs+toString(ires)]->fill();
+          if (ires > 3)  _xsec[ires-4]->fill(sqrtS()/GeV);
         }
-        else _nMeson[ires]->fill();
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nMeson, crossSection()/nanobarn/sumOfWeights());
+      const double sf = crossSection()/nanobarn/sumOfWeights();
+      scale(_nMeson, sf);
+      scale(_xsec, sf);
+      for (size_t ih=0; ih<4; ++ih) {
+        barchart(_xsec[ih], _est[ih]);
+      }
       // loop over tables in paper
-      for (unsigned int ih=1; ih<5; ++ih) {
-       	for (unsigned int iy=1; iy<2; ++iy) {
-          unsigned int iloc=ih+iy-2;
-       	  assert(iloc<=8);
+      for (size_t ih=1; ih<5; ++ih) {
+       	for (size_t iy=1; iy<2; ++iy) {
+          string iloc = toString(ih+iy-2);
        	  BinnedEstimatePtr<string> mult;
        	  book(mult, ih, 1, iy);
           for (auto& b : mult->bins()) {
-            if (isCompatibleWithSqrtS(std::stod(b.xEdge())/GeV)) {
-              b.setVal(_nMeson[iloc]->val());
-              b.setErr(_nMeson[iloc]->err());
-            }
-          }
-        }
-      }
-      for (unsigned int iy=1; iy<6; ++iy) {
-        unsigned int iloc=3+iy;
-        assert(iloc<=8);
-        Estimate1DPtr mult;
-        book(mult, 5, 1, iy);
-        for (auto& b : mult->bins()) {
-          if (inRange(sqrtS(), b.xMin(), b.xMax())) {
-            b.setVal(_nMeson[iloc]->val());
-            b.setErr(_nMeson[iloc]->err());
+            const double eVal = stod(b.xEdge());
+            const string en = toString(round(eVal/MeV));
+            b.set(_nMeson[en+iloc]->val(), _nMeson[en+iloc]->err());
           }
         }
       }
@@ -195,7 +195,10 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    CounterPtr _nMeson[9];
+    map<string,CounterPtr> _nMeson;
+    Histo1DPtr _xsec[5];
+    Estimate1DPtr _est[5];
+    string _sqs = "";
     /// @}
 
 
