@@ -23,12 +23,12 @@ namespace Rivet {
       // histos
       book(_h, 1, 1, 1);
 
-      _edge = "OTHER"s;
       for (const string& edge : _h.binning().edges<0>()) {
-        if (isCompatibleWithSqrtS(std::stod(edge)*GeV)) {
-          _edge = edge;
+        if (isCompatibleWithSqrtS(stod(edge)*GeV)) {
+          _sqs = edge;
         }
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -43,7 +43,7 @@ namespace Rivet {
         ++ntotal;
       }
       if (ntotal==5 && nCount[211]==1 && nCount[-211]==1 &&
-          nCount[321]==1 && nCount[-321]==1 && nCount[111]==1) _h->fill(_edge);
+          nCount[321]==1 && nCount[-321]==1 && nCount[111]==1) _h->fill(_sqs);
     }
 
 
@@ -58,7 +58,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _h;
-    string _edge;
+    string _sqs = "";
     /// @}
 
 
