@@ -23,16 +23,17 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // book histos
-      if (inRange(sqrtS()/GeV,1.4,3.0)) {
-	      for (unsigned int ix=0; ix<4; ++ix)
-	        book(_nMeson[ix],"TMP/nMeson_"+toString(ix+1));
-      }
-      else {
-	      throw Error("Invalid CMS energy for ARGUS_1988_I262713");
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        for (size_t ix=0; ix<4; ++ix) {
+          book(_nMeson[en+toString(ix)], "TMP/nMeson_"+en+"_"+toString(ix+1));
+        }
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
@@ -78,7 +79,7 @@ namespace Rivet {
             }
           }
           if (matched) {
-            _nMeson[0]->fill();
+            _nMeson[_sqs+"0"s]->fill();
             resonant=true;
             break;
           }
@@ -89,13 +90,13 @@ namespace Rivet {
       if (ntotal==4) {
         if (nCount[PID::K0S]==2 &&
            nCount[PID::PIPLUS]==1 && nCount[PID::PIMINUS]==1 ) {
-          _nMeson[1]->fill();
+          _nMeson[_sqs+"1"s]->fill();
         }
         else if ( nCount[PID::K0S]==1 && nCount[PID::PI0]==1 &&
            ((nCount[PID::KPLUS ]==1 && nCount[PID::PIMINUS]==1) ||
             (nCount[PID::KMINUS]==1 && nCount[PID::PIPLUS ]==1))) {
-          _nMeson[2]->fill();
-          if (!resonant) _nMeson[3]->fill();
+          _nMeson[_sqs+"2"s]->fill();
+          if (!resonant) _nMeson[_sqs+"3"s]->fill();
         }
       }
     }
@@ -105,14 +106,13 @@ namespace Rivet {
     void finalize() {
       scale(_nMeson, crossSection()/nanobarn/sumOfWeights());
       // loop over tables in paper
-      for (unsigned int ix=0; ix<4; ++ix) {
+      for (size_t ix=0; ix<4; ++ix) {
         BinnedEstimatePtr<string> mult;
         book(mult, ix+1, 1, 1);
         for (auto& b : mult->bins()) {
-          if (isCompatibleWithSqrtS(std::stod(b.xEdge())/GeV)) {
-            b.setVal(_nMeson[ix]->val());
-            b.setErr(_nMeson[ix]->err());
-          }
+          const double eVal = std::stod(b.xEdge());
+          const string en = toString(round(eVal/MeV));
+          b.set(_nMeson[en+toString(ix)]->val(), _nMeson[en+toString(ix)]->err());
         }
       }
     }
@@ -122,7 +122,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    CounterPtr _nMeson[4];
+    map<string,CounterPtr> _nMeson;
+    string _sqs = "";
     /// @}
 
 
