@@ -23,18 +23,18 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // book histos
-      if (inRange(sqrtS()/GeV,0.8,3.4)) {
-        for (unsigned int ix=0; ix<4; ++ix) {
-          book(_nMeson[ix],"TMP/nMeson_"+toString(ix+1));
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        for (size_t ix=0; ix<4; ++ix) {
+          book(_nMeson[en+toString(ix)],"TMP/nMeson_"+en+"_"+toString(ix+1));
         }
       }
-      else {
-        throw Error("Invalid CMS energy for ARGUS_1989_I266416");
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
@@ -59,20 +59,20 @@ namespace Rivet {
       // find any rho mesons
       Particles rho=apply<UnstableParticles>(event, "UFS").particles(Cuts::abspid==213);
       for (unsigned int ix=0;ix<rho.size();++ix) {
-       	if(rho[ix].children().empty()) continue;
+       	if (rho[ix].children().empty()) continue;
        	map<long,int> nRes=nCount;
        	int ncount = ntotal;
        	findChildren(rho[ix],nRes,ncount);
         bool matched = false;
-        for (unsigned int iy=ix+1;iy<rho.size();++iy) {
-          if(rho[iy].children().empty()) continue;
-          if(rho[ix].pid()!=-rho[iy].pid()) continue;
+        for (size_t iy=ix+1; iy<rho.size(); ++iy) {
+          if (rho[iy].children().empty()) continue;
+          if (rho[ix].pid()!=-rho[iy].pid()) continue;
           map<long,int> nRes2=nRes;
           int ncount2 = ncount;
           findChildren(rho[iy],nRes2,ncount2);
-          if(ncount2 !=0 ) continue;
+          if (ncount2 !=0 ) continue;
           matched=true;
-          for (auto const& val : nRes2) {
+          for (const auto& val : nRes2) {
             if (val.second!=0) {
               matched = false;
               break;
@@ -83,7 +83,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _nMeson[1]->fill();
+          _nMeson[_sqs+"1"s]->fill();
           foundRes=true;
           break;
         }
@@ -105,7 +105,7 @@ namespace Rivet {
             }
           }
           if (matched2) {
-            _nMeson[2]->fill();
+            _nMeson[_sqs+"2"s]->fill();
             foundRes=true;
             break;
           }
@@ -114,8 +114,8 @@ namespace Rivet {
       // 4 pion final-state
       if (ntotal==4) {
         if (nCount[PID::PIPLUS]==1 && nCount[PID::PIMINUS]==1 && nCount[PID::PI0]==2) {
-          _nMeson[0]->fill();
-          if (!foundRes) _nMeson[3]->fill();
+          _nMeson[_sqs+"0"s]->fill();
+          if (!foundRes) _nMeson[_sqs+"3"]->fill();
         }
       }
     }
@@ -125,14 +125,13 @@ namespace Rivet {
     void finalize() {
       scale(_nMeson, crossSection()/nanobarn/sumOfWeights());
       // loop over tables in paper
-      for (unsigned int ix=0; ix<4; ++ix) {
+      for (size_t ix=0; ix<4; ++ix) {
         BinnedEstimatePtr<string> mult;
         book(mult, ix+1, 1, 1);
         for (auto& b : mult->bins()) {
-          if (isCompatibleWithSqrtS(std::stod(b.xEdge())/GeV)) {
-            b.setVal(_nMeson[ix]->val());
-            b.setErr(_nMeson[ix]->err());
-          }
+          const double eVal = std::stod(b.xEdge());
+          const string en = toString(round(eVal/MeV));
+          b.set(_nMeson[en+toString(ix)]->val(), _nMeson[en+toString(ix)]->err());
         }
       }
     }
@@ -142,7 +141,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    CounterPtr _nMeson[4];
+    map<string,CounterPtr> _nMeson;
+    string _sqs = "";
     /// @}
 
 
