@@ -15,7 +15,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -54,49 +54,50 @@ namespace Rivet {
       Particles upsilons = ufs.particles(Cuts::pid==300553);
       // Continuum
       if (upsilons.empty()) {
-	_c_cont->fill();
+        _c_cont->fill();
         MSG_DEBUG("No Upsilons found => continuum event");
-	for(const Particle &p : ufs.particles(Cuts::abspid==411 or Cuts::abspid==421 or Cuts::abspid==413)) {
-	  double xp = p.p3().mod()/sqrt(sqr(meanBeamMom)-sqr(p.mass()));
-	  if(p.abspid()==421) {
-	    _h_x_D0->fill(xp);
-	    _n_D0->fill(10.6);
-	  }
-	  else if(p.abspid()==411) {
-	    _h_x_Dp->fill(xp);
-	    _n_Dp->fill(10.6);
-	  }
-	  else if(p.abspid()==413) {
-	    _h_x_DStar->fill(xp);
-	    _n_DStar->fill(10.6);
-	  }
-	}
+        for (const Particle &p : ufs.particles(Cuts::abspid==411 or Cuts::abspid==421 or Cuts::abspid==413)) {
+          double xp = p.p3().mod()/sqrt(sqr(meanBeamMom)-sqr(p.mass()));
+          if(p.abspid()==421) {
+            _h_x_D0->fill(xp);
+            _n_D0->fill(Ecms);
+          }
+          else if(p.abspid()==411) {
+            _h_x_Dp->fill(xp);
+            _n_Dp->fill(Ecms);
+          }
+          else if(p.abspid()==413) {
+            _h_x_DStar->fill(xp);
+            _n_DStar->fill(Ecms);
+          }
+        }
       }
       // upsilon decay
       else {
         for (const Particle& ups : upsilons) {
-	  _c_ups->fill();
+          _c_ups->fill();
           Particles unstable;
           // Find the decay products we want
           findDecayProducts(ups, unstable);
-	  // boost to rest frame (if required)
+          // boost to rest frame (if required)
           LorentzTransform cms_boost;
-          if (ups.p3().mod() > 1*MeV)
+          if (ups.p3().mod() > 1*MeV) {
             cms_boost = LorentzTransform::mkFrameTransformFromBeta(ups.momentum().betaVec());
-          for(const Particle& p : unstable) {
+          }
+          for (const Particle& p : unstable) {
             const FourMomentum p2 = cms_boost.transform(p.momentum());
-	    double modp = p2.p3().mod();
-	    if(p.abspid()==421) {
-	      _h_p_D0->fill(modp);
-	    }
-	    else if(p.abspid()==411) {
-	      _h_p_Dp->fill(modp);
-	    }
-	    else if(p.abspid()==413) {
-	      _h_p_DStar->fill(modp);
-	    }
-	  }
-	}
+            double modp = p2.p3().mod();
+            if(p.abspid()==421) {
+              _h_p_D0->fill(modp);
+            }
+            else if(p.abspid()==411) {
+              _h_p_Dp->fill(modp);
+            }
+            else if(p.abspid()==413) {
+              _h_p_DStar->fill(modp);
+            }
+          }
+        }
       }
     }
 
@@ -104,15 +105,16 @@ namespace Rivet {
     void findDecayProducts(Particle mother, Particles& unstable) {
       for(const Particle & p: mother.children()) {
         const int id = p.abspid();
-	if (id == 411 || id == 421) {
-	  unstable.push_back(p);
-	}
-	else if (id == 413 ) {
-	  unstable.push_back(p);
-	  findDecayProducts(p, unstable);
-	}
-	else if(!p.children().empty())
-	  findDecayProducts(p, unstable);
+        if (id == 411 || id == 421) {
+          unstable.push_back(p);
+        }
+        else if (id == 413 ) {
+          unstable.push_back(p);
+          findDecayProducts(p, unstable);
+        }
+        else if(!p.children().empty()) {
+          findDecayProducts(p, unstable);
+        }
       }
     }
 
@@ -122,37 +124,37 @@ namespace Rivet {
       double brD0 = 0.0389;
       double brDp = 0.0898;
       double brDStar = 0.677;
-      if(_c_cont->numEntries()!=0) {
-	scale(_n_D0      , 1./sumOfWeights()*crossSection()/nanobarn);
-	scale(_n_Dp      , 1./sumOfWeights()*crossSection()/nanobarn);
-	scale(_n_DStar  ,  1./sumOfWeights()*crossSection()/nanobarn);
-	scale(_h_x_D0   , brD0/sumOfWeights()*crossSection()/nanobarn*sqr(sqrtS()));
-	scale(_h_x_Dp   , brDp/sumOfWeights()*crossSection()/nanobarn*sqr(sqrtS()));
-	scale(_h_x_DStar, brD0*brDStar/sumOfWeights()*crossSection()/nanobarn*sqr(sqrtS()));
+      if (_c_cont->numEntries()!=0) {
+        scale(_n_D0      , 1./sumOfWeights()*crossSection()/nanobarn);
+        scale(_n_Dp      , 1./sumOfWeights()*crossSection()/nanobarn);
+        scale(_n_DStar  ,  1./sumOfWeights()*crossSection()/nanobarn);
+        scale(_h_x_D0   , brD0/sumOfWeights()*crossSection()/nanobarn*sqr(sqrtS()));
+        scale(_h_x_Dp   , brDp/sumOfWeights()*crossSection()/nanobarn*sqr(sqrtS()));
+        scale(_h_x_DStar, brD0*brDStar/sumOfWeights()*crossSection()/nanobarn*sqr(sqrtS()));
       }
-      if(_c_ups->numEntries()!=0) {
-	scale(_h_p_D0   , 1e3*0.5*brD0/ *_c_ups);
-	scale(_h_p_Dp   , 1e3*0.5*brDp/ *_c_ups);
-	scale(_h_p_DStar, 1e3*0.5*brD0*brDStar/ *_c_ups);
+      if (_c_ups->numEntries()!=0) {
+        scale(_h_p_D0   , 1e3*0.5*brD0/ *_c_ups);
+        scale(_h_p_Dp   , 1e3*0.5*brDp/ *_c_ups);
+        scale(_h_p_DStar, 1e3*0.5*brD0*brDStar/ *_c_ups);
       }
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    Histo1DPtr _n_D0,_n_Dp,_n_DStar;
+    /// @{
+    BinnedHistoPtr<string> _n_D0,_n_Dp,_n_DStar;
     Histo1DPtr _h_x_D0,_h_x_Dp,_h_x_DStar;
     Histo1DPtr _h_p_D0,_h_p_Dp,_h_p_DStar;
     CounterPtr _c_cont, _c_ups;
-    //@}
+    const string Ecms = "10.6";
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(ARGUS_1991_I315059);
 
 
