@@ -24,12 +24,15 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       declare(FinalState(), "FS");
 
-      // Book histograms
-      if (isCompatibleWithSqrtS(10.47*GeV)) {
-        book(_h_N, 2, 1, 1);
-        book(_h_tot_N,4,1,1);
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal, 1e-3))  _sqs = en;
       }
+      raiseBeamErrorIf(_sqs.empty());
+      // Book histograms
+      book(_h_N, 2, 1, 1);
       book(_h_N_Upsilon, 3, 1, 1);
+      book(_h_tot_N,4,1,1);
       book(_h_N_tot_Upsilon,5,1,1);
       // counters for R
       book(_c_hadrons, "/TMP/sigma_hadrons");
@@ -39,8 +42,8 @@ namespace Rivet {
     }
 
     /// Recursively walk the decay tree to find decay products of @a p
-    void findDecayProducts(Particle mother, unsigned int& nCharged) {
-      for (const Particle & p: mother.children()) {
+    void findDecayProducts(const Particle& mother, unsigned int& nCharged) const {
+      for (const Particle& p : mother.children()) {
         if (!p.children().empty()) {
           findDecayProducts(p, nCharged);
         }
@@ -68,13 +71,13 @@ namespace Rivet {
           if (PID::isCharged(p.pid())) ++nCharged;
         }
         // mu+mu- + photons
-        if (nCount[-13]==1 and nCount[13]==1 &&
-           ntotal==2+nCount[22])
+        if (_sqs == "9360"s && nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
           _c_muons->fill();
+        }
         // everything else
         else {
-          _c_hadrons->fill();
-          if (_h_N) {
+          if (_sqs == "9360"s) _c_hadrons->fill();
+          else if (_sqs == "10470"s) {
             _h_N->fill(nCharged);
             _h_tot_N->fill(Ecm1, nCharged);
             _w_cont->fill();
@@ -82,7 +85,7 @@ namespace Rivet {
         }
       }
       // upsilon 4s
-      else {
+      else if (_sqs == "10575"s) {
         for (const Particle& ups : upsilons) {
           unsigned int nCharged(0);
           findDecayProducts(ups,nCharged);
@@ -96,21 +99,18 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      Estimate0D R = *_c_hadrons/ *_c_muons;
+      // multi @ 9.36 GeV
       BinnedEstimatePtr<string> mult;
       book(mult, 1, 1, 1);
-      if (isCompatibleWithSqrtS(9.36*GeV)) {
+      if (_c_muons->val()) {
+        Estimate0D R = *_c_hadrons/ *_c_muons;
         mult->bin(1).set(R.val(), R.errPos());
       }
-      if (_h_N) {
-        normalize(_h_N, 100.);
-      if (_w_cont->val()!=0)
-        scale(_h_tot_N,1./ *_w_cont);
-      }
+      // other energies
+      normalize(_h_N, 100.);
       normalize(_h_N_Upsilon, 100.);
-      if (_w_ups->val()!=0) {
-        scale(_h_N_tot_Upsilon,1./ *_w_ups);
-      }
+      if (_w_cont->val())  scale(_h_tot_N, 1.0/ *_w_cont);
+      if (_w_ups->val())   scale(_h_N_tot_Upsilon, 1.0/ *_w_ups);
     }
 
     /// @}
@@ -120,9 +120,9 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<int> _h_N, _h_N_Upsilon;
     BinnedHistoPtr<string> _h_tot_N, _h_N_tot_Upsilon;
-    CounterPtr _c_hadrons, _c_muons;
-    CounterPtr _w_cont,_w_ups;
+    CounterPtr _c_hadrons, _c_muons, _w_cont, _w_ups;
     const string Ecm1 = "10.47", Ecm2 = "10.575";
+    string _sqs = "";
     /// @}
 
 
