@@ -57,7 +57,7 @@ namespace Rivet {
           for (unsigned int iy=0; iy<fs.particles().size(); ++iy) {
             double p2 = fs.particles()[iy].p3().mod();
             double cTheta=fs.particles()[ix].p3().dot(fs.particles()[iy].p3())/p1/p2;
-            double pre=p1*p2/s;
+            double pre=p1*p2/sqr(sqrtS());
             H0 += pre;
             H2 += 0.5*pre*(3.*sqr(cTheta)-1);
           }
