@@ -23,18 +23,44 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // book histos
-      if (inRange(sqrtS()/GeV,1.5,3.0)) {
-        for (unsigned int ix=0; ix<9; ++ix) {
-          book(_nMeson[ix],"TMP/nMeson_"+toString(ix+1));
-        }
-      }
-      else {
-        throw Error("Invalid CMS energy for ARGUS_2000_I511512");
-      }
+      raiseBeamErrorIf(!inRange(sqrtS()/GeV, 1.5, 3.0));
+      // loop over tables in paper
+      book(_h["K0K0_5"],      3, 1, 1);
+      book(_h["K0K0_3"],      4, 1, 1);
+      book(_h["K0K0_1"],      5, 1, 1);
+      book(_h["K0K0_KSKSpp"], 9, 1, 1);
+      book(_h["K0K0_KSK+pp"], 6, 1, 2);
+      book(_h["K0K0"],       10, 1, 1);
+
+      book(_h["KpKm_KSK+pp"], 6, 1, 1);
+      book(_h["KpKm_KSKSpp"], 8, 1, 1);
+      book(_h["KpKm_K+K-pp"], 9, 1, 2);
+      book(_h["K+K-"],       10, 1, 2);
+
+      book(_h["rhoPi_5"], 3, 1, 3);
+      book(_h["rhoPi_3"], 4, 1, 3);
+      book(_h["rhoPi_1"], 5, 1, 3);
+
+      book(_h["K0K+-_5"], 3, 1, 2);
+      book(_h["K0K+-_3"], 4, 1, 2);
+      book(_h["K0K+-_1"], 5, 1, 2);
+
+      book(_h["K+KS-l-"],  7, 1, 1);
+      book(_h["K+KS-p-"],  8, 1, 2);
+      book(_h["K+K-p0"],   7, 1, 2);
+      book(_h["KSKSp-p0"], 7, 1, 3);
+      book(_h["KSKSp+p-"], 8, 1, 3);
+
+      book(_h["K+K-p+p-_5"], 3, 1, 4);
+      book(_h["K+K-p+p-_3"], 4, 1, 4);
+      book(_h["K+K-p+p-_1"], 5, 1, 4);
+
+      book(_h["num"], "TMP/nMeson_num", refData(11, 1, 1));
+      book(_h["den"], "TMP/nMeson_den", refData(11, 1, 1));
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           nRes[child.pid()]-=1;
           --ncount;
@@ -56,27 +82,29 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if(ntotal==4) {
+      if (ntotal==4) {
         if (nCount[PID::KPLUS]==1 && nCount[PID::KMINUS]==1 &&
             nCount[PID::PIPLUS]==1 && nCount[PID::PIMINUS]==1) {
-          _nMeson[6]->fill();
+          _h["K+K-p+p-_5"]->fill(sqrtS()/GeV);
+          _h["K+K-p+p-_3"]->fill(sqrtS()/GeV);
+          _h["K+K-p+p-_1"]->fill(sqrtS()/GeV);
         }
-        else if (nCount[PID::K0S]==2 &&
-                 nCount[PID::PIPLUS]==1 && nCount[PID::PIMINUS]==1) {
-          _nMeson[8]->fill();
+        else if (nCount[PID::K0S]==2 && nCount[PID::PIPLUS]==1 &&
+                 nCount[PID::PIMINUS]==1) {
+          _h["KSKSp+p-"]->fill(sqrtS()/GeV);
         }
         else if (nCount[PID::K0S]==1 && nCount[PID::PI0]==1 &&
                ((nCount[PID::KPLUS ]==1 && nCount[PID::PIMINUS]==1) ||
                 (nCount[PID::KMINUS]==1 && nCount[PID::PIPLUS ]==1))) {
-          _nMeson[7]->fill();
+          _h["KSKSp-p0"]->fill(sqrtS()/GeV);
         }
 
       }
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       // find any K* mesons
       Particles Kstar=ufs.particles(Cuts::abspid==313 or Cuts::abspid==323);
-      for (unsigned int ix=0;ix<Kstar.size();++ix) {
-       	if(Kstar[ix].children().empty()) continue;
+      for (size_t ix=0; ix<Kstar.size(); ++ix) {
+       	if (Kstar[ix].children().empty()) continue;
        	map<long,int> nRes=nCount;
        	int ncount = ntotal;
        	findChildren(Kstar[ix],nRes,ncount);
@@ -88,62 +116,69 @@ namespace Rivet {
             bool matched=true;
             for (const auto& val : nRes) {
               if (val.first==sign*211 || val.first==-sign*321) {
-                if(val.second!=1) {
+                if (val.second!=1) {
                   matched = false;
                   break;
                 }
               }
               else {
-                if(val.second!=0) {
+                if (val.second!=0) {
                   matched = false;
                   break;
                 }
               }
             }
-            if(matched) _nMeson[3]->fill();
+            if (matched) {
+              _h["K0K+-_5"]->fill(sqrtS()/GeV);
+              _h["K0K+-_3"]->fill(sqrtS()/GeV);
+              _h["K0K+-_1"]->fill(sqrtS()/GeV);
+            }
           }
           else {
             bool matched=false;
             // K*+ K0S pi- + cc
-            for(auto const & val : nRes) {
+            for (const auto& val : nRes) {
               if (val.first==-sign*211 || val.first==PID::K0S) {
-                if(val.second!=1) {
+                if (val.second!=1) {
                   matched = false;
                   break;
                 }
               }
               else {
-                if(val.second!=0) {
+                if (val.second!=0) {
                   matched = false;
                   break;
                 }
               }
             }
-            if (matched) _nMeson[4]->fill();
+            if (matched) {
+              _h["K+KS-l-"]->fill(sqrtS()/GeV);
+              _h["K+KS-p-"]->fill(sqrtS()/GeV);
+            }
             else {
               // K*+ K- pi0 +cc
               matched=false;
-              for (auto const & val : nRes) {
+              for (const auto& val : nRes) {
                 if (val.first==-sign*321 || val.first==PID::PI0) {
-                  if(val.second!=1) {
+                  if (val.second!=1) {
                     matched = false;
                     break;
                   }
                 }
                 else {
-                  if(val.second!=0) {
+                  if (val.second!=0) {
                     matched = false;
                     break;
                   }
                 }
               }
-              if (matched) _nMeson[5]->fill();
+              if (matched)  _h["K+K-p0"]->fill(sqrtS()/GeV);
             }
           }
         }
 
         // K*K*
-        for (unsigned int iy=ix+1;iy<Kstar.size();++iy) {
+        for (size_t iy=ix+1; iy<Kstar.size(); ++iy) {
           if (Kstar[iy].children().empty()) continue;
           if (Kstar[ix].pid()!=-Kstar[iy].pid()) continue;
           map<long,int> nRes2=nRes;
@@ -151,7 +186,7 @@ namespace Rivet {
           findChildren(Kstar[iy],nRes2,ncount2);
           if (ncount2 !=0 ) continue;
           bool matched2 = true;
-          for (auto const & val : nRes2) {
+          for (const auto& val : nRes2) {
             if (val.second!=0) {
               matched2 = false;
               break;
@@ -159,36 +194,48 @@ namespace Rivet {
           }
           if (matched2) {
             if (Kstar[ix].abspid()==313) {
-              _nMeson[0]->fill();
+              _h["K0K0_5"]->fill(sqrtS()/GeV);
+              _h["K0K0_3"]->fill(sqrtS()/GeV);
+              _h["K0K0_1"]->fill(sqrtS()/GeV);
+              _h["K0K0_KSKSpp"]->fill(sqrtS()/GeV);
+              _h["K0K0_KSK+pp"]->fill(sqrtS()/GeV);
+              _h["K0K0"]->fill(sqrtS()/GeV);
+              _h["den"]->fill(sqrtS()/GeV);
             }
             else {
-              _nMeson[1]->fill();
+              _h["KpKm_KSK+pp"]->fill(sqrtS()/GeV);
+              _h["KpKm_KSKSpp"]->fill(sqrtS()/GeV);
+              _h["KpKm_K+K-pp"]->fill(sqrtS()/GeV);
+              _h["K+K-"]->fill(sqrtS()/GeV);
+              _h["num"]->fill(sqrtS()/GeV);
             }
             break;
           }
         }
       }
       // finally the rho phi intermediate states
-      for (const Particle & p1 : ufs.particles(Cuts::pid==PID::RHO0)) {
-       	if(p1.children().empty()) continue;
+      for (const Particle& p1 : ufs.particles(Cuts::pid==PID::RHO0)) {
+       	if (p1.children().empty()) continue;
        	map<long,int> nRes=nCount;
        	int ncount = ntotal;
        	findChildren(p1,nRes,ncount);
-        for (const Particle & p2 : ufs.particles(Cuts::pid==PID::PHI)) {
+        for (const Particle& p2 : ufs.particles(Cuts::pid==PID::PHI)) {
           if (p2.children().empty()) continue;
           map<long,int> nRes2=nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
           if (ncount2 !=0 ) continue;
           bool matched = true;
-          for (auto const & val : nRes2) {
+          for (const auto& val : nRes2) {
             if (val.second!=0) {
               matched = false;
               break;
             }
           }
           if (matched) {
-            _nMeson[2]->fill();
+            _h["rhoPi_5"]->fill(sqrtS()/GeV);
+            _h["rhoPi_3"]->fill(sqrtS()/GeV);
+            _h["rhoPi_1"]->fill(sqrtS()/GeV);
             break;
           }
         }
@@ -198,75 +245,11 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nMeson, crossSection()/nanobarn/sumOfWeights());
-      // loop over tables in paper
-      for (unsigned int ih=3; ih<11; ++ih) {
-        unsigned int imax=5;
-        if (ih==6 || ih==9 || ih==10) imax=3;
-        else if (ih==7 || ih==8)  imax=4;
-        for (unsigned int iy=1; iy<imax; ++iy) {
-          unsigned int iloc=1000;
-          // K*0 K*bar0
-          if ((iy==1 && (ih==3||ih==4||ih==5||ih==9||ih==10)) ||
-              (iy==2&&ih==6)) {
-            iloc=0;
-          }
-          // K*+ K*-
-          else if ( (iy==1 && (ih==6 || ih==8)) ||
-              (iy==2 && (ih==9 || ih==10))) {
-            iloc=1;
-          }
-          // rho phi
-          else if(iy==3 && (ih>=3&&ih<=5)) {
-            iloc=2;
-          }
-          // K*0 K- pi+ + cc
-          else if(iy==2 && (ih>=3&&ih<=5)) {
-            iloc=3;
-          }
-          // K+K-pi+pi-
-          else if(iy==4 && (ih>=3&&ih<=5)) {
-            iloc=6;
-          }
-          // K*+ K0S pi-+cc
-          else if( (ih==7&&iy==1) || (ih==8&&iy==2)) {
-            iloc=4;
-          }
-          // K*+ K- pi0 +cc
-          else if(ih==7&&iy==2) {
-            iloc=5;
-          }
-          // KS0 K+ pi- pi0 +cc
-          else if(ih==7&&iy==3) {
-            iloc=7;
-          }
-          // KS0 KS0 pi+ pi-
-          else if(ih==8&&iy==3) {
-            iloc=8;
-          }
-          assert(iloc<=8);
-          Estimate1DPtr mult;
-          book(mult, ih, 1, iy);
-          for (auto& b : mult->bins()) {
-            if (inRange(sqrtS(), b.xMin(), b.xMax())) {
-              b.setVal(_nMeson[iloc]->val());
-              b.setErr(_nMeson[iloc]->err());
-            }
-          }
-        }
-      }
+      scale(_h, crossSection()/nanobarn/sumOfWeights());
       // finally the ratio K*+/K*0
-      if (_nMeson[0]->numEntries()>0) {
-        Estimate0D R = *_nMeson[1]/ *_nMeson[0];
-        Estimate1DPtr mult;
-        book(mult, 11, 1, 1);
-        for (auto& b : mult->bins()) {
-          if (isCompatibleWithSqrtS(b.xMid())) {
-            b.setVal(R.val());
-            b.setErr(R.err());
-          }
-        }
-      }
+      Estimate1DPtr mult;
+      book(mult, 11, 1, 1);
+      divide(_h["num"], _h["den"], mult);
     }
 
     /// @}
@@ -274,7 +257,7 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    CounterPtr _nMeson[9];
+    map<string,Histo1DPtr> _h;
     /// @}
 
 
