@@ -85,22 +85,23 @@ namespace Rivet {
           // Find the decay products we want
           findDecayProducts(ups, unstable);
           LorentzTransform cms_boost;
-          if (ups.p3().mod() > 1*MeV)
+          if (ups.p3().mod() > 1*MeV) {
             cms_boost = LorentzTransform::mkFrameTransformFromBeta(ups.momentum().betaVec());
-            const double mass = ups.mass();
-            // loop over decay products
-            for (const Particle& p : unstable) {
-              const int id = p.pid();
-              const FourMomentum p2 = cms_boost.transform(p.momentum());
-              const double xp = 2.*p2.E()/mass;
-              const double beta = p2.p3().mod()/p2.E();
-              if (id==111) {
-                _n_Ups[0]->fill(Ecm);
-                _h_ups1_pi->fill(xp,1./beta);
-              }
-              else if (id==221) {
-                _n_Ups[1]->fill(Ecm);
-                _h_ups1_eta->fill(xp,1./beta);
+          }
+          const double mass = ups.mass();
+          // loop over decay products
+          for (const Particle& p : unstable) {
+            const int id = p.pid();
+            const FourMomentum p2 = cms_boost.transform(p.momentum());
+            const double xp = 2.*p2.E()/mass;
+            const double beta = p2.p3().mod()/p2.E();
+            if (id==111) {
+              _n_Ups[0]->fill(Ecm);
+              _h_ups1_pi->fill(xp,1./beta);
+            }
+            else if (id==221) {
+              _n_Ups[1]->fill(Ecm);
+              _h_ups1_eta->fill(xp,1./beta);
             }
           }
         }
