@@ -1,5 +1,10 @@
 // -*- C++ -*-
 #include "Rivet/Analysis.hh"
+#include "Rivet/Projections/FinalState.hh"
+#include "Rivet/Projections/FastJets.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
+#include "Rivet/Projections/MissingMomentum.hh"
+#include "Rivet/Projections/DirectFinalState.hh"
 #include "Rivet/Projections/UnstableParticles.hh"
 
 namespace Rivet {
