@@ -14,7 +14,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -38,37 +38,27 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       scale(_c_eta,1./sumOfWeights()*crossSection()/nanobarn);
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr mult;
+      Estimate1DPtr mult;
       book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, _c_eta->val(), ex, make_pair(_c_eta->err(),_c_eta->err()));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
+      for (auto& b : mult->bins()) {
+        if (inRange(sqrtS()/GeV, b.xMin(), b.xMax())) {
+          b.set(_c_eta->val(), _c_eta->err());
+        }
       }
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
+    /// @{
     CounterPtr _c_eta;
-    //@}
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(DASP_1979_I132410);
 
 
