@@ -22,19 +22,18 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      for(unsigned int ix=0;ix<2;++ix) {
-        book(_c_hadrons[ix], "/TMP/sigma_hadrons_"+toString(ix+1), refData<YODA::BinnedEstimate<string>>(1+ix,1,1));
-        book(_c_muons[ix],   "/TMP/sigma_muons_" +toString(ix+1), refData<YODA::BinnedEstimate<string>>(1+ix,1,1));
+      for (size_t ix=0; ix<2; ++ix) {
+        const auto& ref = refData<YODA::BinnedEstimate<string>>(1+ix,1,1);
+        book(_c_hadrons[ix], "/TMP/sigma_hadrons_"+toString(ix+1), ref);
+        book(_c_muons[ix],   "/TMP/sigma_muons_" +toString(ix+1),  ref);
         for (const string& en : _c_hadrons[ix].binning().edges<0>()) {
-          double end = std::stod(en)*GeV;
-          if(isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          double eval = stod(en);
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if(_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
 
@@ -45,27 +44,26 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22]) {
-        for(unsigned int ix=0;ix<2;++ix) _c_muons[ix]->fill(_ecms[ix]);
+      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+        for (size_t ix=0; ix<2; ++ix) _c_muons[ix]->fill(_sqs[ix]);
       }
       // everything else
       else {
-	for(unsigned int ix=0;ix<2;++ix) _c_hadrons[ix]->fill(_ecms[ix]);
+        for (size_t ix=0;ix<2;++ix) _c_hadrons[ix]->fill(_sqs[ix]);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=-0;ix<2;++ix) {
+      for (size_t ix=-0; ix<2; ++ix) {
         BinnedEstimatePtr<string> mult;
         book(mult, 1+ix, 1, 1);
-        divide(_c_hadrons[ix],_c_muons[ix],mult);
+        divide(_c_hadrons[ix], _c_muons[ix], mult);
       }
     }
 
@@ -75,7 +73,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons[2], _c_muons[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
@@ -84,5 +82,4 @@ namespace Rivet {
 
   RIVET_DECLARE_PLUGIN(DESY147_1978_I131524);
 
-
 }
