@@ -25,20 +25,18 @@ namespace Rivet {
       for (size_t i=0; i<2; ++i) {
         const auto& ref = refData(i+1, 1, 1);
         book(_h_hadrons[i], "d0"+to_string(i+1)+"_sigma_hadrons", ref);
-        book(_h_muons[i], "d0"+to_string(i+1)+"_sigma_muons", ref);
+        book(_h_muons[i], "d0"+to_string(i+1)+"_sigma_muons",     ref);
       }
-      book(_c_hadrons, "d03_sigma_hadrons", refData<YODA::BinnedEstimate<string>>(3,1,1));
-      book(_c_muons, "d03_sigma_muons"   , refData<YODA::BinnedEstimate<string>>(3,1,1) );
+      const auto& ref = refData<YODA::BinnedEstimate<string>>(3,1,1);
+      book(_c_hadrons, "d03_sigma_hadrons", ref);
+      book(_c_muons,   "d03_sigma_muons",   ref);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty() && !inRange(sqrtS()/GeV,7.4,9.43))
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      if(_ecms.empty()) _ecms="OTHER";
+      raiseBeamErrorIf(_sqs.empty() && !inRange(sqrtS()/GeV, 7.4, 9.43));
     }
 
 
@@ -56,23 +54,26 @@ namespace Rivet {
       if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
         _h_muons[0]->fill(sqrtS()/GeV);
         _h_muons[1]->fill(sqrtS()/GeV);
-        _c_muons->fill(_ecms);
+        _c_muons->fill(_sqs);
       }
       // everything else
       else {
         _h_hadrons[0]->fill(sqrtS()/GeV);
         _h_hadrons[1]->fill(sqrtS()/GeV);
-        _c_hadrons->fill(_ecms);
+        _c_hadrons->fill(_sqs);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=0;ix<2;++ix) {
+      scale({_c_hadrons, _c_muons}, crossSectionPerEvent());
+      scale(_h_hadrons, crossSectionPerEvent());
+      scale(_h_muons, crossSectionPerEvent());
+      for (size_t ix=0; ix<2; ++ix) {
         Estimate1DPtr mult;
         book(mult, ix+1, 1, 1);
-        divide(_h_hadrons[ix],_h_muons[ix],mult);
+        divide(_h_hadrons[ix], _h_muons[ix], mult);
       }
       BinnedEstimatePtr<string> mult;
       book(mult, 3, 1, 1);
@@ -86,7 +87,7 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
     Histo1DPtr _h_hadrons[2], _h_muons[2];
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
