@@ -22,17 +22,16 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      book(_c_hadrons, "/TMP/sigma_hadrons", refData<YODA::BinnedEstimate<string>>(2,1,1));
-      book(_c_muons,   "/TMP/sigma_muons"  , refData<YODA::BinnedEstimate<string>>(2,1,1));
+      const auto& ref = refData<YODA::BinnedEstimate<string>>(2,1,1);
+      book(_c_hadrons, "/TMP/sigma_hadrons", ref);
+      book(_c_muons,   "/TMP/sigma_muons"  , ref);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
-
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -43,16 +42,15 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) { // mu+mu- + photons
+        _c_muons->fill(_sqs);
+      }
+      else { // everything else
+        _c_hadrons->fill(_sqs);
       }
-      // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	_c_muons->fill(_ecms);
-      // everything else
-      else
-	_c_hadrons->fill(_ecms);
     }
 
 
@@ -69,7 +67,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -78,5 +76,4 @@ namespace Rivet {
 
   RIVET_DECLARE_PLUGIN(PLUTO_1977_I110272);
 
-
 }
