@@ -27,51 +27,48 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       // // Book histograms
       book(_c_hadrons , "/TMP/sigma_hadrons", refData<YODA::BinnedEstimate<string>>(1, 1, 1));
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_c_muons[ix], "/TMP/sigma_muons_"+toString(ix), refData<YODA::BinnedEstimate<string>>(1+2*ix, 1, 1));
         book(_c_kaons[ix], "/TMP/sigma_kaons_"+toString(ix), refData<YODA::BinnedEstimate<string>>(1+2*ix, 1, 1));
         for (const string& en : _c_muons[ix].binning().edges<0>()) {
-          // these points are really Upsilon(1S) decay
-          if(en == "9.45 - 9.466"s || en=="9.45 - 9.456"s) continue;
           const size_t idx = en.find("-");
-          if(idx!=std::string::npos) {
-            const double emin = std::stod(en.substr(0,idx));
-            const double emax = std::stod(en.substr(idx+1,string::npos));
-            if(inRange(sqrtS()/GeV, emin, emax)) {
-              _ecms[ix] = en;
-              break;
+          if (idx != string::npos) {
+            const double emin = stod(en.substr(0,idx));
+            const double emax = stod(en.substr(idx+1,string::npos));
+            if (inRange(sqrtS()/GeV, emin, emax)) {
+              _sqs[ix] = en;  break;
             }
           }
           else {
-            const double end = std::stod(en)*GeV;
-            if (isCompatibleWithSqrtS(end)) {
-              _ecms[ix] = en;
-              break;
+            const double eval = stod(en)*GeV;
+            if (isCompatibleWithSqrtS(eval)) {
+              _sqs[ix] = en; break;
             }
           }
         }
       }
-      if (isCompatibleWithSqrtS(9.4*GeV)) {
-        book(_h_spectrum1, 5, 1, 1);
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
+      size_t ih = 3;
+      for (const double eval : {30.0, 9.4, 9.456}) {
+        const string label = toString(round(eval/MeV));
+        if (isCompatibleWithSqrtS(eval))  _sqs[2] = label;
+        book(_h[label], ++ih, 1, 1);
       }
-      else if (isCompatibleWithSqrtS(30.0*GeV, 1E-2)) {
-        book(_h_spectrum1, 4, 1, 1);
-      }
-      book(_h_spectrum2, 6, 1, 1);
-      book(_c_hadronsY,"TMP/nUps");
+      book(_c_hadronsY, "TMP/nUps");
     }
 
     /// Recursively walk the decay tree to find decay products of @a p
-    void findDecayProducts(Particle mother, Particles &kaons, Particles& stable) {
-      for(const Particle & p: mother.children()) {
+    void findDecayProducts(const Particle& mother, Particles& kaons, Particles& stable) const {
+      for (const Particle& p: mother.children()) {
         const int id = p.pid();
-        if(id==130 || id ==310) {
-          kaons.push_back(p);
+        if (id==130 || id==310) {
+          kaons += p;
         }
         if (id==111 or p.children().empty())
-          stable.push_back(p);
-        else
+          stable += p;
+        else {
           findDecayProducts(p, kaons, stable);
+        }
       }
     }
 
@@ -80,8 +77,7 @@ namespace Rivet {
     void analyze(const Event& event) {
       // Get beams and average beam momentum
       const ParticlePair& beams = apply<Beam>(event, "Beams").beams();
-      const double meanBeamMom = ( beams.first.p3().mod() +
-                                   beams.second.p3().mod() ) / 2.0;
+      const double meanBeamMom = 0.5*(beams.first.p3().mod() + beams.second.p3().mod());
       MSG_DEBUG("Avg beam momentum = " << meanBeamMom);
       // Find the Upsilons among the unstables
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
@@ -97,21 +93,24 @@ namespace Rivet {
           nCount[p.pid()] += 1;
           ++ntotal;
         }
-        // mu+mu- + photons
-        if(nCount[-13]==1 and nCount[13]==1 &&
-           ntotal==2+nCount[22]) {
-          for(unsigned int ix=0;ix<2;++ix) _c_muons[ix]->fill(_ecms[ix]);
+        if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+          // mu+mu- + photons
+          for (size_t ix=0; ix<2; ++ix) {
+            if (!_sqs[ix].empty()) _c_muons[ix]->fill(_sqs[ix]);
+          }
+        }
+        else { // everything else
+          if (!_sqs[0].empty())  _c_hadrons->fill(_sqs[0]);
         }
-        // everything else
-        else
-          _c_hadrons->fill(_ecms[0]);
         // unstable particles
         for (const Particle& p : ufs.particles(Cuts::pid==130 or Cuts::pid==310)) {
-          if(_h_spectrum1) {
-            double xp = p.p3().mod()/meanBeamMom;
-            _h_spectrum1->fill(xp);
+          if (!_sqs[2].empty()) {
+            const double xp = p.p3().mod()/meanBeamMom;
+            _h[_sqs[2]]->fill(xp);
+          }
+          for (size_t ix=0; ix<2; ++ix) {
+            if (!_sqs[ix].empty()) _c_kaons[ix]->fill(_sqs[ix]);
           }
-          for(unsigned int ix=0;ix<2;++ix) _c_kaons[ix]->fill(_ecms[ix]);
         }
       }
       else {
@@ -122,8 +121,9 @@ namespace Rivet {
           findDecayProducts(ups, kaons, stable);
           // boost to rest frame (if required)
           LorentzTransform cms_boost;
-          if (ups.p3().mod() > 1*MeV)
-            cms_boost = LorentzTransform::mkFrameTransformFromBeta(ups.momentum().betaVec());
+          if (ups.p3().mod() > 1*MeV) {
+            cms_boost = LorentzTransform::mkFrameTransformFromBeta(ups.mom().betaVec());
+          }
           const double mass = ups.mass();
 
           map<long,int> nCount;
@@ -132,23 +132,24 @@ namespace Rivet {
             nCount[p.pid()] += 1;
             ++ntotal;
           }
-          for( const Particle & kaon : kaons) {
-            const FourMomentum p2 = cms_boost.transform(kaon.momentum());
+          for (const Particle & kaon : kaons) {
+            const FourMomentum p2 = cms_boost.transform(kaon.mom());
             const double xp = 2.*p2.p3().mod()/mass;
-            _h_spectrum2->fill(xp);
-            _c_kaons[0]->fill("9.45 - 9.466"s);
-            _c_kaons[1]->fill("9.45 - 9.456"s);
+            if (!_sqs[2].empty())  _h[_sqs[2]]->fill(xp);
+            for (size_t ix=0; ix<2; ++ix) {
+              if (!_sqs[ix].empty()) _c_kaons[ix]->fill(_sqs[ix]);
+            }
           }
           // mu+mu- + photons
-          if(nCount[-13]==1 and nCount[13]==1 &&
-             ntotal==2+nCount[22]) {
-            _c_muons[0]->fill("9.45 - 9.466"s);
-            _c_muons[1]->fill("9.45 - 9.456"s);
+          if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+            for (size_t ix=0; ix<2; ++ix) {
+              if (!_sqs[ix].empty()) _c_muons[ix]->fill(_sqs[ix]);
+            }
           }
           // everything else
           else {
-            _c_hadrons->fill("9.45 - 9.466"s);
-            _c_hadronsY->fill();
+            if (!_sqs[0].empty()) _c_hadrons->fill(_sqs[0]);
+            if (_sqs[2] == "9456"s)  _c_hadronsY->fill();
           }
         }
       }
@@ -159,17 +160,20 @@ namespace Rivet {
     void finalize() {
       BinnedEstimatePtr<string> ratio;
       book(ratio,1,1,1);
-      divide(_c_kaons[0],_c_muons[0],ratio);
+      divide(_c_kaons[0], _c_muons[0], ratio);
       book(ratio,2,1,1);
-      divide(_c_kaons[0],_c_hadrons,ratio);
+      divide(_c_kaons[0], _c_hadrons,  ratio);
       book(ratio,3,1,1);
-      divide(_c_kaons[1],_c_muons[1],ratio);
+      divide(_c_kaons[1], _c_muons[1], ratio);
       // normalize the spectra if required
-      if(_h_spectrum1) {
-        scale(_h_spectrum1, sqr(sqrtS())*crossSection()/microbarn/sumOfWeights());
-      }
-      if(_h_spectrum2) {
-        scale(_h_spectrum2, 1./ *_c_hadronsY);
+      for (auto& item : _h) {
+        if (item.first == "9456"s) {
+          if (_c_hadronsY->val())  scale(item.second, 1.0/ *_c_hadronsY);
+        }
+        else {
+          // beam energy not well defined during merging!
+          scale(item.second, sqr(sqrtS())*crossSection()/microbarn/sumOfWeights());
+        }
       }
     }
 
@@ -178,10 +182,10 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    BinnedHistoPtr<string> _c_hadrons,_c_muons[2],_c_kaons[2];
-    string _ecms[2];
-    Histo1DPtr _h_spectrum1, _h_spectrum2;
+    BinnedHistoPtr<string> _c_hadrons, _c_muons[2], _c_kaons[2];
+    map<string, Histo1DPtr> _h;
     CounterPtr _c_hadronsY;
+    string _sqs[3];
     /// @}
 
 
