@@ -24,14 +24,12 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nProton, 1, 1, 1);
       for (const string& en : _nProton.binning().edges<0>()) {
-        const double end = sqrt(std::stod(en)*GeV);
-        if (isCompatibleWithSqrtS(end)) {
-          _s = en;
-          break;
+        const double eval = sqrt(stod(en));
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_s.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -42,11 +40,10 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        ++nCount[p.pid()];
+        ++ntotal;
       }
-      if(ntotal==2 && nCount[2212]==1 && nCount[-2212]==1)
-	_nProton->fill(_s);
+      if (ntotal==2 && nCount[2212]==1 && nCount[-2212]==1) _nProton->fill(_sqs);
     }
 
 
@@ -61,7 +58,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nProton;
-    string _s;
+    string _sqs = "";
     /// @}
 
 
@@ -69,6 +66,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(FENICE_1994_I377833);
-
-
 }
