@@ -24,14 +24,12 @@ namespace Rivet {
       // Book histograms
       book(_c_hadrons, 1, 1, 1);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        const double end = sqrt(std::stod(en)*GeV);
-        if (isCompatibleWithSqrtS(end)) {
-          _s = en;
-          break;
+        const double eval = sqrt(stod(en));
+        if (isCompatibleWithSqrtS(eval, 1e-3)) {
+          _sqs = en; break;
         }
       }
-      if (_s.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -42,14 +40,12 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        ++nCount[p.pid()];
+        ++ntotal;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	vetoEvent;
-      _c_hadrons->fill(_s);
+      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) vetoEvent;
+      _c_hadrons->fill(_sqs);
     }
 
 
@@ -64,7 +60,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons;
-    string _s;
+    string _sqs = "";
     /// @}
 
 
@@ -72,6 +68,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(FENICE_1996_I426675);
-
-
 }
