@@ -24,14 +24,12 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_nNeutron, 1,1,1);
       for (const string& en : _nNeutron.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -42,11 +40,10 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        ++nCount[p.pid()];
+        ++ntotal;
       }
-      if(ntotal==2 && nCount[2112]==1 && nCount[-2112]==1)
-	_nNeutron->fill(_ecms);
+      if (ntotal==2 && nCount[2112]==1 && nCount[-2112]==1) _nNeutron->fill(_sqs);
     }
 
 
@@ -61,7 +58,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nNeutron;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
