@@ -28,23 +28,21 @@ namespace Rivet {
       book(_c_neutral, 2, 1, 2);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms = en;
-            break;
+        if(idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1,string::npos));
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs = en; break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval= stod(en);
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -53,25 +51,21 @@ namespace Rivet {
       const FinalState& fs = apply<FinalState>(event, "FS");
 
       map<long,int> nCount;
-      int ntotal(0),ncharged(0),nneutral(0);
+      int ntotal(0), ncharged(0), nneutral(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
-	if(PID::isCharged(p.pid()))
-	  ncharged += 1;
-	else
-	  nneutral += 1;
+        ++nCount[p.pid()];
+        ++ntotal;
+        if (PID::isCharged(p.pid())) ++ncharged;
+        else                         ++nneutral;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	_c_muons->fill(_ecms);
+      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) _c_muons->fill(_sqs);
       // everything else
       else {
-	if(ntotal==2) vetoEvent;
-	_c_hadrons->fill(_ecms);
-	_c_charged->fill(sqrtS()/GeV,ncharged);
-	_c_neutral->fill(sqrtS()/GeV,nneutral);
+        if (ntotal==2) vetoEvent;
+        _c_hadrons->fill(_sqs);
+        _c_charged->fill(sqrtS()/GeV,ncharged);
+        _c_neutral->fill(sqrtS()/GeV,nneutral);
       }
     }
 
@@ -90,7 +84,7 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
     Profile1DPtr _c_neutral,_c_charged;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -98,6 +92,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(GAMMAGAMMA_1979_I141722);
-
-
 }
