@@ -21,34 +21,34 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       // get the CMS point
-      unsigned int ix=0;
-      if (isCompatibleWithSqrtS(1.01955))     ix=1;
-      else if(isCompatibleWithSqrtS(1.01965)) ix=2;
-      else if(isCompatibleWithSqrtS(1.01985)) ix=3;
-      else if(isCompatibleWithSqrtS(1.01995)) ix=4;
-      else throw Error("Unexpected sqrtS !");
-      for (unsigned int iy=0; iy<2; ++iy) {
-        book(_h[iy],1,ix,iy+1);
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(10*eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en+"0"s], 1, ih, 1);
+        book(_h[en+"1"s], 1, ih, 2);
+        ++ih;
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      Particles pi0,gamma;
+      Particles pi0, gamma;
       map<long,Particles> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-        if (p.pid()==PID::PI0)          pi0.push_back(p);
-        else if (p.pid()==PID::GAMMA) gamma.push_back(p);
+        if (p.pid() == PID::PI0)          pi0 += p;
+        else if (p.pid() == PID::GAMMA) gamma += p;
         ++ntotal;
       }
       // three particles (pi0 pi0 gamma)
       if (ntotal!=3 || pi0.size()!=2 || gamma.size()!=1) vetoEvent;
-      _h[0]->fill((pi0[0].mom()+  pi0[1].mom()).mass()/MeV);
-      _h[1]->fill((pi0[0].mom()+gamma[0].mom()).mass()/MeV);
-      _h[1]->fill((pi0[1].mom()+gamma[0].mom()).mass()/MeV);
+      _h[_sqs+"0"]->fill((pi0[0].mom()+  pi0[1].mom()).mass()/MeV);
+      _h[_sqs+"1"]->fill((pi0[0].mom()+gamma[0].mom()).mass()/MeV);
+      _h[_sqs+"1"]->fill((pi0[1].mom()+gamma[0].mom()).mass()/MeV);
     }
 
 
@@ -62,7 +62,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h[2];
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
 
