@@ -23,14 +23,12 @@ namespace Rivet {
       book(_n4pi, 1,1,1);
       book(_n2pigamma, 2,1,1);
       for (const string& en : _n4pi.binning().edges<0>()) {
-        const double end = std::stod(en)*MeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -43,11 +41,11 @@ namespace Rivet {
         nCount[p.pid()] += 1;
       }
       if (nCount[111]==2) {
-        if( nCount[211] == 1 && nCount[-211] == 1 ) {
-          _n4pi->fill(_ecms);
+        if (nCount[211] == 1 && nCount[-211] == 1) {
+          _n4pi->fill(_sqs);
         }
-        else if( nCount[22] == 1) {
-          _n2pigamma->fill(_ecms);
+        else if (nCount[22] == 1) {
+          _n2pigamma->fill(_sqs);
         }
       }
     }
@@ -55,9 +53,9 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      scale(_n4pi,fact);
-      scale(_n2pigamma,fact);
+      const double fact = crossSection()/ sumOfWeights() /nanobarn;
+      scale(_n4pi, fact);
+      scale(_n2pigamma, fact);
     }
 
     /// @}
@@ -66,7 +64,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _n4pi,_n2pigamma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
