@@ -25,14 +25,12 @@ namespace Rivet {
       book(_c_hadrons, 1, 1, 1);
       book(_c_muons, "/TMP/sigma_muons", refData<YODA::BinnedEstimate<string>>(1, 1, 1));
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en);
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -43,16 +41,15 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        ++nCount[p.pid()];
+        ++ntotal;
+      }
+      if (nCount[-13]==1 and nCount[13]==1 &&	 ntotal==2+nCount[22]) { // mu+mu- + photons
+        _c_muons->fill(_sqs);
+      }
+      else { // everything else
+        _c_hadrons->fill(_sqs);
       }
-      // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	_c_muons->fill(_ecms);
-      // everything else
-      else
-	_c_hadrons->fill(_ecms);
     }
 
 
@@ -61,8 +58,7 @@ namespace Rivet {
       BinnedEstimatePtr<string> mult;
       book(mult, 1, 1, 2);
       divide(_c_hadrons,_c_muons,mult);
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      scale(_c_hadrons,fact);
+      scale(_c_hadrons, crossSection()/ sumOfWeights() /nanobarn);
     }
 
     /// @}
@@ -71,7 +67,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
