@@ -247,7 +247,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double iq;
+      unsigned int iq;
       double mean, dispersion, cq, R2, R3, K3;
       for (auto& histo : _g["mult_all"]->bins()) {
         iq = 2;
@@ -509,7 +509,7 @@ namespace Rivet {
 
 
     inline void _histo_to_moments(const BinnedHistoPtr<int>& histo_input,
-                                  double iq, double& mean, double& dispersion, double& cq,
+                                  unsigned int iq, double& mean, double& dispersion, double& cq,
                                   double& R2, double& R3, double& K3) {
 
       double mysumWX = 0.;
@@ -532,17 +532,17 @@ namespace Rivet {
         for (const auto& b : histo_input->bins()) { // loop over points
           const double xval = b.xEdge();
           const double weight = b.sumW();
-          var = var + weight * pow((xval - mean),iq) ;
-          c = c+pow(xval,iq)*weight;
+          var = var + weight * intpow((xval - mean),iq) ;
+          c = c+intpow(xval,iq)*weight;
           r2 = r2+xval*(xval-1)*weight;
           r3 = r3+xval*(xval-1)*(xval-2)*weight;
         }
         var = var/mysumW;
-        dispersion = pow(var,1./iq);
-        cq = c/(mysumW*pow(mean,iq));
-        R2 = r2/(mysumW*pow(mean,2));
-        R3 = r3/(mysumW*pow(mean,3));
-        K3 = R3 - 3*R2 + 2;
+        dispersion = pow(var,1.0/(double)iq);
+        cq = c/(mysumW*intpow(mean,iq));
+        R2 = r2/(mysumW*intpow(mean,2));
+        R3 = r3/(mysumW*intpow(mean,3));
+        K3 = subtract(R3, 3*R2 - 2);
       }
     }
 
