@@ -15,7 +15,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -38,25 +38,24 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_histChTot, 200.0/sumOfWeights()); // bin width (2) and %age (100)
+      scale(_histChTot, 100.0/sumOfWeights()); // %age (100)
     }
 
-    //@}
+    /// @}
 
 
   private:
 
     /// @name Histograms
-    //@{
-    Histo1DPtr _histChTot;
+    /// @{
+    BinnedHistoPtr<int> _histChTot;
     Profile1DPtr _histAver;
-    //@}
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(DELPHI_1991_I301657);
 
 
