@@ -39,7 +39,7 @@ namespace Rivet {
       size_t ie=0;
       for (double eVal : allowedEnergies()) {
 
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
 
         size_t offset , offset2;
@@ -81,9 +81,7 @@ namespace Rivet {
         }
         ++ie;
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
     void fillMoment(array<BinnedProfilePtr<int>,3>& mom, double val) {
@@ -147,7 +145,7 @@ namespace Rivet {
     void finalize() {
       for (double eVal : allowedEnergies()) {
 
-        const string en = toString(int(eVal));
+        const string en = toString(round(eVal));
 
         for (auto& item : _h) {
           if (item.first.substr(0,3) != en)  continue;
