@@ -35,7 +35,7 @@ namespace Rivet {
       declare(ParisiTensor(fs), "Parisi");
       declare(Hemispheres(thrust), "Hemispheres");
       declare(FastJets(fs, JetAlg::DURHAM, 0.7), "DurhamJets");
-      declare(FastJets(fs, JetAlg::JADE  , 0.7), "JadeJets"  );
+      declare(FastJets(fs, JetAlg::JADE       ), "JadeJets"  );
 
       // book histograms
       vector<double> bins={0.00,0.12,0.24,0.36,0.48,0.60,0.72,0.84,0.96};
