@@ -15,14 +15,13 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
       // get the hadronic final state
-      const GammaGammaKinematics& diskin = declare(GammaGammaKinematics(), "Kinematics");
-      const FinalState & fs = declare(GammaGammaFinalState(diskin), "FS");
-      declare(FastJets(fs, FastJets::KT,1.),"Jets");
+      const FinalState & fs = declare(GammaGammaFinalState(), "FS");
+      declare(FastJets(fs, JetAlg::KT,1.),"Jets");
 
       // Book histograms
       book(_h_y, 1, 1, 1);
@@ -47,19 +46,18 @@ namespace Rivet {
 
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
+    /// @{
     Histo1DPtr _h_y;
-    //@}
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(L3_2004_I661114);
 
 
