@@ -15,7 +15,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -31,31 +31,31 @@ namespace Rivet {
     void analyze(const Event& event) {
       const FinalState& cfs = apply<FinalState>(event, "CFS");
       MSG_DEBUG("Total charged multiplicity = " << cfs.size());
-      _histChTot->fill(cfs.size(), 1.0);
-      _histAver->fill(sqrtS(),cfs.size(),1.0);
+      _histChTot->fill(cfs.size());
+      _histAver->fill(Ecm, cfs.size());
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_histChTot, 200.0/sumOfWeights()); // bin width (2) and %age (100)
+      scale(_histChTot, 100.0/sumOfWeights()); // %age (100)
     }
 
-    //@}
+    /// @}
 
 
   private:
 
     /// @name Histograms
-    //@{
-    Histo1DPtr _histChTot;
-    Profile1DPtr _histAver;
-    //@}
+    /// @{
+    BinnedHistoPtr<int> _histChTot;
+    BinnedProfilePtr<string> _histAver;
+    const string Ecm = "91.2";
+    /// @}
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(OPAL_1992_I321190);
 
 
