@@ -43,7 +43,7 @@ namespace Rivet {
       size_t ih = 1;
       for (double eVal : allowedEnergies()) {
 
-        const string en = toString(int(eVal/MeV));
+        const string en = toString(round(eVal/MeV));
         if (isCompatibleWithSqrtS(eVal))  _sqs = en;
 
         book(_h[en+"thrust"],      1,1,ih);
@@ -65,9 +65,7 @@ namespace Rivet {
         book(_h[en+"xi"],         19,1,ih);
         ++ih;
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -150,7 +148,7 @@ namespace Rivet {
 
       // scale histos + fill averages
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal/MeV));
+        const string en = toString(round(eVal/MeV));
 
         const double sumw = _mult[en]->sumW();
         if (sumw == 0)  continue;
@@ -162,7 +160,7 @@ namespace Rivet {
         }
 
         for (size_t ih=1; ih <= m_ch->numBins(); ++ih) {
-          if (m_ch->bin(ih).xEdge() != int(eVal))  continue;
+          if (m_ch->bin(ih).xEdge() != round(eVal))  continue;
 
           const double nch     = _mult[en]->xMean();
           const double nch_err = _mult[en]->xStdErr();
