@@ -5,55 +5,63 @@
 namespace Rivet {
 
 
+  /// @brief V0 production ratios at 0.9 and 7 TeV
   class LHCB_2011_I917009 : public Analysis {
   public:
 
     /// Constructor
-    LHCB_2011_I917009()
-      : Analysis("LHCB_2011_I917009"),
-        rap_beam(0.0), pt_min(0.0),
-        pt1_edge(0.65), pt2_edge(1.0),
-        pt3_edge(2.5), rap_min(2.),
-        rap_max(0.0), dsShift(0)
-    {   }
+    RIVET_DEFAULT_ANALYSIS_CTOR(LHCB_2011_I917009);
 
     /// @name Analysis methods
     /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
-      int y_nbins = 4;
       fillMap(partLftMap);
-      if (isCompatibleWithSqrtS(900*GeV)) {
+
+      for (double eVal : allowedEnergies()) {
+        const int en = round(eVal);
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+
+        rap_beam = (en == 900)? 6.87 : 8.92;
+        rap_max  = (en == 900)? 4. : 4.5;
+        bool is7TeV = en == 7000;
+
+        // Create the sets of temporary histograms that will be used to make the ratios in the finalize()
+        for (size_t i = 0; i < 12; ++i) {
+          book(_h[en+i], "TMP/"+to_str(en+i), 4+is7TeV, 2.0, rap_max);
+        }
+        for (size_t i = 12; i < 15; ++i) {
+          book(_h[en+i], "TMP/"+to_str(en+i), refData(8*is7TeV+5, 1, 1));
+        }
+        for (size_t i = 15; i < 18; ++i) {
+          book(_h[en+i], "TMP/"+to_str(en+i), 4+is7TeV, rap_beam - rap_max, rap_beam - 2.0);
+        }
+
+        int dsId = 8*is7TeV + 1;
+        for (size_t j = 0; j < 3; ++j) {
+          book(_s[en+10+j], dsId, 1, j+1);
+          book(_s[en+20+j], dsId+1, 1, j+1);
+        }
+        dsId += 2;
+        for (size_t j = 3; j < 6; ++j) {
+          book(_s[en+30+j-3], dsId, 1, 1);
+          dsId += 1;
+          book(_s[en+40+j-3], dsId, 1, 1);
+          dsId += 1;
+        }
+
+      }
+      raiseBeamErrorIf(_sqs==0);
+
+      if (_sqs == 900) {
         rap_beam = 6.87;
         rap_max = 4.;
         pt_min = 0.25;
-      } else if (isCompatibleWithSqrtS(7000*GeV)) {
+      } else {
         rap_beam = 8.92;
         rap_max = 4.5;
         pt_min = 0.15;
-        y_nbins = 5;
-        dsShift = 8;
-      } else {
-        MSG_ERROR("Incompatible beam energy!");
-      }
-
-      // Create the sets of temporary histograms that will be used to make the ratios in the finalize()
-      for (size_t i = 0; i < 12; ++i)  book(_tmphistos[i], "TMP/"+to_str(i), y_nbins, rap_min, rap_max);
-      for (size_t i = 12; i < 15; ++i) book(_tmphistos[i], "TMP/"+to_str(i), refData(dsShift+5, 1, 1));
-      for (size_t i = 15; i < 18; ++i) book(_tmphistos[i], "TMP/"+to_str(i), y_nbins, rap_beam - rap_max, rap_beam - rap_min);
-
-      int dsId = dsShift + 1;
-      for (size_t j = 0; j < 3; ++j) {
-        book(s1[j], dsId, 1, j+1);
-        book(s2[j], dsId+1, 1, j+1);
-      }
-      dsId += 2;
-      for (size_t j = 3; j < 6; ++j) {
-        book(s3[j-3], dsId, 1, 1);
-        dsId += 1;
-        book(s4[j-3], dsId, 1, 1);
-        dsId += 1;
       }
 
       declare(UnstableParticles(), "UFS");
@@ -88,41 +96,38 @@ namespace Rivet {
         // skip this particle if it has too high or too low rapidity (extremely rare cases when E = +- pz)
         if ( std::isnan(y) || std::isinf(y) ) continue;
         y = fabs(y);
-        if (!inRange(y, rap_min, rap_max)) continue;
+        if (!inRange(y, 2.0, rap_max)) continue;
         pT = sqrt((qmom.px() * qmom.px()) + (qmom.py() * qmom.py()));
-        if (!inRange(pT, pt_min, pt3_edge)) continue;
+        if (!inRange(pT, pt_min, 2.5)) continue;
         // Filling corresponding temporary histograms for pT intervals
-        if (inRange(pT, pt_min, pt1_edge)) _tmphistos[partIdx*3]->fill(y);
-        if (inRange(pT, pt1_edge, pt2_edge)) _tmphistos[partIdx*3+1]->fill(y);
-        if (inRange(pT, pt2_edge, pt3_edge)) _tmphistos[partIdx*3+2]->fill(y);
+        if (inRange(pT, pt_min, 0.65)) _h[_sqs+partIdx*3]->fill(y);
+        if (inRange(pT, 0.65, 1.0)) _h[_sqs+partIdx*3+1]->fill(y);
+        if (inRange(pT, 1.0, 2.5)) _h[_sqs+partIdx*3+2]->fill(y);
         // Fill histo in rapidity for whole pT interval
-        _tmphistos[partIdx+9]->fill(y);
+        _h[_sqs+partIdx+9]->fill(y);
         // Fill histo in pT for whole rapidity interval
-        _tmphistos[partIdx+12]->fill(pT);
+        _h[_sqs+partIdx+12]->fill(pT);
         // Fill histo in rapidity loss for whole pT interval
-        _tmphistos[partIdx+15]->fill(rap_beam - y);
+        _h[_sqs+partIdx+15]->fill(rap_beam - y);
       }
     }
 
 
     // Generate the ratio histograms
     void finalize() {
-      for (size_t j = 0; j < 3; ++j) {
-        divide(_tmphistos[j], _tmphistos[3+j], s1[j]);
-        divide(_tmphistos[j], _tmphistos[6+j], s2[j]);
-      }
-      for (size_t j = 3; j < 6; ++j) {
-        divide(_tmphistos[3*j], _tmphistos[3*j+1], s3[j-3]);
-        divide(_tmphistos[3*j], _tmphistos[3*j+2], s4[j-3]);
+      for (double eVal : allowedEnergies()) {
+        const int en = round(eVal);
+        for (size_t j = 0; j < 3; ++j) {
+          divide(_h[en+j], _h[en+3+j], _s[en+10+j]);
+          divide(_h[en+j], _h[en+6+j], _s[en+20+j]);
+          divide(_h[en+3*(j+3)], _h[en+3*(j+3)+1], _s[en+30+j]);
+          divide(_h[en+3*(j+3)], _h[en+3*(j+3)+2], _s[en+40+j]);
+        }
       }
     }
 
     /// @}
 
-
-
-  private:
-
     // Get particle lifetime from hardcoded data
     double getLifeTime(int pid) {
       double lft = -1.0;
@@ -156,20 +161,22 @@ namespace Rivet {
       ConstGenVertexPtr ivtx = part->production_vertex();
       while (ivtx) {
 
-          vector<ConstGenParticlePtr> part_in = HepMCUtils::particles(ivtx, Relatives::PARENTS);
+        vector<ConstGenParticlePtr> part_in = HepMCUtils::particles(ivtx, Relatives::PARENTS);
 
-          if (part_in.size() < 1) { lftSum = -1.; break; };
-          ConstGenParticlePtr part = part_in.at(0);//(*iPart_invtx);
-          if ( !(part) ) { lftSum = -1.; break; };
-          ivtx = part->production_vertex();
-          if ( (part->pdg_id() == 2212) || !(ivtx) ) break; //reached beam
-          plft = getLifeTime(part->pdg_id());
-          if (plft < 0.) { lftSum = -1.; break; };
-          lftSum += plft;
-        };
+        if (part_in.size() < 1) { lftSum = -1.; break; };
+        ConstGenParticlePtr part = part_in.at(0);//(*iPart_invtx);
+        if ( !(part) ) { lftSum = -1.; break; };
+        ivtx = part->production_vertex();
+        if ( (part->pdg_id() == 2212) || !(ivtx) ) break; //reached beam
+        plft = getLifeTime(part->pdg_id());
+        if (plft < 0.) { lftSum = -1.; break; };
+        lftSum += plft;
+      };
       return (lftSum * c_light);
     }
 
+  private:
+
     /// @name Private variables
     /// @{
 
@@ -177,21 +184,19 @@ namespace Rivet {
     double rap_beam;
 
     // The edges of the intervals of transverse momentum
-    double pt_min, pt1_edge, pt2_edge, pt3_edge;
+    double pt_min;
 
     // The limits of the rapidity window
-    double rap_min;
     double rap_max;
 
-    // Indicates which set of histograms will be output to yoda file (according to beam energy)
-    int dsShift;
-
     // Map between PDG id and particle lifetimes in seconds
     map<int, double> partLftMap;
 
     // Set of PDG Ids for stable particles (PDG Id <= 100 are considered stable)
     static const int stablePDGIds[205];
 
+    size_t _sqs = 0;
+
     /// @}
 
     /// @name Helper histograms
@@ -201,8 +206,8 @@ namespace Rivet {
     /// Next 3 histograms contain the particles in y bins for the whole pT interval (3 histos)
     /// Next 3 histograms contain the particles in y_loss bins for the whole pT interval (3 histos)
     /// Last 3 histograms contain the particles in pT bins for the whole rapidity (y) interval (3 histos)
-    Histo1DPtr _tmphistos[18];
-    array<Estimate1DPtr,3> s1,s2,s3,s4;
+    map<size_t,Histo1DPtr> _h;
+    map<size_t,Estimate1DPtr> _s;
     /// @}
 
     // Fill the PDG ID to Lifetime[seconds] map
