@@ -12,61 +12,54 @@ namespace Rivet {
     /// @{
 
     /// Constructor
-    LHCB_2012_I1119400() : Analysis("LHCB_2012_I1119400"),
-      _p_min(5.0),
-      _pt_min(0.0),_pt1_edge(0.8), _pt2_edge(1.2),
-      //_eta_nbins(4),
-      _eta_min(2.5),
-      _eta_max(4.5)
-    {   }
+    RIVET_DEFAULT_ANALYSIS_CTOR(LHCB_2012_I1119400);
 
     /// @}
 
-
-    public:
-
     /// @name Analysis methods
     /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
+
       fillMap(_partLftMap);
 
-      int id_shift = 0;
-      if (isCompatibleWithSqrtS(7000*GeV)) id_shift = 1;
       // define ratios if second pdgid in pair is -1, it means that is a antiparticle/particle ratio
-
-      _ratiotype["pbarp"]         = make_pair(2212, -1);
-      _ratiotype["kminuskplus"]   = make_pair(321, -1);
-      _ratiotype["piminuspiplus"] = make_pair(211, -1);
+      _ratiotype["pbarp"]         = make_pair(2212,  -1);
+      _ratiotype["kminuskplus"]   = make_pair( 321,  -1);
+      _ratiotype["piminuspiplus"] = make_pair( 211,  -1);
       _ratiotype["ppi"]           = make_pair(2212, 211);
-      _ratiotype["kpi"]           = make_pair(321, 211);
+      _ratiotype["kpi"]           = make_pair( 321, 211);
       _ratiotype["pk"]            = make_pair(2212, 321);
 
       std::map<string, int > _hepdataid;
-      _hepdataid["pbarp"]         =  1 + id_shift;
-      _hepdataid["kminuskplus"]   =  3 + id_shift;
-      _hepdataid["piminuspiplus"] =  5 + id_shift;
-      _hepdataid["ppi"]           =  7 + id_shift;
-      _hepdataid["kpi"]           =  9 + id_shift;
-      _hepdataid["pk"]            = 11 + id_shift;
+      _hepdataid["pbarp"]         =  1;
+      _hepdataid["kminuskplus"]   =  3;
+      _hepdataid["piminuspiplus"] =  5;
+      _hepdataid["ppi"]           =  7;
+      _hepdataid["kpi"]           =  9;
+      _hepdataid["pk"]            = 11;
 
-      std::map<std::string, std::pair<int, int> >::iterator it;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
 
-      // booking histograms
-      for (it=_ratiotype.begin(); it!=_ratiotype.end(); it++) {
-        book(_h_ratio_lowpt [it->first], _hepdataid[it->first], 1, 1);
-        book(_h_ratio_midpt [it->first], _hepdataid[it->first], 1, 2);
-        book(_h_ratio_highpt[it->first], _hepdataid[it->first], 1, 3);
-        book(_h_num_lowpt   [it->first], "TMP/num_l_"+it->first,refData(_hepdataid[it->first], 1, 1));
-        book(_h_num_midpt   [it->first], "TMP/num_m_"+it->first,refData(_hepdataid[it->first], 1, 2));
-        book(_h_num_highpt  [it->first], "TMP/num_h_"+it->first,refData(_hepdataid[it->first], 1, 3));
-        book(_h_den_lowpt   [it->first], "TMP/den_l_"+it->first,refData(_hepdataid[it->first], 1, 1));
-        book(_h_den_midpt   [it->first], "TMP/den_m_"+it->first,refData(_hepdataid[it->first], 1, 2));
-        book(_h_den_highpt  [it->first], "TMP/den_h_"+it->first,refData(_hepdataid[it->first], 1, 3));
+        int is7TeV(en == "7000"s);
+        for (const auto& it : _ratiotype) {
+          book(_h_ratio_lowpt [en+it.first], _hepdataid[it.first]+is7TeV, 1, 1);
+          book(_h_ratio_midpt [en+it.first], _hepdataid[it.first]+is7TeV, 1, 2);
+          book(_h_ratio_highpt[en+it.first], _hepdataid[it.first]+is7TeV, 1, 3);
+          const string suff = it.first+toString(is7TeV);
+          book(_h_num_lowpt   [en+it.first], "TMP/num_l_"+suff, refData(_hepdataid[it.first]+is7TeV, 1, 1));
+          book(_h_num_midpt   [en+it.first], "TMP/num_m_"+suff, refData(_hepdataid[it.first]+is7TeV, 1, 2));
+          book(_h_num_highpt  [en+it.first], "TMP/num_h_"+suff, refData(_hepdataid[it.first]+is7TeV, 1, 3));
+          book(_h_den_lowpt   [en+it.first], "TMP/den_l_"+suff, refData(_hepdataid[it.first]+is7TeV, 1, 1));
+          book(_h_den_midpt   [en+it.first], "TMP/den_m_"+suff, refData(_hepdataid[it.first]+is7TeV, 1, 2));
+          book(_h_den_highpt  [en+it.first], "TMP/den_h_"+suff, refData(_hepdataid[it.first]+is7TeV, 1, 3));
+        }
       }
-
-      declare(ChargedFinalState(Cuts::etaIn(_eta_min, _eta_max) && Cuts::pT >= _pt_min*GeV), "CFS");
+      raiseBeamErrorIf(_sqs.empty());
+      declare(ChargedFinalState(Cuts::etaIn(2.5, 4.5) && Cuts::pT >= 0*GeV), "CFS");
     }
 
 
@@ -83,7 +76,7 @@ namespace Rivet {
 
         // cut in momentum
         const FourMomentum& qmom = p.momentum();
-        if (qmom.p3().mod() < _p_min) continue;
+        if (qmom.p3().mod() < 5.0) continue;
 
         // Lifetime cut: ctau sum of all particle ancestors < 10^-9 m according to the paper (see eq. 5)
         const double MAX_CTAU = 1.0e-9; // [m]
@@ -93,44 +86,42 @@ namespace Rivet {
         double eta = qmom.eta();
         double pT  = qmom.pT();
 
-        std::map<std::string, std::pair<int, int> >::iterator it;
-
-        for (it=_ratiotype.begin(); it!=_ratiotype.end(); it++) {
+        for (const auto& it : _ratiotype) {
           // check what type of ratio is
-          if ((it->second.second)==-1) {
+          if ((it.second.second)==-1) {
             // check ptbin
-            if (pT < _pt1_edge) {
+            if (pT < 0.8) {
               // filling histos for numerator and denominator
-              if (id == -abs(it->second.first)) _h_num_lowpt[it->first]->fill(eta);
-              if (id ==  abs(it->second.first)) _h_den_lowpt[it->first]->fill(eta);
+              if (id == -abs(it.second.first)) _h_num_lowpt[_sqs+it.first]->fill(eta);
+              if (id ==  abs(it.second.first)) _h_den_lowpt[_sqs+it.first]->fill(eta);
             }
-            else if (pT < _pt2_edge) {
+            else if (pT < 1.2) {
               // filling histos for numerator and denominator
-              if (id == -abs(it->second.first)) _h_num_midpt[it->first]->fill(eta);
-              if (id ==  abs(it->second.first)) _h_den_midpt[it->first]->fill(eta);
+              if (id == -abs(it.second.first)) _h_num_midpt[_sqs+it.first]->fill(eta);
+              if (id ==  abs(it.second.first)) _h_den_midpt[_sqs+it.first]->fill(eta);
             }
             else {
               // filling histos for numerator and denominator
-              if (id == -abs(it->second.first)) _h_num_highpt[it->first]->fill(eta);
-              if (id ==  abs(it->second.first)) _h_den_highpt[it->first]->fill(eta);
+              if (id == -abs(it.second.first)) _h_num_highpt[_sqs+it.first]->fill(eta);
+              if (id ==  abs(it.second.first)) _h_den_highpt[_sqs+it.first]->fill(eta);
             }
           }
           else {
             // check what type of ratio is
-            if (pT < _pt1_edge) {
+            if (pT < 0.8) {
               // filling histos for numerator and denominator
-              if (abs(id) == abs(it->second.first))  _h_num_lowpt[it->first]->fill(eta);
-              if (abs(id) == abs(it->second.second)) _h_den_lowpt[it->first]->fill(eta);
+              if (abs(id) == abs(it.second.first))  _h_num_lowpt[_sqs+it.first]->fill(eta);
+              if (abs(id) == abs(it.second.second)) _h_den_lowpt[_sqs+it.first]->fill(eta);
             }
-            else if (pT < _pt2_edge) {
+            else if (pT < 1.2) {
               // filling histos for numerator and denominator
-              if (abs(id) == abs(it->second.first))  _h_num_midpt[it->first]->fill(eta);
-              if (abs(id) == abs(it->second.second)) _h_den_midpt[it->first]->fill(eta);
+              if (abs(id) == abs(it.second.first))  _h_num_midpt[_sqs+it.first]->fill(eta);
+              if (abs(id) == abs(it.second.second)) _h_den_midpt[_sqs+it.first]->fill(eta);
             }
             else {
               // filling histos for numerator and denominator
-              if (abs(id) == abs(it->second.first))  _h_num_highpt[it->first]->fill(eta);
-              if (abs(id) == abs(it->second.second)) _h_den_highpt[it->first]->fill(eta);
+              if (abs(id) == abs(it.second.first))  _h_num_highpt[_sqs+it.first]->fill(eta);
+              if (abs(id) == abs(it.second.second)) _h_den_highpt[_sqs+it.first]->fill(eta);
             }
           }
         }
@@ -140,13 +131,13 @@ namespace Rivet {
 
     // Generate the ratio histograms
     void finalize() {
-      std::map<std::string, std::pair<int, int> >::iterator it;
-
-      // booking histograms
-      for (it=_ratiotype.begin(); it!=_ratiotype.end(); it++) {
-        divide(_h_num_lowpt[it->first],  _h_den_lowpt[it->first],  _h_ratio_lowpt[it->first]);
-        divide(_h_num_midpt[it->first],  _h_den_midpt[it->first],  _h_ratio_midpt[it->first]);
-        divide(_h_num_highpt[it->first], _h_den_highpt[it->first], _h_ratio_highpt[it->first]);
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        for (const auto& it : _ratiotype) {
+          divide(_h_num_lowpt[en+it.first],  _h_den_lowpt[en+it.first],  _h_ratio_lowpt[en+it.first]);
+          divide(_h_num_midpt[en+it.first],  _h_den_midpt[en+it.first],  _h_ratio_midpt[en+it.first]);
+          divide(_h_num_highpt[en+it.first], _h_den_highpt[en+it.first], _h_ratio_highpt[en+it.first]);
+        }
       }
     }
 
@@ -205,41 +196,31 @@ namespace Rivet {
     }
 
     /// @name Private variables
-    // Momentum threshold
-    double _p_min;
-
-    // The edges of the intervals of transversal momentum
-    double _pt_min;
-    double _pt1_edge;
-    double _pt2_edge;
-
-    // The limits of the pseudorapidity window
-    //int    _eta_nbins;
-    double _eta_min;
-    double _eta_max;
 
     // Map between PDG id and particle lifetimes in seconds
-    std::map<int, double> _partLftMap;
+    map<int, double> _partLftMap;
 
     // Set of PDG Ids for stable particles (PDG Id <= 100 are considered stable)
     static const int _stablePDGIds[205];
 
     // Define histograms
     // ratio
-    std::map<std::string, Estimate1DPtr > _h_ratio_lowpt;
-    std::map<std::string, Estimate1DPtr > _h_ratio_midpt;
-    std::map<std::string, Estimate1DPtr > _h_ratio_highpt;
+    map<string, Estimate1DPtr > _h_ratio_lowpt;
+    map<string, Estimate1DPtr > _h_ratio_midpt;
+    map<string, Estimate1DPtr > _h_ratio_highpt;
     // numerator
-    std::map<std::string, Histo1DPtr > _h_num_lowpt;
-    std::map<std::string, Histo1DPtr > _h_num_midpt;
-    std::map<std::string, Histo1DPtr > _h_num_highpt;
+    map<string, Histo1DPtr > _h_num_lowpt;
+    map<string, Histo1DPtr > _h_num_midpt;
+    map<string, Histo1DPtr > _h_num_highpt;
     // denominator
-    std::map<std::string, Histo1DPtr > _h_den_lowpt;
-    std::map<std::string, Histo1DPtr > _h_den_midpt;
-    std::map<std::string, Histo1DPtr > _h_den_highpt;
+    map<string, Histo1DPtr > _h_den_lowpt;
+    map<string, Histo1DPtr > _h_den_midpt;
+    map<string, Histo1DPtr > _h_den_highpt;
 
     // Map of ratios and IDs of numerator and denominator
-    std::map<string, pair<int,int> > _ratiotype;
+    map<string, pair<int,int> > _ratiotype;
+
+    string _sqs = "";
 
     // Fill the PDG Id to Lifetime[seconds] map
     // Data was extracted from LHCb Particle Table through LHCb::ParticlePropertySvc
