@@ -19,20 +19,19 @@ namespace Rivet {
     /// Book histograms and initialise projections before the run
     void init() {
       declare(UnstableParticles(), "UFS");
-      int iloc=-1;
-      if (isCompatibleWithSqrtS(7000)) {
-	iloc = 0;
+      for (double eVal : allowedEnergies()) {
+        const int en = int(eVal+0.5);
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+
+        int ih(en==13000);
+        book(_h_B[en], {2.0,2.5,3.0,3.5,4.0,4.5});
+        for (auto& b : _h_B[en]->bins()) {
+          book(b, 1+ih, 1, b.index());
+        }
+        book(_h_pT[en], 3, 1, 1+ih);
+        book(_h_y[en],  4, 1, 1+ih);
       }
-      else if  (isCompatibleWithSqrtS(13000)) {
-	iloc = 1;
-      }
-      else
-	throw UserError("Centre-of-mass energy of the given input is neither 7 or 13 TeV.");
-      book(_h_B,{2.0,2.5,3.0,3.5,4.0,4.5});
-      for(unsigned int iy=0;iy<5;++iy)
-        book(_h_B->bin(iy+1),1+iloc,1,1+iy);
-      book(_h_pT,3,1,1+iloc);
-      book(_h_y ,4,1,1+iloc);
+      raiseBeamErrorIf(_sqs==0);
     }
 
 
@@ -42,12 +41,12 @@ namespace Rivet {
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       for (const Particle& p : ufs.particles(Cuts::pid==521)) {
         double absrap = p.absrap();
-	if(absrap<2. || absrap>4.5) continue;
-        double pT = p.perp();
-	if(pT>40.) continue;
-	_h_B ->fill(absrap,pT);
-	_h_pT->fill(pT);
-	_h_y ->fill(absrap);
+        if (absrap<2. || absrap>4.5) continue;
+        double pT = p.pT();
+        if (pT>40.*GeV) continue;
+        _h_B[_sqs]->fill(absrap, pT/GeV);
+        _h_pT[_sqs]->fill(pT/GeV);
+        _h_y[_sqs]->fill(absrap);
       }
     }
 
@@ -55,11 +54,11 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       // 1/2 due rapidity folding +/-
-      double factor = 0.5*crossSection()/nanobarn/sumOfWeights();
-      scale(_h_B,factor);
+      const double factor = 0.5*crossSection()/nanobarn/sumOfWeights();
+      scale(_h_B, factor);
       divByGroupWidth(_h_B);
-      scale(_h_pT,factor);
-      scale(_h_y ,factor/1000.);
+      scale(_h_pT, factor);
+      scale(_h_y,  factor/1000.);
     }
 
     /// @}
@@ -67,8 +66,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DGroupPtr _h_B;
-    Histo1DPtr _h_pT,_h_y;
+    map<int,Histo1DGroupPtr> _h_B;
+    map<int,Histo1DPtr> _h_pT, _h_y;
+    int _sqs = 0;
     /// @}
 
 
