@@ -21,14 +21,19 @@ namespace Rivet {
     void init() {
       // projection
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0; ix<2; ++ix) {
-        book(_h[ix],{2.,3.,3.5,4.5});
-        for(unsigned int iy=0; iy<3; ++iy) {
-          book(_h[ix]->bin(iy+1),
-               "TMP/h_"+toString(ix+1)+"_"+toString(iy+1),
-               refData(2,1,1+iy));
+
+      for (double eVal : allowedEnergies()) {
+        const int en = int(eVal+0.5);
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+
+        for (size_t ix=0; ix<2; ++ix) {
+          book(_h[en+ix], {2.,3.,3.5,4.5});
+          for (auto& b : _h[en+ix]->bins()) {
+            book(b,"TMP/h_"+toString(ix+1)+"_"+toString(b.index())+"_"+toString(en), refData(2,1,b.index()));
           }
+        }
       }
+      raiseBeamErrorIf(_sqs==0);
     }
 
 
@@ -40,28 +45,23 @@ namespace Rivet {
         const double pT = p.perp();
         const double y  = p.absrap();
         const bool anti = p.pid()<0;
-        _h[anti]->fill(y,pT);
+        _h[_sqs+anti]->fill(y,pT);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      unsigned int is=0;
-      if (isCompatibleWithSqrtS(7000)) {
-      	is=1;
-      }
-      else if (isCompatibleWithSqrtS(8000)) {
-      	is=2;
-      }
-      else  {
-      	throw Error("Invalid CMS energy for LHCB_2018_I1674916");
-      }
-      // asymmetry
-      for(unsigned int iy=0;iy<3;++iy) {
+
+      for (double eVal : allowedEnergies()) {
+        const int en = int(eVal+0.5);
+        int ih = 2+(en==8000);
+        // asymmetry
         Estimate1DPtr tmp;
-        book(tmp,1+is,1,1+iy);
-        asymm(_h[0]->bin(iy+1),_h[1]->bin(iy+1),tmp);
+        for (const auto& b : _h[en+0]->bins()) {
+          book(tmp, ih, 1, b.index());
+          asymm(b, _h[en+1]->bin(b.index()), tmp);
+        }
       }
     }
 
@@ -70,7 +70,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DGroupPtr _h[2];
+    map<int,Histo1DGroupPtr> _h;
+    int _sqs = 0;
     /// @}
 
 
