@@ -1,7 +1,6 @@
 // -*- C++ -*-
 #include "Rivet/Analysis.hh"
 #include "Rivet/Projections/UnstableParticles.hh"
-#include "Rivet/Tools/BinnedHistogram.hh"
 
 namespace Rivet {
 
@@ -9,22 +8,17 @@ namespace Rivet {
   class LHCF_2012_I1115479 : public Analysis {
   public:
 
-    LHCF_2012_I1115479()
-      : Analysis("LHCF_2012_I1115479")
-    {   }
-
+    RIVET_DEFAULT_ANALYSIS_CTOR(LHCF_2012_I1115479);
 
   public:
 
     void init() {
       declare(UnstableParticles(),"UFS");
 
-      {Histo1DPtr tmp; _binnedHistos_y_pT.add( 8.9,  9.0, book(tmp, 1, 1, 1));}
-      {Histo1DPtr tmp; _binnedHistos_y_pT.add( 9.0,  9.2, book(tmp, 2, 1, 1));}
-      {Histo1DPtr tmp; _binnedHistos_y_pT.add( 9.2,  9.4, book(tmp, 3, 1, 1));}
-      {Histo1DPtr tmp; _binnedHistos_y_pT.add( 9.4,  9.6, book(tmp, 4, 1, 1));}
-      {Histo1DPtr tmp; _binnedHistos_y_pT.add( 9.6, 10.0, book(tmp, 5, 1, 1));}
-      {Histo1DPtr tmp; _binnedHistos_y_pT.add(10.0, 11.0, book(tmp, 6, 1, 1));}
+      book(_g, {8.9, 9., 9.2, 9.4, 9.6, 10., 11.});
+      for (auto& b : _g->bins()) {
+        book(b, b.index(), 1, 1);
+      }
     }
 
 
@@ -41,24 +35,24 @@ namespace Rivet {
           if (pT > 0.6*GeV) continue;
 
           const double scaled_weight = 1.0/(dphi*pT/GeV);
-          _binnedHistos_y_pT.fill(y, pT/GeV, scaled_weight);
+          _g->fill(y, pT/GeV, scaled_weight);
         }
       }
     }
 
 
     void finalize() {
-      _binnedHistos_y_pT.scale( 1./sumOfWeights() , this);
+      scale(_g, 1./sumOfWeights());
+      divByGroupWidth(_g);
     }
 
   private:
 
-    BinnedHistogram _binnedHistos_y_pT;
+    Histo1DGroupPtr _g;
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(LHCF_2012_I1115479);
 
 }
