@@ -26,12 +26,17 @@ namespace Rivet {
 
       // Book histograms
 
+      // Full
+      book(_h_n_stables, "h_n_stables", {1, 2, 3, 4, 5, 6, 7, 8});
+
       // Leptonic
       book(_h_2B_m2enu, "h_2B_m2enu", 200,0.,3.15);
       book(_h_2B_menu, "h_2B_menu" , 200,0.,1.8 );
 
       // 1 hadron
       book(_h_1B_xpi, "h_1B_xpi", 25,0.0,1.0);
+      book(_h_1B_xpim, "h_1B_xpim", 25,0.0,1.0);
+      book(_h_1B_xpip, "h_1B_xpip", 25,0.0,1.0);
 
       // 2 hadrons
       book(_h_2B_m2pipi, "h_2B_m2pipi", 200,0.,3.15);
@@ -238,6 +243,10 @@ namespace Rivet {
           swap(nu_e ,nu_ebar );
           swap(nu_mu,nu_mubar);
         }
+
+        // Start with filling global tau decay histograms
+        _h_n_stables->fill(nstable);
+
         // cerr << "testing before loop " << nstable << " "
         //      << pip.size() << " " << pim.size() << " " << pi0.size() << " "
         //      << Kp.size() << " " << Km.size() << " " << K0S.size() << " " <<  K0L.size() << "\n";
@@ -246,6 +255,12 @@ namespace Rivet {
           if (pim.size()==1) {
             double xpi = pim[0].mom().p()/tau.mom().p();
             _h_1B_xpi->fill(xpi);
+            if (tau.pid()>0) {
+              _h_1B_xpim->fill(xpi);
+            }
+            else {
+              _h_1B_xpip->fill(xpi);
+            }
           }
         }
         else if (nstable==3 ) {
@@ -502,17 +517,23 @@ namespace Rivet {
         }
       }
     }
+    
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
 
+      // All decays
+      normalize(_h_n_stables);
+
       // Leptonic
       normalize(_h_2B_m2enu);
       normalize(_h_2B_menu );
 
       // 1 hadron
       normalize(_h_1B_xpi);
+      normalize(_h_1B_xpim);
+      normalize(_h_1B_xpip);
 
       // 2 hadrons
       normalize(_h_2B_m2pipi);
@@ -587,16 +608,20 @@ namespace Rivet {
 
     /// @}
 
-
     /// @name Histograms
     /// @{
 
+    /// Histograms for full info
+    BinnedHistoPtr<int> _h_n_stables;
+
     /// Histograms for leptonic decay
     Histo1DPtr _h_2B_m2enu,_h_2B_menu;
     Histo1DPtr _h_2B_m2munu,_h_2B_mmunu;
 
     /// Histograms for 1 hadron decay
     Histo1DPtr _h_1B_xpi;
+    Histo1DPtr _h_1B_xpim;
+    Histo1DPtr _h_1B_xpip;
 
     /// Histograms for 2 hadron decay
     Histo1DPtr _h_2B_m2pipi,_h_2B_mpipi;
@@ -662,3 +687,4 @@ namespace Rivet {
   RIVET_DECLARE_PLUGIN(MC_DECAY_TAU);
 
 }
+
