@@ -1,19 +1,19 @@
 // -*- C++ -*-
-#include "Rivet/Analyses/MC_JetSplittings.hh"
+#include "Rivet/Analyses/MC_KTSPLITTINGS_BASE.hh"
 #include "Rivet/Projections/FinalState.hh"
 #include "Rivet/Projections/FastJets.hh"
 
 namespace Rivet {
 
-  
+
 
 
   /// @brief MC validation analysis for jet events
-  class MC_KTSPLITTINGS : public MC_JetSplittings {
+  class MC_KTSPLITTINGS : public MC_KTSPLITTINGS_BASE {
   public:
 
     MC_KTSPLITTINGS()
-      : MC_JetSplittings("MC_KTSPLITTINGS", 4, "Jets")
+      : MC_KTSPLITTINGS_BASE("MC_KTSPLITTINGS", 4, "Jets")
     {    }
 
 
@@ -23,25 +23,24 @@ namespace Rivet {
       // set clustering radius from input option
       const double R = getOption<double>("R", 0.6);
 
-      FastJets jetpro(FinalState(), FastJets::KT, R);
+      FastJets jetpro(FinalState(), JetAlg::KT, R);
       declare(jetpro, "Jets");
-      MC_JetSplittings::init();
+      MC_KTSPLITTINGS_BASE::init();
     }
 
 
     void analyze(const Event& event) {
-      MC_JetSplittings::analyze(event);
+      MC_KTSPLITTINGS_BASE::analyze(event);
     }
 
 
     void finalize() {
-      MC_JetSplittings::finalize();
+      MC_KTSPLITTINGS_BASE::finalize();
     }
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(MC_KTSPLITTINGS);
 
 }
