@@ -1,17 +1,17 @@
 // -*- C++ -*-
-#include "Rivet/Analyses/MC_ParticleAnalysis.hh"
+#include "Rivet/Analyses/MC_PARTICLES_BASE.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 
 namespace Rivet {
 
 
   /// @brief MC validation analysis for muons
-  class MC_MUONS : public MC_ParticleAnalysis {
+  class MC_MUONS : public MC_PARTICLES_BASE {
   public:
 
     MC_MUONS()
-      : MC_ParticleAnalysis("MC_MUONS", 2, "muon")
+      : MC_PARTICLES_BASE("MC_MUONS", 2, "muon")
     {    }
 
 
@@ -25,28 +25,27 @@ namespace Rivet {
       } else if (!dressed) {
         declare(PromptFinalState(muons), "Muons");
       } else {
-        DressedLeptons dleps(FinalState(Cuts::abspid == PID::PHOTON), muons, 0.1);
+        LeptonFinder dleps(muons, FinalState(Cuts::abspid == PID::PHOTON), 0.1);
         declare(dleps, "Muons");
       }
 
-      MC_ParticleAnalysis::init();
+      MC_PARTICLES_BASE::init();
     }
 
 
     void analyze(const Event& event) {
       const Particles mus = apply<ParticleFinder>(event, "Muons").particlesByPt(Cuts::pT > 0.5*GeV);
-      MC_ParticleAnalysis::_analyze(event, mus);
+      MC_PARTICLES_BASE::_analyze(event, mus);
     }
 
 
     void finalize() {
-      MC_ParticleAnalysis::finalize();
+      MC_PARTICLES_BASE::finalize();
     }
 
   };
 
 
-
   RIVET_DECLARE_PLUGIN(MC_MUONS);
 
 }
