@@ -14,12 +14,12 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
       // Initialise and register projections
-      declare(UnstableParticles(Cuts::pid==223 or Cuts::pid==221), "UFS");
+      declare(UnstableParticles(), "UFS");
       // Book histograms
       book(_h_eta  , 1, 1, 1);
       book(_h_omega, 2, 1, 1);
@@ -27,7 +27,7 @@ namespace Rivet {
       book(_weight_omega,"TMP/weight_omega");
     }
 
-    void findDecayProducts(const Particle & mother, unsigned int & nstable, unsigned int & npi, 
+    void findDecayProducts(const Particle & mother, unsigned int & nstable, unsigned int & npi,
                            unsigned int & nep, unsigned int & nem, unsigned int & ngamma,
 			   FourMomentum & ptot) {
       for(const Particle & p : mother.children()) {
@@ -66,12 +66,12 @@ namespace Rivet {
       static double mpi    = 134.9770*MeV;
 
       // Loop over eta and omega mesons
-      for( const Particle& p : apply<UnstableParticles>(event, "UFS").particles()) {
+      for( const Particle& p : apply<UnstableParticles>(event, "UFS").particles(Cuts::pid==223 or Cuts::pid==221)) {
        	unsigned nstable(0),npi(0),nep(0),nem(0),ngamma(0);
        	FourMomentum ptot;
       	findDecayProducts(p,nstable,npi,nep,nem,ngamma,ptot);
 	if(p.pid()==221) {
-	  if(nstable==3 && nem==1 && nep==1 && ngamma==1) {
+	  if(nstable==3 && nem==1 && nem==1 && ngamma==1) {
 	    double q = ptot.mass();
 	    double beta = sqrt(1.-4*sqr(me/q));
 	    double p = 1.-sqr(q/meta);
@@ -83,7 +83,7 @@ namespace Rivet {
 	  }
 	}
 	else {
-	  if(nstable==3 && nem==1 && nep==1 && npi==1) {
+	  if(nstable==3 && nem==1 && nem==1 && npi==1) {
 	    double q = ptot.mass();
 	    double beta = sqrt(1.-4*sqr(me/q));
 	    double p = sqrt(sqr(1.+sqr(q)/(sqr(momega)-sqr(mpi)))-4.*sqr(momega*q/(sqr(momega)-sqr(mpi))));
@@ -105,20 +105,19 @@ namespace Rivet {
       scale(_h_omega, 1.5 *M_PI/alpha/ *_weight_omega);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
+    /// @{
     Histo1DPtr _h_eta,_h_omega;
     CounterPtr _weight_eta,_weight_omega;
-    //@}
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(A2_2017_I1486671);
 
 
