@@ -43,12 +43,6 @@ namespace Rivet {
     /// Perform the per-event analysis
     void analyze(const Event& event) {
 
-      const double sqrts_tol = 10. ;
-      if (!isCompatibleWithSqrtS(27.4*GeV, sqrts_tol)) {
-        MSG_ERROR("Incorrect beam energy used: " << sqrtS()/GeV);
-        throw Error("Unexpected sqrtS ! Only 27.4 GeV is supported");
-      }
-
       const DileptonFinder& zfinder = apply<DileptonFinder>(event, "DileptonFinder");
       if (zfinder.particles().size() >= 1) {
 
