@@ -53,12 +53,6 @@ namespace Rivet {
         }
       }
 
-      const double sqrts_tol = 10. ;
-      if (!isCompatibleWithSqrtS(38.8*GeV, sqrts_tol)) {
-        MSG_ERROR("Incorrect beam energy used: " << sqrtS()/GeV);
-        throw Error("Unexpected sqrtS ! Only 38.8 GeV is supported");
-      }
-
       const DileptonFinder& zfinder = apply<DileptonFinder>(event, "DileptonFinder");
       if (zfinder.particles().size() >= 1) {
 
