@@ -30,14 +30,18 @@ namespace Rivet {
       // Booking histograms
       // hydrogen d01-d16
       book(_hist_M_xF, {-0.05, 0.05, 0.1, 0.15, 0.2, 0.25, 0.3, 0.35, 0.4, 0.45, 0.5, 0.55, 0.6, 0.65, 0.7, 0.75, 0.8});
-      for (auto& b : _hist_M_xF->bins()) book(b, b.index(), 1, 1);
+      for (auto& b : _hist_M_xF->bins()) {
+        book(b, b.index(), 1, 1);
+      }
 
       // deuterium d17-d32
 
       // hydrogen d40
       book(_hist_pT_M, {4.2, 5.2, 6.2, 7.2, 8.7, 10.85, 12.85});
       _hist_pT_M->maskBin(5); int idx = 0;
-      for (auto& b : _hist_pT_M->bins()) book(b, 40, 1, ++idx);
+      for (auto& b : _hist_pT_M->bins()) {
+        book(b, 40, 1, ++idx);
+      }
 
     }
 
@@ -45,20 +49,14 @@ namespace Rivet {
     /// Perform the per-event analysis
     void analyze(const Event& event) {
 
-      const double sqrts_tol = 10.;
-      if (!isCompatibleWithSqrtS(38.8*GeV, sqrts_tol)) {
-        MSG_ERROR("Incorrect beam energy used: " << sqrtS()/GeV);
-        throw Error("Unexpected sqrtS ! Only 38.8 GeV is supported");
-      }
-
       // Muons
       const DileptonFinder& zfinder = apply<DileptonFinder>(event, "DileptonFinder");
       if (zfinder.particles().size() <= 0) vetoEvent;
 
-      double Zmass = zfinder.bosons()[0].momentum().mass()/GeV;
-      double Zpt   = zfinder.bosons()[0].momentum().pT()/GeV;
-      double Zpl   = zfinder.bosons()[0].momentum().pz()/GeV;
-      double ZE    = zfinder.bosons()[0].momentum().E();
+      double Zmass = zfinder.bosons()[0].mom().mass()/GeV;
+      double Zpt   = zfinder.bosons()[0].mom().pT()/GeV;
+      double Zpl   = zfinder.bosons()[0].mom().pz()/GeV;
+      double ZE    = zfinder.bosons()[0].mom().E();
       double xF = 2.*Zpl/sqrtS();
 
       // Filling dimuon mass in bins of xF
@@ -79,7 +77,7 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       // xf bin width = 0.2, x-section in picobarn
-      const double scalefactor=crossSection()/picobarn/(sumOfWeights() * M_PI *0.2 );
+      const double scalefactor = crossSection()/picobarn/(sumOfWeights() * M_PI *0.2);
       scale(_hist_pT_M, scalefactor);
 
       // x-section is quoted in nanobarn
