@@ -28,23 +28,23 @@ namespace Rivet {
         const size_t idx1 = en.find("_");
         const string en2 = idx1!=std::string::npos ? en.substr(0,idx1) : en;
         const size_t idx2 = en.find("-");
-        if(idx2!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx2));
-          const double emax = std::stod(en.substr(idx2+1,string::npos));
-          if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms.push_back(en);
+        if (idx2 != string::npos) {
+          const double emin = stod(en.substr(0,idx2));
+          const double emax = stod(en.substr(idx2+1,string::npos));
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs.push_back(en);
             break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
+          const double end = stod(en)*GeV;
           if (isCompatibleWithSqrtS(end)) {
-            _ecms.push_back(en);
+            _sqs.push_back(en);
             break;
           }
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -55,19 +55,20 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22]) {
-        for(const string & en : _ecms)
+      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+        for (const string& en : _sqs) {
           _c_muons->fill(en);
+        }
       }
       // everything else
       else {
-        for(const string & en : _ecms)
+        for (const string& en : _sqs) {
           _c_hadrons->fill(en);
+        }
       }
     }
 
@@ -76,7 +77,7 @@ namespace Rivet {
     void finalize() {
       BinnedEstimatePtr<string> mult;
       book(mult, 1, 1, 1);
-      divide(_c_hadrons, _c_muons,mult);
+      divide(_c_hadrons, _c_muons, mult);
     }
 
     /// @}
@@ -85,7 +86,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    vector<string> _ecms;
+    vector<string> _sqs;
     /// @}
 
 
