@@ -26,42 +26,39 @@ namespace Rivet {
       book(_npion, 1, 1, 1);
       for (const string& en : _npion.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms = en;
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1,string::npos));
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs = en;
             break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=4) vetoEvent;
+      if (fs.particles().size() != 4) vetoEvent;
       for (const Particle& p : fs.particles()) {
-	if(abs(p.pid())!=PID::PIPLUS) vetoEvent;
+        if (p.abspid() != PID::PIPLUS) vetoEvent;
       }
-      _npion->fill(_ecms);
-
+      _npion->fill(_sqs);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_npion, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_npion, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -70,7 +67,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _npion;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -78,6 +75,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD2_2000_I511375);
-
-
 }
