@@ -25,23 +25,21 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_numEtaGamma, 1, 1, 1);
       for (const string& en : _numEtaGamma.binning().edges<0>()) {
-        double end = std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  --nRes[child.pid()];
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          --nRes[child.pid()];
+          --ncount;
+        }
+        else findChildren(child,nRes,ncount);
       }
     }
 
@@ -54,38 +52,36 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
 
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	if(p.children().empty()) continue;
-	// find the omega
-	if(p.pid()==221) {
-	  map<long,int> nRes = nCount;
-	  int ncount = ntotal;
-	  findChildren(p,nRes,ncount);
-	  // eta pi+pi-
-	  if(ncount!=1) continue;
-	  bool matched = true;
-          for(auto const & val : nRes) {
-	    if(val.first==22) {
-	      if(val.second !=1) {
-		matched = false;
-		break;
-	      }
-	    }
-	    else if(val.second!=0) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  if(matched)
-	    _numEtaGamma->fill(_ecms);
-	}
+        if (p.children().empty()) continue;
+        // find the omega
+        if (p.pid()==221) {
+          map<long,int> nRes = nCount;
+          int ncount = ntotal;
+          findChildren(p,nRes,ncount);
+          // eta pi+pi-
+          if (ncount!=1) continue;
+          bool matched = true;
+          for (const auto& val : nRes) {
+            if (val.first==22) {
+              if (val.second !=1) {
+                matched = false;
+                break;
+              }
+            }
+            else if (val.second!=0) {
+              matched = false;
+              break;
+            }
+          }
+          if (matched) _numEtaGamma->fill(_sqs);
+        }
       }
-
     }
 
 
@@ -100,7 +96,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _numEtaGamma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -108,6 +104,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD2_2001_I554522);
-
-
 }
