@@ -21,15 +21,14 @@ namespace Rivet {
 
       declare(FinalState(), "FS");
       book(_nK0K0, 1, 1, 1);
-      
+
       for (const string& en : _nK0K0.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -41,19 +40,16 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      if(ntotal==2 &&
-	 nCount[130]==1 && nCount[310]==1)
-	_nK0K0->fill(_ecms);
-
+      if (ntotal==2 && nCount[130]==1 && nCount[310]==1) _nK0K0->fill(_sqs);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nK0K0, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_nK0K0, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -62,7 +58,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nK0K0;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -70,6 +66,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD2_2003_I601222);
-
-
 }
