@@ -14,14 +14,14 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
 
       // Initialise and register projections
       declare(FinalState(), "FS");
-      book(_numPiPiGamma, "TMP/PiPiGamma");
+      book(_numPiPiGamma, 1, 1, 1);
     }
 
 
@@ -39,49 +39,27 @@ namespace Rivet {
       // three particles (pi0 pi0 gamma)
       if(ntotal!=3) vetoEvent;
       if(nCount[111]==2 && nCount[22]==1)
-	_numPiPiGamma->fill();
+	_numPiPiGamma->fill(round(sqrtS()/MeV));
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-
-      double sigma = _numPiPiGamma->val();
-      double error = _numPiPiGamma->err();
-      sigma *= crossSection()/ sumOfWeights() /picobarn;
-      error *= crossSection()/ sumOfWeights() /picobarn;
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr mult;
-      book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/MeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
-
+      scale(_numPiPiGamma, crossSection()/ sumOfWeights() /picobarn);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    CounterPtr _numPiPiGamma;
-    //@}
+    /// @{
+    BinnedHistoPtr<int> _numPiPiGamma;
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(CMD2_2004_I630009);
 
 
