@@ -23,29 +23,25 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_sigma[ix], 1+ix, 1, 1);
         for (const string& en : _sigma[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*MeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          const double eval = stod(en)*MeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty() && _ecms[2].empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty() && _sqs[2].empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  --nRes[child.pid()];
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+        if (child.children().empty()) {
+          --nRes[child.pid()];
+          --ncount;
+        }
+        else findChildren(child,nRes,ncount);
       }
     }
 
@@ -57,50 +53,44 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      if(ntotal==2 && nCount[22]==1 && nCount[111]==1)
-	_sigma[1]->fill(_ecms[1]);
+      if (ntotal==2 && nCount[22]==1 && nCount[111]==1)	_sigma[1]->fill(_sqs[1]);
 
 
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	if(p.children().empty()) continue;
-	// find the omega
-	if(p.pid()==221) {
-	  map<long,int> nRes = nCount;
-	  int ncount = ntotal;
-	  findChildren(p,nRes,ncount);
-	  // eta pi+pi-
-	  if(ncount!=1) continue;
-	  bool matched = true;
-	  for(auto const & val : nRes) {
-	    if(val.first==22) {
-	      if(val.second !=1) {
-		matched = false;
-		break;
-	      }
-	    }
-	    else if(val.second!=0) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  if(matched)
-	    _sigma[0]->fill(_ecms[0]);
-	}
+        if (p.children().empty()) continue;
+        // find the omega
+        if (p.pid()==221) {
+          map<long,int> nRes = nCount;
+          int ncount = ntotal;
+          findChildren(p,nRes,ncount);
+          // eta pi+pi-
+          if (ncount!=1) continue;
+          bool matched = true;
+          for (const auto& val : nRes) {
+            if (val.first==22) {
+              if (val.second !=1) {
+                matched = false;
+                break;
+              }
+            }
+            else if (val.second!=0) {
+              matched = false;
+              break;
+            }
+          }
+          if (matched) _sigma[0]->fill(_sqs[0]);
+        }
       }
-
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      for (unsigned int ix=0;ix<2;++ix) {
-        scale(_sigma[ix],fact);
-      }
+      scale(_sigma, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -109,7 +99,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
@@ -117,6 +107,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD2_2005_I658856);
-
-
 }
