@@ -25,33 +25,30 @@ namespace Rivet {
 
       // Book histograms
       book(_npion, 3,1,1);
-      vector<int> enint({370, 390, 410, 430, 450, 470, 480, 500, 510, 520});
-      icms=-1;
-      for(const int& en : enint) {
-        double end = double(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          icms = en;
-          break;
+      for (double eVal : allowedEnergies()) {
+        int en = round(eVal/MeV);
+        if (isCompatibleWithSqrtS(eVal)) {
+          _sqs = en; break;
         }
       }
-      if(icms<0) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs < 0);
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size() != 2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-	if(abs(p.pid())!=PID::PIPLUS) vetoEvent;
+        if (p.abspid() != PID::PIPLUS) vetoEvent;
       }
-      _npion->fill(icms);
+      _npion->fill(_sqs);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_npion,crossSection()/ sumOfWeights() /nanobarn);
+      scale(_npion,crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -60,7 +57,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<int> _npion;
-    int icms;
+    int _sqs = -1;
     /// @}
 
 
@@ -68,6 +65,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD2_2006_I728191);
-
-
 }
