@@ -25,34 +25,29 @@ namespace Rivet {
 
       // Book histograms
       book(_npion, 2,1,1);
-      vector<int> enint({600, 630, 660, 690, 720, 750, 760, 764, 770, 774, 778, 780, 781, 782,
-          783, 784, 786, 790, 794, 800, 810, 820, 840, 880, 920, 940, 950, 958, 970});
-      icms=-1;
-      for(const int& en : enint) {
-        double end = double(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          icms = en;
-          break;
+      for (double en : allowedEnergies()) {
+        if (isCompatibleWithSqrtS(en)) {
+          _sqs = round(en/MeV); break;
         }
       }
-      if(icms<0) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs < 0);
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-	if(abs(p.pid())!=PID::PIPLUS) vetoEvent;
+        if (p.abspid() != PID::PIPLUS) vetoEvent;
       }
-      _npion->fill(icms);
+      _npion->fill(_sqs);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_npion,crossSection()/ sumOfWeights() /nanobarn);
+      scale(_npion, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -61,7 +56,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<int> _npion;
-    int icms;
+    int _sqs = -1;
     /// @}
 
 
@@ -69,6 +64,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD2_2007_I728302);
-
-
 }
