@@ -26,13 +26,12 @@ namespace Rivet {
       // Book histograms
       book(_nproton, 1,1,6);
       for (const string& en : _nproton.binning().edges<0>()) {
-        double end = en=="1900 (2012)"s ? 1.9 : std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = en=="1900 (2012)"s? 1.9 : stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -43,13 +42,13 @@ namespace Rivet {
       for (const Particle& p : fs.particles()) {
         if (p.abspid() != PID::PROTON) vetoEvent;
       }
-      _nproton->fill(_ecms);
+      _nproton->fill(_sqs);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nproton, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_nproton, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -58,7 +57,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nproton;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -66,6 +65,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD3_2016_I1385598);
-
-
 }
