@@ -15,13 +15,13 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
-      
+
       declare(FinalState(), "FS");
-      book(_nK0K0, "TMP/K0K0");
+      book(_nK0K0, "TMP/K0K0", refData(1,1,6));
 
     }
 
@@ -39,47 +39,30 @@ namespace Rivet {
       }
       if(ntotal==2 &&
 	 nCount[130]==1 && nCount[310]==1)
-	_nK0K0->fill();
+	_nK0K0->fill(sqrtS()/MeV);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double sigma = _nK0K0->val();
-      double error = _nK0K0->err();
-      sigma *= crossSection()/ sumOfWeights() /nanobarn;
-      error *= crossSection()/ sumOfWeights() /nanobarn;
-      Scatter2D temphisto(refData(1, 1, 6));
-      Scatter2DPtr mult;
-      book(mult, 1, 1, 6);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/MeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      scale(_nK0K0,crossSection()/ sumOfWeights() /nanobarn);
+      Estimate1DPtr tmp;
+      book(tmp,1,1,6);
+      barchart(_nK0K0,tmp);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    CounterPtr _nK0K0;
-    //@}
+    /// @{
+    Histo1DPtr _nK0K0;
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(CMD3_2016_I1444990);
 
 
