@@ -23,28 +23,25 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
-      for(unsigned int ix=0;ix<3;++ix) {
+      for (size_t ix=0; ix<3; ++ix) {
         book(_c_phi[ix], 1+ix, 1, 6);
         for (const string& en : _c_phi[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty() && _ecms[2].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty() && _sqs[2].empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for(const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  --nRes[child.pid()];
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          --nRes[child.pid()];
+          --ncount;
+        }
+        else findChildren(child,nRes,ncount);
       }
     }
 
@@ -56,43 +53,43 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles(Cuts::pid==221)) {
-	if(p.children().empty()) continue;
-	map<long,int> nRes = nCount;
-	int ncount = ntotal;
-	findChildren(p,nRes,ncount);
-	bool matched = false;
-	for (const Particle& p2 : ufs.particles(Cuts::pid==333)) {
-	  map<long,int> nResB = nRes;
-	  int ncountB = ncount;
-	  findChildren(p2,nResB,ncountB);
-	  if(ncountB!=0) continue;
-	  bool matched = true;
-	  for(auto const & val : nResB) {
-	    if(val.second!=0) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  if(matched) {
-	    for(unsigned int ix=0;ix<3;++ix) _c_phi[ix]->fill(_ecms[ix]);
-	    break;
-	  }
-	}
-	if(matched) break;
+        if (p.children().empty()) continue;
+        map<long,int> nRes = nCount;
+        int ncount = ntotal;
+        findChildren(p,nRes,ncount);
+        bool matched = false;
+        for (const Particle& p2 : ufs.particles(Cuts::pid==333)) {
+          map<long,int> nResB = nRes;
+          int ncountB = ncount;
+          findChildren(p2,nResB,ncountB);
+          if (ncountB!=0) continue;
+          bool matched = true;
+          for (const auto& val : nResB) {
+            if (val.second!=0) {
+              matched = false;
+              break;
+            }
+          }
+          if (matched) {
+            for (size_t ix=0; ix<3; ++ix) {
+              _c_phi[ix]->fill(_sqs[ix]);
+            }
+            break;
+          }
+        }
+        if (matched) break;
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/nanobarn/sumOfWeights();
-      for(unsigned int ix=0;ix<3;++ix)
-        scale(_c_phi[ix],fact);
+      scale(_c_phi, crossSection()/nanobarn/sumOfWeights());
     }
 
     /// @}
@@ -101,7 +98,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_phi[3];
-    string _ecms[3];
+    string _sqs[3];
     /// @}
 
 
@@ -109,6 +106,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD3_2019_I1740541);
-
-
 }
