@@ -23,29 +23,29 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(Cuts::pid==20223), "UFS");
       book(_sigma,1,1,1);
+      book(_res[0], "TMP/c_0", refData(2, 1, 1));
+      book(_res[1], "TMP/c_1", refData(2, 1, 2));
       for (const string& en : _sigma.binning().edges<0>()) {
-        const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/MeV, emin, emax)) {
-            _ecms.push_back(en);
+        const size_t idx = en.find(" to ");
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+4,string::npos));
+          if (inRange(sqrtS()/MeV, emin, emax)) {
+            _sqs.push_back(en);
           }
         }
         else {
-          const double end = std::stod(en)*MeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms.push_back(en);
+          const double eVal = stod(en)*MeV;
+          if (isCompatibleWithSqrtS(eVal)) {
+            _sqs.push_back(en);
           }
         }
       }
-      for (unsigned int ix=0; ix<2; ++ix) {
-        book(_res[ix], "TMP/c_"+toString(ix),refData(2, 1, ix+1));
-      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for(const Particle &child : p.children()) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
           --ncount;
@@ -68,30 +68,27 @@ namespace Rivet {
       }
       // the FS cross section
       bool foundFS = false;
-      if (ntotal==5 && nCount[310]==1 &&
-	        ( ( nCount[211]==2 && nCount[-211]==1 && nCount[-321] ==1 ) ||
-            ( nCount[211]==1 && nCount[-211]==2 && nCount[ 321] ==1 ) ) ) {
+      if (ntotal==5 && nCount[310]==1 && ((nCount[211]==2 && nCount[-211]==1 && nCount[-321] ==1) ||
+                                          (nCount[211]==1 && nCount[-211]==2 && nCount[ 321] ==1))) {
         foundFS = true;
-        for(const string & en : _ecms) _sigma->fill(en);
+        for (const string& en : _sqs) _sigma->fill(en);
       }
       // check for intermediate f_1
       for (const Particle& p : apply<FinalState>(event, "UFS").particles()) {
         if (p.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
-        findChildren(p,nRes,ncount);
-        if(ncount!=2) continue;
+        findChildren(p, nRes, ncount);
+        if (ncount!=2) continue;
         bool matched = true;
         for (const auto& val : nRes) {
           if (abs(val.first)==211 ) {
             if (val.second !=1) {
-              matched = false;
-              break;
+              matched = false; break;
             }
           }
           else if (val.second!=0) {
-            matched = false;
-            break;
+            matched = false; break;
           }
         }
         if (matched) {
@@ -107,11 +104,11 @@ namespace Rivet {
     void finalize() {
       const double fact = crossSection()/nanobarn/sumOfWeights();
       scale(_sigma,fact);
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         scale(_res[ix], fact);
         Estimate1DPtr tmp;
         book(tmp,2,1,1+ix);
-        barchart(_res[ix],tmp);
+        barchart(_res[ix], tmp);
       }
     }
 
@@ -122,7 +119,7 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _sigma;
     Histo1DPtr _res[2];
-    vector<string> _ecms;
+    vector<string> _sqs;
     /// @}
 
 
@@ -130,5 +127,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD3_2022_I2108984);
-
 }
