@@ -22,43 +22,45 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      for (unsigned int ix=0; ix<3; ++ix) {
+      for (size_t ix=0; ix<3; ++ix) {
         book(_sigma[ix], 1, 1+ix, 1);
         for (const string& en : _sigma[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*MeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          const double eval = stod(en)*MeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty() && _ecms[2].empty()) {
-        MSG_ERROR("Beam energy incompatible with analysis.");
-      }
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty() && _sqs[2].empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size() != 2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-        if (abs(p.pid())!=PID::PIPLUS) vetoEvent;
+        if (p.abspid() != PID::PIPLUS) vetoEvent;
       }
-      for(unsigned int ix=0;ix<3;++ix) {
-        if(!_ecms[ix].empty()) _sigma[ix]->fill(_ecms[ix]);
+      for (size_t ix=0; ix<3; ++ix) {
+        if (!_sqs[ix].empty()) _sigma[ix]->fill(_sqs[ix]);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      const double gev2nb =0.389e6;
-      const double beta = sqrt(1.-4.*sqr(0.13957039/sqrtS()));
+      scale(_sigma, crossSection()/sumOfWeights()/nanobarn);
+      const double gev2nb = 0.389e6;
       const double alpha = 1./137.035999084;
-      const double sigma0 = gev2nb*M_PI*sqr(alpha)*beta*sqr(beta)/3/sqr(sqrtS());
-      for(unsigned int ix=0;ix<3;++ix)
-        scale(_sigma[ix], crossSection()/ sumOfWeights() /nanobarn /sigma0);
+      for (size_t ix=0; ix<3; ++ix) {
+        for (auto& b : _sigma[ix]->bins()) {
+          const double eval = stod(b.xEdge())*MeV;
+          const double beta = sqrt(1.-4.*sqr(0.13957039/eval));
+          const double sigma0 = gev2nb*M_PI*sqr(alpha)*beta*sqr(beta)/3/sqr(eval);
+          b.scaleW(1.0/sigma0);
+        }
+      }
     }
 
     /// @}
@@ -67,7 +69,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[3];
-    string _ecms[3];
+    string _sqs[3];
     /// @}
 
 
@@ -75,5 +77,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD3_2023_I2634277);
-
 }
