@@ -27,40 +27,37 @@ namespace Rivet {
       book(_sigma1, 1,1,1);
       book(_sigma2, 2,1,1);
       for (const string& en : _sigma1.binning().edges<0>()) {
-        double end = std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          ecms = en;
-          break;
+        double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      icms=-1;
-      for(const int& en : _sigma2.binning().edges<0>()) {
-        double end = double(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          icms = en;
-          break;
+      for (int en : _sigma2.binning().edges<0>()) {
+        double eval = en*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _isqs = en; break;
         }
       }
-      if(ecms.empty() && icms<0) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty() && _isqs < 0.);
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-	if(abs(p.pid())!=PID::PIPLUS) vetoEvent;
+        if (p.abspid() != PID::PIPLUS) vetoEvent;
       }
-      if(!ecms.empty()) _sigma1->fill(ecms);
-      if(icms>0       ) _sigma2->fill(icms);
+      if (!_sqs.empty()) _sigma1->fill(_sqs);
+      if (_isqs > 0)  _sigma2->fill(_isqs);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_sigma1,crossSection()/ sumOfWeights() /nanobarn);
-      scale(_sigma2,crossSection()/ sumOfWeights() /nanobarn);
+      scale(_sigma1, crossSection()/sumOfWeights()/nanobarn);
+      scale(_sigma2, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -70,8 +67,8 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string>  _sigma1;
     BinnedHistoPtr<int>     _sigma2;
-    string ecms;
-    int icms;
+    string _sqs = "";
+    int _isqs = -1;
     /// @}
 
 
@@ -79,6 +76,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CMD_1985_I221309);
-
-
 }
