@@ -26,34 +26,30 @@ namespace Rivet {
       book(_numOmegaPi, 1, 1, 1);
       for (const string& en : _numOmegaPi.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/MeV, emin, emax)) {
-            _ecms = en;
-            break;
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1,string::npos));
+          if (inRange(sqrtS()/MeV, emin, emax)) {
+            _sqs = en; break;
           }
         }
         else {
-          const double end = std::stod(en)*MeV;
+          const double end = stod(en)*MeV;
           if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  nRes[child.pid()]+=1;
-	  ++ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          nRes[child.pid()] += 1;
+          ++ncount;
+        }
+        else findChildren(child,nRes,ncount);
       }
     }
 
@@ -65,33 +61,32 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       // three particles (pi0 pi0 gamma)
-      if(ntotal!=3) vetoEvent;
+      if (ntotal!=3) vetoEvent;
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	if(p.children().empty()) continue;
-	// find the omega
-	if(p.pid()==223) {
-	  map<long,int> nRes;
-	  int ncount(0);
-	  findChildren(p,nRes,ncount);
-	  // only omega to pi0 gamma mode
-	  if(ncount!=2) continue;
-	  if(nRes[111]!=1 || nRes[22]!=1) continue;
-	  // omega pi0
-	  if(nCount[111]-nRes[111]==1)
-	    _numOmegaPi->fill(_ecms);
-	}
+        if (p.children().empty()) continue;
+        // find the omega
+        if (p.pid()==223) {
+          map<long,int> nRes;
+          int ncount(0);
+          findChildren(p,nRes,ncount);
+          // only omega to pi0 gamma mode
+          if (ncount!=2) continue;
+          if (nRes[111]!=1 || nRes[22]!=1) continue;
+          // omega pi0
+          if (nCount[111]-nRes[111]==1)  _numOmegaPi->fill(_sqs);
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_numOmegaPi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_numOmegaPi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -99,7 +94,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _numOmegaPi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -107,6 +102,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2000_I527752);
-
-
 }
