@@ -22,23 +22,21 @@ namespace Rivet {
 
       // Initialise and register projections
       declare(FinalState(), "FS");
-      for (unsigned int ix=0;ix<2;++ix) {
-        for (unsigned int iy=0;iy<4;++iy)
+      for (size_t ix=0; ix<2; ++ix) {
+        for (size_t iy=0; iy<4; ++iy) {
           book(_sigma[ix][iy], 1+ix, 1, 1+iy);
-        
+        }
         for (const string& en : _sigma[ix][3].binning().edges<0>()) {
-          double end = std::stod(en)*MeV;
-          if(isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          double eval = stod(en)*MeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if(_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
-    
-    
+
+
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
@@ -46,24 +44,24 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      if(ntotal==2) {
-	if(nCount[321]==1 && nCount[-321]==1) {
-          for(unsigned int ix=0;ix<2;++ix)
-            _sigma[ix][0]->fill(_ecms[ix]);
+      if (ntotal==2) {
+        if (nCount[321]==1 && nCount[-321]==1) {
+          _sigma[0][0]->fill(_sqs[0]);
+          _sigma[1][0]->fill(_sqs[1]);
         }
-        else if(nCount[130]==1 && nCount[310]==1) {
-          for(unsigned int ix=0;ix<2;++ix) {
-            _sigma[ix][1]->fill(_ecms[ix]);
-            _sigma[ix][2]->fill(_ecms[ix]);
-          }
+        else if (nCount[130]==1 && nCount[310]==1) {
+          _sigma[0][1]->fill(_sqs[0]);
+          _sigma[0][2]->fill(_sqs[0]);
+          _sigma[1][1]->fill(_sqs[1]);
+          _sigma[1][2]->fill(_sqs[1]);
         }
       }
-      else if(ntotal==3 && nCount[211] == 1 && nCount[-211] == 1 && nCount[111] == 1) {
-        for(unsigned int ix=0;ix<2;++ix)
-          _sigma[ix][3]->fill(_ecms[ix]);
+      else if (ntotal==3 && nCount[211] == 1 && nCount[-211] == 1 && nCount[111] == 1) {
+        _sigma[0][3]->fill(_sqs[0]);
+        _sigma[1][3]->fill(_sqs[1]);
       }
 
     }
@@ -71,12 +69,9 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      for (unsigned int ix=0;ix<2;++ix) {
-        for (unsigned int iy=0;iy<4;++iy) {
-          scale(_sigma[ix][iy],fact);
-        }
-      }
+      const double fact = crossSection()/sumOfWeights()/nanobarn;
+      scale(_sigma[0], fact);
+      scale(_sigma[1], fact);
     }
 
     /// @}
@@ -85,7 +80,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _sigma[2][4];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
@@ -93,6 +88,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2001_I533574);
-
-
 }
