@@ -23,18 +23,16 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_npion[ix], 1+ix, 1, 1);
         for (const string& en : _npion[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
 
@@ -45,21 +43,22 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (ntotal!=4) vetoEvent;
+      if (nCount[-211]==2&&nCount[211]==2) {
+        _npion[0]->fill(_sqs[0]);
+      }
+      else if (nCount[-211]==1 && nCount[211]==1 && nCount[111]==2) {
+        _npion[1]->fill(_sqs[1]);
       }
-      if(ntotal!=4) vetoEvent;
-      if(nCount[-211]==2&&nCount[211]==2)
-	_npion[0]->fill(_ecms[0]);
-      else if(nCount[-211]==1&&nCount[211]==1&&nCount[111]==2)
-	_npion[1]->fill(_ecms[1]);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for (unsigned int ix=0;ix<2;++ix)
-        scale(_npion[ix], crossSection()/ sumOfWeights() /nanobarn);
+      scale(_npion, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -68,7 +67,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _npion[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
@@ -76,6 +75,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2001_I579319);
-
-
 }
