@@ -25,13 +25,12 @@ namespace Rivet {
 
       book(_num3pi, 1, 1, 1);
       for (const string& en : _num3pi.binning().edges<0>()) {
-        double end = std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -42,19 +41,19 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (ntotal!=3) vetoEvent;
+      if (nCount[-211]==1&&nCount[211]==1&&nCount[111]==1) {
+        _num3pi->fill(_sqs);
       }
-      if(ntotal!=3) vetoEvent;
-      if(nCount[-211]==1&&nCount[211]==1&&nCount[111]==1)
-	_num3pi->fill(_ecms);
-
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_num3pi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_num3pi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -63,7 +62,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _num3pi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -71,6 +70,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2002_I582183);
-
-
 }
