@@ -24,24 +24,21 @@ namespace Rivet {
       book(_nK0K0, 1, 1, 1);
       for (const string& en : _nK0K0.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms = en;
-            break;
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1,string::npos));
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs = en; break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -53,19 +50,18 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (ntotal==2 && nCount[130]==1 && nCount[310]==1) {
+        _nK0K0->fill(_sqs);
       }
-      if(ntotal==2 &&
-	 nCount[130]==1 && nCount[310]==1)
-	_nK0K0->fill(_ecms);
-
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nK0K0, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_nK0K0, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -74,7 +70,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nK0K0;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -82,6 +78,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2006_I720035);
-
-
 }
