@@ -25,23 +25,21 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_numEtaPiPi, 1, 1, 1);
       for (const string& en : _numEtaPiPi.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  --nRes[child.pid()];
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+        if (child.children().empty()) {
+          --nRes[child.pid()];
+          --ncount;
+        }
+        else findChildren(child,nRes,ncount);
       }
     }
 
@@ -53,42 +51,41 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	if(p.children().empty()) continue;
-	// find the eta
-	if(p.pid()==221) {
-	  map<long,int> nRes = nCount;
-	  int ncount = ntotal;
-	  findChildren(p,nRes,ncount);
-	  // eta pi+pi-
-	  if(ncount!=2) continue;
-	  bool matched = true;
-	  for(auto const & val : nRes) {
-	    if(abs(val.first)==211) {
-	      if(val.second !=1) {
-		matched = false;
-		break;
-	      }
-	    }
-	    else if(val.second!=0) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  if(matched)
-	    _numEtaPiPi->fill(_ecms);
-	}
+        if (p.children().empty()) continue;
+        // find the eta
+        if (p.pid()==221) {
+          map<long,int> nRes = nCount;
+          int ncount = ntotal;
+          findChildren(p,nRes,ncount);
+          // eta pi+pi-
+          if (ncount!=2) continue;
+          bool matched = true;
+          for (const auto& val : nRes) {
+            if (abs(val.first)==211) {
+              if (val.second !=1) {
+                matched = false;
+                break;
+              }
+            }
+            else if (val.second!=0) {
+              matched = false;
+              break;
+            }
+          }
+          if (matched) _numEtaPiPi->fill(_sqs);
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_numEtaPiPi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_numEtaPiPi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -97,7 +94,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _numEtaPiPi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -105,6 +102,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2015_I1332929);
-
-
 }
