@@ -22,13 +22,12 @@ namespace Rivet {
       declare(FinalState(), "FS");
       book(_num3pi, 1,1,1);
       for (const string& en : _num3pi.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -39,18 +38,19 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (ntotal!=3) vetoEvent;
+      if (nCount[-211]==1 && nCount[211]==1 && nCount[111]==1) {
+        _num3pi->fill(_sqs);
       }
-      if(ntotal!=3) vetoEvent;
-      if(nCount[-211]==1&&nCount[211]==1&&nCount[111]==1)
-	_num3pi->fill(_ecms);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_num3pi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_num3pi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -59,7 +59,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _num3pi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -67,6 +67,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2015_I1389908);
-
-
 }
