@@ -23,24 +23,21 @@ namespace Rivet {
       book(_numPi0Gamma, 1, 1, 5);
       for (const string& en : _numPi0Gamma.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/MeV, emin, emax)) {
-            _ecms = en;
-            break;
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1,string::npos));
+          if (inRange(sqrtS()/MeV, emin, emax)) {
+            _sqs = en; break;
           }
         }
         else {
-          const double end = std::stod(en)*MeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*MeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -52,18 +49,19 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (ntotal==2 && nCount[22]==1 && nCount[111]==1) {
+        _numPi0Gamma->fill(_sqs);
       }
-      if(ntotal==2 && nCount[22]==1 && nCount[111]==1)
-	_numPi0Gamma->fill(_ecms);
 
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_numPi0Gamma, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_numPi0Gamma, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -72,7 +70,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _numPi0Gamma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
