@@ -23,35 +23,33 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_nkaon[ix], 1+ix, 1, 1);
         for (const string& en : _nkaon[ix].binning().edges<0>()) {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if (_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-	if(abs(p.pid())!=PID::KPLUS) vetoEvent;
+        if (p.abspid() != PID::KPLUS) vetoEvent;
       }
-      for(unsigned int ix=0;ix<2;++ix) _nkaon[ix]->fill(_ecms[ix]);
+      for (size_t ix=0; ix<2; ++ix) _nkaon[ix]->fill(_sqs[ix]);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nkaon, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_nkaon, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -60,7 +58,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nkaon[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
@@ -68,6 +66,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2016_I1484677);
-
-
 }
