@@ -26,23 +26,21 @@ namespace Rivet {
       book(_numOmegaPi, 1, 1, 1);
 
       for (const string& en : _numOmegaPi.binning().edges<0>()) {
-        double end = std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  nRes[child.pid()]+=1;
-	  ++ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p,map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          nRes[child.pid()] += 1;
+          ++ncount;
+        }
+        else findChildren(child,nRes,ncount);
       }
     }
 
@@ -53,33 +51,32 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       // three particles (pi0 pi0 gamma)
-      if(ntotal!=3) vetoEvent;
+      if (ntotal!=3) vetoEvent;
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	if(p.children().empty()) continue;
-	// find the omega
-	if(p.pid()==223) {
-	  map<long,int> nRes;
-	  int ncount(0);
-	  findChildren(p,nRes,ncount);
-	  // only omega to pi0 gamma mode
-	  if(ncount!=2) continue;
-	  if(nRes[111]!=1 || nRes[22]!=1) continue;
-	  // omega pi0
-	  if(nCount[111]-nRes[111]==1)
-	    _numOmegaPi->fill(_ecms);
-	}
+        if (p.children().empty()) continue;
+        // find the omega
+        if (p.pid()==223) {
+          map<long,int> nRes;
+          int ncount(0);
+          findChildren(p,nRes,ncount);
+          // only omega to pi0 gamma mode
+          if (ncount!=2) continue;
+          if (nRes[111]!=1 || nRes[22]!=1) continue;
+          // omega pi0
+          if (nCount[111]-nRes[111]==1) _numOmegaPi->fill(_sqs);
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_numOmegaPi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_numOmegaPi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -87,14 +84,10 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _numOmegaPi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
-
   };
 
-
   RIVET_DECLARE_PLUGIN(SND_2016_I1489182);
-
-
 }
