@@ -22,25 +22,23 @@ namespace Rivet {
       declare(FinalState(), "FS");
       book(_nKKpi, 1, 1, 1);
       for (const string& en : _nKKpi.binning().edges<0>()) {
-        const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms = en;
+        const size_t idx = en.find(" to ");
+        if (idx!=string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+4,string::npos));
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs = en;
             break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -55,14 +53,15 @@ namespace Rivet {
         ++ntotal;
       }
 
-      if(ntotal==3 && nCount[130]==1 && nCount[310]==1 && nCount[111] ==1)
-        _nKKpi->fill(_ecms);
+      if (ntotal==3 && nCount[130]==1 && nCount[310]==1 && nCount[111] ==1) {
+        _nKKpi->fill(_sqs);
+      }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nKKpi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_nKKpi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -71,7 +70,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nKKpi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -79,6 +78,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2018_I1637194);
-
-
 }
