@@ -28,22 +28,21 @@ namespace Rivet {
       book( _nKKPi, 1, 1, 1);
       book(_nPhiPi,"TMP/nPhiPi", refData(2,1,1));
       for (const string& en : _nKKPi.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double end = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(end, 5e-3)) {
+          _sqs = en; break;
         }
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  nRes[child.pid()]-=1;
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          nRes[child.pid()] -= 1;
+          --ncount;
+        }
+        else findChildren(child,nRes,ncount);
       }
     }
 
@@ -54,45 +53,45 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+       	nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (ntotal==3 && nCount[321]==1 && nCount[-321]==1 && nCount[111]==1) {
+        // KK pi state
+        _nKKPi->fill(_sqs);
       }
-      // KK pi state
-      if(ntotal==3 && nCount[321]==1 &&
-	 nCount[-321]==1 && nCount[111]==1)
-	_nKKPi->fill(_ecms);
       // phi pi state
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles(Cuts::pid==333)) {
-	if(p.children().empty()) continue;
-	map<long,int> nRes = nCount;
-	int ncount = ntotal;
-	findChildren(p,nRes,ncount);
-	if(ncount!=1) continue;
-	bool matched = true;
-	for(auto const & val : nRes) {
-	  if(val.first==111) {
-	    if(val.second!=1) {
-	      matched = false;
-	      break;
-	      }
-	  }
-	  else if(val.second!=0) {
-	    matched = false;
-	    break;
-	  }
-	}
-	if(matched) {
-	  _nPhiPi->fill(sqrtS()/GeV);
-	  break;
-	}
+        if (p.children().empty()) continue;
+        map<long,int> nRes = nCount;
+        int ncount = ntotal;
+        findChildren(p,nRes,ncount);
+        if (ncount!=1) continue;
+        bool matched = true;
+        for (const auto& val : nRes) {
+          if (val.first==111) {
+            if (val.second!=1) {
+              matched = false;
+              break;
+            }
+          }
+          else if (val.second!=0) {
+            matched = false;
+            break;
+          }
+        }
+        if (matched) {
+          _nPhiPi->fill(sqrtS()/GeV);
+          break;
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact =  crossSection()/ sumOfWeights() /nanobarn;
+      double fact =  crossSection()/sumOfWeights()/nanobarn;
       scale(_nKKPi ,fact);
       scale(_nPhiPi,fact);
       Estimate1DPtr  mult;
@@ -106,7 +105,7 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _nKKPi;
     Histo1DPtr _nPhiPi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -114,5 +113,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2020_I1806118);
-
 }
