@@ -24,15 +24,13 @@ namespace Rivet {
 
       // Book histograms
       book(_nneutron, 1, 1, 1);
-
       for (const string& en : _nneutron.binning().edges<0>()) {
-        double end = std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -41,15 +39,15 @@ namespace Rivet {
       const FinalState& fs = apply<FinalState>(event, "FS");
       if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-        if(abs(p.pid())!=PID::NEUTRON) vetoEvent;
+        if (p.abspid() != PID::NEUTRON) vetoEvent;
       }
-      _nneutron->fill(_ecms);
+      _nneutron->fill(_sqs);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nneutron, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_nneutron, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -58,7 +56,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nneutron;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -66,5 +64,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2022_I2102082);
-
 }
