@@ -24,28 +24,25 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_numEtaGamma, 1, 1, 1);
       for (const string& en : _numEtaGamma.binning().edges<0>()) {
-        const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms = en;
-            break;
+        const size_t idx = en.find(" to ");
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+4,string::npos));
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs = en; break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -92,7 +89,7 @@ namespace Rivet {
           }
         }
         if (matched) {
-          _numEtaGamma->fill(_ecms);
+          _numEtaGamma->fill(_sqs);
         }
       }
     }
@@ -100,7 +97,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_numEtaGamma, crossSection()/ sumOfWeights() /picobarn);
+      scale(_numEtaGamma, crossSection()/sumOfWeights()/picobarn);
     }
 
     /// @}
@@ -109,7 +106,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _numEtaGamma;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
