@@ -24,16 +24,15 @@ namespace Rivet {
       declare(UnstableParticles(Cuts::pid==223), "UFS");
       book(_nOmegaPi, 1, 1, 1);
       for (const string& en : _nOmegaPi.binning().edges<0>()) {
-        double end = std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
       for (const Particle &child : p.children()) {
         if (child.children().empty()) {
           --nRes[child.pid()];
@@ -58,7 +57,7 @@ namespace Rivet {
       }
       // require 4 pi final state
       if (ntotal!=4) vetoEvent;
-      if (nCount[211]!=1 || nCount[-211]!=1 || nCount[111]!=2) vetoEvent;
+      if (nCount[211] != 1 || nCount[-211] != 1 || nCount[111] != 2) vetoEvent;
       // omega
       for (const Particle& p : apply<FinalState>(event, "UFS").particles()) {
       	if (p.children().empty()) continue;
@@ -82,7 +81,7 @@ namespace Rivet {
       	  }
       	}
       	if (matched) {
-      	  _nOmegaPi->fill(_ecms);
+      	  _nOmegaPi->fill(_sqs);
           break;
         }
       }
@@ -91,7 +90,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nOmegaPi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_nOmegaPi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -100,7 +99,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nOmegaPi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -108,5 +107,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(SND_2023_I2693057);
-
 }
