@@ -20,14 +20,12 @@ namespace Rivet {
       declare(FinalState(), "FS");
       book(_nK0K0, 1, 1, 1);
       for (const string& en : _nK0K0.binning().edges<0>()) {
-        const double end = std::stod(en)*MeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -39,19 +37,19 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (ntotal==2 && nCount[130]==1 && nCount[310]==1) {
+        _nK0K0->fill(_sqs);
       }
-      if(ntotal==2 &&
-	 nCount[130]==1 && nCount[310]==1)
-	_nK0K0->fill(_ecms);
 
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_nK0K0, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_nK0K0, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -59,12 +57,11 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nK0K0;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
 
 
   RIVET_DECLARE_PLUGIN(SND_2024_I2809918);
-
 }
