@@ -25,13 +25,12 @@ namespace Rivet {
       book(_nneutron, 1, 1, 1);
 
       for (const string& en : _nneutron.binning().edges<0>()) {
-        double end = 2.*std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = 2.0*stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -40,9 +39,9 @@ namespace Rivet {
       const FinalState& fs = apply<FinalState>(event, "FS");
       if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-        if(abs(p.pid())!=PID::NEUTRON) vetoEvent;
+        if(p.abspid() != PID::NEUTRON) vetoEvent;
       }
-      _nneutron->fill(_ecms);
+      _nneutron->fill(_sqs);
     }
 
 
@@ -57,12 +56,11 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _nneutron;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
 
 
   RIVET_DECLARE_PLUGIN(SND_2024_I2809929);
-
 }
