@@ -9,6 +9,7 @@
 #include "Rivet/Projections/SmearedJets.hh"
 #include "Rivet/Projections/SmearedParticles.hh"
 #include "Rivet/Tools/RivetONNXrt.hh"
+#include "Rivet/Tools/ExptSmearingFunctions.hh"
 
 #include "Rivet/Tools/Cutflow.hh"
 
@@ -51,7 +52,7 @@ namespace Rivet {
       const FinalState fsj(Cuts::abseta < 4.8);
 	    FastJets Sj(fsj, JetAlg::ANTIKT, 0.4, JetMuons::NONE);
       _smallR_jDef = Sj.jetDef();
-      SmearedJets SSj(Sj, JET_SMEAR_ATLAS_RUN2, JET_BTAG_MV2C10_77_2016);
+      SmearedJets SSj(Sj, JET_SMEAR_ATLAS_RUN2, JET_BTAG_ATLAS_RUN2_2016_MV2C10_77);
     	declare(SSj, "smearedSjet");
 
       declare(MissingMom(), "Etmiss");
@@ -747,30 +748,6 @@ namespace Rivet {
       return;
     }
 
-    // Based on ATL-PHYS-PUB-2016-012 fig 12
-    static double JET_BTAG_MV2C10_77_2016(const Jet & j){
-      if (j.bTagged()){
-        // N.B. !!! There is no overflow bin.
-        // There is a clear downward curve in efficiency as pT->inf, but the value to use for pT > 500
-        // is super-unclear. The used value (0.69) is certainly a reasonable extrapolation, but it should
-        // be noted that tuning this value can make a really significant difference to the bin counts O(10%)
-        // HOWEVER: atlas really needs to start increasing the range of this sort of plot
-        // The behaviour of jets pT>500 is much more interesting and significant than those in the range 20<pt<25.
-        const static vector<double>binedges_pt = {0.00, 30.0, 40.00, 50.00, 60.0, 75.00, 90.0, 105., 150., 200., 500 };
-        const static vector<double> eff_pt = {0.63, 0.705, 0.74, 0.76, 0.775, 0.785, 0.795, 0.80, 0.79, 0.75, 0.68};
-
-        return eff_pt[binIndex(j.pt(), binedges_pt, true)];
-      }
-      else if (j.cTagged()){
-        //n.b. there is also a pt/eta table for c mistags, but if that's significant I'll eat my hat.
-        return 1./5.;
-      }
-      else if (j.tauTagged()){
-        return 1./16.;
-      }
-      else return 1./110.;
-    }
-
     /// @name Other private variables belonging to the analysis
     /// @{
 
