@@ -5,7 +5,7 @@
 namespace Rivet {
 
 
-  /// @brief Add a short analysis description here
+  /// @brief e+e- > p pbar
   class DM1_1979_I141565 : public Analysis {
   public:
 
@@ -14,13 +14,13 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
       // Initialise and register projections
       declare(FinalState(), "FS");
-      book(_nProton,  "/TMP/nProton" );
+      book(_nProton,  "/TMP/nProton", refData(1,1,1) );
     }
 
 
@@ -35,46 +35,30 @@ namespace Rivet {
 	++ntotal;
       }
       if(ntotal==2 && nCount[2212]==1 && nCount[-2212]==1)
-	_nProton->fill();
+	_nProton->fill(sqrtS()/GeV);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      double sigma = _nProton->val()*fact;
-      double error = _nProton->err()*fact;
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr mult;
+      scale(_nProton, crossSection()/ sumOfWeights() /nanobarn);
+      Estimate1DPtr mult;
       book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      barchart(_nProton,mult);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    CounterPtr _nProton;
-    //@}
+    /// @{
+    Histo1DPtr _nProton;
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(DM1_1979_I141565);
 
 
