@@ -24,13 +24,12 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
       book(_n3pi, 1, 1, 1);
       for (const string& en : _n3pi.binning().edges<0>()) {
-        double end = std::stod(en)*MeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*MeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -41,17 +40,18 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
+      }
+      if (ntotal==3 && nCount[211] == 1 && nCount[-211] == 1 && nCount[111] == 1) {
+        _n3pi->fill(_sqs);
       }
-      if(ntotal==3 && nCount[211] == 1 && nCount[-211] == 1 && nCount[111] == 1)
-	_n3pi->fill(_ecms);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_n3pi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_n3pi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -60,7 +60,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _n3pi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -68,6 +68,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(DM1_1980_I140174);
-
-
 }
