@@ -26,34 +26,30 @@ namespace Rivet {
       book(_numEtaPiPi, 1,1,1);
       for (const string& en : _numEtaPiPi.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/MeV, emin, emax)) {
-            _ecms = en;
-            break;
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1,string::npos));
+          if (inRange(sqrtS()/MeV, emin, emax)) {
+            _sqs = en; break;
           }
         }
         else {
-          const double end = std::stod(en)*MeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*MeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  --nRes[child.pid()];
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          --nRes[child.pid()];
+          --ncount;
+        }
+        else findChildren(child,nRes,ncount);
       }
     }
 
@@ -64,42 +60,41 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	if(p.children().empty()) continue;
-	// find the omega
-	if(p.pid()==221) {
-	  map<long,int> nRes = nCount;
-	  int ncount = ntotal;
-	  findChildren(p,nRes,ncount);
-	  // eta pi+pi-
-	  if(ncount!=2) continue;
-	  bool matched = true;
-	  for(auto const & val : nRes) {
-	    if(abs(val.first)==211) {
-	      if(val.second !=1) {
-		matched = false;
-		break;
-	      }
-	    }
-	    else if(val.second!=0) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  if(matched)
-	    _numEtaPiPi->fill(_ecms);
-	}
+        if (p.children().empty()) continue;
+        // find the omega
+        if (p.pid()==221) {
+          map<long,int> nRes = nCount;
+          int ncount = ntotal;
+          findChildren(p,nRes,ncount);
+          // eta pi+pi-
+          if (ncount!=2) continue;
+          bool matched = true;
+          for (const auto& val : nRes) {
+            if (abs(val.first)==211) {
+              if (val.second !=1) {
+                matched = false;
+                break;
+              }
+            }
+            else if (val.second!=0) {
+              matched = false;
+              break;
+            }
+          }
+          if (matched) _numEtaPiPi->fill(_sqs);
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_numEtaPiPi, crossSection()/ sumOfWeights() /nanobarn);
+      scale(_numEtaPiPi, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -108,7 +103,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _numEtaPiPi;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
