@@ -26,30 +26,29 @@ namespace Rivet {
       // Book histograms
       book(_npion,1,1,1);
       for (const string& en : _npion.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const FinalState& fs = apply<FinalState>(event, "FS");
-      if(fs.particles().size()!=2) vetoEvent;
+      if (fs.particles().size()!=2) vetoEvent;
       for (const Particle& p : fs.particles()) {
-	if(abs(p.pid())!=PID::PIPLUS) vetoEvent;
+        if (p.abspid() != PID::PIPLUS) vetoEvent;
       }
-      _npion->fill(ecms);
+      _npion->fill(_sqs);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_npion,crossSection()/ sumOfWeights() /nanobarn);
+      scale(_npion, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -58,7 +57,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _npion;
-    string ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -66,6 +65,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(DM2_1989_I267118);
-
-
 }
