@@ -23,60 +23,49 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      unsigned int iloc(0);
-      if (isCompatibleWithSqrtS(22*GeV)) {
-        iloc=1;
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en+"EEC"],   1, 1, ih);
+        book(_h[en+"AEEC"],  3, 1, ih);
+        book(_c[en], "TMP/weightSum"+en);
+        ++ih;
       }
-      else if (isCompatibleWithSqrtS(34*GeV)) {
-        iloc=2;
-      }
-      else {
-        MSG_ERROR("Beam energy not supported!");
-      }
-      book(_histEEC,   1, 1, iloc);
-      book(_histAEEC,  3, 1, iloc);
-      book(_weightSum, "TMP/weightSum");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
 
-      if (edges[0].empty())  edges[0] = _histEEC->xEdges();
-      if (edges[1].empty())  edges[1] = _histAEEC->xEdges();
+      if (edges[0].empty())  edges[0] = _h[_sqs+"EEC"]->xEdges();
+      if (edges[1].empty())  edges[1] = _h[_sqs+"AEEC"]->xEdges();
 
       // First, veto on leptonic events by requiring at least 4 charged FS particles
       const FinalState& fs = apply<FinalState>(event, "FS");
       // Even if we only generate hadronic events, we still need a cut on numCharged >= 2.
-      if ( fs.particles().size() < 2) {
-        MSG_DEBUG("Failed leptonic event cut");
-        vetoEvent;
-      }
-      MSG_DEBUG("Passed leptonic event cut");
-      _weightSum->fill();
+      if (fs.particles().size() < 2) vetoEvent;
+      _c[_sqs]->fill();
 
-      double Evis = 0.0;
-      for (const Particle& p : fs.particles()) {
-        Evis += p.E();
-      }
-      double Evis2 = sqr(Evis);
+      const double Evis2 = sqr(sum(fs.particles(), Kin::E, 0.0));
       // (A)EEC
       // Need iterators since second loop starts at current outer loop iterator, i.e. no "foreach" here!
       for (Particles::const_iterator p_i = fs.particles().begin(); p_i != fs.particles().end(); ++p_i) {
         for (Particles::const_iterator p_j = p_i; p_j != fs.particles().end(); ++p_j) {
-          const Vector3 mom3_i = p_i->momentum().p3();
-          const Vector3 mom3_j = p_j->momentum().p3();
-          const double energy_i = p_i->momentum().E();
-          const double energy_j = p_j->momentum().E();
+          const Vector3 mom3_i = p_i->p3();
+          const Vector3 mom3_j = p_j->p3();
+          const double energy_i = p_i->E();
+          const double energy_j = p_j->E();
           const double thetaij = mom3_i.unit().angle(mom3_j.unit());
           double eec = (energy_i*energy_j) / Evis2;
           if (p_i != p_j)  eec *= 2.;
-          _histEEC->fill(map2string(thetaij, 0), eec);
+          _h[_sqs+"EEC"]->fill(map2string(thetaij, 0), eec);
           if (thetaij < 0.5*M_PI) {
-            _histAEEC->fill(map2string(thetaij, 1), -eec);
+            _h[_sqs+"AEEC"]->fill(map2string(thetaij, 1), -eec);
           }
           else {
-            _histAEEC->fill(map2string(M_PI-thetaij, 1), eec);
+            _h[_sqs+"AEEC"]->fill(map2string(M_PI-thetaij, 1), eec);
           }
         }
       }
@@ -90,15 +79,15 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_histEEC,  1.0/ *_weightSum);
-      for(auto & b: _histEEC->bins()) {
-        const size_t idx = b.index();
-        b.scaleW(1./axes[0].width(idx));
-      }
-      scale(_histAEEC, 1.0/ *_weightSum);
-      for(auto & b: _histAEEC->bins()) {
-        const size_t idx = b.index();
-        b.scaleW(1./axes[1].width(idx));
+      for (const auto& item : _c) {
+        size_t ih = 0;
+        for (const string& obs : vector<string>{"EEC"s, "AEEC"s}) {
+          scale(_h[item.first+obs], 1.0/item.second->sumW());
+          for (auto& b: _h[item.first+obs]->bins()) {
+            b.scaleW(1.0/axes[ih].width(b.index()));
+          }
+          ++ih;
+        }
       }
     }
 
@@ -107,9 +96,10 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    BinnedHistoPtr<string> _histEEC, _histAEEC;
+    map<string,BinnedHistoPtr<string>> _h;
+    map<string,CounterPtr> _c;
     vector<string> edges[2];
-    CounterPtr _weightSum;
+    string _sqs = "";
     YODA::Axis<double> axes[2] = { YODA::Axis<double>(50, 0.0, M_PI),
                                    YODA::Axis<double>(24, 0.0628, 0.5*M_PI) };
     /// @}
