@@ -23,18 +23,22 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // book histos
-      if(inRange(sqrtS()/GeV,1.2,3.0)) {
-        book(_nRho,"TMP/nRho");
-      }
-      else {
-        throw Error("Invalid CMS energy for CELLO_1989_I267081");
+      book(_mult[0], 1, 1, 1);
+      book(_mult[1], 2, 1, 1);
+      book(_nRho, "TMP/nRho");
+      for (const string& en : _mult[0].binning().edges<0>()) {
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
+        }
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-        if(child.children().empty()) {
-          nRes[child.pid()]-=1;
+    void findChildren(const Particle& p, map<long,int>& nRes, int& ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          nRes[child.pid()] -= 1;
           --ncount;
         }
         else {
@@ -55,33 +59,29 @@ namespace Rivet {
       }
       // find any rho mesons
       Particles rho=apply<UnstableParticles>(event, "UFS").particles(Cuts::abspid==213);
-      for (unsigned int ix=0;ix<rho.size();++ix) {
-       	if(rho[ix].children().empty()) continue;
+      for (size_t ix=0; ix<rho.size(); ++ix) {
+       	if (rho[ix].children().empty()) continue;
        	map<long,int> nRes=nCount;
        	int ncount = ntotal;
        	findChildren(rho[ix],nRes,ncount);
         bool matched = false;
-        for (unsigned int iy=ix+1;iy<rho.size();++iy) {
+        for (size_t iy=ix+1; iy<rho.size(); ++iy) {
           if (rho[iy].children().empty()) continue;
           if (rho[ix].pid()!=-rho[iy].pid()) continue;
           map<long,int> nRes2=nRes;
           int ncount2 = ncount;
           findChildren(rho[iy],nRes2,ncount2);
-          if (ncount2 !=0 ) continue;
+          if (ncount2 !=0) continue;
           matched=true;
-          for (auto const & val : nRes2) {
+          for (const auto& val : nRes2) {
             if (val.second!=0) {
-              matched = false;
-              break;
+              matched = false; break;
             }
           }
-          if (matched) {
-            break;
-          }
+          if (matched)  break;
         }
         if (matched) {
-          _nRho->fill();
-          break;
+          _nRho->fill(); break;
         }
       }
     }
@@ -90,16 +90,8 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       scale(_nRho, crossSection()/nanobarn/sumOfWeights());
-      // loop over tables in paper
-      BinnedEstimatePtr<string> mult;
-      for (unsigned int ix=0; ix<2; ++ix) {
-        book(mult, ix+1, 1, 1);
-        for (auto& b : mult->bins()) {
-          if (isCompatibleWithSqrtS(std::stod(b.xEdge()))) {
-            b.set(_nRho->val(), _nRho->err());
-          }
-        }
-      }
+      _mult[0]->binAt(_sqs).set(_nRho->val(), _nRho->err(), "stats");
+      _mult[1]->binAt(_sqs).set(_nRho->val(), _nRho->err(), "stats");
     }
 
     /// @}
@@ -107,7 +99,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
+    string _sqs = "";
     CounterPtr _nRho;
+    BinnedEstimatePtr<string> _mult[2];
     /// @}
 
 
@@ -115,5 +109,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CELLO_1989_I267081);
-
 }
