@@ -21,36 +21,30 @@ namespace Rivet {
 
       // Initialise and register projections
       declare(ChargedFinalState(), "FS");
-      if     ( isCompatibleWithSqrtS(22.0*GeV) ) _sqs = "22.0";
-      else if( isCompatibleWithSqrtS(27.7*GeV) ) _sqs = "27.7";
-      else if( isCompatibleWithSqrtS(30.0*GeV) ) _sqs = "30.0";
-      else if( isCompatibleWithSqrtS(31.6*GeV) ) _sqs = "31.6";
-      else
-        MSG_WARNING("CoM energy of events sqrt(s) = " << sqrtS()/GeV
-                    << " doesn't match any available analysis energy .");
-      // Book histograms
       book(_mult, 2, 1, 1);
-
+      for (const string& en : _mult.binning().edges<0>()) {
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
+        }
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const ChargedFinalState& fs = apply<ChargedFinalState>(event, "FS");
-      _mult->fill(_sqs,fs.particles().size());
+      _mult->fill(_sqs, fs.particles().size());
     }
 
-
-    /// Normalise histograms etc., after the run
-    void finalize() {
-    }
     /// @}
 
 
     /// @name Histograms
     /// @{
     BinnedProfilePtr<string> _mult;
-    string _sqs;
+    string _sqs = "";
     /// @}
 
 
@@ -58,6 +52,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(JADE_1979_I142874);
-
-
 }
