@@ -20,13 +20,13 @@ namespace Rivet {
     void init() {
       const ChargedFinalState cfs;
       declare(cfs, "CFS");
-      if( !(isCompatibleWithSqrtS(12.0*GeV) ||
-	    isCompatibleWithSqrtS(30.0*GeV) ||
-	    isCompatibleWithSqrtS(35.0*GeV) )) {
-        MSG_WARNING("CoM energy of events sqrt(s) = " << sqrtS()/GeV
-                    << " doesn't match any available analysis energy .");
-      }
       book(_mult, 1, 1, 1);
+      for (int en : _mult.binning().edges<0>()) {
+        if (isCompatibleWithSqrtS(double(en))) {
+          _sqs = en; break;
+        }
+      }
+      raiseBeamErrorIf(_sqs < 0);
     }
 
 
@@ -34,22 +34,18 @@ namespace Rivet {
     void analyze(const Event& event) {
       const FinalState& cfs = apply<FinalState>(event, "CFS");
       MSG_DEBUG("Total charged multiplicity = " << cfs.size());
-      _mult->fill(int(sqrtS()),cfs.size());
+      _mult->fill(_sqs, cfs.size());
     }
 
-
-    /// Normalise histograms etc., after the run
-    void finalize() {
-    }
     /// @}
 
   private:
 
     // Histogram
     BinnedProfilePtr<int> _mult;
+    int _sqs = -1;
 
   };
 
   RIVET_DECLARE_PLUGIN(JADE_1983_I190818);
-
 }
