@@ -23,14 +23,16 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      unsigned int iloc(0);
-      if (isCompatibleWithSqrtS( 14.)) iloc=1;
-      else if(isCompatibleWithSqrtS( 22.)) iloc=2;
-      else if (isCompatibleWithSqrtS( 34.)) iloc=3;
-      else MSG_ERROR("Beam energy not supported!");
-      book(_histEEC , 1, 1, iloc);
-      book(_histAEEC, 2, 1, iloc);
-      book(_weightSum, "TMP/weightSum");
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en+"EEC"], 1, 1, ih);
+        book(_h[en+"AEEC"], 2, 1, ih);
+        book(_c[en], "TMP/weightSum"+en);
+        ++ih;
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -39,36 +41,24 @@ namespace Rivet {
       // First, veto on leptonic events by requiring at least 4 charged FS particles
       const FinalState& fs = apply<FinalState>(event, "FS");
       // Even if we only generate hadronic events, we still need a cut on numCharged >= 2.
-      if ( fs.particles().size() < 2) {
-        MSG_DEBUG("Failed leptonic event cut");
-        vetoEvent;
-      }
-      MSG_DEBUG("Passed leptonic event cut");
-      _weightSum->fill();
+      if ( fs.particles().size() < 2)  vetoEvent;
+      _c[_sqs]->fill();
 
-      double Evis = 0.0;
-      for (const Particle& p : fs.particles()) {
-        Evis += p.E();
-      }
-      double Evis2 = sqr(Evis);
+      const double Evis2 = sqr(sum(fs.particles(), Kin::E, 0.0));
       // (A)EEC
       // Need iterators since second loop starts at current outer loop iterator, i.e. no "foreach" here!
       for (Particles::const_iterator p_i = fs.particles().begin(); p_i != fs.particles().end(); ++p_i) {
         for (Particles::const_iterator p_j = p_i; p_j != fs.particles().end(); ++p_j) {
-          const Vector3 mom3_i = p_i->momentum().p3();
-          const Vector3 mom3_j = p_j->momentum().p3();
-          const double energy_i = p_i->momentum().E();
-          const double energy_j = p_j->momentum().E();
+          const Vector3 mom3_i = p_i->p3();
+          const Vector3 mom3_j = p_j->p3();
+          const double energy_i = p_i->E();
+          const double energy_j = p_j->E();
           const double thetaij = mom3_i.unit().angle(mom3_j.unit())/M_PI*180.;
           double eec = (energy_i*energy_j) / Evis2;
-          if(p_i != p_j) eec *= 2.;
-          _histEEC ->fill(thetaij,  eec);
-          if (thetaij < 90.) {
-            _histAEEC->fill(thetaij, -eec);
-          }
-          else {
-            _histAEEC  ->fill(180.-thetaij, eec);
-          }
+          if (p_i != p_j) eec *= 2.;
+          _h[_sqs+"EEC"]->fill(thetaij,  eec);
+          if (thetaij < 90.)  _h[_sqs+"AEEC"]->fill(thetaij, -eec);
+          else                _h[_sqs+"AEEC"]->fill(180.-thetaij, eec);
         }
       }
     }
@@ -76,8 +66,10 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_histEEC   , 180.0/M_PI*1000./ *_weightSum);
-      scale(_histAEEC  , 180.0/M_PI*1000./ *_weightSum);
+      for (const auto& item : _c) {
+        scale(_h[item.first+"EEC"],  180.0/M_PI*1000./item.second->sumW());
+        scale(_h[item.first+"AEEC"], 180.0/M_PI*1000./item.second->sumW());
+      }
     }
 
     /// @}
@@ -85,8 +77,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _histEEC, _histAEEC;
-    CounterPtr _weightSum;
+    map<string,Histo1DPtr> _h;
+    map<string,CounterPtr> _c;
+    string _sqs = "";
     /// @}
 
 
@@ -94,5 +87,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(JADE_1984_I202784);
-
 }
