@@ -24,13 +24,12 @@ namespace Rivet {
       book(_c_hadrons, "/TMP/sigma_hadrons", refData<YODA::BinnedEstimate<string>>(1,1,1));
       book(_c_muons,   "/TMP/sigma_muons"  , refData<YODA::BinnedEstimate<string>>(1,1,1));
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -44,13 +43,13 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if(nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
         // mu+mu- + photons
-        _c_muons->fill(_ecms);
+        _c_muons->fill(_sqs);
       }
       else {
         // everything else
-        _c_hadrons->fill(_ecms);
+        _c_hadrons->fill(_sqs);
       }
     }
 
@@ -59,7 +58,7 @@ namespace Rivet {
     void finalize() {
       BinnedEstimatePtr<string> mult;
       book(mult, 1, 1, 1);
-      divide(_c_hadrons,_c_muons,mult);
+      divide(_c_hadrons, _c_muons, mult);
     }
 
     /// @}
@@ -68,7 +67,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -76,6 +75,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(JADE_1987_I234905);
-
-
 }
