@@ -25,20 +25,17 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
 
-      int ioff=-1;
-      if (isCompatibleWithSqrtS(35*GeV)) {
-      	ioff=0;
-      }
-      else if (isCompatibleWithSqrtS(44*GeV)) {
-      	ioff=1;
-      }
-      else {
-      	MSG_ERROR("Beam energy " << sqrtS() << " not supported!");
-      }
       // Book histograms
-      book(_h_gamma, 1+ioff, 1, 1);
-      book(_h_pi0  , 3+ioff, 1, 1);
-      if (ioff==0)  book(_h_eta, 5, 1, 1);
+      size_t ih = 0;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en+"gamma"], 1+ih, 1, 1);
+        book(_h[en+"pi0"],   3+ih, 1, 1);
+        if (ih == 0)  book(_h[en+"eta"], 5, 1, 1);
+        ++ih;
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -50,19 +47,19 @@ namespace Rivet {
       // gamma
       const FinalState& fs = apply<FinalState>(event, "FS");
       for (const Particle& p : fs.particles(Cuts::pid==22)) {
-      	_h_gamma->fill(p.E()/meanBeamMom);
+      	_h[_sqs+"gamma"]->fill(p.E()/meanBeamMom);
       }
       // pi0, eta
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
-      for (const Particle& p : ufs.particles(Cuts::pid==111 or Cuts::pid==221)) {
+      for (const Particle& p : ufs.particles(Cuts::pid==111 || Cuts::pid==221)) {
       	const double modp = p.p3().mod();
       	const double xE = p.E()/meanBeamMom;
       	const double beta = modp/p.E();
       	if (p.pid()==111) {
-      	  _h_pi0->fill(xE,1./beta);
+      	  _h[_sqs+"pi0"]->fill(xE, 1.0/beta);
         }
-      	else if (_h_eta) {
-      	  _h_eta->fill(xE,1./beta);
+      	else if (_sqs == "35"s) {
+      	  _h[_sqs+"eta"]->fill(xE, 1.0/beta);
         }
       }
     }
@@ -70,22 +67,22 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_h_gamma, crossSection()*sqr(sqrtS())/microbarn/sumOfWeights());
-      scale(_h_pi0  , crossSection()*sqr(sqrtS())/microbarn/sumOfWeights());
-      if(_h_eta) scale(_h_eta  , crossSection()*sqr(sqrtS())/microbarn/sumOfWeights());
+      for (auto& item : _h) {
+        const double en = stod(item.first.substr(0,2));
+        scale(item.second, crossSection()*sqr(en)/microbarn/sumOfWeights());
+      }
     }
 
     /// @}
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_gamma, _h_pi0, _h_eta;
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
   };
 
 
   RIVET_DECLARE_PLUGIN(JADE_1990_I282847);
-
-
 }
