@@ -26,24 +26,21 @@ namespace Rivet {
       book(_c_muons,   "/TMP/sigma_muons"  , refData<YODA::BinnedEstimate<string>>(1,1,1));
       for (const string& en : _c_hadrons.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
-          if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms = en;
-            break;
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1,string::npos));
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs = en; break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -54,16 +51,14 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	_c_muons->fill(_ecms);
-      // everything else
-      else
-	_c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
+        _c_muons->fill(_sqs);
+      }
+      else _c_hadrons->fill(_sqs); // everything else
     }
 
 
@@ -80,14 +75,11 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
-
   };
 
 
   RIVET_DECLARE_PLUGIN(MARKJ_1980_I158857);
-
-
 }
