@@ -25,14 +25,12 @@ namespace Rivet {
       book(_c_hadrons, "/TMP/sigma_hadron", refData<YODA::BinnedEstimate<string>>(1,1,1));
       book(_c_muons,   "/TMP/sigma_muons" , refData<YODA::BinnedEstimate<string>>(1,1,1));
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -43,25 +41,23 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
       // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	_c_muons->fill(_ecms);
-      // everything else
-      else
-	_c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
+        _c_muons->fill(_sqs);
+      }
+      else _c_hadrons->fill(_sqs); // everything else
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
       BinnedEstimatePtr<string> mult;
-      book(mult,1,1,1);
+      book(mult, 1, 1, 1);
       divide(_c_hadrons, _c_muons, mult);
-      scale(_c_hadrons,crossSection()/ sumOfWeights() /nanobarn);
+      scale(_c_hadrons, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -70,7 +66,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -78,6 +74,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(MARKJ_1984_I196567);
-
-
 }
