@@ -27,13 +27,12 @@ namespace Rivet {
       book(_c_hadrons2, "/TMP/sigma_hadrons2", refData<YODA::BinnedEstimate<int>>(2,1,1));
       book(_c_muons2,   "/TMP/sigma_muons2"  , refData<YODA::BinnedEstimate<int>>(2,1,1));
       for (const string& en : _c_hadrons1.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -44,19 +43,18 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22]) {
-	_c_muons1->fill(_ecms);
-	_c_muons2->fill(round(sqrtS()/GeV));
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
+        // mu+mu- + photons
+        _c_muons1->fill(_sqs);
+        _c_muons2->fill(round(sqrtS()/GeV));
       }
-      // everything else
       else {
-	_c_hadrons1->fill(_ecms);
-	_c_hadrons2->fill(round(sqrtS()/GeV));
+        // everything else
+        _c_hadrons1->fill(_sqs);
+        _c_hadrons2->fill(round(sqrtS()/GeV));
       }
     }
 
@@ -65,10 +63,10 @@ namespace Rivet {
     void finalize() {
       BinnedEstimatePtr<string> mult1;
       book(mult1, 1, 1, 1);
-      divide(_c_hadrons1,_c_muons1,mult1);
+      divide(_c_hadrons1, _c_muons1, mult1);
       BinnedEstimatePtr<int> mult2;
       book(mult2, 2, 1, 1);
-      divide(_c_hadrons2,_c_muons2,mult2);
+      divide(_c_hadrons2, _c_muons2, mult2);
     }
 
     /// @}
@@ -78,7 +76,7 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _c_hadrons1, _c_muons1;
     BinnedHistoPtr<int>    _c_hadrons2, _c_muons2;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -86,6 +84,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(PLUTO_1979_I140294);
-
-
 }
