@@ -23,13 +23,12 @@ namespace Rivet {
       // counters for R
       book(_c_hadrons, 2, 1, 1);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -43,13 +42,13 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if(nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
         // mu+mu- + photons
         vetoEvent;
       }
       else {
         // everything else
-        _c_hadrons->fill(_ecms);
+        _c_hadrons->fill(_sqs);
       }
 
     }
@@ -57,8 +56,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      scale(_c_hadrons,fact);
+      scale(_c_hadrons, crossSection()/sumOfWeights()/nanobarn);
     }
 
     /// @}
@@ -67,7 +65,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons;
-    string _ecms;
+    string _sqs;
     /// @}
 
 
@@ -75,6 +73,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(PLUTO_1979_I140818);
-
-
 }
