@@ -21,12 +21,17 @@ namespace Rivet {
       // Initialise and register projections
       declare(FinalState(), "FS");
       book(_c_hadrons, "sigma_hadrons", refData<YODA::BinnedEstimate<string>>(1,1,1));
-      book(_c_muons, "sigma_muons"    , refData<YODA::BinnedEstimate<string>>(1,1,1));
+      book(_c_muons,   "sigma_muons",   refData<YODA::BinnedEstimate<string>>(1,1,1));
       book(_mult, 1, 1, 1);
-      for (const string label : {"22.0", "27.6", "30.0", "31.6"}) {
-        const double E = std::stod(label);
-        if (isCompatibleWithSqrtS(E*GeV))  Ecm = label;
+      for (const string& en : _c_hadrons.binning().edges<0>()) {
+        const size_t idx = en.find("-");
+        if (idx != string::npos)  continue;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
+        }
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -40,19 +45,20 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
-        _c_muons->fill(Ecm); // mu+mu- + photons
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
+        _c_muons->fill(_sqs); // mu+mu- + photons
+        if (_sqs != "22.0"s)  _c_muons->fill("-"s);
       }
       else {
-        _c_hadrons->fill(Ecm); // everything else
+        _c_hadrons->fill(_sqs); // everything else
+        if (_sqs != "22.0"s)  _c_hadrons->fill("-"s);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      const double fact = crossSection()/ sumOfWeights() /nanobarn;
-      scale({_c_hadrons, _c_muons}, fact);
+      scale({_c_hadrons, _c_muons}, crossSection()/sumOfWeights()/nanobarn);
       divide(_c_hadrons, _c_muons, _mult);
     }
 
@@ -63,7 +69,7 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
     BinnedEstimatePtr<string> _mult;
-    string Ecm = "";
+    string _sqs = "";
     /// @}
 
 
@@ -71,6 +77,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(PLUTO_1979_I142517);
-
-
 }
