@@ -21,16 +21,24 @@ namespace Rivet {
     void init() {
       const ChargedFinalState cfs;
       declare(cfs, "CFS");
-      for (const string label : {"9.4", "12.0", "13.0", "17.0", "22.0", "27.6", "30.2", "30.7", "31.3"}) {
-        const double sqrts = std::stod(label);
-        if (isCompatibleWithSqrtS(sqrts*GeV))  Ecm = label;
-      }
-      if (Ecm != "") {
-        book(_mult, 1, 1, 1);
-      }
-      else {
-        MSG_WARNING("CoM energy of events sqrt(s) = " << sqrtS()/GeV << " doesn't match any available analysis energy .");
+      book(_mult, 1, 1, 1);
+      for (const string& en : _mult.binning().edges<0>()) {
+        const size_t idx = en.find("-");
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1, string::npos));
+          if (inRange(sqrtS()/GeV, emin, emax)) {
+            _sqs = en; break;
+          }
+        }
+        else {
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
+          }
+        }
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -51,17 +59,14 @@ namespace Rivet {
           pmother = inparts[0]; // first mother particle
           int mother_pid = abs(pmother->pdg_id());
           if (mother_pid==PID::K0S || mother_pid==PID::LAMBDA) {
-            prompt = false;
-            break;
-          }
-          else if (mother_pid<6) {
-            break;
+            prompt = false; break;
           }
+          else if (mother_pid<6)  break;
           ivertex = pmother->production_vertex();
         }
         if (prompt) ++nPart;
       }
-      _mult->fill(Ecm, nPart);
+      _mult->fill(_sqs, nPart);
     }
 
 
@@ -76,7 +81,7 @@ namespace Rivet {
   private:
 
     BinnedProfilePtr<string> _mult;
-    string Ecm = "";
+    string _sqs = "";
 
   };
 
