@@ -23,29 +23,26 @@ namespace Rivet {
       // counters for R
       book(_c_hadrons[0], "/TMP/sigma_hadrons", refData<YODA::BinnedEstimate<string>>(1,1,1));
       book(_c_hadrons[1], 2,1,1);
-      book(_c_muons, "/TMP/sigma_muons",refData<YODA::BinnedEstimate<string>>(1,1,1));
-      for(unsigned int ix=0;ix<2;++ix) {
+      book(_c_muons, "/TMP/sigma_muons", refData<YODA::BinnedEstimate<string>>(1,1,1));
+      for (size_t ix=0; ix<2; ++ix) {
         for (const string& en : _c_hadrons[ix].binning().edges<0>()) {
           const size_t idx = en.find("-");
-          if(idx!=std::string::npos) {
-            const double emin = std::stod(en.substr(0,idx));
-            const double emax = std::stod(en.substr(idx+1,string::npos));
-            if(inRange(sqrtS()/GeV, emin, emax)) {
-              _ecms[ix] = en;
-              break;
+          if (idx != string::npos) {
+            const double emin = stod(en.substr(0,idx));
+            const double emax = stod(en.substr(idx+1, string::npos));
+            if (inRange(sqrtS()/GeV, emin, emax)) {
+              _sqs[ix] = en; break;
             }
           }
           else {
-            const double end = std::stod(en)*GeV;
-            if (isCompatibleWithSqrtS(end)) {
-              _ecms[ix] = en;
-              break;
+            const double eval = stod(en)*GeV;
+            if (isCompatibleWithSqrtS(eval)) {
+              _sqs[ix] = en; break;
             }
           }
         }
       }
-      if(_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
 
@@ -59,25 +56,24 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if(nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
         // mu+mu- + photons
-        _c_muons->fill(_ecms[0]);
+        _c_muons->fill(_sqs[0]);
       }
       else {
         // everything else
-        _c_hadrons[0]->fill(_ecms[0]);
-        _c_hadrons[1]->fill(_ecms[1]);
+        _c_hadrons[0]->fill(_sqs[0]);
+        _c_hadrons[1]->fill(_sqs[1]);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /nanobarn;
-      scale(_c_hadrons[1],fact);
+      scale(_c_hadrons[1], crossSection()/sumOfWeights()/nanobarn);
       BinnedEstimatePtr<string> mult;
       book(mult, 1, 1, 1);
-      divide(_c_hadrons[0],_c_muons,mult);
+      divide(_c_hadrons[0], _c_muons, mult);
     }
 
     /// @}
@@ -86,14 +82,11 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons[2], _c_muons;
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
 
   };
 
-
   RIVET_DECLARE_PLUGIN(PLUTO_1982_I166799);
-
-
 }
