@@ -25,24 +25,21 @@ namespace Rivet {
       book(_c_muons,   "/TMP/sigma_muons"  , refData<YODA::BinnedEstimate<string>>(1,1,1));
       for (const string& en : _c_hadrons.binning().edges<0>()) {
         const size_t idx = en.find("-");
-        if(idx!=std::string::npos) {
-          const double emin = std::stod(en.substr(0,idx));
-          const double emax = std::stod(en.substr(idx+1,string::npos));
+        if (idx != string::npos) {
+          const double emin = stod(en.substr(0,idx));
+          const double emax = stod(en.substr(idx+1,string::npos));
           if(inRange(sqrtS()/GeV, emin, emax)) {
-            _ecms = en;
-            break;
+            _sqs = en; break;
           }
         }
         else {
-          const double end = std::stod(en)*GeV;
-          if (isCompatibleWithSqrtS(end)) {
-            _ecms = en;
-            break;
+          const double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs = en; break;
           }
         }
       }
-      if (_ecms.empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -56,13 +53,12 @@ namespace Rivet {
         nCount[p.pid()] += 1;
         ++ntotal;
       }
-      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
         // mu+mu- + photons
-        _c_muons->fill(_ecms);
+        _c_muons->fill(_sqs);
       }
       else {
-        // everything else
-        _c_hadrons->fill(_ecms);
+        _c_hadrons->fill(_sqs); // everything else
       }
     }
 
@@ -71,7 +67,7 @@ namespace Rivet {
     void finalize() {
       BinnedEstimatePtr<string> mult;
       book(mult, 1, 1, 1);
-      divide(_c_hadrons,_c_muons,mult);
+      divide(_c_hadrons, _c_muons, mult);
     }
 
     /// @}
@@ -80,7 +76,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -88,6 +84,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(TASSO_1980_I143690);
-
-
 }
