@@ -28,44 +28,21 @@ namespace Rivet {
 
 
       // Book histograms
-      book(_mult, 1,1,1);
-      unsigned int iloc(0);
-      sqs = 1.0;
-      if(isCompatibleWithSqrtS(13*GeV)) {
-	iloc = 1;
-	sqs = 13.0;
-        sloc="13.0";
+      book(_p, 1, 1, 1);
+      for (const string& en : _p.binning().edges<0>()) {
+        if (isCompatibleWithSqrtS(stod(en)*GeV))  _sqs = en;
       }
-      else if(isCompatibleWithSqrtS(17*GeV)) {
-	iloc = 2;
-        sqs = 17.0;
-        sloc=  "17.0";
-      }
-      else if (isCompatibleWithSqrtS(22*GeV)) {
-	iloc = 2;
-        sloc= "22.0";
-	sqs = 22.;
-      }
-      else if(isCompatibleWithSqrtS(27.6*GeV)) {
-	iloc = 3;
-	sqs = 27.6;
-        sloc="27.6";
-      }
-      else if (isCompatibleWithSqrtS(30.3*GeV)) {
-	iloc = 3;
-	sqs = 30.3;
-        sloc= "30.3";
-      }
-      else if (isCompatibleWithSqrtS(31.2*GeV)) {
-	iloc = 3;
-	sqs = 31.2;
-        sloc= "31.2";
-      }
-      else
-	MSG_ERROR("Beam energy not supported!");
+      raiseBeamErrorIf(_sqs.empty());
 
-      book(_h_rap,iloc+1,1,1);
-      book(_h_x  ,iloc+4,1,1);
+      if (sqrtS() > 25*GeV)       _pre = "hi";
+      else if (sqrtS() > 15*GeV)  _pre = "me";
+      else                        _pre = "lo";
+      book(_h["lorap"], 2,1,1);
+      book(_h["lox"],   5,1,1);
+      book(_h["merap"], 3,1,1);
+      book(_h["mex"],   6,1,1);
+      book(_h["hirap"], 4,1,1);
+      book(_h["hix"],   7,1,1);
     }
 
 
@@ -75,16 +52,15 @@ namespace Rivet {
       // thrust
       const Thrust& thrust = apply<Thrust>(event, "Thrust");
       Vector3 axis=thrust.thrustAxis();
-      _mult->fill(sloc,cfs.particles().size());
+      _p->fill(_sqs, cfs.particles().size());
       for (const Particle& p : cfs.particles()) {
-	const Vector3 mom3 = p.p3();
-	double pp = mom3.mod();
-	double xP = 2.*pp/sqs;
-	_h_x->fill(xP);
+        const Vector3 mom3 = p.p3();
+        double pp = mom3.mod();
+        double xP = 2.*pp/sqrtS();
+        _h[_pre+"x"]->fill(xP);
         const double mom = dot(axis, mom3);
-	const double rap = 0.5 * log((p.E() + mom) /
-				     (p.E() - mom));
-	_h_rap->fill(fabs(rap));
+        const double rap = 0.5*log((p.E() + mom) / (p.E() - mom));
+        _h[_pre+"rap"]->fill(fabs(rap));
       }
     }
 
@@ -92,8 +68,16 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
 
-      scale(_h_rap, 1./sumOfWeights());
-      scale(_h_x  , crossSection()*sqr(sqs)/sumOfWeights()/microbarn);
+      for (auto& item : _h) {
+        if (item.first.find("rap") != string::npos) {
+          scale(item.second, 1.0/sumOfWeights());
+        }
+        else {
+          // These observables aren't well defined: the histograms are filled
+          // for an energy range but the scaling requires a specific energy.
+          scale(item.second, crossSection()*sqr(sqrtS())/sumOfWeights()/microbarn);
+        }
+      }
     }
 
     /// @}
@@ -101,10 +85,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_rap, _h_x;
-    BinnedProfilePtr<string> _mult;
-    double sqs;
-    string sloc;
+    map<string,Histo1DPtr> _h;
+    BinnedProfilePtr<string> _p;
+    string _sqs = "", _pre = "";
     /// @}
 
 
@@ -112,6 +95,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(TASSO_1980_I143691);
-
-
 }
