@@ -27,21 +27,18 @@ namespace Rivet {
 
       // Thrust and sphericity
       declare(Sphericity(cfs), "Sphericity");
+
       // Book histograms
-      unsigned int ihist=0;
-      if      (isCompatibleWithSqrtS(12*GeV)) {
-	ihist=1;
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en+"S"],   ih, 1, 1);
+        book(_h[en+"A"], 2+ih, 1, 1);
+        book(_h[en+"x"], 4+ih, 1, 1);
+        ++ih;
       }
-      else if (isCompatibleWithSqrtS(30*GeV)) {
-	ihist=2;
-      }
-      else
-	MSG_ERROR("Beam energy " << sqrtS() << " GeV not supported!");
-
-      book(_h_S ,   ihist, 1, 1);
-      book(_h_A , 2+ihist, 1, 1);
-      book(_h_x , 4+ihist, 1, 1);
-
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -49,17 +46,16 @@ namespace Rivet {
     void analyze(const Event& event) {
       // Get beams and average beam momentum
       const ParticlePair& beams = apply<Beam>(event, "Beams").beams();
-      const double meanBeamMom = ( beams.first.p3().mod() +
-                                   beams.second.p3().mod() ) / 2.0;
+      const double meanBeamMom = 0.5*(beams.first.p3().mod() + beams.second.p3().mod());
       const ChargedFinalState& cfs = apply<ChargedFinalState>(event, "CFS");
       const Sphericity& sphericity = apply<Sphericity>(event, "Sphericity");
-      _h_S->fill(sphericity.sphericity());
-      _h_A->fill(sphericity.aplanarity());
+      _h[_sqs+"S"]->fill(sphericity.sphericity());
+      _h[_sqs+"A"]->fill(sphericity.aplanarity());
       for (const Particle& p : cfs.particles()) {
         const Vector3 mom3 = p.p3();
         const double mom = mom3.mod();
         const double xp = mom/meanBeamMom;
-        _h_x->fill(xp);
+        _h[_sqs+"x"]->fill(xp);
       }
 
     }
@@ -67,11 +63,7 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-
-      normalize(_h_S);
-      normalize(_h_A);
-      normalize(_h_x);
-
+      normalize(_h);
     }
 
     /// @}
@@ -79,7 +71,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_S,_h_A,_h_x;
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
 
@@ -87,6 +80,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(TASSO_1980_I153511);
-
-
 }
