@@ -25,21 +25,16 @@ namespace Rivet {
       declare(UnstableParticles(), "UFS");
 
       // Book histograms
-      sqs = 1.0;
-      if(isCompatibleWithSqrtS(14*GeV)) {
-	book(_h_E, 2,1,1);
-	book(_h_p, 2,2,2);
-	book(_h_x, 2,3,3);
-	sqs = 14.0;
+      size_t ih = 2;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en+"E"], ih, 1, 1);
+        book(_h[en+"p"], ih, 2, 2);
+        book(_h[en+"x"], ih, 3, 3);
+        ++ih;
       }
-      else if (isCompatibleWithSqrtS(34*GeV)) {
-	book(_h_E, 3,1,1);
-	book(_h_p, 3,2,2);
-	book(_h_x, 3,3,3);
-	sqs = 34.0;
-      }
-      else
-        MSG_ERROR("Not compatible with energy " << sqrtS() << "GeV.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -47,30 +42,32 @@ namespace Rivet {
     void analyze(const Event& event) {
       // Get beams and average beam momentum
       const ParticlePair& beams = apply<Beam>(event, "Beams").beams();
-      const double meanBeamMom = ( beams.first.p3().mod() +
-                                   beams.second.p3().mod() ) / 2.0;
+      const double meanBeamMom = 0.5*(beams.first.p3().mod() + beams.second.p3().mod());
       MSG_DEBUG("Avg beam momentum = " << meanBeamMom);
 
       for (const Particle& p : apply<UnstableParticles>(event, "UFS").particles(Cuts::pid==PID::PI0)) {
-	if(!p.parents().empty() && p.parents()[0].pid()==PID::K0S)
-	  continue;
-	double xE = p.E()/meanBeamMom;
-	double beta = p.p3().mod()/p.E();
-	_h_E->fill(p.E()       );
-	_h_p->fill(p.p3().mod());
-	_h_x->fill(xE,1./beta);
+        if (!p.parents().empty() && p.parents()[0].pid()==PID::K0S) continue;
+        double xE = p.E()/meanBeamMom;
+        double beta = p.p3().mod()/p.E();
+        _h[_sqs+"E"]->fill(p.E()/GeV);
+        _h[_sqs+"p"]->fill(p.p3().mod()/GeV);
+        _h[_sqs+"x"]->fill(xE, 1.0/beta);
       }
-
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
 
-      scale(_h_E, crossSection()/nanobarn/sumOfWeights());
-      scale(_h_p, crossSection()/nanobarn/sumOfWeights());
-      scale(_h_x, sqr(sqs)*crossSection()/microbarn/sumOfWeights());
-
+      for (auto& item : _h) {
+        if (item.first.find("x") != string::npos) {
+          const double en = stod(item.first.substr(0,2));
+          scale(item.second, sqr(en)*crossSection()/microbarn/sumOfWeights());
+        }
+        else {
+          scale(item.second, crossSection()/nanobarn/sumOfWeights());
+        }
+      }
     }
 
     /// @}
@@ -78,12 +75,11 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_E,_h_p,_h_x;
-    double sqs;
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
   };
 
   RIVET_DECLARE_PLUGIN(TASSO_1982_I168232);
-
 }
