@@ -22,43 +22,22 @@ namespace Rivet {
       // Initialise and register projections
       declare(Beam(), "Beams");
       declare(ChargedFinalState(), "FS");
-      if(isCompatibleWithSqrtS(12*GeV)) {
-	book(_h_x2,2,1,1);
-	book(_h_x3,3,1,1);
-      }
-      else if (isCompatibleWithSqrtS(14*GeV)) {
-	book(_h_x1,1,1,1);
-	book(_h_x2,2,1,2);
-	book(_h_x3,3,1,2);
-      }
-      else if (isCompatibleWithSqrtS(22*GeV)) {
-	book(_h_x1,1,1,2);
-	book(_h_x2,2,1,3);
-	book(_h_x3,3,1,3);
-      }
-      else if (isCompatibleWithSqrtS(25*GeV)) {
-	book(_h_x2,2,1,4);
-	book(_h_x3,3,1,4);
-      }
-      else if (isCompatibleWithSqrtS(30*GeV)) {
-	book(_h_x2,2,1,5);
-	book(_h_x3,3,1,5);
-      }
-      else if (isCompatibleWithSqrtS(34*GeV)) {
-	book(_h_x2,2,1,6);
-	book(_h_x3,3,1,6);
-      }
-      else if (isCompatibleWithSqrtS(35*GeV)) {
-        book(_h_x2, 2,1,7);
-        book(_h_x3, 3,1,7);
-      }
-
-      if(inRange(sqrtS()/GeV, 29.9,36.7))
-        book(_h_x1, 1,1,3);
-
-      if(_h_x1==Histo1DPtr() && _h_x2==Histo1DPtr() && _h_x3==Histo1DPtr())
-      	MSG_ERROR("Beam energy not supported!");
 
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en+"x2"], 2, 1, ih);
+        book(_h[en+"x3"], 3, 1, ih);
+        if (en == "14"s || en == "22"s) {
+          book(_h[en+"x1"], 1, 1, ih-1);
+        }
+        else if (en == "30"s) {
+          book(_h["x1"], 1, 1, 3);
+        }
+        ++ih;
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -69,34 +48,34 @@ namespace Rivet {
       const size_t numParticles = fs.particles().size();
 
       // Even if we only generate hadronic events, we still need a cut on numCharged >= 2.
-      if (numParticles < 2) {
-        MSG_DEBUG("Failed leptonic event cut");
-        vetoEvent;
-      }
-      MSG_DEBUG("Passed leptonic event cut");
+      if (numParticles < 2)  vetoEvent;
 
       // Get beams and average beam momentum
       const ParticlePair& beams = apply<Beam>(event, "Beams").beams();
-      const double meanBeamMom = ( beams.first.p3().mod() +
-                                   beams.second.p3().mod() ) / 2.0;
+      const double meanBeamMom = 0.5*(beams.first.p3().mod() + beams.second.p3().mod());
       MSG_DEBUG("Avg beam momentum = " << meanBeamMom);
 
       for (const Particle& p : fs.particles()) {
-	double xp = p.p3().mod()/meanBeamMom;
-	if(_h_x1!=Histo1DPtr()) _h_x1->fill(xp);
-	if(_h_x2!=Histo1DPtr()) _h_x2->fill(xp);
-	if(_h_x3!=Histo1DPtr()) _h_x3->fill(xp);
+        double xp = p.p3().mod()/meanBeamMom;
+        if (_sqs == "14"s || _sqs == "22"s)  _h[_sqs+"x1"]->fill(xp);
+        else if (sqrtS() > 29*GeV)  _h["x1"]->fill(xp);
+        _h[_sqs+"x2"]->fill(xp);
+        _h[_sqs+"x3"]->fill(xp);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-
-      scale(_h_x1, crossSection()/microbarn/sumOfWeights()*sqr(sqrtS()));
-      scale(_h_x2, crossSection()/microbarn/sumOfWeights()*sqr(sqrtS()));
-      scale(_h_x3, 1./sumOfWeights());
-
+      for (auto& item : _h) {
+        if (item.first.find("x3") != string::npos) {
+          scale(item.second, 1.0/sumOfWeights());
+        }
+        else {
+          // The sqrtS-dependence is not reentrant safe
+          scale(item.second, crossSection()/microbarn/sumOfWeights()*sqr(sqrtS()));
+        }
+      }
     }
 
     /// @}
@@ -104,7 +83,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_x1,_h_x2,_h_x3;
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
 
@@ -112,6 +92,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(TASSO_1982_I177174);
-
-
 }
