@@ -20,70 +20,57 @@ namespace Rivet {
     void init() {
       // Initialise and register projections
       declare(FinalState(), "FS");
-      // book histos
-      if (inRange(sqrtS()/GeV,2.,3.1)) {
-        if (sqrtS()<=2.4) {
-          book(_h_cTheta,2,1,1);
-        }
-        else if (sqrtS()<=2.8) {
-          book(_h_cTheta,2,1,2);
-        }
-       	book(_cProton, 1, 1, 1);
-      }
-      else {
-        throw Error("Invalid CMS energy for TASSO_1983_I191417");
-      }
 
-      _ecms = "OTHER"s;
-      for (const string& edge : _cProton.binning().edges<0>()) {
-        if (isCompatibleWithSqrtS(std::stod(edge)*GeV)) {
-          _ecms = edge;
-          break;
+      // book histos
+      book(_h["cProton"], 1,1,1);
+      book(_h["cTheta1"], 2,1,1);
+      book(_h["cTheta2"], 2,1,2);
+      for (const string& en : _h["cProton"].binning().edges<0>()) {
+        if (isCompatibleWithSqrtS(stod(en)*GeV)) {
+          _sqs = en; break;
         }
       }
+      raiseBeamErrorIf(_sqs.empty());
       _axis = YODA::Axis<double>({0., 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7});
+      _edges = _h["cTheta2"].binning().edges<0>();
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
-      if(_h_cTheta && _edges.empty()) _edges=_h_cTheta->xEdges();
-      Particles part = apply<FinalState>(event,"FS").particles();
-      if (part.size()!=2) vetoEvent;
+      const Particles& part = apply<FinalState>(event,"FS").particles();
+      if (part.size() != 2) vetoEvent;
       double cTheta(0.);
-      bool foundP(false),foundM(false);
+      bool foundP(false), foundM(false);
       for (const Particle& p : part) {
         if (p.pid()==PID::PROTON) {
-          foundP=true;
-          cTheta = abs(p.momentum().z()/p.momentum().p3().mod());
+          foundP = true;
+          cTheta = abs(p.mom().z()/p.mom().p3().mod());
         }
         else if (p.pid()==PID::ANTIPROTON) {
-          foundM=true;
+          foundM = true;
         }
       }
       if (!foundP || !foundM)  vetoEvent;
-      if (cTheta<=0.6) _cProton->fill(_ecms);
-      if (_h_cTheta) {
+      if (cTheta<=0.6)  _h["cProton"]->fill(_sqs);
+      if (sqrtS() <= 2.8) {
         const size_t idx = _axis.index(cTheta);
-        if (0 < idx && idx < _axis.numBins())
-          _h_cTheta->fill(_edges[idx-1]);
-        else 
-          _h_cTheta->fill("OTHER"s);
+        if (0 < idx && idx < _axis.numBins()) {
+          _h[sqrtS()> 2.4? "cTheta2"s : "cTheta1"s]->fill(_edges[idx-1]);
+        }
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      const double fact = crossSection()/nanobarn/sumOfWeights();
-      if (_h_cTheta) {
-        scale(_h_cTheta,fact);
-        for(auto & b : _h_cTheta->bins()) {
+      scale(_h, crossSection()/nanobarn/sumOfWeights());
+      for (const string& label : vector<string>{"cTheta1"s,"cTheta2"s}) {
+        for (auto& b : _h[label]->bins()) {
           const size_t idx = b.index();
           b.scaleW(1./_axis.width(idx));
         }
       }
-      scale(_cProton, fact);
     }
 
     /// @}
@@ -91,8 +78,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    BinnedHistoPtr<string> _h_cTheta, _cProton;
-    string _ecms;
+    map<string,BinnedHistoPtr<string>> _h;
+    string _sqs = "";
     vector<string> _edges;
     YODA::Axis<double> _axis;
     /// @}
@@ -102,5 +89,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(TASSO_1983_I191417);
-
 }
