@@ -5,7 +5,7 @@
 namespace Rivet {
 
 
-  /// @brief Add a short analysis description here
+  /// @brief Measurement of $R$ for energies between 39.8 and 45.2 GeV
   class TASSO_1984_I199468 : public Analysis {
   public:
 
@@ -27,16 +27,12 @@ namespace Rivet {
       book(_c_hadrons2, "/TMP/sigma_hadrons2", refData(2,1,1));
       book(_c_muons2,   "/TMP/sigma_muons2"  , refData(2,1,1));
       for (const string& en : _c_hadrons1.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty() &&
-         !inRange(sqrtS()/GeV,39.8, 43.1) &&
-         !inRange(sqrtS()/GeV,43.2, 45.2))
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -48,30 +44,29 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22]) {
-	_c_muons1->fill(_ecms);
-	_c_muons2->fill(sqrtS()/GeV);
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
+        // mu+mu- + photons
+        _c_muons1->fill(_sqs);
+        _c_muons2->fill(sqrtS()/GeV);
       }
-      // everything else
       else {
-	_c_hadrons1->fill(_ecms);
-	_c_hadrons2->fill(sqrtS()/GeV);
+        // everything else
+        _c_hadrons1->fill(_sqs);
+        _c_hadrons2->fill(sqrtS()/GeV);
       }
     }
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      BinnedEstimatePtr<string> mult1;
-      book(mult1, 1, 1, 1);
-      divide(_c_hadrons1,_c_muons1,mult1);
-      Estimate1DPtr mult2;
-      book(mult2, 2, 1, 1);
-      divide(_c_hadrons2,_c_muons2,mult2);
+      BinnedEstimatePtr<string> ratio1;
+      book(ratio1, 1, 1, 1);
+      divide(_c_hadrons1, _c_muons1, ratio1);
+      Estimate1DPtr ratio2;
+      book(ratio2, 2, 1, 1);
+      divide(_c_hadrons2, _c_muons2, ratio2);
     }
     /// @}
 
@@ -79,13 +74,11 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _c_hadrons1, _c_muons1;
     Histo1DPtr _c_hadrons2, _c_muons2;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
   };
 
 
   RIVET_DECLARE_PLUGIN(TASSO_1984_I199468);
-
-
 }
