@@ -23,25 +23,15 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      unsigned int iloc(0);
-      if(isCompatibleWithSqrtS(14*GeV)) {
-	iloc=1;
+      size_t ih = 1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en], ih, 1, 1);
+        book(_c[en], "TMP/weightSum"+en);
+        ++ih;
       }
-      else if (isCompatibleWithSqrtS(22*GeV)) {
-	iloc=2;
-      }
-      else if (isCompatibleWithSqrtS(34.8*GeV)) {
-	iloc=3;
-      }
-      else if (isCompatibleWithSqrtS(43.5*GeV)) {
-	iloc=4;
-      }
-      else
-	MSG_WARNING("CoM energy of events sqrt(s) = " << sqrtS()/GeV
-                    << " doesn't match any available analysis energy .");
-      assert(iloc!=0);
-      book(_histEEC, iloc, 1, 1);
-      book(_weightSum, "TMP/weightSum");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -50,30 +40,22 @@ namespace Rivet {
       // First, veto on leptonic events by requiring at least 4 charged FS particles
       const FinalState& fs = apply<FinalState>(event, "FS");
       // Even if we only generate hadronic events, we still need a cut on numCharged >= 2.
-      if ( fs.particles().size() < 2) {
-        MSG_DEBUG("Failed leptonic event cut");
-        vetoEvent;
-      }
-      MSG_DEBUG("Passed leptonic event cut");
+      if ( fs.particles().size() < 2)  vetoEvent;
 
-      _weightSum->fill();
-      double Evis = 0.0;
-      for (const Particle& p : fs.particles()) {
-        Evis += p.E();
-      }
-      double Evis2 = sqr(Evis);
+      _c[_sqs]->fill();
+      const double Evis2 = sqr(sum(fs.particles(), Kin::E, 0.0));
       // (A)EEC
       // Need iterators since second loop starts at current outer loop iterator, i.e. no "foreach" here!
       for (Particles::const_iterator p_i = fs.particles().begin(); p_i != fs.particles().end(); ++p_i) {
         for (Particles::const_iterator p_j = p_i; p_j != fs.particles().end(); ++p_j) {
-          const Vector3 mom3_i = p_i->momentum().p3();
-          const Vector3 mom3_j = p_j->momentum().p3();
-          const double energy_i = p_i->momentum().E();
-          const double energy_j = p_j->momentum().E();
+          const Vector3 mom3_i = p_i->p3();
+          const Vector3 mom3_j = p_j->p3();
+          const double energy_i = p_i->E();
+          const double energy_j = p_j->E();
           const double cosij = dot(mom3_i.unit(), mom3_j.unit());
           double eec = (energy_i*energy_j) / Evis2;
-	  if(p_i != p_j) eec *= 2.;
-          _histEEC->fill(cosij, eec);
+          if (p_i != p_j) eec *= 2.0;
+          _h[_sqs]->fill(cosij, eec);
         }
       }
     }
@@ -81,7 +63,9 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_histEEC,  1.0/ *_weightSum);
+      for (const auto& item : _c) {
+        scale(_h[item.first],  1.0/item.second->sumW());
+      }
     }
 
     /// @}
@@ -89,8 +73,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _histEEC;
-    CounterPtr _weightSum;
+    map<string,Histo1DPtr> _h;
+    map<string,CounterPtr> _c;
+    string _sqs = "";
     /// @}
 
 
@@ -98,6 +83,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(TASSO_1987_I248660);
-
-
 }
