@@ -23,16 +23,15 @@ namespace Rivet {
 
       size_t ih = 0;
       for (double eVal : allowedEnergies()) {
-        const string en = toString(int(eVal/MeV));
+        const string en = toString(round(eVal/MeV));
         if (isCompatibleWithSqrtS(eVal)) {
           _sqs = en;
           _ie = ih+1;
         }
         book(_h[en], 5, 1, ++ih);
+        book(_c[en], "_sumW_"+en);
       }
-      if (_sqs == "" && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_sqs.empty());
       book(_p, 2, 1, 1);
     }
 
@@ -42,6 +41,7 @@ namespace Rivet {
       if (Ecm == "")  Ecm = _p->bin(_ie).xEdge();
       const FinalState& cfs = apply<FinalState>(event, "CFS");
       MSG_DEBUG("Total charged multiplicity = " << cfs.size());
+      _c[_sqs]->fill();
       _h[_sqs]->fill(cfs.size());
       _p->fill(Ecm, cfs.size());
     }
@@ -49,7 +49,12 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_h, 1.0/sumOfWeights());
+      scale(_h, crossSectionPerEvent());
+      scale(_c, crossSectionPerEvent());
+      for (auto& item : _h) {
+        const double w = _c[item.first]->sumW();
+        if (!isZero(w))  scale(item.second, 1.0/w);
+      }
     }
 
     /// @}
@@ -61,6 +66,7 @@ namespace Rivet {
     /// @{
     map<string,BinnedHistoPtr<int>> _h;
     BinnedProfilePtr<string> _p;
+    map<string,CounterPtr> _c;
     string Ecm = "", _sqs = "";
     size_t _ie = 0;
     /// @}
