@@ -24,27 +24,17 @@ namespace Rivet {
 
       const ChargedFinalState cfs;
       declare(cfs, "CFS");
-      // Thrust
-      const Thrust thrust(cfs);
-      declare(thrust, "Thrust");
-      declare(Hemispheres(thrust), "Hemispheres");
-
-      int offset = 0;
-      if (isCompatibleWithSqrtS(14.0*GeV))
-	offset=1;
-      else if(isCompatibleWithSqrtS(22.0*GeV))
-	offset=2;
-      else if(isCompatibleWithSqrtS(34.8*GeV))
-	offset=3;
-      else if(isCompatibleWithSqrtS(43.5*GeV))
-	offset=4;
-      else
-	MSG_ERROR("Beam energy " << sqrtS() << " not supported!");
-      // Book histograms
-      book(_h_diff , 1, 1, offset);
-      book(_h_heavy, 2, 1, offset);
-      book(_h_light, 3, 1, offset);
+      declare(Hemispheres(Thrust(cfs)), "Hemispheres");
 
+      size_t ih = 0;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        book(_h[en+"diff"],  1, 1, ++ih);
+        book(_h[en+"heavy"], 2, 1,   ih);
+        book(_h[en+"light"], 3, 1,   ih);
+      }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -55,24 +45,23 @@ namespace Rivet {
       if (cfs.particles().size() < 3 ) vetoEvent;
 
       const Hemispheres& hemi = apply<Hemispheres>(event, "Hemispheres");
-      _h_heavy->fill(hemi.scaledM2high());
-      _h_light->fill(hemi.scaledM2low() );
-      _h_diff ->fill(hemi.scaledM2diff());
+      _h[_sqs+"heavy"]->fill(hemi.scaledM2high());
+      _h[_sqs+"light"]->fill(hemi.scaledM2low() );
+      _h[_sqs+"diff"]->fill(hemi.scaledM2diff());
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      normalize(_h_diff );
-      normalize(_h_heavy);
-      normalize(_h_light);
+      normalize(_h);
     }
     /// @}
 
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_diff,_h_heavy,_h_light;
+    map<string,Histo1DPtr> _h;
+    string _sqs = "";
     /// @}
 
 
@@ -80,6 +69,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(TASSO_1989_I279165);
-
-
 }
