@@ -31,10 +31,13 @@ namespace Rivet {
 
 
       // Book histograms
-      _sqs = 10; size_t i = 0;
+      _isqs = 10; size_t i = 0;
       for (double eVal : allowedEnergies()) {
 
-        if (isCompatibleWithSqrtS(eVal))  _sqs = i;
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal)) {
+          _sqs = en; _isqs = i;
+        }
 
         size_t _ih, _iy;
         if (i==0) { _ih=1; _iy=0; }
@@ -44,27 +47,25 @@ namespace Rivet {
         else           { _ih=0; _iy=1; }
 
         if (_ih==0) {
-          book(_h_K0_x[i], 1, 1, _iy);
+          book(_h[en+"K0_x"], 1, 1, _iy);
           if (_iy != 3) {
             book(_p_K0_S_1[i], 5, 1, 2*_iy-1);
             book(_p_K0_S_2[i],"TMP/p_K0_S_2_"+to_string(i),refData(5, 1, 2*_iy));
           }
-          book(_h_Kstar_x[i-2], 8, 1, _iy);
+          book(_h[en+"Kstar_x"], 8, 1, _iy);
           if (_iy == 2) {
             book(_p_Kstar_S_1, 10, 1, 1);
             book(_p_Kstar_S_2, "TMP/p_Kstar_S_2", refData(10,1,2));
           }
         }
         else {
-          book(_h_K0_x[i],   _ih+1, 1, 1);
+          book(_h[en+"K0_x"], _ih+1, 1, 1);
           book(_p_K0_S_1[i], _ih+5, 1, 1);
           book(_p_K0_S_2[i], "TMP/p_K0_S_2"+to_string(i), refData(_ih+5,1,2));
         }
         ++i;
       }
-      if (_sqs == 10 && !merging()) {
-        throw BeamError("Invalid beam energy for " + name() + "\n");
-      }
+      raiseBeamErrorIf(_isqs == 10);
       book(_n_K0,    4, 1, 1);
       book(_n_Kstar, 9, 1, 1);
     }
@@ -95,22 +96,22 @@ namespace Rivet {
         double modp = p.p3().mod();
         double beta = modp/p.E();
         if (p.abspid()==323) {
-          if (_sqs>1)  _h_Kstar_x[_sqs-2]->fill(xE,1./beta);
+          if (_isqs>1)  _h[_sqs+"Kstar_x"]->fill(xE,1./beta);
           ++nKstar;
         }
         else {
-          _h_K0_x[_sqs]->fill(xE,1./beta);
+          _h[_sqs+"K0_x"]->fill(xE,1./beta);
           ++nK0;
         }
       }
-      _n_K0   ->fill(_dedges[_sqs],nK0   );
-      _n_Kstar->fill(_dedges[_sqs],nKstar);
+      _n_K0   ->fill(_dedges[_isqs],nK0   );
+      _n_Kstar->fill(_dedges[_isqs],nKstar);
       const double sphere = sphericity.sphericity();
-      if (_sqs != 2) {
-        _p_K0_S_1[_sqs]->fill(sphere,nK0);
-        _p_K0_S_2[_sqs]->fill(sphere,cfs.particles().size());
+      if (_isqs != 2) {
+        _p_K0_S_1[_isqs]->fill(sphere,nK0);
+        _p_K0_S_2[_isqs]->fill(sphere,cfs.particles().size());
       }
-      if (_sqs == 3) {
+      if (_isqs == 3) {
         _p_Kstar_S_1->fill(sphere,nKstar);
         _p_Kstar_S_2->fill(sphere,cfs.particles().size());
       }
@@ -119,14 +120,20 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      const double sf = sqr(sqrtS())*crossSection()/sumOfWeights();
-      scale(_h_K0_x,   sf/microbarn);
-      scale(_h_Kstar_x, sf/nanobarn);
+      const double sf = crossSection()/sumOfWeights();
+      for (auto& item : _h) {
+        const double en = stod(item.first.substr(0,5))*MeV;
+        if (item.first.find("K0_x") != string::npos) {
+          scale(item.second, sqr(en)*sf/microbarn);
+        }
+        else {
+          scale(item.second, sqr(en)*sf/nanobarn);
+        }
+      }
 
       size_t i=0;
       for (double eVal : allowedEnergies()) {
-
-        if (isCompatibleWithSqrtS( eVal*GeV ))  _sqs = i;
+        (void)eVal;
 
         size_t _ih, _iy;
         if (i==0) { _ih=1; _iy=0; }
@@ -155,7 +162,7 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_K0_x[5], _h_Kstar_x[3];
+    map<string,Histo1DPtr> _h;
 
     Profile1DPtr _p_K0_S_1[5], _p_K0_S_2[5], _p_Kstar_S_1, _p_Kstar_S_2;
 
@@ -163,7 +170,9 @@ namespace Rivet {
 
     vector<string> _dedges{"14.8"s, "21.5"s, "34.5"s, "35.0"s, "42.6"s};
 
-    size_t _sqs;
+    size_t _isqs;
+
+    string _sqs = "";
     /// @}
 
 
