@@ -23,8 +23,7 @@ namespace Rivet {
     void init() {
 
       // Initialise and register projections
-      Cut cut = Cuts::etaIn(-10.,10.);
-      DileptonFinder zfinder(91.2*GeV, 0.0, cut && Cuts::abspid == PID::MUON,
+      DileptonFinder zfinder(91.2*GeV, 0.0, Cuts::abseta < 10. && Cuts::abspid == PID::MUON,
                              Cuts::massIn(4.0*GeV, 100.0*GeV), LeptonOrigin::PROMPT);
       declare(zfinder, "DileptonFinder");
 
@@ -42,24 +41,19 @@ namespace Rivet {
     /// Perform the per-event analysis
     void analyze(const Event& event) {
 
-      double sqrts_tol = 10. ;
-      if (!isCompatibleWithSqrtS(200*GeV, sqrts_tol)) {
-        MSG_ERROR("Incorrect beam energy used: " << sqrtS()/GeV);
-        throw Error("Unexpected sqrtS ! Only 200 GeV is supported");
-      }
       const DileptonFinder& zfinder = apply<DileptonFinder>(event, "DileptonFinder");
       if (zfinder.particles().size() < 1) vetoEvent;
-      double mass = zfinder.bosons()[0].momentum().mass()/GeV;
-      double pt_DY   = zfinder.bosons()[0].momentum().pT()/GeV;
-      double y_DY    = abs(zfinder.bosons()[0].momentum().rapidity());
+      double mass = zfinder.bosons()[0].mom().mass()/GeV;
+      double pt_DY   = zfinder.bosons()[0].mom().pT()/GeV;
+      double y_DY    = abs(zfinder.bosons()[0].mom().rap());
 
       _h_m_DiMuon->fill(mass/GeV);
       _h_pT_DiMuon->fill(pt_DY);
       _h_y_DiMuon ->fill(y_DY);
-      if (inRange( y_DY, 1.2, 2.2) && inRange(mass, 4.8, 8.2) && pt_DY > 0)
+      if (inRange( y_DY, 1.2, 2.2) && inRange(mass, 4.8, 8.2) && pt_DY > 0) {
         _h_pT->fill(pt_DY, 1./2./pt_DY/M_PI);
-      if ( y_DY >= 1.2 && y_DY <= 2.2)
-        _h_mass->fill(mass);
+      }
+      if ( y_DY >= 1.2 && y_DY <= 2.2)  _h_mass->fill(mass);
 
     }
 
@@ -71,8 +65,8 @@ namespace Rivet {
       normalize(_h_m_DiMuon);
       normalize(_h_pT_DiMuon);
       normalize(_h_y_DiMuon);
-      scale(_h_pT, crossSection()/picobarn/(sumOfWeights())/2.);
-      scale(_h_mass, crossSection()/picobarn/(sumOfWeights())/2.);
+      scale(_h_pT, crossSection()/picobarn/sumOfWeights()/2.);
+      scale(_h_mass, crossSection()/picobarn/sumOfWeights()/2.);
 
     }
 
