@@ -29,6 +29,7 @@ namespace Rivet {
 
       // Book histograms
       book(_h_pi0_pt, 8, 1, 1);
+      _axis = YODA::Axis<double>({5., 6., 7., 8., 9., 10., 12., 16.});
 
     }
 
@@ -36,14 +37,25 @@ namespace Rivet {
     /// Perform the per-event analysis
     void analyze(const Event& event) {
 
-      Particles particles = apply<UnstableParticles>(event, "fs").particles();
+      if (_edges.empty())  _edges = _h_pi0_pt->xEdges();
 
-      for(const Particle& p : particles) {
-        _h_pi0_pt->fill(p.pT() / GeV, 1 / (p.pT() / GeV));
+      const Particles& particles = apply<UnstableParticles>(event, "fs").particles();
+
+      for (const Particle& p : particles) {
+        discfill(p.pT() / GeV, 1 / (p.pT() / GeV));
       }
 
     }
 
+    void discfill(const double value, double weight) {
+      const size_t idx = _axis.index(value);
+      string edge("OTHER");
+      if (idx && idx <= _edges.size()) {
+        edge = _edges[idx-1];
+        weight /= _axis.width(idx);
+      }
+      _h_pi0_pt->fill(edge, weight);
+    }
 
     /// Normalise histograms etc., after the run
     void finalize() {
@@ -57,7 +69,9 @@ namespace Rivet {
 
     /// @name Histograms
     ///@{
-    Histo1DPtr _h_pi0_pt;
+    BinnedHistoPtr<string> _h_pi0_pt;
+    YODA::Axis<double> _axis;
+    vector<string> _edges;
     ///@}
 
 
