@@ -15,8 +15,7 @@ namespace Rivet {
   public:
 
     /// Constructor
-    STAR_2016_I1414638 ()
-      : Analysis("STAR_2016_I1414638") {}
+    RIVET_DEFAULT_ANALYSIS_CTOR(STAR_2016_I1414638);
 
 
     void init() {
@@ -25,12 +24,16 @@ namespace Rivet {
       declare(ChargedFinalState(Cuts::abseta < 1.0 && Cuts::pT > 0.2*GeV), "CFS");
 
       // Histograms
-      int energy = -1;
-      for (int i = 0, N = energies.size(); i < N; ++i) {
-        if (isCompatibleWithSqrtS(197.*energies[i]*GeV, 1e-1)) energy = i;
+      size_t ih = 0;
+      for (double eVal : allowedEnergies()) {
+        const int en = round(eVal/MeV);
+        if (isCompatibleWithSqrtS(eVal))  _sqs = en;
+        for (size_t i=1; i <= cenAxis.numBins(); ++i) {
+          book(h_v32[en+i], 1+i+9*ih, 1, 1);
+        }
+        ++ih;
       }
-      if (energy == -1) MSG_ERROR("Incompatible beam energy!");
-      for (int i = 0; i < 9; ++i) book(h_v32[centralityBins[i]], 1 + i + 9 * energy, 1, 1);
+      raiseBeamErrorIf(_sqs == 0);
     }
 
 
@@ -45,8 +48,8 @@ namespace Rivet {
       const CentralityProjection& cent = apply<CentralityProjection>(event,"CMULT");
       const double c = cent();
       // Find the correct histogram to fill.
-      auto hItr = h_v32.upper_bound(c);
-      if (hItr == h_v32.end()) return;
+      size_t idx = cenAxis.index(c);
+      if (!idx || idx > cenAxis.numBins())  vetoEvent;
       for (int i = 0, N = particles.size(); i < N; ++i){
         for (int j = i + 1; j < N; ++j) {
           const double eta1 = particles[i].eta();
@@ -54,7 +57,7 @@ namespace Rivet {
           if (eta1 * eta2 < 0) {
             const double deltaPhi = abs(particles[i].phi() - particles[j].phi());
             // Fill profile with v_2(2)^2 from eq. (1) in the paper.
-            hItr->second->fill(abs(eta1 - eta2), cos(3.*deltaPhi));
+            h_v32[_sqs+idx]->fill(abs(eta1 - eta2), cos(3.*deltaPhi));
           }
         }
       }
@@ -69,7 +72,7 @@ namespace Rivet {
     /// @name Bin edges
     /// @{
     /// The centrality bins
-    const doubles centralityBins = {5., 10., 20., 30., 40., 50., 60., 70., 80.};
+    YODA::Axis<double> cenAxis = YODA::Axis<double>({5., 10., 20., 30., 40., 50., 60., 70., 80.});
     /// The analysis energies
     const doubles energies = {7.7, 11.5, 14.5, 19.6, 27.0, 39.0, 62.4, 200.0};
     /// @}
@@ -78,6 +81,8 @@ namespace Rivet {
     /// The histograms
     map<double, Profile1DPtr> h_v32;
 
+    int _sqs = 0;
+
   };
 
 
