@@ -25,15 +25,15 @@ namespace Rivet {
 
       // Book histograms
       book(_c_hadrons, "/TMP/sigma_hadrons",refData<YODA::BinnedEstimate<string>>(1,1,1));
-      book(_c_muons,   "/TMP/sigma_muons"  ,refData<YODA::BinnedEstimate<string>>(1,1,1));
-      book(_c_D_star,  "/TMP/sigma_D_star" ,refData(2,1,1));
-      
-      for (const string& ecms : _c_hadrons.binning().edges<0>()) {
-        if (isCompatibleWithSqrtS(std::stod(ecms)*GeV)) {
-          _ecms = ecms;
-          break;
+      book(_c_muons,   "/TMP/sigma_muons",  refData<YODA::BinnedEstimate<string>>(1,1,1));
+      book(_c_D_star,  "/TMP/sigma_D_star", refData(2,1,1));
+
+      for (const string& en : _c_hadrons.binning().edges<0>()) {
+        if (isCompatibleWithSqrtS(stod(en)*GeV, 1e-3)) {
+          _sqs = en; break;
         }
       }
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -44,36 +44,29 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      // mu+mu- + photons
-      if(!_ecms.empty()) {
-        if(nCount[-13]==1 and nCount[13]==1 &&
-           ntotal==2+nCount[22])
-          _c_muons->fill(_ecms);
-        // everything else
-        else
-          _c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
+        // mu+mu- + photons
+        _c_muons->fill(_sqs);
       }
+      else  _c_hadrons->fill(_sqs); // everything else
       const FinalState& ufs = apply<UnstableParticles>(event, "UFS");
       bool found = false;
-      for (const Particle & p : ufs.particles()) {
-	if(abs(p.pid())!=413 && abs(p.pid())!=423) continue;
-	bool fs = true;
-	for (const Particle & child : p.children()) {
-	  if(child.pid()==p.pid()) {
-	    fs = false;
-	    break;
-	  }
-	}
-	if(fs) {
-	  found = true;
-	  break;
-	}
+      for (const Particle& p : ufs.particles()) {
+        if (p.abspid() != 413 && p.abspid() != 423) continue;
+        bool fs = true;
+        for (const Particle& child : p.children()) {
+          if (child.pid()==p.pid()) {
+            fs = false; break;
+          }
+        }
+        if (fs) {
+          found = true; break;
+        }
       }
-      if(found)
-	_c_D_star->fill(sqrtS());
+      if (found) _c_D_star->fill(sqrtS());
     }
 
 
@@ -82,12 +75,12 @@ namespace Rivet {
       // R
       BinnedEstimatePtr<string> tmp;
       book(tmp,1,1,1);
-      divide(_c_hadrons,_c_muons,tmp);
+      divide(_c_hadrons, _c_muons, tmp);
       double fact = crossSection()/ sumOfWeights() /nanobarn;
-      scale(_c_D_star,fact);
+      scale(_c_D_star, fact);
       Estimate1DPtr tmp2;
       book(tmp2,2,1,1);
-      barchart(_c_D_star,tmp2);
+      barchart(_c_D_star, tmp2);
     }
 
     /// @}
@@ -97,7 +90,7 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
     Histo1DPtr _c_D_star;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -105,6 +98,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(CRYSTAL_BALL_1986_I238081);
-
-
 }
