@@ -22,19 +22,17 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      for(unsigned int ix=0;ix<2;++ix) {
+      for (size_t ix=0; ix<2; ++ix) {
         book(_c_hadrons[ix], "/TMP/sigma_hadrons_"+toString(ix+1), refData<YODA::BinnedEstimate<string>>(1+ix,1,1));
         book(_c_muons[ix],   "/TMP/sigma_muons_" +toString(ix+1), refData<YODA::BinnedEstimate<string>>(1+ix,1,1));
         for (const string& en : _c_hadrons[ix].binning().edges<0>()) {
-          double end = std::stod(en)*GeV;
-          if(isCompatibleWithSqrtS(end)) {
-            _ecms[ix] = en;
-            break;
+          double eval = stod(en)*GeV;
+          if (isCompatibleWithSqrtS(eval)) {
+            _sqs[ix] = en; break;
           }
         }
       }
-      if(_ecms[0].empty() && _ecms[1].empty())
-        MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs[0].empty() && _sqs[1].empty());
     }
 
 
@@ -45,27 +43,28 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22]) {
-	for(unsigned int ix=0;ix<2;++ix) _c_muons[ix]->fill(_ecms[ix]);
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
+        // mu+mu- + photons
+        _c_muons[0]->fill(_sqs[0]);
+        _c_muons[1]->fill(_sqs[1]);
       }
-      // everything else
       else {
-	for(unsigned int ix=0;ix<2;++ix) _c_hadrons[ix]->fill(_ecms[ix]);
+        // everything else
+        _c_hadrons[0]->fill(_sqs[0]);
+        _c_hadrons[1]->fill(_sqs[1]);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=-0;ix<2;++ix) {
+      for (size_t ix=-0; ix<2; ++ix) {
         BinnedEstimatePtr<string> mult;
         book(mult, 1+ix, 1, 1);
-        divide(_c_hadrons[ix],_c_muons[ix],mult);
+        divide(_c_hadrons[ix], _c_muons[ix], mult);
       }
     }
 
@@ -75,14 +74,10 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons[2], _c_muons[2];
-    string _ecms[2];
+    string _sqs[2];
     /// @}
 
-
   };
 
-
   RIVET_DECLARE_PLUGIN(CRYSTAL_BALL_1990_I294419);
-
-
 }
