@@ -21,7 +21,7 @@ namespace Rivet {
       // Initialise and register projections
       declare(UnstableParticles(Cuts::abspid==413), "UFS");
       //Histograms
-      for(unsigned int ix=0;ix<2;++ix) book(_h[ix],1,1,1+ix);
+      for (unsigned int ix=0;ix<2;++ix) book(_h[ix],1,1,1+ix);
       book(_r,2,1,1);
     }
 
@@ -30,18 +30,19 @@ namespace Rivet {
     void analyze(const Event& event) {
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       for (const Particle& p : ufs.particles()) {
-	const double xp = p.p3().mod()/sqrt(0.25*sqr(sqrtS())-p.mass2());
-	if(xp>0.3) _r->fill(sqrtS());
-	_h[0]->fill(xp);
-	if(!p.fromBottom()) _h[1]->fill(xp);
+        const double xp = p.p3().mod()/sqrt(0.25*sqr(sqrtS())-p.mass2());
+        if(xp>0.3) _r->fill(29);
+        _h[0]->fill(xp);
+        if(!p.fromBottom()) _h[1]->fill(xp);
       }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      for(unsigned int ix=0;ix<2;++ix)
-	scale(_h[ix], sqr(sqrtS())*crossSection()/microbarn/sumOfWeights());
+      for (unsigned int ix=0;ix<2;++ix) {
+        scale(_h[ix], sqr(sqrtS())*crossSection()/microbarn/sumOfWeights());
+      }
       scale(_r,crossSection()/nanobarn/sumOfWeights());
     }
 
@@ -50,7 +51,8 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h[2], _r;
+    Histo1DPtr _h[2];
+    BinnedHistoPtr<int> _r;
     /// @}
 
 
