@@ -25,23 +25,21 @@ namespace Rivet {
       book(_c_muons,   "/TMP/sigma_muons"  , refData<YODA::BinnedEstimate<string>>(2,1,1));
       book(_c_DD, 3, 1, 1);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
-    void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
-      for (const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  nRes[child.pid()]-=1;
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+    void findChildren(const Particle& p, map<long,int>& nRes, int &ncount) const {
+      for (const Particle& child : p.children()) {
+        if (child.children().empty()) {
+          nRes[child.pid()] -= 1;
+          --ncount;
+        }
+        else  findChildren(child, nRes, ncount);
       }
     }
 
@@ -52,69 +50,63 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	_c_muons->fill(_ecms);
-      // everything else
-      else
-	_c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 && nCount[13]==1 && ntotal==2+nCount[22]) {
+        // mu+mu- + photons
+        _c_muons->fill(_sqs);
+      }
+      else  _c_hadrons->fill(_sqs); // everything else
       // identified final state with D mesons
       const FinalState& ufs = apply<UnstableParticles>(event, "UFS");
-      for(unsigned int ix=0;ix<ufs.particles().size();++ix) {
-	bool matched = false;
+      for (unsigned int ix=0; ix<ufs.particles().size(); ++ix) {
+        bool matched = false;
        	const Particle& p1 = ufs.particles()[ix];
        	int id1 = abs(p1.pid());
-       	if(id1 != 411 && id1 != 421) continue;
+       	if (id1 != 411 && id1 != 421) continue;
       	// check fs
       	bool fs = true;
       	for (const Particle & child : p1.children()) {
-      	  if(child.pid()==p1.pid()) {
-      	    fs = false;
-      	    break;
+      	  if (child.pid()==p1.pid()) {
+      	    fs = false; break;
       	  }
       	}
-      	if(!fs) continue;
+      	if (!fs) continue;
       	// find the children
       	map<long,int> nRes = nCount;
       	int ncount = ntotal;
       	findChildren(p1,nRes,ncount);
       	// loop over the other fs particles
-       	for(unsigned int iy=ix+1;iy<ufs.particles().size();++iy) {
+       	for (size_t iy=ix+1; iy<ufs.particles().size(); ++iy) {
        	  const Particle& p2 = ufs.particles()[iy];
        	  fs = true;
-       	  for (const Particle & child : p2.children()) {
-       	    if(child.pid()==p2.pid()) {
-       	      fs = false;
-       	      break;
+       	  for (const Particle& child : p2.children()) {
+       	    if (child.pid()==p2.pid()) {
+       	      fs = false; break;
        	    }
        	  }
-       	  if(!fs) continue;
-       	  if(p2.pid()/abs(p2.pid())==p1.pid()/abs(p1.pid())) continue;
+       	  if (!fs) continue;
+       	  if (p2.pid()/abs(p2.pid())==p1.pid()/abs(p1.pid())) continue;
        	  int id2 = abs(p2.pid());
-       	  if(id2 != 411 && id2 != 421) continue;
-      	  if(!p2.parents().empty() && p2.parents()[0].pid()==p1.pid())
-      	    continue;
+       	  if (id2 != 411 && id2 != 421) continue;
+      	  if (!p2.parents().empty() && p2.parents()[0].pid()==p1.pid()) continue;
       	  map<long,int> nRes2 = nRes;
       	  int ncount2 = ncount;
       	  findChildren(p2,nRes2,ncount2);
-      	  if(ncount2!=0) continue;
-	  matched=true;
-	  for(auto const & val : nRes2) {
-	    if(val.second!=0) {
-	      matched = false;
-	      break;
-	    }
-	  }
-	  if(matched) {
-	    _c_DD  ->fill(_ecms);
-	    break;
-	  }
-	}
-	if(matched) break;
+      	  if (ncount2!=0) continue;
+          matched=true;
+          for (const auto& val : nRes2) {
+            if (val.second!=0) {
+              matched = false;
+              break;
+            }
+          }
+          if (matched) {
+            _c_DD->fill(_sqs); break;
+          }
+        }
+        if (matched) break;
       }
     }
 
@@ -124,8 +116,8 @@ namespace Rivet {
       double fact = crossSection()/ sumOfWeights() /nanobarn;
       BinnedEstimatePtr<string> mult;
       book(mult, 2, 1, 1);
-      divide(_c_hadrons,_c_muons,mult);
-      scale(_c_DD,fact);
+      divide(_c_hadrons, _c_muons, mult);
+      scale(_c_DD, fact);
     }
 
     /// @}
@@ -134,7 +126,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons, _c_DD;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
