@@ -14,7 +14,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    ///@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -26,29 +26,28 @@ namespace Rivet {
     }
 
 
-    void findDecayProducts(const Particle & mother,
-			   unsigned int & nstable,
-			   Particles& pip, Particles& pim,
-			   Particles & onium) {
-      for(const Particle & p : mother.children()) {
+    void findDecayProducts(const Particle & mother, unsigned int & nstable,
+                           Particles& pip, Particles& pim, Particles & onium) {
+      for (const Particle& p : mother.children()) {
         int id = p.pid();
-      	if ( id == PID::PIMINUS) {
-	  pim.push_back(p);
-	  ++nstable;
-	}
+      	if (id == PID::PIMINUS) {
+          pim.push_back(p);
+          ++nstable;
+        }
        	else if (id == PID::PIPLUS) {
        	  pip.push_back(p);
        	  ++nstable;
        	}
-	else if (id==443) {
-	  onium.push_back(p);
-	  ++nstable;
-	}
-	else if ( !p.children().empty() ) {
-	  findDecayProducts(p,nstable,pip,pim,onium);
-	}
-	else
-	  ++nstable;
+        else if (id==443) {
+          onium.push_back(p);
+          ++nstable;
+        }
+        else if ( !p.children().empty() ) {
+          findDecayProducts(p,nstable,pip,pim,onium);
+        }
+        else {
+          ++nstable;
+        }
       }
     }
 
@@ -60,8 +59,8 @@ namespace Rivet {
       	Particles pip, pim, onium;
       	findDecayProducts(ups,nstable,pip,pim,onium);
       	// check for onium
-      	if(onium.size() !=1 || nstable !=3 || pip.size()!=1 || pim.size() !=1 ) continue;
-	double mpipi = (pip[0].momentum()+pim[0].momentum()).mass();
+      	if (onium.size() !=1 || nstable !=3 || pip.size()!=1 || pim.size() !=1) continue;
+      	double mpipi = (pip[0].momentum()+pim[0].momentum()).mass();
       	_h[0]->fill(sqr(mpipi));
 	double mpi = 2.*pip[0].mass();
 	double x = (mpipi-mpi)/(ups.mass()-onium[0].mass()-mpi);
@@ -76,13 +75,13 @@ namespace Rivet {
 	normalize(_h[ix],1.,false);
     }
 
-    ///@}
+    /// @}
 
 
     /// @name Histograms
-    ///@{
+    /// @{
     Histo1DPtr _h[2];
-    ///@}
+    /// @}
 
 
   };
