@@ -22,8 +22,8 @@ namespace Rivet {
       // Initialise and register projections
       declare(UnstableParticles(), "UFS");
       //Histograms
-      book(_h_K0,2,1,1);
-      book(_h_Kp,4,1,1);
+      book(_h["K0"], 2, 1, 1);
+      book(_h["Kp"], 4, 1, 1);
     }
 
 
@@ -31,20 +31,18 @@ namespace Rivet {
     void analyze(const Event& event) {
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       for (const Particle& p : ufs.particles(Cuts::abspid==321 or Cuts::abspid==310 or Cuts::abspid==130)) {
-	const double xp = 2.*p.p3().mod()/sqrtS();
-	const double beta = p.p3().mod() / p.E();
-	if(p.abspid()==321)
-	  _h_Kp->fill(xp,1./beta);
-	else
-	  _h_K0->fill(xp,1./beta);
+        const double xp = p.p3().mod();
+        const double beta = p.p3().mod() / p.E();
+        if (p.abspid()==321)  _h["Kp"]->fill(xp,1./beta);
+        else                  _h["K0"]->fill(xp,1./beta);
       }
     }
-    
+
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_h_K0, 1./sumOfWeights());
-      scale(_h_Kp, 1./sumOfWeights());
+      // cross section differential in xp, now plotting p so need to convert
+      scale(_h, 1./sumOfWeights()*sqrtS()/2);
     }
 
     ///@}
@@ -52,7 +50,7 @@ namespace Rivet {
 
     /// @name Histograms
     ///@{
-    Histo1DPtr _h_K0,_h_Kp;
+    map<string,Histo1DPtr> _h;
     ///@}
 
 
