@@ -26,21 +26,20 @@ namespace Rivet {
       book(_nEvent  , 1, 1, 1);
       book(_nHadrons, 2, 1, 1);
       for (const string& en : _nEvent.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const ChargedFinalState& fs = apply<ChargedFinalState>(event, "FS");
-      _nEvent->fill(_ecms);
-      _nHadrons->fill(_ecms,fs.particles().size());
+      _nEvent->fill(_sqs);
+      _nHadrons->fill(_sqs, fs.particles().size());
     }
 
     /// Normalise histograms etc., after the run
@@ -55,7 +54,7 @@ namespace Rivet {
     /// @{
     BinnedHistoPtr<string> _nEvent;
     BinnedProfilePtr<string> _nHadrons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
