@@ -25,20 +25,18 @@ namespace Rivet {
       // Book histograms
       book(_nHadrons, 6, 1, 1);
       for (const string& en : _nHadrons.binning().edges<0>()) {
-        const double end = std::stod(en)*GeV;
-        if (isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
     /// Perform the per-event analysis
     void analyze(const Event& event) {
-      const ChargedFinalState& fs = apply<ChargedFinalState>(event, "FS");
-      _nHadrons->fill(_ecms,fs.particles().size());
+      _nHadrons->fill(_sqs, apply<ChargedFinalState>(event, "FS").particles().size());
     }
 
 
@@ -50,7 +48,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedProfilePtr<string> _nHadrons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
