@@ -20,24 +20,17 @@ namespace Rivet {
     void init() {
       // Initialise and register projections
       declare(FinalState(), "FS");
+
+      if (!inRange(sqrtS()/GeV, 2.0, 2.8)) raiseBeamErrorIf(true);
+
       // book histos
-      if (inRange(sqrtS()/GeV,2.,2.8)) {
-        if (inRange(sqrtS()/GeV,2.1,2.4)) {
-          book(_h_cTheta,3,1,1);
-        }
-        else if(sqrtS()<=2.8) {
-          book(_h_cTheta,3,1,2);
-        }
-        book(_cProton, 1, 1, 1);
-      }
-      else {
-        throw Error("Invalid CMS energy for TPC_1987_I246557");
-      }
+      book(_h_cTheta1, 3, 1, 1);
+      book(_h_cTheta2, 3, 1, 2);
+      book(_cProton, 1, 1, 1);
 
       // Determine which sqrtS bin needs to be filled
-      _edge = "OTHER"s;
       for (const string& edge : _cProton.binning().edges<0>()) {
-        if (isCompatibleWithSqrtS(std::stod(edge)*GeV)) {
+        if (isCompatibleWithSqrtS(stod(edge)*GeV)) {
           _edge = edge;
           break;
         }
@@ -61,14 +54,17 @@ namespace Rivet {
       }
       if (!foundP || !foundM) vetoEvent;
       if (cTheta<=0.6)    _cProton->fill(_edge);
-      if (_h_cTheta) _h_cTheta->fill(cTheta);
+      if (sqrtS() <= 2.8) {
+        (inRange(sqrtS()/GeV, 2.1, 2.4)? _h_cTheta1 : _h_cTheta2)->fill(cTheta);
+      }
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
       const double fact = crossSection()/nanobarn/sumOfWeights();
-      if (_h_cTheta) scale(_h_cTheta,fact);
+      scale(_h_cTheta1, fact);
+      scale(_h_cTheta2, fact);
       scale(_cProton, fact);
     }
 
@@ -77,9 +73,9 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _h_cTheta;
+    Histo1DPtr _h_cTheta1, _h_cTheta2;
     BinnedHistoPtr<string> _cProton;
-    string _edge;
+    string _edge = "OTHER"s;
     /// @}
 
 
