@@ -25,20 +25,16 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      unsigned int iloc(0);
-      if(isCompatibleWithSqrtS(53.3*GeV)) {
-	iloc=1;
+      for (double eVal : allowedEnergies()) {
+        const string en = toString(round(eVal/MeV));
+        if (isCompatibleWithSqrtS(eVal)) _sqs = en;
+        bool offset(en == "59500"s);
+        book(_h[en+"eec"],   1+offset, 1, 1);
+        book(_h[en+"eecpi"], 1+offset, 1, 2);
+        book(_h[en+"aeec"],  1+offset, 1, 3);
+        book(_c[en], "TMP/weightSum_"+en);
       }
-      else if (isCompatibleWithSqrtS(59.5*GeV)) {
-	iloc=2;
-      }
-      else
-	MSG_ERROR("Beam energy not supported!");
-      book(_histEEC   , iloc, 1, 1);
-      book(_histEEC_Pi, iloc, 1, 2);
-      book(_histAEEC  , iloc, 1, 3);
-      book(_weightSum,"TMP/weightSum");
-
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -47,37 +43,29 @@ namespace Rivet {
       // First, veto on leptonic events by requiring at least 4 charged FS particles
       const FinalState& fs = apply<FinalState>(event, "FS");
       // Even if we only generate hadronic events, we still need a cut on numCharged >= 2.
-      if ( fs.particles().size() < 2) {
-        MSG_DEBUG("Failed leptonic event cut");
-        vetoEvent;
-      }
-      MSG_DEBUG("Passed leptonic event cut");
-      _weightSum->fill();
+      if ( fs.particles().size() < 2)  vetoEvent;
+      _c[_sqs]->fill();
 
-      double Evis = 0.0;
-      for (const Particle& p : fs.particles()) {
-        Evis += p.E();
-      }
-      double Evis2 = sqr(Evis);
+      const double Evis2 = sqr(sum(fs.particles(), Kin::E, 0.0));
       // (A)EEC
       // Need iterators since second loop starts at current outer loop iterator, i.e. no "foreach" here!
       for (Particles::const_iterator p_i = fs.particles().begin(); p_i != fs.particles().end(); ++p_i) {
         for (Particles::const_iterator p_j = p_i; p_j != fs.particles().end(); ++p_j) {
-          const Vector3 mom3_i = p_i->momentum().p3();
-          const Vector3 mom3_j = p_j->momentum().p3();
-          const double energy_i = p_i->momentum().E();
-          const double energy_j = p_j->momentum().E();
+          const Vector3 mom3_i = p_i->mom().p3();
+          const Vector3 mom3_j = p_j->mom().p3();
+          const double energy_i = p_i->mom().E();
+          const double energy_j = p_j->mom().E();
           const double thetaij = mom3_i.unit().angle(mom3_j.unit())/M_PI*180.;
           double eec = (energy_i*energy_j) / Evis2;
-	  if(p_i != p_j) eec *= 2.;
+          if (p_i != p_j) eec *= 2.;
           if (thetaij < 90.) {
-	    _histEEC ->fill(thetaij,  eec);
-            _histAEEC->fill(thetaij, -eec);
-	  }
+            _h[_sqs+"eec"]->fill(thetaij, eec);
+            _h[_sqs+"aeec"]->fill(thetaij, -eec);
+          }
           else {
-	    _histEEC_Pi->fill(180.-thetaij, eec);
-            _histAEEC  ->fill(180.-thetaij, eec);
-	  }
+            _h[_sqs+"eecpi"]->fill(180.-thetaij, eec);
+            _h[_sqs+"aeec"]->fill(180.-thetaij, eec);
+          }
         }
       }
     }
@@ -85,9 +73,14 @@ namespace Rivet {
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      scale(_histEEC   , 180.0/M_PI/ *_weightSum);
-      scale(_histEEC_Pi, 180.0/M_PI/ *_weightSum);
-      scale(_histAEEC  , 180.0/M_PI/ *_weightSum);
+      scale(_c, crossSectionPerEvent());
+      scale(_h, crossSectionPerEvent());
+      for (const auto& item : _c) {
+        if (isZero(item.second->sumW())) continue;
+        scale(_h[item.first+"eec"],   180.0/M_PI/item.second->sumW());
+        scale(_h[item.first+"eecpi"], 180.0/M_PI/item.second->sumW());
+        scale(_h[item.first+"aeec"],   180.0/M_PI/item.second->sumW());
+      }
     }
 
     /// @}
@@ -95,15 +88,13 @@ namespace Rivet {
 
     /// @name Histograms
     /// @{
-    Histo1DPtr _histEEC, _histEEC_Pi, _histAEEC;
-    CounterPtr _weightSum;
+    map<string,Histo1DPtr> _h;
+    map<string,CounterPtr> _c;
+    string _sqs = "";
     /// @}
 
-
   };
 
 
   RIVET_DECLARE_PLUGIN(TOPAZ_1989_I279575);
-
-
 }
