@@ -25,13 +25,12 @@ namespace Rivet {
       book(_c_hadrons, 2, 1, 1);
       book(_c_muons,   4, 1, 1);
       for (const string& en : _c_hadrons.binning().edges<0>()) {
-        double end = std::stod(en)*GeV;
-        if(isCompatibleWithSqrtS(end)) {
-          _ecms = en;
-          break;
+        const double eval = stod(en)*GeV;
+        if (isCompatibleWithSqrtS(eval)) {
+          _sqs = en; break;
         }
       }
-      if(_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
+      raiseBeamErrorIf(_sqs.empty());
     }
 
 
@@ -42,22 +41,20 @@ namespace Rivet {
       map<long,int> nCount;
       int ntotal(0);
       for (const Particle& p : fs.particles()) {
-	nCount[p.pid()] += 1;
-	++ntotal;
+        nCount[p.pid()] += 1;
+        ++ntotal;
       }
-      // mu+mu- + photons
-      if(nCount[-13]==1 and nCount[13]==1 &&
-	 ntotal==2+nCount[22])
-	_c_muons->fill(_ecms);
-      // everything else
-      else
-	_c_hadrons->fill(_ecms);
+      if (nCount[-13]==1 and nCount[13]==1 && ntotal==2+nCount[22]) {
+        // mu+mu- + photons
+        _c_muons->fill(_sqs);
+      }
+      else _c_hadrons->fill(_sqs); // everything else
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/ sumOfWeights() /picobarn;
+      const double fact = crossSection()/ sumOfWeights() /picobarn;
       scale(_c_hadrons, fact);
       scale(_c_muons,   fact);
     }
@@ -68,7 +65,7 @@ namespace Rivet {
     /// @name Histograms
     /// @{
     BinnedHistoPtr<string> _c_hadrons, _c_muons;
-    string _ecms;
+    string _sqs = "";
     /// @}
 
 
@@ -76,6 +73,4 @@ namespace Rivet {
 
 
   RIVET_DECLARE_PLUGIN(TOPAZ_1993_I353845);
-
-
 }
