@@ -45,3 +45,5 @@ from . import TASSO_1990_I294755 # remove sum bin
 from . import TPC_1985_I205868 # pseudo-2D object should really be 1D
 from . import ZEUS_1995_I392386 # pseudo-2D object should really be 1D
 from . import ZEUS_2005_I676091 # undo Born-level correction
+from . import ZEUS_2021_I1869927 # discrete axes should be continuous
+from . import ZEUS_2023_I2694205 # split the long 1D AO into slices
