@@ -314,7 +314,7 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
                 isNominal = (nominalVariationKey == histogramkey)
                 # Maybe add this mc_errs option to the plotoptions dict and only
                 # pass the plotoptions dict to the function?
-                outputdict['histograms'][filename+label]['ErrorBars'] = mc_errs
+                outputdict['histograms'][filename+label].setdefault('ErrorBars', mc_errs)
 
                 thisObj = yoda.plotting.utils.mkPlotFriendlyScatter(histogram,includeOverflows=keepOverflows)
 
@@ -410,8 +410,8 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
                 # iterate over bins
                 for ibin, y in enumerate(nominalScatter.vals(nominalScatter.dim()-1)):
                     totErrDn, totErrUp = BandScatter.point(ibin).errs(BandScatter.dim()-1)
-                    totErrDn = totErrDn*totErrDn
-                    totErrUp = totErrUp*totErrUp
+                    totErrDn = totErrDn*totErrDn if mc_errs else 0.0
+                    totErrUp = totErrUp*totErrUp if mc_errs else 0.0
 
                     # add PDF uncertainty in quadrature
                     for errs in PDFerrors:
