@@ -22,11 +22,9 @@ namespace Rivet {
 
 
   double Analysis::sqrtS() const {
-    double sqrts = handler().runSqrtS();
-    if (sqrts <= 0 || isnan(sqrts)) {
-      MSG_DEBUG("Suspicious beam energy. You're probably running rivet-merge. Fetching beam energy from option.");
-      sqrts = getOption<double>("ENERGY", 0);
-    }
+    double sqrts = getOption<double>("ENERGY", 0.0);
+    if (isZero(sqrts) || isnan(sqrts))  return handler().runSqrtS();
+    MSG_DEBUG("Using beam energy from 'ENERGY' option: " << sqrts);
     return sqrts;
   }
 
@@ -39,10 +37,7 @@ namespace Rivet {
   }
 
   vector<double> Analysis::allowedEnergies() const {
-    // Check if the ENERGY option was provided
-    double enOpt = getOption("ENERGY", 0.0);
-    if (enOpt)  return { enOpt };
-    // If not, return list of allowed energies from info file
+    // Return list of allowed energies from info file
     vector<double> energies;
     for (const auto& beams : info().energies()) {
       energies.push_back( ::Rivet::sqrtS(beams) );
@@ -194,6 +189,13 @@ namespace Rivet {
   }
 
 
+  void Analysis::raiseBeamErrorIf(const bool condition) const {
+    if (condition && !merging()) {
+     throw BeamError("Invalid beam energy for " + name() + "\n");
+    }
+  }
+
+
   // bool Analysis::isCompatible(const ParticlePair& beams) const {
   //   return isCompatible(beams.first.pid(),  beams.second.pid(),
   //                       beams.first.energy(), beams.second.energy());
