@@ -38,6 +38,7 @@ namespace Rivet {
   AnalysisHandler::AnalysisHandler()
     : _ntrials(0.0),
       _isEndOfFile(false),
+      _subeventWarning(true),
       _userxs{NAN, NAN},
       _initialised(false),
       _checkBeams(true),
@@ -46,7 +47,7 @@ namespace Rivet {
       _unmatchWeightNames(""),
       _nominalWeightName(""),
       _weightCap(0.),
-      _NLOSmearing(0.),
+      _NLOSmearing(-1.0),
       _defaultWeightIdx(0),
       _rivetDefaultWeightIdx(0),
       _customDefaultWeightIdx(-1),
@@ -62,7 +63,9 @@ namespace Rivet {
     if (!printed && getLog().getLevel() <= 20) {
       cout << endl
            << "The MCnet usage guidelines apply to Rivet: see http://www.montecarlonet.org/GUIDELINES" << endl
-           << "Please acknowledge Rivet in results made using it, and cite https://arxiv.org/abs/1912.05451" << endl;
+           << "Please acknowledge Rivet in results made using it, and cite https://arxiv.org/abs/2404.15984"
+           << " and https://arxiv.org/abs/2312.15070" << endl;
+      // << https://arxiv.org/abs/1912.05451" << endl;
       // << "https://arxiv.org/abs/1003.0694" << endl;
       printed = true;
     }
@@ -119,7 +122,12 @@ namespace Rivet {
     // Set the Run's beams based on this first event
     /// @todo Improve this const ugliness
     const Event evt(const_cast<GenEvent&>(ge), _weightIndices);
-    if (_checkBeams)  setRunBeams(Rivet::beams(evt));
+    try {
+      setRunBeams(Rivet::beams(evt));
+    }
+    catch (const BeamError& e) {
+      if (_checkBeams) throw e;
+    }
 
     MSG_DEBUG("Initialising the analysis handler");
     _eventNumber = ge.event_number();
@@ -227,7 +235,7 @@ namespace Rivet {
     // If there are no weights, add a nominal one
     if (_weightNames.empty()) {
       _weightNames.push_back("");
-      _customDefaultWeightIdx =_rivetDefaultWeightIdx = _defaultWeightIdx = 0;
+      _customDefaultWeightIdx = _rivetDefaultWeightIdx = _defaultWeightIdx = 0;
       _weightIndices = { 0 };
       return;
     }
@@ -278,7 +286,12 @@ namespace Rivet {
     }
 
     // Warn user if still no nominal weight could be identified
-    if (nDefaults == 0) {
+    if (nDefaults == 0 && _skipMultiWeights) {
+      nom_winner = _weightNames[_defaultWeightIdx];
+      MSG_ERROR("Could not identify nominal weight. Will retain first encountered weight: '"
+                << nom_winner << "'");
+    }
+    else if (nDefaults == 0) {
       MSG_WARNING("Could not identify nominal weight. Will continue assuming variations-only run.");
       // Put candidates in quotes in case weight name contains whitespace
       MSG_WARNING("Candidate weight names:\n    '" << join(_weightNames, "'\n    '") << "'");
@@ -295,15 +308,15 @@ namespace Rivet {
 
       // If running in single-weight mode, remove all bar the nominal weight
       _weightIndices.clear();
-      _weightNames.clear();
       if (customNomIdx >= 0 && customNomIdx != (int)_defaultWeightIdx) {
         _weightIndices.push_back(customNomIdx);
-        _weightNames.push_back(_weightNames[customNomIdx]);
+        _weightNames = { _weightNames[customNomIdx] };
         _customDefaultWeightIdx = 0;
         MSG_WARNING("Specified nominal weight different from auto-detected nominal weight. Will retain both.");
       }
+      else  _weightNames.clear();
       _weightIndices.push_back(_defaultWeightIdx);
-      _weightNames.push_back(_weightNames[_defaultWeightIdx]);
+      _weightNames.push_back(nom_winner);
       _rivetDefaultWeightIdx = _weightIndices.size() - 1;
 
     }
@@ -493,6 +506,11 @@ namespace Rivet {
         }
       }
     }
+    if (_subeventWarning && _subEventWeights.size() > 1) {
+      MSG_WARNING("Correlated subevents detected. Grouped fills will be collapsed, " \
+                  "but bin-edge migration may affect uncertainties.\n");
+      _subeventWarning = false;
+    }
     MSG_DEBUG("Analyzing subevent #" << _subEventWeights.size() - 1 << ".");
 
     // Warn if the subevent list is getting very long without flushing
@@ -1796,7 +1814,7 @@ namespace Rivet {
 
   double AnalysisHandler::runSqrtS() const {
     double rtn = sqrtS(runBeams());
-    if (rtn <= 0. && _beaminfo && _beaminfo->numBins()==2) { // try falling back to _beaminfo
+    if (fuzzyLessEquals(rtn, 0.) && _beaminfo && _beaminfo->numBins()==2) { // try falling back to _beaminfo
       rtn = sqrtS(fabs(_beaminfo->bin(1).val()), fabs(_beaminfo->bin(2).val()));
     }
     return rtn;
