@@ -9,7 +9,7 @@ namespace Rivet {
 
   void Particle::setConstituents(const Particles& cs, bool setmom) {
     _constituents = cs;
-    if (setmom) _momentum = sum(cs, p4, FourMomentum());
+    if (setmom) _momentum = sum(cs, Kin::p4, FourMomentum());
   }
 
 
@@ -62,23 +62,43 @@ namespace Rivet {
   }
 
 
+  bool Particle::isPhysical(bool include_beams) const {
+    if (genParticle() == nullptr) return false;
+    const int status = genParticle()->status();
+    if (status == 1 || status == 2) return true;
+    if (include_beams && status == 4) return true;
+    return false;
+  }
+
+
+  bool Particle::hasPhysicalAncestor(const Cut& c) const {
+    if (genParticle() == nullptr) return false;
+    ConstGenVertexPtr gv = genParticle()->production_vertex();
+    if (gv == nullptr) return false;
+
+    vector<ConstGenParticlePtr> ancestors = HepMCUtils::particles(genParticle(), Relatives::ANCESTORS);
+    for (const auto& a: ancestors) {
+      // A status=1 ancestor should be impossible!
+      if (a->status() != 1 && a->status() != 2) continue;
+      if (c != Cuts::OPEN && !c->accept(Particle(a))) return true;
+    }
+    return false;
+  }
+
+
   Particles Particle::ancestors(const Cut& c, bool physical_only) const {
     Particles rtn;
 
-    // this case needed protecting against (at least for the latest Herwig... not sure why
-    // it didn't show up earlier
     if (genParticle() == nullptr) return rtn;
-
     ConstGenVertexPtr gv = genParticle()->production_vertex();
-
     if (gv == nullptr) return rtn;
 
     vector<ConstGenParticlePtr> ancestors = HepMCUtils::particles(genParticle(), Relatives::ANCESTORS);
-
-    for(const auto &a: ancestors){
-      if(physical_only && a->status() != 1 && a->status() != 2) continue;
+    for (const auto& a: ancestors) {
+      // A status=1 ancestor should be impossible!
+      if (physical_only && a->status() != 1 && a->status() != 2) continue;
       const Particle p(a);
-      if(c != Cuts::OPEN && !c->accept(p)) continue;
+      if (c != Cuts::OPEN && !c->accept(p)) continue;
       rtn += p;
     }
     return rtn;
