@@ -6,8 +6,8 @@ using namespace std;
 namespace Rivet {
 
 
-  Log::LogMap Log::existingLogs;
-  Log::LevelMap Log::defaultLevels;
+  thread_local Log::LogMap Log::existingLogs;
+  thread_local Log::LevelMap Log::defaultLevels;
   bool Log::showTimestamp = false;
   bool Log::showLogLevel = true;
   bool Log::showLoggerName = true;
@@ -78,7 +78,7 @@ namespace Rivet {
         }
       }
       // for (LevelMap::const_iterator l = defaultLevels.begin(); l != defaultLevels.end(); ++l) {
-      // 
+      //
       // }
 
       // emplace returns pair<iterator,bool>
@@ -115,7 +115,6 @@ namespace Rivet {
     const static bool IS_TTY = isatty(1);
     if (!IS_TTY) return "";
 
-    // If stdout is a valid tty, try to use the appropriate codes.
     static const ColorCodes TTY_CODES = {
       {TRACE, "\033[0;36m"},
       {DEBUG, "\033[0;34m"},
@@ -170,7 +169,7 @@ namespace Rivet {
     out += getColorCode(END_COLOR);
     out += " ";
     out += message;
- 
+
     return out;
   }
 
@@ -192,7 +191,7 @@ namespace Rivet {
       		return cerr;
       	} else {
       		cout << log.formatMessage(level, "");
-      		return cout;      		
+      		return cout;
       	}
     } else {
       static ostream devNull(nullptr);
