@@ -5,4 +5,4 @@
 RIVET_BUILD_BEFORE_INSTALL=1 bash ../bin/rivet-build ../analyses/examples/EXAMPLE.cc ../analyses/pluginMC/MC_JETS.cc ../analyses/examples/EXAMPLE_CUTS.cc ../analyses/examples/EXAMPLE_SMEAR.cc -I../include
 export RIVET_ANALYSIS_PATH=$RIVET_ANALYSIS_PATH:$PWD
 
-exec ./testAPI "$srcdir/testApi.hepmc"
+exec ./testAPI
